/*+
 * Project     : SOHO - CDS
 * 
 * Name        : check_sum
 * 
 * Purpose     : CALL_EXTERNAL software to check science telemetry sums.
 * 
 * Explanation : This routine supports the IDL procedure CHECK_SUM.PRO, to
 *		 calculate the check sum of a CDS science telemetry packet.
 * 
 * Use         : Called using CALL_EXTERNAL by the IDL procedure CHECK_SUM.  In
 *		 VMS, this routine is called directly.  In Unix, the
 *		 intermediate routine check_sum_c is called instead.
 *
 *		 TEST1 = CALL_EXTERNAL(FILENAME, 'check_sum', IN, I1, I2, $
 *		 	OUT, VALUE=[0b,1b,1b,0b])
 * 
 * Inputs      : in	   = The packet to be checked.
 *		 i1	   = The index of the first word to be used in
 *			     calculating the checksum.
 *		 i2	   = The index of the last word to be used in
 *			     calculating the checksum.
 * 
 * Outputs     : out	   = The checksum value.
 * 
 * Calls       : None.
 * 
 * Restrictions: None.
 * 
 * Side effects: None.
 * 
 * Category    : Telemetry
 * 
 * Prev. Hist. : None.
 * 
 * Written     : William Thompson, GSFC, 27 June 1995
 * 
 * Modified    : Version 1, William Thompson, GSFC, 27 June 1995
 * 
 * Version     : Version 1, 27 June 1995
-*/

#include <stdio.h>
#include <stdlib.h>

/*****************************************************************************/
/*   ***   ***   ***   ***   ***   ***   ***   ***   ***   ***   ***   ***   */
/*****************************************************************************/
void check_sum(in,i1,i2,out)
     short in[];	/* The input array */
     short i1;		/* The first word */
     short i2;		/* The last word */
     short *out;	/* The output value */
{
  short i;		/* Loop index */
  short temp;

/* Calculate the checksum, ignoring the header and the checksum at the end of
   the packet. */

  temp = in[i1];
  for (i=i1+1; i<=i2; ++i)
    {
      temp = temp ^ in[i];
    }
  *out = temp;
}
