/*+
 * Project     : SOHO - CDS
 * 
 * Name        : check_sum
 * 
 * Purpose     : Unix interface between IDL and check_sum C routine.
 * 
 * Explanation : This routine provides the interface between CALL_EXTERNAL in
 *		 IDL and the check_sum routine written in C.  In VMS this
 *		 routine is not needed, and the check_sum routine can be
 *		 called directly.
 * 
 * Use         : Called using CALL_EXTERNAL by the IDL procedure CHECK_SUM.
 *
 *		 TEST1 = CALL_EXTERNAL(FILENAME, 'check_sum_c', IN, I1, I2, $
 *		 	OUT, VALUE=[0b,1b,1b,0b])
 * 
 * Inputs      : in	   = The packet to be checked.
 *		 i1	   = The index of the first word to be used in
 *			     calculating the checksum.
 *		 i2	   = The index of the last word to be used in
 *			     calculating the checksum.
 * 
 * Outputs     : out	   = The checksum value.
 * 
 * Calls       : check_sum
 * 
 * Restrictions: None.
 * 
 * Side effects: None.
 * 
 * Category    : Telemetry
 * 
 * Prev. Hist. : None.
 * 
 * Written     : William Thompson, GSFC, 27 June 1995
 * 
 * Modified    : Version 1, William Thompson, GSFC, 27 June 1995
 * 
 * Version     : Version 1, 27 June 1995
-*/

#include <stdio.h>

/*****************************************************************************/
/** ****    ****    ****    ****    ****    ****    ****    ****    ****    **/
/*****************************************************************************/
void check_sum_c(argc, argv)
     int argc;			/* The number of arguments */
     void *argv[];		/* The arguments */
{
  short *in, i1, i2, *out;

  /*  Convert the IDL input parameters into C parameters.  */

  in        = (short *)   argv[0];
  i1	    = *(short *)  argv[1];
  i2	    = *(short *)  argv[2];
  out       = (short *)   argv[3];

  /*  Call the C routine check_sum.  */

  check_sum(in,i1,i2,out);
  return;
}
