	PRO SNAP_MOVIE, STUDY, FILENAME, MPEG=MPEG, GIF=GIF, PICT=PICT,	$
		DELETE=DELETE, FRAMEDELAY=FRAMEDELAY, LOOPCNT=LOOPCNT,	$
		JAVASCRIPT=JAVASCRIPT, INCREMENT=INCREMENT, URL=URL,	$
		TITLE=TITLE, REVERSE=REVERSE, NOCLEAN=NOCLEAN,		$
		WINDOWS=WINDOWS, WAVESORT=WAVESORT, SPECTRA=SPECTRA,	$
		WO_CR=WO_CR, FRACTION=FRACTION, QUASI_FIT=QFIT,		$
		CHARSIZE=CHARSIZE, CHARTHICK=CHARTHICK, ROTATE=DIRECTION, $
		NOTITLE=NOTITLE, NOLABEL=NOLABEL, LARGE_TITLE=LARGE_TITLE, $
		JPEG=JPEG, PNG=PNG, INTERNAL_MPEG=INTERNAL_MPEG,	$
		ALT_MPEG=ALT_MPEG, MIN=IMIN, MAX=IMAX, GLOBAL=GLOBAL,	$
		RASTER=RASTER
;+
; Project     :	SOHO - CDS
;
; Name        :	SNAP_MOVIE
;
; Purpose     :	Makes a movie out of CDS snapshots.
;
; Category    :	CDS, Quicklook, Animation, Class3
;
; Explanation :	Uses CDS_SNAPSHOT and WR_MOVIE to generate an animation from a
;		study.  Each frame of the animation is made by running
;		CDS_SNAPSHOT against each raster in the study.  Thus, the first
;		frame will be from s#r00.fits, the second from s#r01.fits, and
;		so on.  This is appropriate when the study consists of a number
;		of repeated rasters with a single target.  The techniques used
;		here can serve as an example of how to put an animation
;		together in more complicated cases.
;
;		Each frame is first generated on the screen by CDS_SNAPSHOT,
;		and then read back from the screen and written to the
;		animation.  Whatever color table is loaded when the program is
;		called will be used for the animation.  The graphics window
;		should remain in view until the animation is completed.
;
; Syntax      :	SNAP_MOVIE, STUDY  [, FILENAME ]  [, /keywords ]
;
; Examples    :	SNAP_MOVIE, 10345, /GIF, /MPEG, /JAVA, /DEL
;
; Inputs      :	STUDY	= The study number to generate the movie from.
;
; Opt. Inputs :	FILENAME = Base filename to use when creating MPEG and GIF
;			   movies.  If a GIF movie is created, then it will be
;			   named filename.gif.  If a MPEG movie is created,
;			   then it will be called filename.mpg.  The default is
;			   to generate the filename from the letter "s" and the
;			   study number, e.g. "s10345.gif".
;
; Outputs     :	The output of the program is one or more animation formats,
;		depending on which keywords were passed.
;
; Opt. Outputs:	None.
;
; Keywords    :	The following keywords are passed to CDS_SNAPSHOT.
;
;		REVERSE = If set, then plot is done in inverse video.  In other
;			  words, white areas on the screen will appear dark,
;			  and visa versa.  This saves toner on greyscale
;			  printers.
;
;		NOCLEAN = If set, then CDS_CLEAN_IMAGE is not called.
;
;		WINDOWS = An array of windows to display.  The windows can be
;			  passed as either the NUMBERS of the data windows
;			  (NOTE: numbering from 0...N-1) or as text with the
;			  LABELS of the desired spectral windows.  The windows
;			  will be displayed in the order given by the WINDOWS
;			  array, unless the WAVESORT keyword is passed.
;
;		WAVESORT = If set, then the windows are displayed in wavelength
;			   order.  (Note that second order lines will be
;			   displayed according to their first order
;			   equivalent.)
;
;		QUASI_FIT= If set, then the routine CDS_QUASI_FIT is called to
;			   extract the images.  See the documentation on that
;			   routine for more information.
;
;		SPECTRA	 = If set, then spectra are shown instead of images.
;			   For some data sets, spectra are shown by default.
;
;		WO_CR	 = If set, then spectra are calculated using AVG_WO_CR
;			   instead of AVERAGE.  Warning, very slow.
;
;		FRACTION = Fraction to pass to SIGRANGE function.  The default
;			   is 0.99.
;
;		CHARSIZE = Character size to use for the window labels.
;
;		CHARTHICK= Character thickness.
;
;		NOTITLE	 = If set, then the title information at the bottom of
;			   the page is suppressed.
;
;		NOLABEL	 = If set, then the labels above each data window are
;			   suppressed.
;
;		ROTATE	 = If passed, then is the value of the parameter passed
;			   to the ROTATE function to change the image
;			   orientation.  For example, using ROTATE=1 would
;			   rotate the image by +90 degrees, while ROTATE=3
;			   would rotate it by -90 degrees.
;
;		MIN,MAX	 = Arrays of the minimum and maximum values to be
;			   applied to each window.  Must be in the same order
;			   as the windows are displayed.
;
;		GLOBAL	 = If the GLOBAL keyword is set, then SNAP_MOVIE will
;			   first make a pass through the data to determine the
;			   MIN and MAX arrays to be passed to CDS_SNAPSHOT.
;
;		RASTER	 = Contains the raster ID to use in making the movie.
;			   This is useful for making movies from studies which
;			   use a series of different rasters.  If RASTER is
;			   passsed as a two-element array, then the second
;			   element contains the raster variation.
;
;		The following keywords are used to determine what kind of movie
;		is produced.  If neither are passed, then the default format is
;		a GIF movie.  If both are passed, then both a GIF and an MPEG
;		movie is created.
;
;		MPEG:		If set, then a MPEG movie is created.
;
;		GIF:		If set, then a GIF movie is created.
;
;		Additional keywords passed to WR_MOVIE are:
;
;		PNG:		When used with /JAVASCRIPT, the files written
;				out are in PNG format, rather than GIF.  This
;				is the default for IDL versions 5.4 and above,
;				which no longer support writing GIF images.
;
;		JPEG:		When used with /JAVASCRIPT, the files written
;				out are in JPEG format, rather than GIF or PNG.
;
;		ALT_MPEG:	Uses an alternate set of parameters for
;				mpeg_encode, courtesy of Stein Vidar Haugan and
;				Bernhard Fleck, which may make a better movie,
;				at the expense of a slightly larger file.
;
;		INTERNAL_MPEG:	If set, then the internal MPEG writer is used
;				instead of spawning mpeg_encode.  This is the
;				default for IDL versions 5.4 and above, which
;				no longer support writing the intermediate GIF
;				images.
;
;		PICT:		If set, then a series of PICT frames are
;				written out.  This is suitable for converting
;				to a VHS tape.  The filenames will be written
;				such that the extensions are the frame number,
;				e.g. "filename.00", "filename.01", etc.
;
;		JAVASCRIPT:	If set, then an Java Script HTML file is
;				written out.
;
;		DELETE:		If set, then the temporary directory 
;				/mpegframes will be deleted before this 
;				procedure exits.
;
;		FRAMEDELAY:	The delay time between frames, in 1/100 of a
;				second.  The default value of 10 gives a movie
;				rate of approximately 10 frames/second.  The
;				bigger the number, the slower the movie will
;				run.  Not applicable to MPEG movies.
;
;		LOOPCNT:	The number of times to loop through the GIF
;				movie.  The default value is 0, which
;				represents an infinite number of loops.
;
;               INCREMENT:	Percent increment for speed control for Java
;				Script movies.  [def= 10]
;
;               URL:		Optional URL path to GIF images for Java Script
;				movies.  The default is that the GIF frames
;				will be in the subdirectory FILENAME.
;
;               TITLE:		Optional HTML title for Java Script movies.
;
;
; Calls       :	READCDSFITS, CDS_SNAPSHOT, WR_MOVIE
;
; Common      :	
;
; Restrictions:	The graphics window used by this routine should remain in view
;		until the animation is completed.
;
;		The process that is running IDL when this procedure 
;		executes must have write priveleges to the working directory
;		or this procedure will fail.
;               
;		If a MPEG movie is being created, then the following programs
;		must be in the current path:
;
;				mpeg_encode
;				giftoppm
;
;		If a GIF movie is being created, then the following program 
;		must be in the current path:
;
;				whirlgif
;
; Side effects:	Files and subdirectory are created in the working directory.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 03-Feb-1998, William Thompson, GSFC
;		Version 2, 10-Apr-1998, William Thompson, GSFC
;			Use TVREAD, to allow reading even obscured windows.
;		Version 3, 23-Oct-2000, William Thompson
;			Added keywords INTERNAL_MPEG, JPEG, and PNG.
;		Version 4, 26-Oct-2000, William Thompson
;			Added keyword ALT_MPEG
;		Version 5, 27-Mar-2002, William Thompson, GSFC
;			Added keywords MIN, MAX, GLOBAL
;
; Contact     :	WTHOMPSON
;-
;
;
	ON_ERROR, 2
;
;  Check the input parameters.
;
	IF N_PARAMS() LT 1 THEN MESSAGE,			$
		'Syntax:  SNAP_MOVIE, STUDY, FILENAME'
	IF N_ELEMENTS(STUDY) NE 1 THEN MESSAGE,			$
		'STUDY must be a single number'
	IF DATATYPE(STUDY,2) GT 3 THEN MESSAGE,			$
		'STUDY must be an integer'
;
;  If the filename wasn't passed, then form it from the study number.
;
	IF N_ELEMENTS(FILENAME) EQ 0 THEN FILENAME = 's' + NTRIM(STUDY)
	IF N_ELEMENTS(FILENAME) GT 1 THEN MESSAGE,		$
		'FILENAME must be a single string'
	IF DATATYPE(FILENAME,1) NE 'String' THEN MESSAGE,	$
		'FILENAME must be a character string'
;
;  Find all the FITS files associated with this study.
;
	SEARCH = ''
	IF N_ELEMENTS(RASTER) GE 1 THEN SEARCH = 'RAS_ID=' + TRIM(RASTER(0))
	IF N_ELEMENTS(RAS_VAR) EQ 2 THEN SEARCH = SEARCH + ',RAS_VAR=' + $
		TRIM(RASTER(1))
	LIST_EXPER, STUDY, OBS, N_OBS, SEARCH=SEARCH
	IF N_OBS EQ 0 THEN MESSAGE,				$
		'No observations found for study number ' + NTRIM(STUDY)
;
;  If the global keyword was set, then first read through the files to extract
;  the minimum and maximum values.
;
	IF KEYWORD_SET(GLOBAL) THEN BEGIN
	    COUNTDOWN, N_OBS, /OPEN
	    FOR I=0,N_OBS-1 DO BEGIN
		COUNTDOWN, I
		A = READCDSFITS(OBS(I).FILENAME)
;
;  Extract the number of windows from either the WINDOWS array, or the data
;  structure.
;
		IF N_ELEMENTS(WINDOWS) GT 0 THEN BEGIN
		    WINS = WINDOWS
		    N_WINDOWS = N_ELEMENTS(WINS)
		END ELSE BEGIN
		    N_WINDOWS = N_ELEMENTS(A.DETDESC)
		    WINS = INDGEN(N_WINDOWS)
		ENDELSE
;
;  Filter out those windows which don't exist.
;
		IXSTOP = A.DETDESC.IXSTOP
		W_VALID = WHERE(IXSTOP(0,WINS) GE 0, COUNT)
		IF COUNT GT 0 THEN BEGIN
		    WINS  = WINS(W_VALID)
		    N_WINDOWS = N_ELEMENTS(WINS)
		END ELSE MESSAGE, 'No windows to display'
		IF I EQ 0 THEN BEGIN
		    IIMIN = FLTARR(N_WINDOWS, N_OBS)
		    IIMAX = FLTARR(N_WINDOWS, N_OBS)
		ENDIF
;
;  Step through the windows, and get the minimum and maximum values.
;
		FOR I_WINDOW = 0,N_WINDOWS-1 DO BEGIN
		    AA = GT_WINDATA(A,WINS(I_WINDOW))
		    DD = GT_WINDESC(A,WINS(I_WINDOW))
		    SZ = SIZE(AA)
		    IF NOT KEYWORD_SET(QFIT) THEN BEGIN
			IF SZ(1) EQ 2048 THEN AA = AA(64:2047-64,*,*,*)
			AA = AVERAGE(TEMPORARY(AA), 1, MISSING=DD.MISSING)
		    END ELSE AA = CDS_QUASI_FIT(AA, DD.MISSING, /QUIET)
		    IF SZ(0) EQ 4 THEN AA = AVERAGE(TEMPORARY(AA), 3,	$
			    MISSING=DD.MISSING)
		    IF (A.HEADER.DETECTOR EQ 'NIS') AND		$
			    (NOT KEYWORD_SET(NOCLEAN)) THEN	$
			    CDS_CLEAN_IMAGE, AA, /NOMISSING
		    IF N_ELEMENTS(FRACTION) EQ 0 THEN FRACTION = 0.99
		    IF (FRACTION LT 1) AND (FRACTION GT 0) THEN AA =	$
			    SIGRANGE(TEMPORARY(AA), FRACTION=FRACTION,	$
			    MISSING=DD.MISSING)
		    IF KEYWORD_SET(REVERSE) THEN BEGIN
			AA = -TEMPORARY(AA)
			DD.MISSING = -DD.MISSING
		    ENDIF
		    AA = GOOD_PIXELS(AA,MISSING=DD.MISSING)
		    IIMIN(I_WINDOW,I) = MIN(AA,MAX=AMAX)
		    IIMAX(I_WINDOW,I) = AMAX
		ENDFOR
	    ENDFOR
	    COUNTDOWN, /CLOSE
;
;  Determine the global minimum and maximum values.
;
	    IMIN = FLTARR(N_WINDOWS)
	    IMAX = FLTARR(N_WINDOWS)
	    FOR I=0,N_WINDOWS-1 DO BEGIN
		IMIN(I) = MIN(GOOD_PIXELS(IIMIN(I,*),MISSING=DD.MISSING))
		IMAX(I) = MAX(GOOD_PIXELS(IIMAX(I,*),MISSING=DD.MISSING))
	    ENDFOR
	ENDIF
;
;  Make sure that the graphics window exists.  If it doesn't, then create a new
;  window.
;
	IF !D.WINDOW GE 0 THEN WINDOW = !D.WINDOW ELSE WINDOW = 0
	DEVICE, WINDOW_STATE=WIN_STATE
	IF NOT WIN_STATE(WINDOW) THEN WINDOW
;
;  Step through the FITS files and display them in turn.
;
	FOR I=0,N_OBS-1 DO BEGIN
	    CDS_SNAPSHOT, TRIM(OBS(I).FILENAME), REVERSE=REVERSE,	$
		    NOCLEAN=NOCLEAN, WINDOWS=WINDOWS, WAVESORT=WAVESORT,$
		    SPECTRA=SPECTRA, WO_CR=WO_CR, FRACTION=FRACTION,	$
		    QUASI_FIT=QFIT, CHARSIZE=CHARSIZE, CHARTHICK=CHARTHICK, $
		    ROTATE=DIRECTION, NOTITLE=NOTITLE, NOLABEL=NOLABEL,	$
		    LARGE_TITLE=LARGE_TITLE, MIN=IMIN, MAX=IMAX
;
;  Read in the image.
;
	    B = TVREAD(/DISABLE)
;
;  Write out the movie frame.  On the last frame, generate the animations.
;
	    WR_MOVIE, FILENAME, B, I, N_OBS, /NOSCALE, MPEG=MPEG, GIF=GIF, $
		    PICT=PICT, DELETE=DELETE, FRAMEDELAY=FRAMEDELAY,	$
		    LOOPCNT=LOOPCNT, JAVASCRIPT=JAVASCRIPT,		$
		    INCREMENT=INCREMENT, URL=URL, TITLE=TITLE, JPEG=JPEG, $
		    PNG=PNG, INTERNAL_MPEG=INTERNAL_MPEG, ALT_MPEG=ALT_MPEG
	ENDFOR
;
	END
