;+
; Project     : SOHO - CDS     
;                   
; Name        : FIT_CDS_MAP
;               
; Purpose     : Produce maps of QL Gaussian fit results
;               
; Category    : Analysis
;               
; Explanation : 
;               
; Syntax      : IDL> fit_cds_map,ql,fmap
;    
; Examples    : 
;
; Inputs      : QL = QL structure to fit
;               
; Opt. Inputs : None
;               
; Outputs     : FMAP = image map with fitted widths, centroids, intensities
;
; Opt. Outputs: None
;               
; Keywords    : WINDOW = window to fit (input)
;               CALIB = set to calibrate spectra before fitting
;
; Common      : None.
;               
; Restrictions: Limited to Gaussian
;               
; Side effects: None.
;               
; History     : Version 1,  17-Jan-1998,  D M Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-            



pro fit_cds_map,ql,fmap,window=window,calib=calib,$
             err=err,_extra=extra,verbose=verbose


for i=0,n_elements(ql)-1 do begin
 err=''
 temp=ql(i)
 if keyword_set(calib) then begin
  err=''
  vds_calib,temp,err=err
 endif
 if err eq '' then begin
  if keyword_set(verbose) then message,'working on QL '+trim(string(i)),/cont
  fit_cds_ql,temp,cent=cent,inten=inten,width=width,_extra=extra,window=window
  map=mk_cds_map(temp,window)
  tmap=add_tag(map,inten,'intensity',index=0)
  tmap=add_tag(tmap,cent,'centroid',index=1)
  tmap=add_tag(tmap,width,'dwidth',index=2)
  fmap=merge_struct(fmap,tmap)
 endif
endfor
return & end

