	PRO REGEN_SYNOP
;+
; Project     :	SOHO - CDS
;
; Name        :	REGEN_SYNOP
;
; Purpose     :	Regenerates the synoptic datasets.
;
; Category    :	CDS, Class3, Synoptic
;
; Explanation :	Scans the directory CDS_CDROM_DATA to determine what time range
;		is represented, and regenerates the synoptic datasets
;		accordingly.  Called from FITSGEN_EVENT.
;
; Syntax      :	REGEN_SYNOP
;
; Examples    :	
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	FIND_FILE, CONCAT_DIR, BREAK_FILE, STR2UTC, LIST_MAIN,
;		MK_SYNOPTIC
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 21-Nov-1996, William Thompson, GSFC
;		Version 2, 02-May-1997, William Thompson, GSFC
;			Make more intelligent about what days to process.
;		Version 3, 11-May-1997, William Thompson, GSFC
;			Fix bug introduced in version 2.
;
; Contact     :	WTHOMPSON
;-
;
	ON_ERROR, 2
;
;  Get a list of all the telemetry files in the CDROM directory, and collect
;  all the dates.
;
	FILES = FIND_FILE( CONCAT_DIR('$CDS_CDROM_DATA', 'tm.*'))
	BREAK_FILE, FILES, DISK, DIR, NAME, EXT
	DATES = STRMID(EXT,1,2) + '-' + STRMID(EXT,4,3)
;
;  Sort the dates, filter out duplicates, and find all contiguous sections.
;
	DATES = DATES(SORT(DATES))
	DATES = DATES(UNIQ(DATES))
	DATES = STR2UTC(DATES)
	N_RANGES = 1
	DMIN = DATES(0)
	DMAX = DATES(0)
	I_DATE = 1
	FOR I_DATE = 1,N_ELEMENTS(DATES)-1 DO BEGIN
	    IF (DATES(I_DATE).MJD-1) NE (DATES(I_DATE-1).MJD) THEN BEGIN
		N_RANGES = N_RANGES + 1
		DMIN = [DMIN, DATES(I_DATE)]
		DMAX = [DMAX, DATES(I_DATE)]
	    END ELSE DMAX(N_RANGES-1) = DATES(I_DATE)
	ENDFOR
	DMAX.MJD = DMAX.MJD + 1
;
;  Step through all the ranges, and list all studies in the requested time
;  range.
;
	FOR I_RANGE = 0,N_RANGES-1 DO BEGIN
	    LIST_MAIN, DMIN(I_RANGE), DMAX(I_RANGE), OBS, N_FOUND
;
;  Extract all the runs of the SUNOP program.  Sort by date.
;
	    IF N_FOUND GT 0 THEN BEGIN
		W = WHERE(STRMID(OBS.OBS_PROG,0,5) EQ 'SYNOP', COUNT)
		IF COUNT GT 0 THEN BEGIN
		    OBS = OBS(W)
		    IF COUNT GT 1 THEN BEGIN
			S = SORT(OBS.OBT_TIME)
			OBS = OBS(S)
		    ENDIF
;
;  Step through each program number, and recreate the synoptic files.
;
		    FOR I = 0,COUNT-1 DO BEGIN
			PROG_NUM = OBS(I).PROG_NUM
			PRINT, 'Making synoptic data from study ' +	$
				TRIM(PROG_NUM)
			MK_SYNOPTIC, PROG_NUM
		    ENDFOR
		ENDIF
	    ENDIF
	ENDFOR
;
	RETURN
	END
