PRO CHECK_INTEG, OUTPUT=OUTPUT, NOFITS=NOFITS
;+
; Project     :	SOHO - CDS
;
; Name        :	CHECK_INTEG
;
; Purpose     :	Checks the integrity of the CDS catalog databases
;
; Category    :	Class4, Operations, Catalog
;
; Explanation :	Makes various checks on the integrity of the CDS catalog
;		databases.
;
; Syntax      :	CHECK_INTEG  [, OUTPUT=OUTPUT ]
;
; Examples    :	
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	OUTPUT	= Name of an output file to contain the result.  If not
;			  passed, then the output is written to the screen.
;
; Calls       :	
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 02-Apr-1996, William Thompson, GSFC
;		Version 2, 12-Apr-1996, William Thompson, GSFC
;			Added checks for OBT_TIME=0, SCI_OBJ='', OBS_MODE=''
;		Version 3, 18-Apr-1996, William Thompson, GSFC
;			Corrected error in one of the checks.
;		Version 4, 30-Apr-1996, William Thompson, GSFC
;			Cope with split databases.
;		Version 5, 29-May-1996, William Thompson, GSFC
;			Cope with empty experiment* databases, and main_ptr=0.
;		Version 6, 25-Mar-1997, William Thompson, GSFC
;			Fixed bug in print statement.
;			Don't print orphaned entries with SEQ_NUM = -1
;		Version 7, 24-Apr-1997, William Thompson, GSFC
;			Corrected test for duplicate PROG_NUM/SEQ_IND
;		Version 8, William Thompson, GSFC, 1 June 1998
;			Don't use PRINTF to the screen.
;			Look for entries in "_year" files
;
; Contact     :	WTHOMPSON
;-
;
;	ON_ERROR, 2
;
;  Open the output file.
;
IF N_ELEMENTS(OUTPUT) EQ 1 THEN OPENW, UNIT, OUTPUT, /GET_LUN
;
;  Open up the databases one by one, and read in the information
;
DBOPEN, 'main'
DBEXT, -1, 'entry,prog_num', ENTRY_M, PROG_NUM_M
;
;  Step through all versions of the experiment catalog.
;
VERSION = ''
TRAILER = ''
REPEAT BEGIN
    IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	PRINTF, UNIT, ''
	PRINTF, UNIT, 'Processing ' + VERSION + 'experiment*' + TRAILER + $
		' databases'
	PRINTF, UNIT, ''
    END ELSE BEGIN
	PRINT, ''
	PRINT, 'Processing ' + VERSION + 'experiment*' + TRAILER + ' databases'
	PRINT, ''
    ENDELSE
;
    DBOPEN, VERSION + 'experiment' + TRAILER
    N_ENTRIES = DB_INFO('entries')
    IF N_ENTRIES(0) EQ 0 THEN GOTO, NEXT_DATABASE
    DBEXT, -1, 'entry,main_ptr,seq_num,seq_ind',	$
	    ENTRY0, MAIN_PTR, SEQ_NUM0, SEQ_IND0
;
    DBOPEN, VERSION + 'experiment1' + TRAILER
    DBEXT, -1, 'entry,seq_num,exper0_ptr', ENTRY1, SEQ_NUM1, EXPER0_PTR
;
    DBOPEN, VERSION+'experiment2'+TRAILER
    DBEXT, -1, 'entry,prog_num,seq_num,exper_ptr',	$
	    ENTRY2, PROG_NUM2, SEQ_NUM2, EXPER_PTR
;
;  Check the sequence numbers.
;
    W = WHERE(SEQ_NUM2 NE SEQ_NUM1(EXPER_PTR-1), COUNT)
    IF COUNT GT 0 THEN BEGIN
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following sequence numbers don't match:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '          Experiment1         Experiment2'
	    PRINTF, UNIT, '       Entry    Seq_Num    Entry    Seq_Num'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I2 = W(I)
		I1 = EXPER0_PTR(EXPER_PTR(I2)-1)-1
		PRINTF, UNIT, ENTRY1(I1), SEQ_NUM1(I1), ENTRY2(I2), $
			SEQ_NUM2(I2), FORMAT='(4I10)'
	    ENDFOR
	    PRINTF, UNIT, ''
	END ELSE BEGIN
	    PRINT, "The following sequence numbers don't match:"
	    PRINT, ''
	    PRINT, '          Experiment1         Experiment2'
	    PRINT, '       Entry    Seq_Num    Entry    Seq_Num'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I2 = W(I)
		I1 = EXPER0_PTR(EXPER_PTR(I2)-1)-1
		PRINT, ENTRY1(I1), SEQ_NUM1(I1), ENTRY2(I2), $
			SEQ_NUM2(I2), FORMAT='(4I10)'
	    ENDFOR
	    PRINT, ''
	ENDELSE
    ENDIF
;
    W = WHERE(SEQ_NUM1 NE SEQ_NUM0(EXPER0_PTR-1), COUNT)
    IF COUNT GT 0 THEN BEGIN
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following sequence numbers don't match:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '          Experiment          Experiment1'
	    PRINTF, UNIT, '       Entry    Seq_Num    Entry    Seq_Num'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I2 = W(I)
		I1 = EXPER0_PTR(I2)-1
		PRINTF, UNIT, ENTRY0(I1), SEQ_NUM0(I1), ENTRY1(I2), $
			SEQ_NUM1(I2), FORMAT='(4I10)'
	    ENDFOR
	    PRINTF, UNIT, ''
	END ELSE BEGIN
	    PRINT, "The following sequence numbers don't match:"
	    PRINT, ''
	    PRINT, '          Experiment          Experiment1'
	    PRINT, '       Entry    Seq_Num    Entry    Seq_Num'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I2 = W(I)
		I1 = EXPER0_PTR(I2)-1
		PRINT, ENTRY0(I1), SEQ_NUM0(I1), ENTRY1(I2), $
			SEQ_NUM1(I2), FORMAT='(4I10)'
	    ENDFOR
	    PRINT, ''
	ENDELSE
    ENDIF
;
;  Check the program numbers.
;
    EXPER_PTR_M = (MAIN_PTR(EXPER0_PTR(EXPER_PTR - 1) - 1) - 1) > 0
    W = WHERE(PROG_NUM2 NE PROG_NUM_M(EXPER_PTR_M), COUNT)
    IF COUNT GT 0 THEN BEGIN
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following Program numbers don't match:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '            Main        Experiment  Experiment1    Experiment2'
	    PRINTF, UNIT, '      Entry    Prog_Num   Entry       Entry     Entry    Prog_Num'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I2 = W(I)
		I1 = EXPER_PTR(I2)-1
		I0 = EXPER0_PTR(I1)-1
		IM = (MAIN_PTR(I0)-1) > 0
		PRINTF, UNIT, ENTRY_M(IM), PROG_NUM_M(IM), ENTRY0(I0),$
			ENTRY1(I1), ENTRY2(I2),PROG_NUM2(I2),	$
			FORMAT='(6I10)'
	    ENDFOR
	    PRINTF, UNIT, ''
	END ELSE BEGIN
	    PRINT, "The following Program numbers don't match:"
	    PRINT, ''
	    PRINT, '            Main        Experiment  Experiment1    Experiment2'
	    PRINT, '      Entry    Prog_Num   Entry       Entry     Entry    Prog_Num'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I2 = W(I)
		I1 = EXPER_PTR(I2)-1
		I0 = EXPER0_PTR(I1)-1
		IM = (MAIN_PTR(I0)-1) > 0
		PRINT, ENTRY_M(IM), PROG_NUM_M(IM), ENTRY0(I0),$
			ENTRY1(I1), ENTRY2(I2),PROG_NUM2(I2),	$
			FORMAT='(6I10)'
	    ENDFOR
	    PRINT, ''
	ENDELSE
    ENDIF
;
;  Open the full range of data, and look for duplicated sequence numbers.
;
    DBOPEN, VERSION + 'experiment2' + TRAILER +',' + VERSION +		$
	    'experiment1' + TRAILER + ',' + VERSION + 'experiment' +	$
	    TRAILER + ',main'
    S = SORT(SEQ_NUM2)
    TEMP = SEQ_NUM2(S)
    W = WHERE(TEMP(1:*) EQ TEMP, COUNT)
    IF COUNT GT 0 THEN BEGIN
	TEMP = ENTRY2(S)
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following sequence numbers are duplicates:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry   Exper_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		PRINTF, UNIT, ''
	    ENDFOR
	END ELSE BEGIN
	    PRINT, "The following sequence numbers are duplicates:"
	    PRINT, ''
	    PRINT, '     Entry   Exper_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		PRINT, ''
	    ENDFOR
	ENDELSE
    ENDIF
;
;  Look for entries that point to the same place.
;
    S = SORT(EXPER_PTR)
    TEMP = EXPER_PTR(S)
    W = WHERE(TEMP(1:*) EQ TEMP, COUNT)
    IF COUNT GT 0 THEN BEGIN
	TEMP = ENTRY2(S)
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following entries in experiment2 have the same pointer:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry   Exper_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		PRINTF, UNIT, ''
	    ENDFOR
	END ELSE BEGIN
	    PRINT, "The following entries in experiment2 have the same pointer:"
	    PRINT, ''
	    PRINT, '     Entry   Exper_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		PRINT, ''
	    ENDFOR
	ENDELSE
    ENDIF
;
    DBOPEN, VERSION + 'experiment1' + TRAILER + ',' + VERSION +	$
	    'experiment' + TRAILER + ',main'
    S = SORT(EXPER0_PTR)
    TEMP = EXPER0_PTR(S)
    W = WHERE(TEMP(1:*) EQ TEMP, COUNT)
    IF COUNT GT 0 THEN BEGIN
	TEMP = ENTRY1(S)
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following entries in experiment1 have the same pointer:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry  Exper0_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER0_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER0_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		PRINTF, UNIT, ''
	    ENDFOR
	END ELSE BEGIN
	    PRINT, "The following entries in experiment1 have the same pointer:"
	    PRINT, ''
	    PRINT, '     Entry  Exper0_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER0_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER0_PTR,SEQ_NUM,PROG_NUM,SEQ_IND',$
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5,FORMAT='(5I10)'
		PRINT, ''
	    ENDFOR
	ENDELSE
    ENDIF
;
;  Look for duplicates of PROG_NUM/SEQ_IND
;
    DBOPEN, VERSION + 'experiment2' + TRAILER + ',' + VERSION +		$
	    'experiment1' + TRAILER + ',' + VERSION + 'experiment' +	$
	    TRAILER + ',main'
    SEQ_MAX = MAX(SEQ_IND0) + 1L
    TEMP = PROG_NUM2*SEQ_MAX + SEQ_IND0(EXPER0_PTR(EXPER_PTR-1)-1)
    S = SORT(TEMP)
    TEMP = TEMP(S)
    W = WHERE(TEMP(1:*) EQ TEMP, COUNT)
    IF COUNT GT 0 THEN BEGIN
	TEMP = ENTRY2(S)
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following entries have the same PROG_NUM/SEQ_IND:"
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry   Exper_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND', $
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5, FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND', $
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5, FORMAT='(5I10)'
		PRINTF, UNIT, ''
	    ENDFOR
	END ELSE BEGIN
	    PRINT, "The following entries have the same PROG_NUM/SEQ_IND:"
	    PRINT, ''
	    PRINT, '     Entry   Exper_Ptr  Seq_Num   Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		I1 = W(I)
		I2 = I1+1
		DBEXT,TEMP(I1),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND', $
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5, FORMAT='(5I10)'
		DBEXT,TEMP(I2),'ENTRY,EXPER_PTR,SEQ_NUM,PROG_NUM,SEQ_IND', $
			TEMP1,TEMP2,TEMP3,TEMP4,TEMP5
		PRINT, TEMP1,TEMP2,TEMP3,TEMP4,TEMP5, FORMAT='(5I10)'
		PRINT, ''
	    ENDFOR
	ENDELSE
    ENDIF
;
;  Look for orphaned entries.
;
    DBOPEN, VERSION+'experiment'+TRAILER+',main'
    TEMP = 0*SEQ_NUM0
    TEMP(EXPER0_PTR-1) = 1
    W = WHERE(TEMP EQ 0, COUNT)
    IF COUNT GT 0 THEN BEGIN
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following entries in experiment are not pointed to:"
	    PRINTF, UNIT, '(Ignore any entries with Seq_Num = -1)'
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry    Seq_Num    Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		DBEXT,ENTRY0(W(I)),'ENTRY,SEQ_NUM,PROG_NUM,SEQ_IND',	$
			TEMP1,TEMP2,TEMP3,TEMP4
		IF TEMP2(0) NE -1 THEN PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4, $
			FORMAT='(5I10)'
	    ENDFOR
	    PRINTF, UNIT, ''
	END ELSE BEGIN
	    PRINT, "The following entries in experiment are not pointed to:"
	    PRINT, '(Ignore any entries with Seq_Num = -1)'
	    PRINT, ''
	    PRINT, '     Entry    Seq_Num    Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		DBEXT,ENTRY0(W(I)),'ENTRY,SEQ_NUM,PROG_NUM,SEQ_IND',	$
			TEMP1,TEMP2,TEMP3,TEMP4
		IF TEMP2(0) NE -1 THEN PRINT, TEMP1,TEMP2,TEMP3,TEMP4, $
			FORMAT='(5I10)'
	    ENDFOR
	    PRINT, ''
	ENDELSE
    ENDIF
;
    DBOPEN, VERSION + 'experiment1' + TRAILER + ',' + VERSION +	$
	    'experiment' + TRAILER + ',main'
    TEMP = 0*SEQ_NUM1
    TEMP(EXPER_PTR-1) = 1
    W = WHERE(TEMP EQ 0, COUNT)
    IF COUNT GT 0 THEN BEGIN
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, "The following entries in experiment1 are not pointed to:"
	    PRINTF, UNIT, '(Ignore any entries with Seq_Num = -1)'
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry    Seq_Num    Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		DBEXT,ENTRY1(W(I)),'ENTRY,SEQ_NUM,PROG_NUM,SEQ_IND',	$
			TEMP1,TEMP2,TEMP3,TEMP4
		IF TEMP2(0) NE -1 THEN PRINTF, UNIT, TEMP1,TEMP2,TEMP3,TEMP4, $
			FORMAT='(5I10)'
	    ENDFOR
	    PRINTF, UNIT, ''
	END ELSE BEGIN
	    PRINT, "The following entries in experiment1 are not pointed to:"
	    PRINT, '(Ignore any entries with Seq_Num = -1)'
	    PRINT, ''
	    PRINT, '     Entry    Seq_Num    Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO BEGIN
		DBEXT,ENTRY1(W(I)),'ENTRY,SEQ_NUM,PROG_NUM,SEQ_IND',	$
			TEMP1,TEMP2,TEMP3,TEMP4
		IF TEMP2(0) NE -1 THEN PRINT, TEMP1,TEMP2,TEMP3,TEMP4, $
			FORMAT='(5I10)'
	    ENDFOR
	    PRINT, ''
	ENDELSE
    ENDIF
;
;  Look for entries in EXPERIMENT with blank OBS_MODE entries.
;
    DBOPEN, VERSION + 'experiment2' + TRAILER + ',' + VERSION +		$
	    'experiment1' + TRAILER + ',' + VERSION + 'experiment' +	$
	    TRAILER + ',main'
    DBEXT, -1, 'ENTRY,PROG_NUM,SEQ_IND,SEQ_NUM,OBS_MODE',	$
	ENTRY, PROG_NUM, SEQ_IND, SEQ_NUM, OBS_MODE
    W = WHERE(STRTRIM(OBS_MODE,2) EQ '', COUNT)
    IF COUNT GT 0 THEN BEGIN
	IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	    PRINTF, UNIT, 'The following entries in EXPERIMENT have blank ' + $
		    'OBS_MODE values'
	    PRINTF, UNIT, ''
	    PRINTF, UNIT, '     Entry    Seq_Num    Prog_Num  Seq_Ind'
	    PRINTF, UNIT, ''
	    FOR I = 0,COUNT-1 DO PRINTF, UNIT, ENTRY(W(I)), SEQ_NUM(W(I)), $
		    PROG_NUM(W(I)), SEQ_IND(W(I)), FORMAT='(5I10)'
	    PRINTF, UNIT, ''
	END ELSE BEGIN
	    PRINT, 'The following entries in EXPERIMENT have blank ' + $
		    'OBS_MODE values'
	    PRINT, ''
	    PRINT, '     Entry    Seq_Num    Prog_Num  Seq_Ind'
	    PRINT, ''
	    FOR I = 0,COUNT-1 DO PRINT, ENTRY(W(I)), SEQ_NUM(W(I)), $
		    PROG_NUM(W(I)), SEQ_IND(W(I)), FORMAT='(5I10)'
	    PRINT, ''
	ENDELSE
    ENDIF
;
;  If processing the full databases, check to see if any sequence numbers are
;  duplicated between the two sets of databases.
;
    IF VERSION EQ 'f' THEN FOR ISEQ = 0L,N_ELEMENTS(SEQ_NUMS)-1L DO BEGIN
	W = WHERE(SEQ_NUMS(ISEQ) EQ SEQ_NUM2, COUNT)
	IF COUNT GT 0 THEN BEGIN
	    IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
		PRINTF, UNIT, 'Sequence number ' +	$
			TRIM(SEQ_NUMS(ISEQ)) +				$
			' in both versions of the experiment databases'
	    END ELSE BEGIN
		PRINT, 'Sequence number ' +	$
			TRIM(SEQ_NUMS(ISEQ)) +				$
			' in both versions of the experiment databases'
	    ENDELSE
	ENDIF
    ENDFOR
;
;  Store SEQ_NUM2 from the two versions of the experiment databases as a single
;  array.
;
    IF N_ELEMENTS(SEQ_NUMS) EQ 0 THEN SEQ_NUMS = SEQ_NUM2 ELSE	$
	    SEQ_NUMS = [SEQ_NUMS, SEQ_NUM2]
;
NEXT_DATABASE:
    IF VERSION EQ '' THEN BEGIN
        VERSION = 'f'
    END ELSE IF TRAILER EQ '' THEN BEGIN
        ITRAILER = 1996
        TRAILER = '_' + TRIM(ITRAILER)
    END ELSE BEGIN
        ITRAILER = ITRAILER + 1
        TRAILER = '_' + TRIM(ITRAILER)
    ENDELSE
ENDREP UNTIL FIND_WITH_DEF('fexperiment2'+TRAILER+'.dbf','$ZDBASE') EQ ''
;
;  Look for entries in MAIN with OBT_TIME equal to zero.
;
DBOPEN, 'main'
ENTRIES = DBFIND('OBT_TIME=0.0D0',/SILENT)
IF !ERR NE 0 THEN BEGIN
    DBEXT, ENTRIES, 'prog_num', PROG_NUM
    IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	PRINTF, UNIT, 'The following entries in MAIN have OBT_TIME=0'
	PRINTF, UNIT, ''
	PRINTF, UNIT, PROG_NUM
	PRINTF, UNIT, ''
    END ELSE BEGIN
	PRINT, 'The following entries in MAIN have OBT_TIME=0'
	PRINT, ''
	PRINT, PROG_NUM
	PRINT, ''
    ENDELSE
ENDIF
;
;  Look for entries in MAIN with blank science objectives.
;
DBEXT, -1, 'PROG_NUM,SCI_OBJ,DATE_OBS', PROG_NUM, SCI_OBJ, DATE_OBS
W = WHERE(STRTRIM(SCI_OBJ,2) EQ '', COUNT)
IF COUNT GT 0 THEN BEGIN
    IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
	PRINTF, UNIT, 'The following entries in MAIN have blank ' + $
		'science objectives'
	PRINTF, UNIT, ''
	PRINTF, UNIT, '  Prog_Num     Date_Obs'
	PRINTF, UNIT
	FOR I = 0, COUNT-1 DO PRINTF, UNIT, PROG_NUM(W(I)),	$
		TAI2UTC(DATE_OBS(W(I)),/VMS), FORMAT='(I10,5X,A)'
	PRINTF, UNIT, ''
    END ELSE BEGIN
	PRINT, 'The following entries in MAIN have blank ' + $
		'science objectives'
	PRINT, ''
	PRINT, '  Prog_Num     Date_Obs'
	PRINT
	FOR I = 0, COUNT-1 DO PRINT, PROG_NUM(W(I)),	$
		TAI2UTC(DATE_OBS(W(I)),/VMS), FORMAT='(I10,5X,A)'
	PRINT, ''
    ENDELSE
ENDIF
;
;  Look for sequence numbers that don't appear in the database.
;
CD, CURRENT=CURRENT
IF KEYWORD_SET(NOFITS) THEN GOTO, DONE
PATHS = FIND_ALL_DIR('$CDS_FITS_DATA',/PLUS_REQUIRED)
CD, PATHS(0)
SPAWN, 'ls', RESULT
;
GET_LUN, IN
FOR I = 0,N_ELEMENTS(RESULT)-1 DO BEGIN
    FILE = RESULT(I)
    IF STRMID(FILE,STRLEN(FILE)-5,5) EQ '.fits' THEN BEGIN
	OPENR, IN, FILE
	FXHREAD, IN, HEADER
	CLOSE, IN
	SEQ_NUM = FXPAR(HEADER,'SEQ_NUM')
	W = WHERE(SEQ_NUM EQ SEQ_NUMS, COUNT)
	IF COUNT EQ 0 THEN BEGIN
	    IF N_ELEMENTS(OUTPUT) EQ 1 THEN BEGIN
		PRINTF, UNIT,	$
			'Unrecorded sequence number: ' + TRIM(SEQ_NUM) + $
			', ' + FILE
	    END ELSE BEGIN
		PRINT,	$
			'Unrecorded sequence number: ' + TRIM(SEQ_NUM) + $
			', ' + FILE
	    ENDELSE
	ENDIF
    ENDIF
ENDFOR
;
DONE:
CD, CURRENT
DBCLOSE
IF N_ELEMENTS(OUTPUT) EQ 1 THEN FREE_LUN, UNIT
IF N_ELEMENTS(IN)     EQ 1 THEN FREE_LUN, IN
END
