	PRO CONV_CDHSSTATE
;+
; Project     :	SOHO - CDS
;
; Name        :	CONV_CDHSSTATE
;
; Purpose     :	Converts format of cdhsstate database to external
;
; Explanation :	Reads in the cdhsstate database and writes it back out again in
;		external format.  This allows the files to be used on multiple
;		computer platforms.
;
;
; Use         :	One should use the following procedure to convert the database
;		to external format:
;
;			1.  Make sure that the title line of the cdhsstate.dbd
;			    database file says
;
;				CDHS state database : Version 0.2 18/12/95
;
;			    This routine is not certified for any other
;			    version.
;
;			2.  Change to the directory containing the database
;			    files to be converted.  *** Very important ***
;
;			3.  Start up IDL and compile this procedure with the
;			    command ".run conv_cdhsstate.prg".  Naming the file
;			    with the .prg extension is used to ensure that the
;			    routine is not executed accidently.
;
;			4.  Make sure that the software is enabled by entering
;			    the command "!priv = 5".  This is another
;			    protective step.
;
;			5.  Execute the procedure with the command
;			    "conv_cdhsstate".
;
;		During the conversion, the software will move the old
;		"cdhsstate.dbf", ".dbh", and ".dbx" files to
;		"old_cdhsstate.dbf", etc.  When the conversion is complete, you
;		will be asked if you want to delete these files or not.
;
; Category    :	This is not part of the CDS software tree.
;
; Written     :	William Thompson, GSFC, 30 April 1996
;-
;
	ON_ERROR, 2
;
;  Make sure that the user has the privilege set correctly to run this routine.
;
	IF !PRIV LT 5 THEN MESSAGE,	$
		'!PRIV must be set to 5 to run this routine.'
;
;  Make sure that the user really wants to convert the database.
;
	PRINT, 'Converting cdhsstate databases to external representation.'
	ASK, 'Are you sure you want to do this? ', ANSWER
	IF ANSWER NE 'Y' THEN BEGIN
		PRINT, 'Execution aborted'
		RETURN
	ENDIF
;
;  Check to make sure that the proper database files are in the current
;  directory.
;
	MESSAGE = 'Database files not in current directory'
	ON_IOERROR, HANDLE_ERROR
	OPENR, UNIT, 'cdhsstate.dbf', /GET_LUN
	FREE_LUN, UNIT
;
;  Determine the correct commands for renaming and deletion.
;
	CASE OS_FAMILY() OF
		'vms': BEGIN
			RENAME = 'RENAME'
			DELETE = 'DELETE'
			END
		'unix': BEGIN
			RENAME = 'mv'
			DELETE = 'rm'
			END
		ELSE: MESSAGE, 'Only supported in VMS or Unix'
	ENDCASE
;
;  Preserve the old database files by renaming them.
;
	MESSAGE = 'Error occured'
;
	SPAWN, RENAME + ' cdhsstate.dbf old_cdhsstate.dbf'
	SPAWN, RENAME + ' cdhsstate.dbx old_cdhsstate.dbx'
	SPAWN, RENAME + ' cdhsstate.dbh old_cdhsstate.dbh'
;
;  Create empty versions of the new database files.
;
	DBCREATE, 'cdhsstate', 1, 1, /EXTERNAL
;
;  Open the old cdhsstate database file, and read in the data.
;
	DBOPEN, 'old_cdhsstate'
	DBEXT, -1, 'DATE,MNEMONIC,PNUMBER,NUMBERP,LOAD,DELAY,ACTIVE',	$
		DATE, MNEMONIC, PNUMBER, NUMBERP, LOAD, DELAY, ACTIVE
	DBEXT, -1, 'DEFAULT,COMMENT', DEFAULT, COMMENT
	DBCLOSE
;
;  Insert the data into the new cdhsstate database.
;
	DBOPEN, 'cdhsstate', 1
	DBBUILD, DATE, MNEMONIC, PNUMBER, NUMBERP, LOAD, DELAY, ACTIVE,	$
		DEFAULT, COMMENT
	DBCLOSE
;
;  Clean up.
;
	ASK ,'Conversion complete, do you wish to delete the old files? ', $
		ANSWER
	IF ANSWER EQ 'Y' THEN SPAWN, DELETE + ' old_cdhsstate.db*'
	RETURN
;
;  Error handling point.
;
HANDLE_ERROR:
	MESSAGE, MESSAGE
;
	END
