	PRO CONV_SERIES_ID
;+
; Project     :	SOHO - CDS
;
; Name        :	CONV_SERIES_ID
;
; Purpose     :	Adds index for CDHS_ID to series_id database.
;
; Explanation :	Adds the CDHS_ID index to the series_id database.
;
; Use         :	One should use the following procedure to convert the databases
;		to the new formats:
;
;			1.  Make sure that the only difference between the old
;			    and new versions of the title lines of the
;			    series_id.dbd database file is that CDHS_ID is
;			    added to list of indices.
;
;			2.  Change to the directory containing the database
;			    files to be converted.  *** Very important ***
;
;			3.  Start up IDL and compile this procedure with the
;			    command ".run conv_series_id.prg".  Naming the file
;			    with the .prg extension is used to ensure that the
;			    routine is not executed accidently.
;
;			4.  Make sure that the software is enabled by entering
;			    the command "!priv = 5".  This is another
;			    protective step.
;
;			5.  Execute the procedure with the command
;			    "conv_series_id".
;
; Category    :	This is not part of the CDS software tree.
;
; Written     :	William Thompson, GSFC, 30 April 1996
;-
;
	ON_ERROR, 2
;
;  Make sure that the user has the privilege set correctly to run this routine.
;
	IF !PRIV LT 5 THEN MESSAGE,	$
		'!PRIV must be set to 5 to run this routine.'
;
;  Make sure that the user really wants to convert the database.
;
	PRINT, 'Converting series_id databases to add CDHS_ID index.'
	ASK, 'Are you sure you want to do this? ', ANSWER
	IF ANSWER NE 'Y' THEN BEGIN
		PRINT, 'Execution aborted'
		RETURN
	ENDIF
;
;  Determine the correct commands for copying and deleting.
;
	CASE OS_FAMILY() OF
		'vms': BEGIN
			COPY   = 'COPY'
			DELETE = 'DELETE'
			END
		'unix': BEGIN
			COPY   = 'cp'
			DELETE = 'rm'
			END
		ELSE: MESSAGE, 'Only supported in VMS or Unix'
	ENDCASE
;
;  Check to make sure that the proper database files are in the current
;  directory.
;
	MESSAGE = 'Database files not in current directory'
	ON_IOERROR, HANDLE_ERROR
	OPENR, UNIT, 'series_id.dbf', /GET_LUN
	FREE_LUN, UNIT
;
;  Decide whether or not the database uses external representation.
;
	DBOPEN, 'rseries_id'
	EXTERNAL = DB_INFO('external')
	EXTERNAL = EXTERNAL(0)
;
;  Reindex the series_id database.
;
	DBCREATE, 'series_id', 1, EXTERNAL=EXTERNAL
	DBOPEN, 'series_id', 1
	DBINDEX
	DBCLOSE
;
;  Copy over the .dbd file, and do the same with rseries_id.
;
	SPAWN, COPY + ' series_id.dbd rseries_id.dbd'
	DBCREATE, 'rseries_id', 1, EXTERNAL=EXTERNAL
	DBOPEN, 'rseries_id', 1
	DBINDEX
	SPAWN, DELETE + ' rseries_id.dbd'
;
	DBCLOSE
	RETURN
;
;  Error handling point.
;
HANDLE_ERROR:
	MESSAGE, MESSAGE
;
	END
