;+
; Project     : SOHO - CDS     
;                   
; Name        : FIX_LINELIST
;               
; Purpose     : Recalculates all the cen_pix values in the linelist db.
;               
; Explanation : The linelist database used by the planning software contains
;               a wavelength and a central pixel for each spectral line. If
;               the wavelength calibration changes significantly, this routine
;               should be used to update the cen_pix tag.
;               
; Use         : IDL> fix_linelist
;    
; Inputs      : None - operates on db pointed to by ZDBASE
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : MOD_LINELIST
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Databases, planning
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 27-Nov-95
;               
; Modified    : 
;
; Version     : Version 1, 27-Nov-95
;-            
pro fix_linelist

;
;  privilege?
;
if !priv ne 2 then begin
   bell
   print,'!priv must equal 2'
   return
endif

;
;  bit of security
;
qzdbase

yes_no, 'Ok to continue? > ', ok, 'No'
if not ok then return

;
;  get contents
;
list_linelist,l,n
if n eq 0 then return

;
;  loop through each line list
;
for i=1,n do begin
   get_linelist,i,l
   if l.ll_id eq i then begin
      nl = n_elements(l.lines)
      new = intarr(nl)
      for j=0,nl-1 do begin
         b = l.detector+strtrim(string(l.lines(j).waveband),2)
         new(j) = wave2pix(b,l.lines(j).wavelnth)
      endfor
   endif else begin
      print,'error on getting linelist ',i
   endelse
   print,' '
   print,'Line list = ',i
   errmsg = ''
   res = mod_linelist(i,cen_pix=new,errmsg=errmsg)
   if errmsg ne '' then begin
      print,errmsg
      return
   endif
endfor
   
end
