	PRO FIX_OBS_SEQ
;+
; Project     :	SOHO - CDS
;
; Name        :	FIX_OBS_SEQ
;
; Purpose     :	Fix blank OBS_SEQ and OBS_MODE values in the catalog
;
; Category    :	Class5, Operations, Catalog
;
; Explanation :	Sets blank OBS_SEQ values in the catalog to suitable values.
;
; Syntax      :	FIX_OBS_SEQ
;
; Examples    :	
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	
;
; Common      :	None.
;
; Restrictions:	!PRIV must be GE 2 to write into the database.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 16-April-1996, William Thompson, GSFC
;
; Contact     :	WTHOMPSON
;-
;
	ON_ERROR, 2
;
;  Make sure that the user has privilege to write into the database.
;
	IF NOT PRIV_ZDBASE(/CAT) THEN MESSAGE,	$
		'No privilege to write into the MAIN database'
;
;  Check that !PRIV is set correctly.
;
	IF !PRIV LT 2 THEN MESSAGE,	$
		'!PRIV must be 2 or greater to write into the database'
;
;  Open the experiment2 database, and extract all the sequence numbers.
;
	DBOPEN, 'experiment2'
	DBEXT, -1, 'seq_num', SEQ_NUM
;
;  Step through all of the sequence numbers, and get the entry.
;
	COUNTDOWN, N_ELEMENTS(SEQ_NUM), /OPEN
	FOR I = 0, N_ELEMENTS(SEQ_NUM)-1 DO BEGIN
	    COUNTDOWN, I
	    GET_EXPER, SEQ_NUM(I), EXPER
;
;  If the OBS_SEQ value is blank, then change it to the correct value.
;
	    MODIFY = 0
	    IF TRIM(EXPER.OBS_SEQ) EQ '' THEN BEGIN
		IF EXPER.RAS_ID GT 0 THEN BEGIN
		    EXPER.OBS_SEQ = 'R' + TRIM(EXPER.RAS_ID) + 'V' +	$
			    TRIM(EXPER.RAS_VAR)
		END ELSE EXPER.OBS_SEQ = 'ENG'
		MODIFY = 1
	    ENDIF
;
;  If the OBS_MODE value is blank, then change it to the correct value.
;
	    IF TRIM(EXPER.OBS_MODE) EQ '' THEN BEGIN
		EXPER.OBS_MODE = EXPER.DETECTOR+'-S'+TRIM(EXPER.SLIT_NUM) + $
			'-R' + TRIM(EXPER.RAS_ID>0) + '-E' +	$
			TRIM(EXPER.EXPTIME)
		MODIFY = 1
	    ENDIF
;
;  If either were changed, then modify the entry in the database.
;
	    IF MODIFY THEN BEGIN
		IF NOT MOD_EXPER(EXPER) THEN BEGIN
		    COUNTDOWN, /CLOSE
		    MESSAGE, 'Unable to modify sequence ' + TRIM(SEQ_NUM(I))
		ENDIF
	    ENDIF
;
	ENDFOR
	COUNTDOWN,/CLOSE
;
	END
