	PRO LIST_PROGRAM, PROGRAMS, N_FOUND, ERRMSG=ERRMSG
;+
; Project     :	SOHO - CDS
;
; Name        :	LIST_PROGRAM
;
; Purpose     :	List the available CDS program definitions.
;
; Explanation :	Extracts the names and IDs of all the CDS multi-observation
;		program definitions.
;
; Use         :	LIST_PROGRAM, PROGRAMS, N_FOUND
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	PROGRAMS = A structure variable containing the following tags
;			   for each program:
;
;			PROGNAME = Name of the program.
;			PROG_ID	 = Unique identifier number.
;
;		N_FOUND	= Number of programs found.
;
; Opt. Outputs:	None.
;
; Keywords    :
;       ERRMSG    = If defined and passed, then any error messages will be
;                   returned to the user in this parameter rather than
;                   depending on the MESSAGE routine in IDL.  If no errors are
;                   encountered, then a null string is returned.  In order to
;                   use this feature, ERRMSG must be defined first, e.g.
;
;                       ERRMSG = ''
;                       LIST_PROGRAM, ERRMSG=ERRMSG, ... 
;                       IF ERRMSG NE '' THEN ...
;
;
; Calls       :	DATATYPE, DBOPEN, DB_INFO, DBEXT, DBCLOSE
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	If the number of programs found is zero, then the output
;		parameter PROGRAMS is not modified.
;
; Category    :	Planning, Database.
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 21 July 1994
;
; Modified    :	Version 1.0, William Thompson, GSFC, 26 July 1994
;               Version 2, Liyun Wang, GSFC/ARC, September 22, 1994
;                  Added the keyword ERRMSG.
;
; Version     :	Version 2, September 22, 1994
;-
;
	ON_ERROR, 2
;
;  Check the number of parameters.
;
        IF N_PARAMS() LT 2 THEN BEGIN
           MESSAGE = 'Syntax:  LIST_PROGRAM, PROGRAMS, N_FOUND'
           IF N_ELEMENTS(ERRMSG) NE 0 THEN BEGIN
              ERRMSG = MESSAGE
              RETURN
           ENDIF ELSE MESSAGE, MESSAGE
        ENDIF
;
;  Open the program database, and extract all the entries.
;
	DBOPEN, 'program'
	N_FOUND = DB_INFO('entries','program')
	IF N_FOUND EQ 0 THEN GOTO, FINISH
	ENTRIES = LINDGEN(N_FOUND) + 1
	DBEXT, ENTRIES, 'progname,prog_id', PROGNAME, PROG_ID
;
;  Define the structure that the data will be returned in.
;
	PROGRAMS = {PROGNAME: 'String', PROG_ID: 0}
;
	IF N_FOUND EQ 1 THEN BEGIN
		PROGRAMS.PROGNAME = PROGNAME(0)
		PROGRAMS.PROG_ID  = PROG_ID(0)
	END ELSE BEGIN
		PROGRAMS = REPLICATE(PROGRAMS, N_FOUND)
		PROGRAMS.PROGNAME = PROGNAME
		PROGRAMS.PROG_ID  = PROG_ID
	ENDELSE
;
;  Close the database and return.
;
FINISH:
	DBCLOSE
;
	RETURN
	END
