;+
; Project     : SOHO - CDS     
;                   
; Name        : PLOT_DEX
;               
; Purpose     : Plot the actual dew to be used in observation.
;               
; Explanation : Plots the data extraction windows used in a raster for
;               illustrative purposes.  It can be used to check the windows 
;               re-calculated by UPDATE_DEX to show the actual windows to 
;               be used.
;               
; Use         : IDL> plot_dex, dw_str, /hard, /soft 
;    
; Inputs      : dw_str  - a valid data structure as returned by GET_DATAWIN.
;                   
; Opt. Inputs : None
;               
; Outputs     : Just plots the results.
;               
; Opt. Outputs: None
;               
; Keywords    : hard - plot only VDS hardware windows
;               soft - plot only the true data extraction windows
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : Based om tp_plot_dew.
;
; Written     : C D Pike, RAL, 15-Feb-96
;               
; Modified    : Version 2, Check validity of input.  CDP, 15-Mar-96
;
; Version     : Version 2, 15-Mar-96
;-            

pro plot_dex, input

;
;  check input
;
if n_params() eq 0 then begin
   print,'Use:  IDL> plot_dex, dex-struct'
   return
endif

if datatype(input,1) ne 'Structure' then begin
   print,'Input parameter must be an extraction window structure'
   return
endif


;
;  record plot setup, assumed on entry to be that for the main plot
;  area
;
savep = !p  & savex = !x & savey = !y


;
;  retrieve the soft window limits
;
w = input.wins.win_def


;
;  error returns
;
if n_elements(w) le 1 then return

n = where(w(3,*) gt 0)
if n(0) eq -1 then begin
   return
endif

;
;  number of soft Data Extraction Windows to handle
;
numdew = n_elements(n)

;
;  act according to instrument
;
ins  = input.detector

case ins of
 'G':  begin
          !p.multi=[0,2,2]
          for i=0,3 do begin
             xst = i*2048
             xe = xst+2047
             plot,[xst,xe],[0,1],/nodata,xstyle=5,ystyle=5,$
                                 title='GIS detector '+string(i+1,form='(i1)') 
             axis,xaxis=0,xstyle=1,xtit='Pixels',chars=1.4
             oplot,[xe,xe,xst,xst],[0,1,1,0]
             for j=0,numdew-1 do begin
                if w(0,j) ge xst and w(0,j) le xe then begin
;
;  if this reversal is not right then kill this line and replace switched_xst
;  2 lines below by w(0,j)
;
                   switched_xst = xe - (w(0,j)+w(2,j)) + 1 +xst
                   nwidth = w(2,j)
                   fill_box,switched_xst+nwidth/2,1.0,nwidth,6,/border
                endif
             endfor
          endfor
       end
 'N':  begin
          numvdsw = n_elements(n)

          plot,[0,1023],[0,1023],/nodata,xstyle=1,ystyle=1,$
                         chars=1.4,yrange=[1023,0],$
                         xtit='CCD columns',ytit='CCD rows'
                     
          oplot,[0,1023],[511,511],line=2
          xyouts,400,800,'NIS1 - 300A band',chars=1.5
          xyouts,400,250,'NIS2 - 500A band',chars=1.5

          for i=0,numdew-1 do begin
             nwidth = w(2,i)
             fill_box,w(0,i)+nwidth/2,w(1,i)+w(3,i),nwidth,6,$
                         /border,ymin=w(1,i)
          endfor
       end   
 else:
endcase

;
;  return plot set up to standard
;
if input.detector eq 'G' then begin
   if !d.name ne 'PS' then begin
      !p = savep & !x = savex & !y = savey
   endif 
endif

end
