;+
; Project     : SOHO - CDS     
;                   
; Name        : UPDATE_RAS_DUR
;               
; Purpose     : Updates all the raster durations in the database.
;               
; Explanation : The calculation of raster durations may change as properties
;               of the CDS are further understood.  This routine allows a 
;               global update of the raster duration parameter using output 
;               from the function CALC_RAS_DUR().
;               
; Use         : IDL> update_ras_dur [, /quiet]
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : QUIET   - if set no details of the changes are output to the 
;                         screen
;
; Calls       : Database access routines
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Database
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 9-Jun-95
;               
; Modified    : Ignore existing negative raster durations as these are
;               a flag to indicate emoirically determined values. CDP 26-Feb-96
;               Don't update if the duration value has not changed.
;                                                                 CDP 10-Jun-96
;
; Version     : Version 3, 10-Jun-96
;-            

pro update_ras_dur, quiet=quiet

;
;  get a list of all fundamental rasters
;
list_f_raster, fr, n

;
;  for each one pick up the variations, calculate the new duration and apply it
;
for i=0,n-1 do begin
   list_v_raster, fr(i).ras_id, rv, nv
   for k=0,nv-1 do begin
      olddur = rv(k).duration
      dur = calc_ras_dur(fr(i).ras_id,rv(k).ras_var)
      if (olddur gt 0.0) and (olddur ne dur) then begin
         OK = mod_v_raster(fr(i).ras_id, rv(k).ras_var,duration=float(dur))
         if not OK then begin
            bell
            print,'Error updating raster database'
            return
         endif
   
         get_raster,fr(i).ras_id, rv(k).ras_var,con
   
         text = ''
         if con.duration eq dur then text = '    -- Confirmed' else $
                                        text = '    -- Error'
         if not keyword_set(quiet) then begin
            print,'Raster '+fmt_vect([fr(i).ras_id,rv(k).ras_var],delim='/')+$
                   ' changed from ',olddur,' to ',dur,text,$
                   form='(a,f7.1,a4,f7.1,a)'
         endif
      endif else begin
            print,'Raster '+fmt_vect([fr(i).ras_id,rv(k).ras_var],delim='/')+$
                   ' NOT changed from ',abs(olddur),' (empirical value).',$
                   form='(a,f7.1,a)'
      endelse    
   endfor
endfor

end
