;+
; Project     : SOHO - CDS     
;                   
; Name        : CDSLR2XY()
;               
; Purpose     : Calculates solar (x,y) values for given OPS position.
;               
; Explanation : Wrapper for the OPS_POINT routine.
;               
; Use         : IDL> print,cdslr2xy(opsl,opsr)
;    
; Inputs      : opsl - the OPS left leg value
;               opsr - the OPS right leg value
;
;               Both may be either scalar or arrays.
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns solar (x,y) values in an array (n,2) where
;               n is the number of input positions.  If n=1 then a simple
;               2-element array is returned.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : OPS_POINT
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Operations
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 28-Jun-96
;               
; Modified    : 
;
; Version     : Version 1, 28-Jun-96
;-          
  
function cdslr2xy,opsl,opsr

;
;  on line help
;
if n_params() eq 0 then begin
   print,'Use:   IDL> print,cdslr2xy(opsl,opsr)
   print,' '
   return,[0,0]
endif

;
;  assess input
;
nl = n_elements(opsl)
nr = n_elements(opsr)
if nl ne nr then begin
   print,'OPSL & OPSR inputs must have same dimensions.'
   return,[0,0]
endif

;
;  low level routine can handle arrays
;
ops_point,opsl,opsr,x,y

return,reform([[x],[y]])

end
