;+
; Project     :	SOHO - CDS
;
; Name        :	CP_GET_INDECES()
;
; Purpose     :	Returns structure elements corrsponding to particular pnumbers.
;
; Explanation : Tests for "Unknown" mnemonic and for pnumber values. Returns the structure array
;               elements corresponding to the pnumbers requested.
;
; Use         : < s = cp_get_indeces ( struct, indeces, ERRMSG=ERRMSG ) >
;
; Inputs      : struct = structure array containing CDHS state database output.
;                 struct.mnemonic = parameter mnemonic
;                 struct.date     = date values last changed
;                 struct.numberp  = no. of parameters associated with mnemonic
;                 struct.pnumber  = parameter number for this entry
;                 struct.load     = flag indicating whether value requires loading
;                 struct.delay    = delay in secs associated with command
;                 struct.active   = value for parameter
;                 struct.default  = default value for parameter
;                 struct.comment  = comment on parameter
;               indeces = pnumbers which expect to be present.
;
; Opt. Inputs : None.
;
; Outputs     : s : Structure array containing requested pnumbers.                        
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;       ERRMSG    = If defined and passed, then any error messages will be
;                   returned to the user in this parameter rather than
;                   depending on the MESSAGE routine in IDL.  If no errors are
;                   encountered, then a null string is returned.  In order to
;                   use this feature, ERRMSG must be defined first, e.g.
;
;                       ERRMSG = ''
;                       GET_STATE, ERRMSG=ERRMSG, ... 
;                       IF ERRMSG NE '' THEN ...
;;
; Calls       :	None.
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	Version 0.0, Martin Carter, RAL, 11/8/95
;
; Modified    :	Version 0.1, MKC, 25/9/95
;                 Modified so that does not return integers if 
;                 input data invalid.
;		Version 0.2, MKC, 28/9/95
;			Added keyword ERRMSG
;               Version 0.3, MKC, 19/12/95
;                 Added delay tag.
;
; Version     :	Version 0.3, 19/12/95
;-
;**********************************************************

FUNCTION cp_get_indeces, struct, indeces, ERRMSG=ERRMSG

  ; form results arrays

  list = indeces

  ; check results OK

  IF struct(0).mnemonic EQ 'Unknown' THEN BEGIN
    message = 'UNKNOWN COMMAND MNEMONIC'
    GOTO, HANDLE_ERROR
  ENDIF

  FOR k = 0, N_ELEMENTS(indeces)-1 DO BEGIN

    ; NB setting array element to array size 1 ok

    list(k) = WHERE ( struct.pnumber EQ indeces(k), count)

    IF count NE 1 THEN BEGIN
      message = 'MISSING OR DUPLICATE PARAMETER NUMBERS'
      GOTO, HANDLE_ERROR
    ENDIF

  ENDFOR 

  RETURN, struct(list)

  ;
  ;  Error handling point.
  ;
  HANDLE_ERROR:
	IF N_ELEMENTS(ERRMSG) NE 0 THEN ERRMSG = 'CP_GET_INDECES: ' + message $
		ELSE MESSAGE, message
  
END


