;+
; Project     : SOHO - CDS
;
; Name        : GET_CDS_ASRUN
;
; Purpose     : return ASRUN raster parameters from CDS Main catalog entry
;
; Category    : planning
;
; Syntax      : IDL> get_cds_asrun,obs,rasters
;
; Inputs      : OBS = main entry from LIST_MAIN (must be scalar)
;
; Outputs     : RASTERS = raster parameters (can be array)
;;
; Keywords    : ERR = error string
;               
; History     : Writte, 30-Nov-1999,  D.M. Zarro (SM&A/GSFC)
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

pro get_cds_asrun,obs,rasters,err=err

rasters='' & err=''

if (datatype(obs) ne 'STC') or (n_elements(obs) ne 1) then begin
 err='input entry must be a scalar structure'
 message,err,/cont
 pr_syntax,'get_cds_asrun,obs,rasters'
 return
endif

if (not have_tag(obs,'prog_num')) then begin
 err='input entry does not have PROG_NUM field'
 message,err,/cont
 return
endif

;-- get asrun rasters

list_exper,obs.prog_num,rasters,nrast
          
if nrast eq 0 then begin
 err='no rasters found for this asrun entry'
 rasters=''
 return
endif

;-- append some extra raster info

for i=0,nrast-1 do begin
 ras_id=rasters(i).ras_id
 ras_var=rasters(i).ras_var
 ras_def=get_cds_raster(ras_id,ras_var)
 temp=join_struct(rasters(i),ras_def)
 new=concat_struct(new,temp)                   
endfor

rasters=new

return & end

