;+
; Project     : SOHO - CDS
;
; Name        : GET_CDS_GIS
;
; Purpose     : get CDS GIS detectors
;
; Category    : planning, database
;
; Explanation : 
;
; Syntax      : IDL> dets=get_cds_gis(study)
;
; Inputs      : STUDY = CDS study structure
;
; Opt. Inputs : None
;
; Outputs     : DETS = array of detector nos. (e.g. [0,2,3], or [1,2])
;                      (returns -1 if no GIS detectors used)
;
; Opt. Outputs: None
;
; Keywords    : ERR = any errors
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Version 1,  1-Jul-1996,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

function get_cds_gis,study,err=err

err='%GET_CDS_GIS: no GIS detectors used'

if datatype(study) ne 'STC' then return,-1
if (study.n_raster_def eq 0) or (not tag_exist(study,'RASTERS')) then return,-1
rasters=study.rasters
nras=n_elements(rasters)

;-- find first GIS raster and assume same detectors for all rasters

for i=0,nras-1 do begin
 ras=get_cds_raster(rasters(i).ras_id,rasters(i).ras_var)
 if trim(ras.detector) eq 'G' then begin
  terr=''
  get_datawin,ras.dw_id,dwin,err=terr
  if terr eq '' then begin
   gis_dets=dwin.wins.win_def(0,*)/2048
   gis_dets=gis_dets(uniq([gis_dets],sort([gis_dets]))) 
   return,gis_dets
  endif else err=terr
 endif
endfor

return,-1 & end

