;+
; Project     :	SOHO - CDS
;
; Name        :	GET_CDS_RASTER
;
; Purpose     :	get a CDS raster from database
;
; Explanation :	speeds up GET_RASTER by saving each raster in common
;
; Use         :	RASTER=GET_CDS_RASTER(RAS_ID,RAS_VAR)
;
; Inputs      :	RAS_ID  = raster id
;             : RAS_VAR = raster variation
;
; Opt. Inputs :	None.
;
; Outputs     :	RASTER = raster definition
;
; Opt. Outputs:	None.
;
; Keywords    : INIT = initialize commons and return
;
; Calls       :	GET_RASTER
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning, Database.
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC)
;
; Version     :	Version 1.0, 28 March 1995
;-


function get_cds_raster,ras_id,ras_var,init=init,err=err

on_error,1

common get_cds_raster,raster_com,sav_rdb
err=''

if keyword_set(init) then begin
 delvarx,raster_com & return,0
endif

if n_elements(ras_id)*n_elements(ras_var) eq 0 then begin
 err='invalid input'
 message,err,/cont
 return,-1
endif

;-- check if database changed

if datatype(sav_rdb) ne 'STR' then sav_rdb=getenv('ZDBASE')
cur_db=getenv('ZDBASE')
if cur_db ne sav_rdb then begin
 message,'ZDBASE changed!!!',/contin
 delvarx,raster_com & sav_rdb=cur_db
endif
 
;-- check common first

rdb=1
if exist(raster_com) then begin
 clook=where(ras_id eq raster_com.ras_id and $
             ras_var eq raster_com.ras_var, cnt)
 if cnt gt 0 then rdb=0
endif

;-- read raster from DB and save in common

if rdb then begin
 get_raster,ras_id,ras_var,raster,err=err
 ras_id=raster.ras_id
 if ras_id lt 0 then return,raster
 raster_com=concat_struct(raster_com,raster)
endif else raster=raster_com(clook(0))

return,raster & end



