;+
; Project     : SOHO - CDS     
;                   
; Name        : GET_CDS_STATE
;               
; Purpose     : determine CDS state just prior to input time
;               
; Category    : Planning
;               
; Explanation :
;               
; Syntax      : IDL> state=get_cds_state(time,look=look)
;    
; Examples    : 
;
; Inputs      : TIME = input time to check prior to
;               
; Opt. Inputs : None
;               
; Outputs     : STATE ={state_structure,$
;                       mode:'X',solarx:0,solary:0,slitn:0,gsetid:0}
;
; Opt. Outputs: None
;               
; Keywords    : LOOK = seconds to look back prior to TIME [def= 1 day]
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; History     : Version 1,  29-July-1996,  D M Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-            

function get_cds_state,time,look=look

;-- default unknown state

state={state_structure,mode:'X',solarx:0,solary:0,slitn:0,gsetid:0}

if not exist(time) then return,state
day_secs=24.*3600.d
if not exist(look) then look=day_secs

tstart=anytim2tai(time)
list_detail,tstart-look,tstart,obs,nobs
if nobs eq 0 then return,state

;--remove engineering studies

no_eng=where(obs.study_id gt 0,nobs)
if nobs eq 0 then return,state else obs=obs(no_eng)

;-- get last plan before input time

index=mk_plan_where(tstart,obs,status=in_plan)
if in_plan then begin
 if (index gt 0) then obs=obs(0:index-1) else return,state
 nobs=n_elements(obs)
endif

;-- get last GSET_ID

gsets=where(obs.gset_id gt 0,cnt)
if cnt gt 0 then begin
 gset_ids=obs(gsets).gset_id
 last_gset_id=gset_ids(cnt-1)
endif else last_gset_id=0

;-- get last pointing and slit #

last_plan=obs(nobs-1)
itime=get_plan_itime(last_plan)
get_detail,last_plan.(itime),last_plan
get_study_par,plan=last_plan,slits=slits,study=study

nslits=n_elements(slits)
if nslits gt 0 then last_slit=slits(nslits-1) else last_slit=0
get_cds_xy,last_plan,last_x,last_y,/last,study=study
state={state_structure,mode:'B',solarx:nint(last_x),solary:nint(last_y),$
            slitn:last_slit,gsetid:last_gset_id}

return,state & end

