;+
; Project     : SOHO - CDS
;
; Name        : GET_GIS_DET
;
; Purpose     : get CDS GIS detectors used by a particular GSET
;
; Category    : planning, database
;
; Explanation : 
;
; Syntax      : IDL> dets=get_gis_det(gset_id)
;
; Inputs      : GSET_ID = GSET ID number
;
; Opt. Inputs : None
;
; Outputs     : DETS = array of detector nos. (e.g. [0,2,3], or [1,2])
;                      (returns -1 if no GIS detectors used)
;
; Opt. Outputs: None
;
; Keywords    : ERR = any errors
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Version 1,  1-Jul-1996,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

function get_gis_det,gset_id,err=err

if not exist(gset_id) then return,-1
err=''
get_gset,gset_id,def,err=err
if err eq '' then begin
 dets=where(def.det_used eq 1)
 return,dets
endif

return,-1 & end

