;+
; Project     :	SOHO - CDS
;
; Name        :	MK_CDS_DBASE
;
; Purpose     :	makes a widget interface to CDS Detailed Plan
;
; Explanation :	
;
; Use         :	MK_CDS_DBASE,PARENT,DBASE
;
; Inputs      :	PARENT = parent widget upon which to construct widgets
;
; Opt. Inputs :	None.
;
; Outputs     :	DBASE  = created child widget 
;
; Opt. Outputs:	None.
;
; Keywords    :	MAP = 1/0 for visible/invisible
;               LFONT = font for label widgets
;               BFONT = font for button widgets
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC),  22 January 1995
;
; Modified    : Changed location of newdata .pdm file.  CDP, 29-Jul-96
;
; Version     : Version 2, 29-Jul-96
;-

pro mk_cds_dbase,parent,dbase,map=map,lfont=lfont,bfont=bfont

if n_elements(map) eq 0 then map=1
mk_dfont,lfont=lfont,bfont=bfont

dbase=widget_base(parent,/column,map=map)

new_vers=float(strmid(!version.release,0,3)) ge 4.

row1=widget_base(dbase,/row)   

;-- col 1, row 1

col1=widget_base(row1,/column,/frame)   

temp2=widget_base(col1,/row)

temp=widget_base(col1,/row)
label=widget_label(temp,value= 'STUDY TITLE:',font=lfont)
study_title=cw_text(temp,value='   ',xsize=40,font=lfont,edit=0)

temp=widget_base(temp2,/row)
label=widget_label(temp,value='ACRONYM:',font=lfont)
obs_prog=cw_text(temp,value='     ',edit=0,xsize=8,font=lfont)

temp=widget_base(temp2,/row)
label=widget_label(temp,value='STUDY_ID:',font=lfont)
study_id=cw_text(temp,value='     ',edit=0,xsize=3,font=lfont)

temp=widget_base(temp2,/row)
label=widget_label(temp,value='STUDYVAR:',font=lfont)
studyvar=cw_text(temp,value='     ',edit=0,xsize=3,font=lfont)


temp=widget_base(col1,/row)
label = WIDGET_BUTTON(temp, value=' SCI_OBJ:', font=bfont,uvalue='bsci_obj',/no_rel)
sci_obj = WIDGET_TEXT(temp, value='', xsize=40,font=lfont,/edit,/all,uvalue='sci_obj')

temp=widget_base(col1,/row)
label = WIDGET_BUTTON(temp, value='SCI_SPEC:', font=bfont, uvalue='bsci_spec',/no_rel)
sci_spec = WIDGET_TEXT(temp, value='', xsize=40,font=lfont,/edit,uvalue='sci_spec',/all)

;-- col 2, row 1

col2=widget_base(row1,/column,/frame)   

obase=widget_base(col2,/row)
objectb=widget_button(obase,value=' OBJECT:',uvalue='object',font=bfont,/no_rel)
object=cw_text(obase,value='      ',xsize=6,font=lfont)

temp=widget_base(col2,/row)
label=widget_button(temp,value=   ' OBJ_ID:',font=bfont,uvalue='bobj_id',/no_rel)
obj_id=widget_text(temp,value='',xsize=6,font=lfont,uvalue='obj_id',/all,/edit)

;temp=widget_base(col2,/row)
;progb=widget_button(temp,value=   'PROG_ID:',uvalue='prgb',font=bfont,/no_rel)
;prog_id=cw_text(temp,value='',xsize=6,font=lfont,uvalue='prog_id')

temp=widget_base(col2,/row)
cmpb=widget_button(temp,value=    ' CMP_NO:',uvalue='cmpb',font=bfont,/no_rel)
cmp_no=cw_text(temp,value='',xsize=6,font=lfont,/all,/edit,$
               uvalue='cmp_no')


;-- col 3, row 1  (time widgets)

col3=widget_base(row1,/column,/frame)   

temp=widget_base(col3,/row)
start_lab=widget_label(temp,value='START_TIME:',font=lfont)
date_obs = cw_text(temp, value='       ',xsize=11,font=lfont)
time_obs = cw_text(temp, value='       ',xsize=12,font=lfont)

temp=widget_base(col3,/row)
stop_lab=widget_label(temp,value= ' STOP_TIME:',font=lfont)
date_end = cw_text(temp, xsize=11,/edit,uvalue='date_end',font=lfont)
time_end = cw_text(temp, xsize=12,/edit,uvalue='time_end',font=lfont)

temp=widget_base(col3,/row)
cur_lab=widget_label(temp,value=  '  CUR_TIME:',font=lfont)
date_cur = cw_text(temp, xsize=11, /edit,uvalue='date_cur',font=lfont)
time_cur = cw_text(temp, xsize=12, /edit,uvalue='time_cur',font=lfont)

temp=widget_base(col3,/row)
me_lab=widget_label(temp,value='  (TIME AT WHICH EDITED PLAN ENTRY WILL START)',font=lfont)

;-- row 2

row2=widget_base(dbase,/row)   

;-- col 1, row 2

col1=widget_base(row2,/column)
col1_1=widget_base(col1,/column,/frame)

temp=widget_base(col1_1,/row)
plab=widget_label(temp, value='POINTING MODE:    ',font=lfont)
pmode=cw_text(temp,value='        ',xsize=10,edit=0,font=lfont)

prep=widget_base(col1_1,/column)

;-- make two different pointing bases for SCIENCE and ENGINEERING pointings

ibase=widget_base(prep)
cbase=widget_base(ibase,/row)
ebase=widget_base(ibase,/row,map=0)
plab=widget_label(cbase,value= '# OF POINTINGS:   ',font=lfont)
n_pointings=cw_text(cbase,value='   ',xsize=4,/edit,font=lfont)

plab=widget_label(ebase,value= 'POINTING TYPE:   ',font=lfont)
choices=['INHERITED','DEFERRED']
if new_vers then e_pointings=call_function('widget_droplist',ebase,$
                 value=choices,font=bfont,uvalue='e_pointings') else $
e_pointings=cw_bselector2(ebase,choices, uvalue='e_pointings', $
                            /return_index,font=bfont,/no_rel)

;temp3=widget_base(col1_1,/row)
;rlab=widget_label(temp3,value= '# OF RASTERS:     ',font=lfont)
;n_rasters=cw_text(temp3,value='   ',uvalue='nrast',edit=0,xsize=4,font=lfont)

nrastb=widget_base(col1_1,/row)   
temp=widget_label(nrastb,value='REPEAT LAST RASTER:',font=lfont)
n_rasters1=cw_text(nrastb,value=' ',xsize=4,/edit,uvalue='n_rasters1',font=lfont)
temp=widget_label(nrastb,value='TIMES',font=lfont)


time_tagged_base=widget_base(col1_1,/column)
temp1=widget_base(time_tagged_base,/row)
xmenu2,['YES','NO'],title='TIME-TAGGED STUDY:',temp1,/row,/exclusive,font=lfont,$
      uvalue=['time_tag_yes','time_tag_no'],buttons=time_tagged,/no_rel,$
      lfont=lfont

temp2=widget_base(time_tagged_base,/row)
xmenu2,['YES','NO'],temp2,/row,font=lfont,title='ENFORCE 5% TIME-TAGGED RULE:',$
      uvalue=['rule_yes','rule_no'],buttons=rule_but,/exclusive,/no_rel,$
      lfont=lfont

;-- GSET ID stuff

col1_2=widget_base(col1,/column,/frame)
gset_base=widget_base(col1_2,/row)   
temp=widget_base(gset_base,/row)
gset_butt=widget_button(temp,font=bfont,value='GSET_ID: ',uvalue='gset_id',/no_rel)
gset_id=cw_text(temp,font=lfont,value='    ',xsize=4,edit=0)
temp=widget_base(gset_base,/row)
fil_lab=widget_label(temp,font=lfont,value='FIL_ID:')
fil_id_lab=cw_text(temp,font=lfont,value='    ',xsize=4,edit=0)

;-- ZONE ID stuff

zbase=widget_base(col1_2,/row)   

source=find_with_def('newdata_selection.pdm','CDS_PLAN_TECH')
if trim(source) eq '' then source=find_with_def('newdata_selection.pdm',!path)

if trim(source) ne '' then begin
 xpd=rd_ascii(source(0))
 xpd(0)='"ZONE_ID:" {'
 xpdmenu,xpd,zbase,font=bfont,base=zbutt
endif else zbutt=widget_label(zbase,value='NO ZONE FILE',/frame,font=lfont)
zmode=widget_text(zbase,value=strpad(' ',30),font=lfont,/frame)

;-- col 2, row 2

col2=widget_base(row2,/column,/frame)

;-- pointing slider

row22=widget_base(col2,/row)

pslider=widget_slider(row22,minimum=0,maximum=1,uvalue='pslider',$
                      title='Pointing Index',font=lfont)


temp=widget_label(row22,value='           ')

rslider=widget_slider(row22,minimum=0,maximum=1,uvalue='rslider',$
                      title='Raster Index',font=lfont)


;-- pointing text widgets

temp=widget_base(col2,/row)
 
temp1=widget_base(temp,/row)
junk=widget_base(temp1,row=2)
lab=widget_label(junk,value='X (arcsec):',font=lfont)
lab2=widget_label(junk,value='(+West/-East)',font=lfont)
ins_x=cw_text(temp1,value=' ',xsize=8,/edit,font=lfont)

temp2=widget_base(temp,/row)
junk=widget_base(temp2,row=2)
lab=widget_label(junk,value='Y (arcsec):',font=lfont)
lab2=widget_label(junk,value='(+North/-South)',font=lfont)
ins_y=cw_text(temp2,value=' ',xsize=8,/edit,font=lfont)


point_base=widget_base(col2,/column)

inhp_base=widget_base(point_base,/row)
inhb=widget_button(inhp_base,value='INHERIT ',$
                    font=bfont,/no_rel,/menu)
inhb_prev=widget_button(inhb,value='Previous ',uvalue='rotp_prev',$
                    font=bfont,/no_rel)
inhb_next=widget_button(inhb,value='Next ',uvalue='rotp_next',$
                    font=bfont,/no_rel)

junk=widget_label(inhp_base,value='plan pointing',font=lfont)

rotp_base = widget_base(point_base, /row)

rotp=widget_button(rotp_base,value='SOLAR ROTATE',$
                    font=bfont,/no_rel,/menu)
rotp1=widget_button(rotp,value='Relative to first pointing in current entry',uvalue='rotp',$
                    font=bfont,/no_rel)
rotp2=widget_button(rotp,value='Relative to last pointing of previous entry',uvalue='rotp_last',$
                    font=bfont,/no_rel)
rotp2=widget_button(rotp,value='Relative to matching pointing index of previous entry',uvalue='rotp_match',$
                    font=bfont,/no_rel)
rotp3=widget_button(rotp,value='Relative to pointing of selected plan entry',uvalue='rotp_sel',$
                    font=bfont,/no_rel)

junk=widget_label(rotp_base,value='pointing coordinates',font=lfont)

lastp_base=widget_base(point_base,/row)
lastp=widget_button(lastp_base,value='IMAGE_TOOL',uvalue='lastp',$
                    font=bfont,/no_rel)
junk=widget_label(lastp_base,value=' pointing history',font=lfont)

flatp_base=widget_base(point_base,/row)
flatp=widget_button(flatp_base,value='FLATFIELD',uvalue='flatp',$
                    font=bfont,/no_rel)
junk=widget_label(flatp_base,value=' pointing',font=lfont)

;temp=widget_base(col2,/row) 
;xmenu2,['ON','OFF'],temp,/row,font=lfont,title='FEATURE TRACKING:',/no_rel,$
;      uvalue=['tracking_yes','tracking_no'],buttons=tracking,/exclusive,$
;      lfont=lfont

;graw_base=widget_base(col2,/column)

;xmenu,['OBTAIN GIS RAW DATA'],temp,/row,/nonexclusive,font=lfont,$
;      uvalue=['get_raw_yes'],buttons=get_raw_id

;-- col3 , row 2

col2=widget_base(row2,/column)   

col2_1=widget_base(col2,/column,/frame)   

stemp=widget_base(col2_1,/column)

unit_str = strpad(['Seconds', 'Minutes', 'Hours'],8,/after)
ldur=widget_base(stemp,/row)
lab=widget_label(ldur,value='DURATION UNITS:',font=lfont)

if new_vers then $
 dur_unitb=call_function('widget_droplist',ldur,value=unit_str,uvalue='dur_unit',font=bfont) else $
  dur_unitb = cw_bselector2(ldur, unit_str, uvalue='dur_unit', /no_rel,/return_index,font=bfont)

durb=widget_base(stemp,/row)   
temp=widget_label(durb,value ='BASIC STUDY DUR:   ',font=lfont)

sduration=cw_text(durb,value='       ',edit=0,xsize=12,font=lfont)

pdurb=widget_base(stemp,/row)   
temp=widget_label(pdurb,value='ACTUAL PLAN DUR:   ',font=lfont)

pduration=cw_text(pdurb,value=' ',xsize=12,/editable,/all,uvalue='pduration',font=lfont) 

srep=widget_base(stemp,/row)   
temp=widget_label(srep,value= 'REPEAT PLAN:',font=lfont)
n_repeat_s=cw_text(srep,value='    1',xsize=4,/editable,$
                      uvalue='n_repeat_s',font=lfont)
temp=widget_label(srep,value='TIMES',font=lfont)


;-- FLAG receipt pointing

frp=widget_base(col2,/column)   

dummy=widget_base(frp)
repoint_base=widget_base(dummy,/column,map=0,/frame)
repoint=widget_button(repoint_base,value='FLAG REPOINT OPTIONS',$
                   font=bfont,/menu,/no_rel)
spoint=widget_button(repoint,value='Use Pointing Specified By Planner',$
                   uvalue='spoint',font=bfont,/no_rel)
ropt2=widget_button(repoint,value='Use Pointing From Flag Master',$
                   font=bfont,/menu,/no_rel)
ropt21=widget_button(ropt2,value='Do NOT Repoint If Flag Coordinates Outside FOV',$
                   font=bfont,uvalue='nrepoint',/no_rel)
ropt22=widget_button(ropt2,value='Repoint If Flag Coordinates Outside FOV',$
                   font=bfont,uvalue='repoint',/no_rel)
rmode=widget_text(repoint_base,xsize=20,value='  ',font=lfont,ysize=2,/frame)

;-- flags

flag_base=widget_base(dummy,/column,map=0,/frame)
temp=widget_base(flag_base,/row)
label=widget_button(temp,value='FLAG-MASTER_ID:',font=bfont,uvalue='flag_master',/no_rel)
flag_master=widget_text(temp,value=' ',xsize=3,font=lfont,/frame)

xmenu2,['SOHO-wide','CDS-local'],flag_base,/row,/exclusive,font=lfont,$
      uvalue=['SOHO-wide','CDS-local'],buttons=flag_type,/no_rel,lfont=lfont
junk=widget_label(flag_base,value='(NOT CURRENTLY USED)',font=lfont)

;-- save widget id's in structure

wids={ prog_id:0,$
       sci_obj:sci_obj,$
       sci_spec:sci_spec,$
       object:object,$
       obj_id:obj_id,$
       cmp_no:cmp_no,$
       start_lab:start_lab,$
       stop_lab:stop_lab,$
       cur_lab:cur_lab,$
       date_obs:date_obs,$
       date_end:date_end,$
       time_obs:time_obs,$
       time_end:time_end,$
       date_cur:date_cur,$
       time_cur:time_cur,$
       pduration:pduration,$
       dur_unitb:dur_unitb,$
       study_id:study_id,$
       studyvar:studyvar,$
       obs_prog:obs_prog,$
       flag_base:flag_base,$
       flag_master:flag_master,$
       flag_type:flag_type,$
       repoint_base:repoint_base,$
       point_base:point_base,$
       repoint:repoint,$
       rmode:rmode,$
;       get_raw_id:get_raw_id,$
       n_rasters1:n_rasters1,$
 ;      tracking:tracking,$
       study_title:study_title,$
       time_tagged:time_tagged,$
       time_tagged_base:time_tagged_base,$
       rule_but:rule_but,$
       n_repeat_s:n_repeat_s,$
       nrastb:nrastb,$
       srep:srep,$
       sduration:sduration,$
       ins_x:ins_x,$
       ins_y:ins_y,$
       n_pointings:n_pointings,$
       e_pointings:e_pointings,$
       pmode:pmode,$
       zmode:zmode,$
       zbase:zbase,$
       cbase:cbase,$
       ebase:ebase,$
       zbutt:zbutt,$
       gset_base:gset_base,$
       gset_id:gset_id,$
       fil_id_lab:fil_id_lab,$
;       n_rasters:n_rasters,$
       rslider:rslider,$
       lastp:lastp,$
       pslider:pslider}

widget_control,dbase,set_uvalue=wids

return & end


