;+
; Project     :	SOHO - CDS
;
; Name        :	REM_FST
;
; Purpose     :	Returns the indeces of the last occurring unique elements in the argument array.
;
; Explanation :	Allows removal of repeated elements in input array. Where elements are repeated
;               returns the index of the last occurring element.
;
; Use         : <rem_fst, vector>
;
; Inputs      : vector = input array.
;
; Opt. Inputs : None.
;
; Outputs     : indeces = indeces of unique elements.
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	None.
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	Version 0.0, Martin Carter, RAL, 24/5/95
;
; Modified    :	
;
; Version     :	Version 0.0, 24/5/95
;-
;**********************************************************

FUNCTION rem_fst, vector

  ; find last occurring unique values in vector

  ; get indeces of sorted values, maintaining order of repeated items

  indeces_0 = BSORT ( vector )
          
  ; find last indeces of repeated values

  indeces_1 = UNIQ ( vector ( indeces_0 ) )

  ; get corresponding indeces in vector

  indeces_2 = indeces_0 ( indeces_1 )

  RETURN, indeces_2

END
