;+
; Project     : SOHO - CDS     
;                   
; Name        : SET_CDS_SDB
;               
; Purpose     : append 'sdb' directories  to ZDBASE
;               
; Category    : Planning
;               
; Syntax      : IDL> set_cds_sdb
;    
; Side effects: Environment/logical ZDBASE is reset
;               
; History     : Version 1,  5-August-1997,  D M Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-            

pro set_cds_sdb,original=original,err=err,cds=cds

;-- only do this if within SSW

defsysv,'!ys_dpath',exists=defined
if not defined then return

err=''
common set_cds_zdb,orig_zdbase

if keyword_set(original) and is_string(orig_zdbase) then begin
 def_dirlist,'ZDBASE',orig_zdbase
 return
endif

status=0b
if keyword_set(cds) then status=fix_zdbase(/cds) 
if not status then status=fix_zdbase(/user)

zdb=chklog('ZDBASE')
if is_blank(orig_zdbase) then orig_zdbase=zdb

;-- check for SDB databases

sdb=chklog('sdb')
if sdb eq '' then sdb=chklog('SDB')
if sdb eq '' then sdb=chklog('SSWDB')
if sdb eq '' then begin
 err='sdb environmental not defined'
 return
endif
sdb_dir=sdb+'/soho/cds/data/plan/database'

;-- check if SDB already appended

spos=strpos(zdb,sdb_dir)
if spos gt -1 then return

;-- expand SDB subdirectories

sdbase=chklog('SDBASE')
if is_blank(sdbase) then begin
 if not is_dir(sdb_dir) then begin
  err='sdb root does not exist'
  return
 endif
 pdir='+'+sdb_dir
 u = find_all_dir(pdir,/path,/plus_required)
 def_dirlist,'SDBASE',u
 sdbase=chklog('SDBASE')
endif

if is_blank(zdb)  then zdbase=sdbase else zdbase=zdb+':'+sdbase

def_dirlist,'ZDBASE',zdbase

dprint,chklog('ZDBASE')

return & end
