;+
; Project     : SOHO - CDS
;
; Name        : XPORT
;
; Purpose     : widget interface to EXPORT_PLAN
;
; Category    : planning
;
; Explanation : 
;
; Syntax      : IDL> XPORT
;
; Inputs      : None
;
; Opt. Inputs : None
;
; Outputs     : None
;
; Opt. Outputs: 
;
; Keywords    : GROUP = widget id of calling widget
;               ERR = error string
;               STATUS = 0/1 if user aborted/proceeded with XPORT
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Version 1, 21-April-1997,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

 pro xport_event,event

 common xport_com,info

 widget_control, event.id, get_uvalue = uservalue
 wtype=widget_info(event.id,/type)
 if (n_elements(uservalue) eq 0) then uservalue=''

;-- check output path

 curr_path=info.path
 widget_control,info.wpath,get_value=path
 path=trim(path(0))
 xport_path,info.path,path,status,group=event.top
 if not status then return

 bname=strtrim(uservalue,2)

 case bname of

 'PATH' : begin
   path=info.path
   xinput,path,group=event.top,'Enter directory location for export file.'
   xport_path,info.path,path,status,group=event.top
  end

 'OPS1' : good=xvalidate(info,event,/bytag)

 'OPS2' : good=xvalidate(info,event,/bytag)

 'QUIT' : begin
   xtext_reset,info
   xkill,event.top
  end

 'RESET': begin
   info.ops1=info.def_ops1 & info.ops2=info.def_ops2
   info.path=info.def_path
   widget_control,info.wops1,set_value=tai2utc(info.ops1,/ecs,/vms)
   widget_control,info.wops2,set_value=tai2utc(info.ops2,/ecs,/vms)
   widget_control,info.wpath,set_value=info.path
   widget_control,info.wmess,set_value=''
  end
 
 'PREVIEW': begin
   good=xvalidate(info,event,/bytag)
   sci=(event.id eq info.pre_sci)
   cds_plan_brief,info.ops1,info.ops2,group=event.top,nobs=nobs,/acr,/det,$
    sci=sci,/point
   if exist(nobs) then begin
    if nobs eq 0 then begin
     if sci then err='No SCIENCE plans during specified period' else $
      err='No DETAILED plans during specified period' 
     xack,err,group=event.top
     return
    endif
   endif
  end 

else:do_nothing=1 
 endcase

;-- check times before running

 if bname eq 'RUN' then begin
  good=xvalidate(info,event,/bytag)
  if good then begin
   widget_control,/hour
   widget_control,info.wmess,set_value='Please wait. Exporting plans...'
   err=''
   export_plan,info.ops1,info.ops2,file=file,path=info.path,err=err
   xshow,event.top
   info.status=1
   if err ne '' then xack,err,group=event.top else begin
    widget_control,info.wmess,set_value='Export file written to: '+file,/app
    xtext,'Export completed',wait=2,/just_reg
   endelse
  endif
 endif

 return & end

;-----------------------------------------------------------------------------

pro xport_path,curr_path,path,status,group=group

common xport_com

status=1
if not chk_dir(path) then begin
 xack,'Non-existent directory: '+path,group=group
 widget_control,info.wpath,set_value=curr_path
 return
endif

if not test_open(path,/write,/quiet) then begin
 xack,'No write access to: '+path,group=group
 widget_control,info.wpath,set_value=curr_path
 return
endif 

info.path=path
widget_control,info.wpath,set_value=info.path

return & end

;-----------------------------------------------------------------------------

pro xport,tstart,tend,status=status,group=group,err=err,modal=modal,last=last

common xport_com

;-- defaults                  

select_windows
if not have_widgets() then begin
 message,'widgets unavailable',/cont
 return
endif

caller=get_caller(stat) 
if stat and (not xalive(group)) then xkill,/all
modal=keyword_set(modal)
if (not modal) and (xregistered('xport') ne 0) then return

status=0

;-- check input times

tgap=1.d-2
secs_per_day=24l*3600l
last=keyword_set(last)
get_utc,ops1 & ops1.time=0
ops2=ops1
ops2.mjd=ops1.mjd+1
ops1=utc2tai(ops1)
ops2=utc2tai(ops2)-tgap
dtime=[ops1,ops2]
ctime=[0.d,0.d]
if datatype(info) eq 'STC' then begin
 if tag_exist(info,'ops1') then ctime(0)=info.ops1
 if tag_exist(info,'ops2') then ctime(1)=info.ops2
endif

;-- export file location

def_path=trim(getenv('CDS_EXPORT_W'))
cd,curr=curr
if def_path eq '' then def_path=curr
if not test_open(def_path,/write,/quiet) then begin
 if test_open(curr,/write,/quiet) then def_path=curr else $
  def_path=getenv('HOME')
endif

;-- create widgets

mk_dfont,lfont=lfont,bfont=bfont

wbase=widget_base(title='XPORT',/column)

row1=widget_base(wbase,/row,/frame)

quit=widget_button(row1,value='DONE',uvalue='QUIT',font=bfont,/no_rel)
reset=widget_button(row1,value='RESET',uvalue='RESET',font=bfont,/no_rel)
preview=widget_button(row1,value='PREVIEW PLANS',font=bfont,/no_rel,/menu)
pre_det=widget_button(preview,value='PREVIEW DETAILED PLANS',uvalue='PREVIEW',font=bfont,/no_rel)
pre_sci=widget_button(preview,value='PREVIEW SCIENCE PLANS',uvalue='PREVIEW',font=bfont,/no_rel)

ok=widget_button(row1,value='EXPORT NOW',uvalue='RUN',font=bfont,/no_rel)

row2=widget_base(wbase,/column,/frame)

wops1=cw_field(row2, Title= 'START TIME:   ',fieldfont=bfont,$
                     /ret, xsize = 24, font = bfont,uvalue='OPS1')

wops2=cw_field(row2,  Title='STOP TIME:    ',fieldfont=bfont,$
                     /ret, xsize = 24, font = bfont,uvalue='OPS2')

row3=widget_base(wbase,/row)
wbutt=widget_button(row3,value='EXPORT LOCATION:',font=bfont,uvalue='PATH',/frame)
wpath=widget_text(row3,value='',font=bfont,/edit,xsize=24)

wlab=widget_label(wbase,value='MESSAGES',font=lfont)
wmess=widget_text(wbase,ysize=5,font=lfont)

;-- create info structure

wids={wops1:wops1,wops2:wops2,wmess:wmess,wpath:wpath,pre_det:pre_det,pre_sci:pre_sci}

def_info={wops1:wops1,wops2:wops2,wmess:wmess,wpath:wpath,def_path:def_path,$
          def_ops1:dtime(0),def_ops2:dtime(1),ops1:ops1,ops2:ops2,$
          path:def_path,pre_det:pre_det,pre_sci:pre_sci,status:0}

;-- try to recover last setup

if datatype(info) eq 'STC' then begin
 if not match_struct(info,def_info,/tags) then info=def_info
endif else info=def_info

copy_struct,wids,info
times=pick_times(tstart,tend,ctime=ctime,dtime=dtime,last=last)
info.ops1=times(0) & info.ops2=times(1)
info.status=0
 
widget_control,wops1,set_value=tai2utc(info.ops1,/ecs,/vms)
widget_control,wops2,set_value=tai2utc(info.ops2,/ecs,/vms)
widget_control,wpath,set_value=info.path

;-- realize and center main base

xrealize,wbase,group=group,/center 

xmanager,'xport',wbase,group=group,modal=modal

xmanager_reset,wbase,group=group,modal=modal,crash='xport'

xshow,group

status=info.status

return & end



