;+
; Project     : SOHO - CDS
;
; Name        : XPROGRAM
;
; Purpose     : widget interface to program database
;
; Category    : operations, widgets
;
; Explanation :
;
; Syntax      : IDL> XPROGRAM,PROG_ID
;
; Inputs      : None
;
; Opt. Inputs : None
;
; Outputs     : PROG_ID
;
; Opt. Outputs: None
;
; Keywords    : GROUP = widget ID of any calling widget
;
; Common      : None
;
; Restrictions: None.
;
; Side effects: None.
;
; History     : Version 1,  6-Jan-1996,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-

 pro xprogram_event,  event                         ;event driver routine

 on_error,1

;-- extract values passed as UVALUES in bases

 widget_control, event.top, get_uvalue = unseen
 info=get_pointer(unseen,/no_copy)
 if datatype(info) ne 'STC' then return 

 widget_control, event.id, get_uvalue = uservalue
 wtype=widget_info(event.id,/type)
 if (n_elements(uservalue) eq 0) then uservalue=''
 bname=strtrim(uservalue,2)
 still_alive=1

;-- list event

 if event.id eq info.alist then begin
  bname=bname(event.index)
  info.prog_id=fix(bname)
 endif

;-- button events

 case bname of 

  'exit': begin
    if event.id eq info.exit2 then info.select=1 else info.select=0
    xkill,event.top
    still_alive=0
   end

  'add': begin
    xprogram_add,prog_id,group=event.top,saved=saved
    if saved then begin
     info.prog_id=prog_id
     xprogram_list,info
    endif
   end

  'view': begin
    xprogram_add,info.prog_id,group=event.top
   end

  else:do_nothing=1
 endcase

;-- update living widgets

 if still_alive then begin
  widget_control,info.viewb,sensitive=(info.prog_id gt 0)
  widget_control,info.exit2,sensitive=(info.prog_id gt 0)
 endif
 
 set_pointer,unseen,info,/no_copy
 return & end

;--------------------------------------------------------------------------- 

pro xprogram_list,info

list_program,programs,nf

if nf eq 0 then begin
 lines='No entries in program database''
 sens=0 & prog_id='0'
endif else begin
 lines=strarr(nf)
 prog_id=strtrim(string(programs.prog_id,'(i3)'),2)
 for i=0,nf-1 do begin
  lines(i)=' '+strpad(prog_id(i),/aft,10)+strpad(programs(i).progname,10,/aft)
  sens=1
 endfor
endelse

widget_control,info.alist,set_value=lines,set_uvalue=prog_id
widget_control,info.alist,sensitive=sens

if nf gt 0 then begin
 clook=where(info.prog_id eq programs.prog_id,count)
 if count eq 1 then begin
  widget_control,info.alist,set_list_select=clook(0)
 endif
endif
return & end

;--------------------------------------------------------------------------- 

pro xprogram,prog_id,group=group,status=status

on_error,1

;-- defaults

if not have_widgets() then begin
 message,'widgets unavailable',/cont
 return
endif

caller=get_caller(stat)
if stat and (not xalive(group)) then xkill,/all

if not exist(prog_id) then prog_id=0

;-- load fonts

mk_dfont,lfont=lfont,bfont=bfont

;-- make widgets

status=0
wbase=widget_base(title='XPROGRAM',/column)

row1=widget_base(wbase,row=1,/frame)

;-- operation buttons

exitb=widget_button(row1,value='EXIT',font=bfont,/no_rel,/menu)
exit2=widget_button(exitb,value='Exit with current selection',uvalue='exit',font=bfont,/no_rel)
exit1=widget_button(exitb,value='Exit with no selection',uvalue='exit',font=bfont,/no_rel)
newb=widget_button(row1,value='ADD NEW PROGRAM',uvalue='add',font=bfont,/no_rel)
viewb=widget_button(row1,value='VIEW SELECTED PROGRAM',uvalue='view',font=bfont,/no_rel)
widget_control,viewb,sensitive=0
widget_control,exit2,sensitive=(prog_id gt 0)

;-- program list

mlabel=strpad('PROG. ID',10,/aft) +' '+strpad('NAME',10,/aft)
alabel=widget_list(wbase,value=mlabel,font=lfont,ysize=1,/frame)
alist=widget_list(wbase,value='',font=lfont,ysize=20)

;-- realize and center main base

xrealize,wbase,group=group,/center

;-- stuff info structure into pointer

make_pointer,unseen
info = $
 {viewb:viewb,alist:alist,prog_id:prog_id,exit1:exit1,exit2:exit2,select:0}

xprogram_list,info

set_pointer,unseen,info,/no_copy
widget_control,wbase,set_uvalue=unseen

xmanager,'xprogram',wbase,group=group,/modal
xmanager_reset,wbase,group=group,/modal

info=get_pointer(unseen,/no_copy)

;-- clean-up

if datatype(info) eq 'STC' then begin
 status=info.select
 if info.select then prog_id=info.prog_id
endif
free_pointer,unseen
 
return & end

