;+
; Project     :	SOHO - CDS
;
; Name        :	XSHOW_RASTER
;
; Purpose     : Widget display of CDS rasters 
;
; Use         : xshow_raster,raster
;
; Inputs      : None.
;
; Opt. Inputs : None.
;
; Outputs     : RASTER = structure with primary raster information for
;                        last selected primary raster.
;               VRASTER = stucture with raster variation information for
;                        last selected raster variation
;
; Opt. Outputs: None.
;
; Keywords    :
;              GROUP    = event id of widget that calls xshow_raster
;              DET      = 'N' or 'G' to filter out NIS or GIS detector rasters
;              IRASTER  = input primary raster
; Explanation :
;              Arranges structures in a matrix format with the tag
;              name in label widget and the tag value in a text widget.
;              If wbase and wtags exist, then widget is just updated
;              with input field values.
;
; Calls       : xstruct
;
; Common      : xshow_raster = contains private widget id's
;
; Restrictions: None.
;
; Side effects: None.
;
; Category    : Widgets
;
; Prev. Hist. : None.
;
; Written     :	Version 1, Zarro (ARC/GSFC) 23 August 1994
;
; Modified    : Version 1.1, Zarro (ARC/GSFC) 24 August 1994
;               Added raster variation widget.
;               Version 2 , Zarro (ARC/GSFC) 10 September 1994
;               Added optional input primary raster IRASTER
;		Version 3, William Thompson, GSFC, 5 July 1996
;			Add RAS_ID to widget list
;
; Version     : Version 3, 5 July 1996
;-

pro xshow_raster_event,  event                         ;event driver routine

common xshow_raster,prast,vrast,sel_raster,sel_vraster,$
       prlist,vrlist,wtags,wbase,wvtags,wvbase,wsize,woff


widget_control, event.id, get_uvalue = uservalue

if (n_elements(uservalue) eq 0) then uservalue=''
wtype=widget_info(event.id,/type)

if uservalue eq 'close' then xkill,event.top

;-- list events

if wtype eq 6 then begin

;-- list primary variations

 if event.id eq prlist then begin
  if n_elements(wvbase) eq 0 then wvbase=0l
  xhide,wvbase
  sel_raster=prast(event.index)
  list_v_raster,sel_raster.ras_id,vrast,nfound
  if nfound eq 0 then begin
   widget_control,vrlist,set_value='NO RASTER VARIATIONS FOUND'
   widget_control,vrlist,sensitive=0
   return
  endif else begin
   widget_control,vrlist,/sensitive
   widget_control,vrlist,set_value='RAS_VAR: '+strtrim(string(vrast.ras_var),2)+' / '+vrast.rv_desc
  endelse

  xstruct,sel_raster,nx=1,/just_reg,group=event.top,$
          wtags=wtags,wbase=wbase,xoff=woff(0)+wsize(0),yoff=woff(1)
 endif

;-- list raster variations

 if event.id eq vrlist then begin
  sel_vraster=vrast(event.index)
  xstruct,sel_vraster,/just_reg,group=event.top,$
          wtags=wvtags,wbase=wvbase,xoff=woff(0)+wsize(0),yoff=woff(1)+.5*wsize(1)
 endif

endif

return & end

;------------------------------------------------------------------------------

pro xshow_raster,raster,vraster,group=group,$
               det=det,iraster=iraster,modal=modal

common xshow_raster,prast,vrast,sel_raster,sel_vraster,$
       prlist,vrlist,wtags,wbase,wvtags,wvbase,wsize,woff

on_error,1

if not have_widgets() then begin
 message,'widgets are unavailable',/cont
 return
endif

caller=get_caller(stat)
if stat and (not xalive(group)) then xkill,/all

;-- create main base

main = widget_base(title ='CDS RASTER DISPLAY',/column)

;-- button widgets

mk_dfont,bfont=bfont
row=widget_base(main,/row,/frame)
closeb=widget_button(row,value='Close',uvalue='close',/no_release,/frame,font=bfont)

;-- get primary rasters

nvfound=0
if datatype(iraster) ne 'STC' then begin
 list_f_raster,prast,nfound,det=det
endif else begin
 prast=iraster
 nfound=n_elements(prast)
endelse

if nfound eq 0 then begin
 message,'no primary rasters found',/contin
 return
endif

label=widget_label(main,value='PRIMARY RASTERS')
prlist=widget_list(main,value='RAS_ID: '+strtrim(string(prast.ras_id),2)+$
	' / '+prast.ras_desc,ysize=10)

;-- list of raster variations

label=widget_label(main,value='RASTER VARIATIONS')
vrlist=widget_list(main,value='',ysize=10)

;-- realize and manage

widget_control,main,/realize
widget_control,main,tlb_get_size=wsize,tlb_get_off=woff

if nfound eq 1 then begin
 list_v_raster,prast.ras_id,vrast,nvfound
 xstruct,prast,nx=1,/just_reg,$
           wtags=wtags,wbase=wbase,xoff=woff(0)+wsize(0),yoff=woff(1)
endif

if nvfound gt 0 then begin
 widget_control,vrlist,set_value='RAS_VAR: '+strtrim(string(vrast.ras_var),2)+' / '+vrast.rv_desc
 if nvfound eq 1 then begin
  xstruct,vrast,/just_reg,$
   wtags=wvtags,wbase=wvbase,xoff=woff(0)+wsize(0),yoff=woff(1)+.5*wsize(1)
 endif
endif

xmanager,'xshow_raster',main ,group_leader=group,/modal
if xalive(main) then xmanager

;-- return last selected raster

if n_elements(sel_raster) ne 0 then raster=sel_raster
if n_elements(sel_vraster) ne 0 then vraster=sel_vraster

return & end



