;+
; Project     : SOHO - CDS     
;                   
; Name        : CAL_SEQ_EVENT
;               
; Purpose     : Processes events from the CAL_SEQ_MENU.
;               
; Explanation : Any events originating within the widgets realized by 
;               CAL_SEQ_MENU are handled by this routine.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ev  -  the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with CAL_SEQ_MENU in EGSE sci_ana routines.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 21-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 21-Dec-93
;-            

PRO cal_seq_event, ev

;
;  COMMON blocks for widget id's
;
@MainWidgets.com
@CalSeq.com
@CalFits.com
      
;
;  interpret type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  could have been a BUTTON
;                    ======
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value, get_uvalue=uvalue
 
;
;  Done (ie exit) request received
; 
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, cal_seq_base, /destroy
   ENDIF

;
;  Reset request received
; 
   IF (value EQ 'Reset') THEN BEGIN
      seq_text = 0
      WIDGET_CONTROL, cal_seq_base, /destroy
   ENDIF

ENDIF

;
;  or it could have been one of the SLIDERS
;                                   =======
;
if type eq 'WIDGET_SLIDER' then begin
  WIDGET_CONTROL, ev.id, GET_VALUE=value, get_uvalue=uvalue
;
;  it was setting the lower serial number to be displayed
;
  if uvalue eq 'Ser#_min' then begin
     seq_list_min = value
     if seq_list_min ge seq_list_max then begin
        seq_list_min = seq_list_max - 1
        widget_control, cal_seq_min_id, set_val=seq_list_min
     endif
  endif else begin
;
;  it was setting the higher serial number to be displayed
;
     seq_list_max = value
     if seq_list_max le seq_list_min then begin
        seq_list_max = seq_list_min + 1
        widget_control, cal_seq_max_id, set_val=seq_list_max
     endif
  endelse
  
;
;  find where these serial numbers are in the text list
;
  n = where((strmid(seq_text,0,10) ge seq_list_min) and $
            (strmid(seq_text,0,10) le seq_list_max))

;
;  there are gaps in the list numbers so beware
;
  if n(0) ge 0 then begin

;
;  extract them from the main list
;
     seq_n1 = min(n) & seq_n2 = max(n)
     texta = seq_text(seq_n1:seq_n2)

;
;  for the text list to be displayed, set a '.' in the repeat lines.
;
     for i=0,n_elements(texta)-1 do begin
        if strmid(texta(i),0,10) eq '      -1  ' then texta(i) = '       .  '+$
                                  strmid(texta(i),10,strlen(texta(i))-10)
     endfor

;
;  display the requested list
;
     widget_control,seq_list_id,set_val=texta

  endif else begin
     texta = ' '
     widget_control,seq_list_id,set_val=texta
  endelse   

endif

;
;  or it was an INDEX input from the list itself
;               =====
;
if type eq 'WIDGET_LIST' then begin

   line = seq_text(ev.index+seq_n1)

   a = str_sep(line,' ')
   a = a(where(a ne ''))

;
;  was it a valid choice, ie not one of the repeat lines?
;
   if n_elements(a) lt 8 then begin
      bell
      widget_control,msg_widg,/append,set_v='Not a valid choice.'
   endif else begin
      cal_file_id = a(9)
      cal_ser_num = strmid(string(fix(a(0))+10000,form='(i5)'),1,4)
      cal_ras_cnt = '000'
      status = 1  & count = 0
      while status eq 1 do begin
         cal_vers = strmid(string(count+100,form='(i3)'),1,2)
         cal_fits_file = cal_file_id+'_'+cal_ser_num+'_'+$
                         cal_ras_cnt+'.'+cal_vers
         status = check_cal_file(cal_fits_file)
         count = count + 1
      endwhile
      if writing_fits then widget_control,fitsfile_widg,set_val=cal_fits_file
;
;  display info from the cal_log.txt file
;
      rast = strmid(string(a(2)+10000,form='(i5)'),1,4)
      stext = 'filr.'+rast+'.dt'

      openr,lun,concat_dir('$CDS_PLAN_TECH','cal_log.txt'),/get_lun,error=err
      if err ne 0 then begin
         bell
         widget_control, msg_widg, /append, set_val='Cannot open cal_log.txt'
         return
      endif else begin
         text = ' '
         while not eof(lun) do begin
            readf,lun,text
            if strpos(text,stext) ge 0 then begin
               widget_control, msg_widg, /append, set_val=' '
               widget_control, msg_widg, /append, set_val=' '
               widget_control, msg_widg, /append, $
                   set_val=string('============ Seq ID ',a(0),' =============',$
                                  form='(a,i4,a)')
               widget_control, msg_widg, /append, $
                      set_val=string('Using raster #',rast,form='(a,i2)')
               widget_control, msg_widg, /append, set_val=' '
               widget_control, msg_widg, /append, $
                                             set_val=strmid(text,30,70)
               while strlen(text) ne 0 and not eof(lun) do begin
                  readf,lun,text
                  if strlen(text) gt 10 then begin
                     widget_control, msg_widg, /append, $
                                     set_val=strmid(text,30,70)
                  endif
               endwhile
               free_lun, lun
               widget_control, msg_widg, /append, $
                            set_val='======================================'
               return
            endif
         endwhile
         free_lun, lun
      endelse
   endelse
endif

END
