;+
; Project     : SOHO - CDS     
;                   
; Name        : CAL_SEQ_MENU
;               
; Purpose     : Defines the science analyser calibration sequence window.
;               
; Explanation : Creates the widgets which form the window within which
;               the calibration sequences can be selected.
;               
; Use         : cal_seq_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE sci_ana programs only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 21-Dec-93
;               
; Modified    : Put in Reset button, CDP 8-Mar-94
;
; Version     : Version 2, 8-Mar-94
;-            

PRO cal_seq_menu

;
;  COMMON blocks for widget id communication
; 
@MainWidgets.com
@CalSeq.com

;
;  guard against trigger happy users
;
if xregistered('cal_seq') then begin
   widget_control,msg_widg,set_val='One click will do thanks!',/append
   return
endif

;
;  create main base
;
cal_seq_base = WIDGET_BASE(title='Calibration sequence selection',$
                           /FRAME, /COLUMN, xoffset=700,$
                           group_leader = main_base)

;
;  and subsidiary ones
;
menu_base  = WIDGET_BASE(cal_seq_base, /COLUMN)
m1_widg    = WIDGET_BASE(menu_base, /ROW)


;
;  open and read the data file (set a -1 in place of the blank serial number
;  on repeat lines.
;
if datatype(seq_text,1) ne 'String' then begin
   bell
   widget_control,msg_widg,/append,$
                  set_val='Reading in sequence data file....please wait.'
   seq_text = strarr(10000)
   line = ' '
   openr,lun,concat_dir('$CDS_PLAN_TECH','cal_table.dt'),/get_lun,error=err

;
;  deal with error
;
   if err ne 0 then begin
      widget_control,msg_widg,/append,set_val='Failed to open CAL_TABLE.DT'
      seq_text = 0
      return
   endif

   i = 0
   while not EOF(lun) do begin
      readf,lun,line
      if strmid(line,0,10) eq '          ' then line = '      -1  '+$
                                strmid(line,10,strlen(line)-10)
      if strmid(line,0,1) ne '#' then begin
         seq_text(i) = line
         i = i + 1
      endif
   endwhile
   free_lun,lun

;
;  trim to only needed space
;
   seq_text = seq_text(where(seq_text ne ''))

;
;  find maximum serial number
;
   max_seq_id = max(strmid(seq_text,0,10))
 
endif


;
;  pick out the lines where required range is
;
if seq_list_max eq 0 then seq_list_max = max_seq_id
n = where((strmid(seq_text,0,10) ge seq_list_min) and $
          (strmid(seq_text,0,10) le seq_list_max))

;
;  and store the range of records to be used
;
seq_n1 = min(n) & seq_n2 = max(n)

;
;  and the actual list to be displayed
;
texta = seq_text(seq_n1:seq_n2)

;
;  and for display purposes put a '.' for the repeat lines serial number
;
for i=0,n_elements(texta)-1 do begin
   if strmid(texta(i),0,10) eq '      -1  ' then texta(i) = '       .  '+$
                             strmid(texta(i),10,strlen(texta(i))-10)
endfor
;
;  form the widgets
;
;
;  first the 'Done' button to exit
;
doneid = widget_button(m1_widg, value='Done')

;
;  then the clear and exit
;
clearid = widget_button(m1_widg, value='Reset')


;
;  and sliders for setting range displayed
;
if (seq_list_min lt 16) or (seq_list_min gt max_seq_id) then seq_list_min = 16
cal_seq_min_id = widget_slider(menu_base,title='Start serial number',$
                               min=16,max=max_seq_id,$
                               value=seq_list_min,uvalue='Ser#_min')

if (seq_list_max lt 16) or (seq_list_max gt max_seq_id) then $
                             seq_list_max = max_seq_id
cal_seq_max_id = widget_slider(menu_base,title='End serial number',$
                               min=16,max=max_seq_id,$
                               value=seq_list_max,$
                               uvalue='Ser#_max')


;
;  and the list widget to display the list
;
seq_list_id = widget_list(menu_base, value=texta, ysize=50)




;
;  make it all appear
;
WIDGET_CONTROL, cal_seq_base, /realize

end
