;+
; Project     : SOHO - CDS     
;                   
; Name        : CALIBRATION*
;               
; Purpose     : Main code to run the EGSE science analysis.
;               
; Explanation : A main code to set up the structures and declare and initialise
;               the variables used in the EGSE science analysis.
;               
; Use         : .run calibration
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : Based on normal sci_ana
;
; Written     : C D Pike, RAL, 16-Dec-93
;               
; Modified    : Split rasterlength in scihead to 2 single bytes (mirror,slit)
;               CDP, 9-Feb-94
;               Cater for hex bug, CDP, 1-6-99
;
; Version     : Version 3, 1-Jun-99
;-            

;
;  load all the COMMON blocks used throughout the program
;
@Decomp.com
@GISWidgets.com
@HeaderWidgets.com
@IO_units.com       
@Images.com
@Mode.com
@Packets.com
@Rawscience.com
@ReviewWidgets.com
@SpecialWidgets.com
@VDSWidgets.com
@MainWidgets.com
@VDSData.com
@GISData.com
@RawData.com
@CalFits.com
@GAS_Details.com
@CalSeq.com
@Profiles.com
@Cal_Lines.com
@Monitor.com
@Posn_Details.com

;-----------------------------------------------------------------------------
; Define structures for version 3.0 of CDS science data stream packet format
;-----------------------------------------------------------------------------
; Logic of packet reading is .....
;
; a) Read packet_header (20 bytes)
; b) Test value of .ID
;    if '2'xl then read_VDS_raster  (286 bytes)  ie total = 20+286   = 306 bytes
;    if '1'xl then read_GIS_raster  (286 bytes)  ie total = 20+286   = 306 bytes
;    if '11'xl or '12'xl then read_sci_cnt (2 bytes) 
;       then read_exp_hdr (284 bytes)              total = 20+2+284 = 306 bytes
;    if '21'xl or '22'xl then read_sci_cnt (2 bytes) 
;       then read_science_packet (284 bytes)       total = 20+2+284 = 306 bytes
;    else read_data (286 bytes)                    total = 20+286   = 306 bytes 
;-----------------------------------------------------------------------------
;
;General packet header structure
;
PacketHeader = {PacketHeaderDef,                $
                Msgid:               FIX(0),    $
		MsgLen:              FIX(0),    $
		MsgReqid:            FIX(0),    $    
		ap_id:               BYTARR(2), $
		counter:             FIX(0),    $
		length:              FIX(0),    $
		Time:                BYTARR(6), $
		ID:                  BYTE(0),   $
		StreamPacketCounter: BYTE(0)}

;
;Define Science data header
;
SciHeader = {SciHeaderDef, $
		StudyID:               BYTE(0),   $
		DataCompScheme:        BYTE(0),   $ 
		DataExtWindowID:       FIX(0),    $
		SequenceID:            FIX(0),    $
		RasterLengthM:         BYTE(0),   $
		RasterLengthS:         BYTE(0),   $
		OPSLCoordinate:        FIX(0),    $
		OPSRCoordinate:        FIX(0),    $
                SlitPosition:          FIX(0),    $
		SlitNumber:            BYTE(0),   $
		MirrorPosition:        BYTE(0),   $
		ExposureTime:          FIX(0),    $
		StudyCounter:          FIX(0),    $
		RasterCounter:         FIX(0),    $
                DataCompOption:        FIX(0),    $
                SciProcStatus:         FIX(0)}

;
;Exposure header
;
;  remember the 2 byte packet counter which could be in here at the beginning
;  is actually read in read_sci_cnt on its own
;
Exphdr= {ExpHeaderDef, $
		SolarX:                FIX(0),      $
		ExposureStart:         BYTARR(6),   $
		ExposureNumber:        FIX(0),      $
		OPSLCoordinate:        FIX(0),      $
		OPSRCoordinate:        FIX(0),      $
		SlitPosition:          FIX(0),      $
                SunSensorPitch:        FIX(0),      $
                SunSensorYaw:          FIX(0),      $
                SolarY:                FIX(0),      $
                MirrorPosition:        BYTE(0),     $
                EventStatus:           BYTE(0),     $
                EventLevel:            FIX(0),      $
		StudyCounter:          FIX(0),      $
		RasterCounter:         FIX(0),      $
                Science:               BYTARR(252), $
		ChkSum:                FIX(0)}

;
; VDS Window Data.
;
VDSWindow = {VDSWdw, $
                StartX:  FIX(0),$
                StartY:  FIX(0),$
                LengthX: FIX(0),$
                LengthY: FIX(0)}

;
;GIS Window Data
;
GISWindow = {GISWdw,            $
		Start:  FIX(0), $
		Length: FIX(0)}


;
;VDS raster packet
;
VDSrasterhdr = {VDSrasterdef,                                 $
		Scihead:              {SciHeaderDef},         $
                BinFactorXY:          BYTE(0),                $
                NumDataWindows:       BYTE(0),                $
		VDSWin :              REPLICATE({VDSWdw},32), $
		Chksum:               FIX(0)}

;				
;GIS raster packet 
;
GISrasterhdr = {GISrasterdef,                                 $
		Scihead:              {SciHeaderDef},         $
                Spare1:               BYTARR(12),             $
                NumDataWindows:       FIX(0),                 $
		GISWin :              REPLICATE({GISWdw},61), $
		Chksum :              FIX(0)}
	


;
;  science packet - remember again that the packet counter is read separately
;  and is therefore not included here. 
;
Sci_Packet = {SciPacketDef, $
              ExpNumber:     FIX(0),            $
              StudyCounter:  FIX(0),            $
              RasterCounter: FIX(0),            $
              Data:          BYTARR(276),       $
	      Chksum:        FIX(0)}	

;
;  any packet ie a dummy read for any unwanted packets
;
Any_Packet = {AnyPacketDef, $
              Data: BYTARR(286)}


;
;  a structure to keep check of the VDS data and its display
;
vds_data_str = {vds_data_rec,$
            vds_exp:        fix(-1), $           ; last exposure read
            max_in_mem:     fix(0),  $           ; max number of exp in memory
            exp_in_a:       fix(-1), $           ; exp displayed in window A
            exp_in_b:       fix(-1), $           ; exp displayed in window B
            first_in_mem:   fix(0),  $           ; first exp in memory
            last_in_mem:    fix(-1), $           ; last exp in memory
            curr_a_img:     intarr(1024,1024),$  ; image array in A
            curr_b_img:     intarr(1024,1024)}   ; image array in B
            

;
;  a structure to keep check of the GIS data and its display
;
gis_data_str = {gis_data_rec,$
            gis_exp:        fix(-1), $           ; last exposure read
            exp_in_a:       fix(-1), $           ; exp displayed in window A
            exp_in_b:       fix(-1), $           ; exp displayed in window B
            gis_plot_wave:  fix(0),  $           ; pixel(0) or lambda(1) plot
            gis_plot_linear:fix(1),  $           ; linear(1) or log(0) plot
            agis_last_x:    fltarr(2),  $        ; last window in A
            bgis_last_x:    fltarr(2),  $        ; last window in B
            gis_select:           'A',  $        ; display selected
            agis_plot_choice: bytarr(5),$        ; which bands in A selected
            bgis_plot_choice: bytarr(5),$        ; which bands in B selected
            curr_a_data:    intarr(8192),$       ; spectrum in A
            curr_b_data:    intarr(8192)}        ; spectrum in B

;
; Initialize buffers and flags
;
sci_writettr = LONG(0)
sci_readptr  = LONG(0)
sci_mode     = FIX(0)
sci_pause    = FIX(0)
sci_going    = FIX(0)
cds_mode     = FIX(0)
reviewing    = FIX(0)
review_stats = INTARR(30)
new_rev_stat = FIX(-1)
raw_gis_data = bytarr(286)
raw_vds_data = bytarr(286)
;
; initialize images and plots 
;
have_v_rst_hdr  =  0
have_v_exp_hdr =  0
have_g_rst_hdr =  0
have_g_exp_hdr =  0
header_select  =  0
gis_display    =  0
vds_display    =  0
header_format  =  1
special_format =  2
raw_format     =  2
raw_gis_request = 0
raw_vds_request = 0
raw_gis_file   = ''
raw_gis_dump   =  0
raw_gis_display = 1
raw_vds_file   = ''
raw_vds_dump   =  0
sp_request     =  0
packet_no      = LONG(0)
last_packet    =  0
last_pkt_id    =  0
last_sci_cnt   =  0
sp_def_cnt     = -1
writing_fits   =  1
gasid = 'None'
gasvoltage = 0
gascurrent = 0.0
gaspressure = 0
seq_list_min = 16
seq_list_max = 0
cal_fits_file = 'None_0000_000.00'
plotting_prof = 0
plen_fac = 1
maxvala = 0
maxvalb = 0
last_window = ' '
disp_vds_lines = 0
disp_gis_lines = 0
vm_count = -1
gm_count = -1
opsl_count = -1
opsr_count = -1
slitn_count = -1
slitp_count = -1
mirrp_count = -1
v_monitor_mode = 0
g_monitor_mode = 0
m_monitor_mode = 0
vds_monitor = fltarr(1000)
gis_monitor = fltarr(1000)
opsl_monitor = intarr(1000)
opsr_monitor = intarr(1000)
slitn_monitor = bytarr(1000)
slitp_monitor = intarr(1000)
mirrp_monitor = bytarr(1000)
cal_hor_posn  = 0.0
cal_vert_posn = 0.0
vds_disp_yst  = 362
vds_disp_yend = 661
vds_back_sub  = 0

;
;  data decompression setup
;
bits = ['0000'xl, '0001'xl, '0003'xl, '0007'xl, '000F'xl, $
                 '001F'xl, '003F'xl, '007F'xl, '00FF'xl, $
                 '01FF'xl, '03FF'xl, '07FF'xl, '0FFF'xl, $
                 '1FFF'xl, '3FFF'xl, '7FFF'xl, 'FFFF'xl]

; quasilog tables

qutab12 = settab ( 3, 5)
qutab16 = settab ( 4, 4) 


;
;Let's go
;
main_menu


END
