;+
; Project     : SOHO - CDS     
;                   
; Name        : CHECK_CAL_FILE()
;               
; Purpose     : To check if a calibration FITS file has already been used.
;               
; Explanation : The calibration FITS files will be named with a 'version'
;               number in the file name.  In order not to overwrite files
;               or create confusion by having multiple files with the same
;               name a complete list of used file names is kept in the file
;               $CDS_CAL_FITS/cal_fits.log  It is not possible to simply
;               search the data directory because files will be archived after
;               a few days.  This routine searches the log file for a previous
;               entry.
;               
; Use         : status = check_cal_file('file name')
;    
; Inputs      : file_name  - the file name to be checked
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns 1 if file exists else zero
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 22-Dec-93
;-            

function check_cal_file, infile

;
;  common for main widgets
;
@MainWidgets.com

on_ioerror, finish

;
;  does log file exist?
;
if not file_exist(concat_dir('$CDS_CAL_FITS','cal_fits.log')) then begin
   bell
   widget_control, msg_widg, set_val='Creating new FITS log file.',/append
   openw,lun,concat_dir('$CDS_CAL_FITS','cal_fits.log'),/get_lun
   printf,lun,';'
   printf,lun,';  Calibration FITS log file.'
   printf,lun,';  An entry is made here whenever a file name is used.'
   printf,lun,';'
   free_lun,lun
endif

;
;  now open the log file for checking
;
openr,lun,concat_dir('$CDS_CAL_FITS','cal_fits.log'),/get_lun

;
;  read in the contents
;
text = strarr(10000)
line = ' '
i = 0
while not eof(lun) do begin
   readf,lun,line
   text(i) = line
   i = i+1
endwhile
free_lun,lun

;
;  trim to that needed
;
text = text(where(text ne ''))

;
;  search for requested file
;
hit = where(text eq infile)
hit = hit(0)

;
;  return the result
;
if hit ge 0 then return,1 else return,0

finish:
free_lun,lun
return,0


end
