;+
; Project     : SOHO - CDS     
;                   
; Name        : CHECK_FITS_NAME
;               
; Purpose     : Check if proposed FITS filename is unique.
;               
; Explanation : Checks in the FITS file log to see if the current FITS file
;               name has already been used.  If so, increment the postfix
;               number.
;               
; Use         : check_fits_name, fits_file_name
;    
; Inputs      : fits_file_name  -  the current FITS file name
;               
; Opt. Inputs : None
;               
; Outputs     : Returns revised version of input if needed.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 10-Feb-94
;               
; Modified    : 
;
; Version     : Version 1, 10-Feb-94
;-            

pro check_fits_name, file

;
;  common for file name widget
;
@MainWidgets.com

;
;  starting with the postfix number of the input file
;
count = fix(strmid(file,14,2))

;
;  search for next free one
;
status = 1 
while status eq 1 do begin
   cal_vers = strmid(string(count+100,form='(i3)'),1,2)
   file = strmid(file,0,14) + cal_vers
   status = check_cal_file(file)
   count = count + 1
endwhile

;
;  display current file
;
widget_control,fitsfile_widg,set_val=file

end
