;+
; Project     : SOHO - CDS     
;                   
; Name        : CTRL_ANALYSIS
;               
; Purpose     : Enable/disable widgets associated with EGSE analysis mode.
;               
; Explanation : Simple widget control of widgets involved in the anlysis and
;               display of VDS/GIS data in the science analysis procedure
;               used in the EGSE. This is done to eliminate the risk of these
;               widgets affecting the ingestion of realtime data because of
;               their CPU intensive nature.
;               
; Use         : ctrl_analysis, set
;    
; Inputs      : set - flag to indicate whether to turn on/off (0/1) the
;                     widgets in question.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Uses COMMON blocks internal to the EGSE sci_ana package.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf 19 oct 92            
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Deleted reference to file_base after inclusion of EXIT button
;               instead of File menu, CDP 27-Oct-93
;
; Version     : Version 1, 7-Oct-93
;-            

PRO ctrl_analysis, set

;
;  include files for COMMON definitions
;
@MainWidgets.com
@VDSWidgets.com
@GISWidgets.com

;
;  control state of widgets, set=0/1 for nosee/see
;
if vds_display then begin
   WIDGET_CONTROL, vds_ana_widg,  SENSITIVE=set
   WIDGET_CONTROL, vds_view_widg, SENSITIVE=set
endif

if gis_display then begin
   WIDGET_CONTROL, gis_ana_widg,  SENSITIVE=set
   WIDGET_CONTROL, gis_view_widg, SENSITIVE=set
endif

WIDGET_CONTROL, input_rt_widg, SENSITIVE=set

end

