;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_CHECK_SET
;               
; Purpose     : Displays the result of the calibration setup check.
;               
; Explanation : Checks the agrrement between the Gas id and the current FITS
;               file name and between the FITS file name here (derived form the
;               selected calibration sequence id) and that written by the
;               EGSE command script.
;               
; Use         : disp_check_set
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE sci_ana programs only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 10-Feb-94
;               
; Modified    : 
;
; Version     : Version 1, 10-Feb-94
;-            

PRO disp_check_set

;
;  COMMON blocks for widget id communication
; 
@CalFits.com
@GAS_Details.com
@Check_Setup.com

;
;  con viewer into thinking something is being done
;
widget_control,setup_widg(0),set_val=' '
widget_control,setup_widg(1),set_val=' '
wait,1

;
;  check if have sensible FITS file name 
;
if strmid(cal_fits_file,0,4) eq 'None' then begin

   widget_control,setup_widg(1),set_val=' '
   flash_msg,setup_widg(0),'System only has default FITS file name'

endif else begin


;
; check sequence id this side (from FITS filename) is same as EGSE side
;
   on_ioerror, err
   egse_name = ' '
   openr,lun,concat_dir('$CDS_PLAN_TECH','filename.txt'),/get_lun
   readf,lun,egse_name
   free_lun,lun

   egse_name = strmid(egse_name,0,9)
   idl_name  = strmid(cal_fits_file,0,9)

   if egse_name eq idl_name then begin
      widget_control,setup_widg(0),set_val='  OK'
   endif else begin
      text = 'EGSE file name: '+egse_name+'  but IDL name: '+idl_name
      flash_msg,setup_widg(0),text
   endelse
endelse

;
;  check current FITS file name is consistent with the current Gas details
;
g1 = strmid(strlowcase(gasid),0,1)
g2 = strmid(cal_fits_file,2,1)

if g1 eq g2 then begin
   widget_control,setup_widg(1),set_val='  OK'
endif else begin
   text = 'Current Gas id = '+gasid+'  but FITS filename starts: '+$
          strmid(cal_fits_file,0,4)
   flash_msg,setup_widg(1),text
endelse

return

;
;  on i/o error
;

err:

flash_msg,setup_widg(0),'Unable to open filename file on EGSE side'


end

