;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_ERR
;               
; Purpose     : Display contents of an IMIF interface module dump.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               format id '07'x, the contents relate to a dump of the Error
;               module and they can be displayed in the appropriate
;               widget by this routine. The widgets used are set up in the
;               routine SP_ERR_MENU.
;               
; Use         : disp_err, packet
;    
; Inputs      : packet  - an int(142) array containing packet data, read by the
;                         routine read_sp_body
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : EGSE version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : 
;
; Version     : Version 1, 7-Oct-93
;-            

PRO disp_err, packet

;
;  load COMMON blocks for widgets identifications
;
@SpecialWidgets.com
@MainWidgets.com

;
;  check output format requested
;
if special_format eq 1 then begin
   fmt  = '(i3,3x,2(2x,i6))' 
endif else begin
   fmt  = '(i3,4x)'
endelse

;
;  this dump comes in one special packet only
;
for i=0,31,2 do begin
   if special_format eq 1 then begin
      widget_control,sp_err_exp(0),/append, $
             set_val=string(i+1,unsign(packet(i:i+1)),format=fmt)
   endif else begin
      hexout,sp_err_exp(0),[fix(i+1),packet(i:i+1)],/append
   endelse
endfor

;
;  spacer
;
widget_control,sp_err_exp(0),/append, set_val=' '
widget_control,sp_err_exp(0),/append, set_val='=========================== '
widget_control,sp_err_exp(0),/append, set_val=' '

END
