;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_GEN_TABLE
;               
; Purpose     : Display contents of a general store dump.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               format id indicating a table dump, they can be displayed in 
;               the appropriate widget by this routine. The widgets used are 
;               set up in the routine SP_GEN_MENU.
;               
; Use         : disp_gen_table, packet, counter, format_id
;    
; Inputs      : packet    - an int(141) array containing packet data, read 
;                           by the routine read_sp_body
;
;               counter   - special packet counter (byte). If it has the 
;                           MSB set it is the last packet in the dump.
;
;               format_id - special packet format, needed because Sequence
;                           table is different from rest (2 bytes normally
;                           containing the length have study_id + length)
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : From a PC routine by M K Carter
;
; Written     : EGSE version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : To display Study ID, CDP, 4-Nov-93
;
; Version     : Version 2, 4-Nov-93
;-            

PRO disp_gen_table, packet, sp_pkt_counter, format_id

;
;  Common block for widget id's
;
@SpecialWidgets.com


;
;  output format can be decimal or hex
;

if special_format eq 1 then fmt = '(5x,i5)' else fmt = '(5x,z4)'

;
;  display information in the widgets defined in sp_gen_menu.
;
if special_format eq 2 then begin
   hexout,sp_gen_exp(0),packet(0)
endif else begin
   temp = unsign(packet(0))
   widget_control,sp_gen_exp(0),set_val=string(temp,form=fmt)
endelse

if special_format eq 2 then begin
   hexout,sp_gen_exp(1),packet(1)
endif else begin
   temp = unsign(packet(1))
   widget_control,sp_gen_exp(1),set_val=string(temp,form=fmt)
endelse

;
;  sort out study ID
;
study_id = fix(byte(byteswap(packet(2))))
if special_format eq 2 then begin
   hexout,sp_gen_exp(2),study_id
endif else begin
   widget_control,sp_gen_exp(2),set_val=string(study_id,form=fmt)
endelse

;
;  and the table length.
;
tab_len = fix(byte(packet(2)))
if special_format eq 2 then begin
   hexout,sp_gen_exp(3),tab_len
endif else begin
   widget_control,sp_gen_exp(3),set_val=string(tab_len,form=fmt)
endelse

;
;  display the available data, first 2 values then 4 values/row
;
if tab_len gt 0 then begin
   hexout,sp_gen_exp(4),packet(3:4),/append
   tab_len = tab_len - 2
   tab_len = tab_len < 136
   nl = fix(tab_len/4)+1
   if (tab_len mod 4) eq 0 then nl = nl - 1
   st = 5
   for i=0,(34<nl)-1 do begin
      hexout,sp_gen_exp(4),packet(st:(st+3 < (tab_len+4))),/append
      st = st + 4
   endfor
endif

;
;  put out spacer
;
widget_control,sp_gen_exp(4),set_val=' ',/append
widget_control,sp_gen_exp(4),set_val='-----------------------',/append
widget_control,sp_gen_exp(4),set_val=' ',/append


end
