;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_IMIF
;               
; Purpose     : Display contents of IMIF module (MCU support) dump.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               format id '01'x, the contents relate to a dump of the IMIF
;               interface module (MCU support) and they can be displayed in 
;               the appropriate widget by this routine. The widgets used are 
;               set up in the routine SP_IMIF_MENU.
;               
; Use         : disp_imif, packet, counter
;    
; Inputs      : packet  - an int(141) array containing packet data, read by the
;                         routine read_sp_body
;
;               counter - special packet counter (byte). If it has the MSB set
;                         it is the last packet in the dump.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : From a PC routine by M K Carter
;
; Written     : EGSE version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Version 1, C D Pike, RAL, 7-Oct-93
;		Version 2, William Thompson, GSFC, 12 November 1993.
;			Added /NTOHS to BYTEORDER and changed /LONG to /NTOHL
;			for platform independence.
;               Version 3, CDP, reworked for new packet definition. 30/Nov/93
;               Version 4, CDP, and again...   13-Jan-94
;
; Version     : Version 4, 12-Jan-94
;-            

PRO disp_imif, packet, sp_pkt_counter

;
;  load COMMON blocks for widgets identifications
;
@SpecialWidgets.com
@MainWidgets.com

;
;  check output format requested
;
if special_format eq 1 then begin
   fmt  = '(4(i8,1x))' 
   fmt1 = '(5(4(i8,1x),/))'
endif else begin
   fmt  = '(4(z8.8,1x))'
   fmt1 = '(5(4(z8.8,1x),/))'
endelse

;
;  this dump comes in two special packets identified by the packet counter
;
CASE (sp_pkt_counter) OF

  0 : BEGIN 

;
;  this packet is to be interpreted as INT32 values 
;
     
         pck = LONG ( packet, 2, N_ELEMENTS(packet)/2)

         widget_control,sp_imif_expa(0),$
             set_val=string(pck(0),format=fmt)

         widget_control,sp_imif_expa(1),$
             set_val=string(pck(1:2),format=fmt)

         widget_control,sp_imif_expa(2),$
             set_val=string(pck(3:6),format=fmt)

         widget_control,sp_imif_expa(3),$
             set_val=string(pck(7:9),format=fmt)

         widget_control,sp_imif_expa(4),$
             set_val=string(pck(10:12),format=fmt)

         widget_control,sp_imif_expa(5),$
             set_val=string((pck(13)*64L)/100000L,format=fmt)

         widget_control,sp_imif_expa(6),$
             set_val=string((pck(14:17)*64L)/100000L,format=fmt)

         widget_control,sp_imif_expa(6),$
             set_val=string((pck(18:21)*64L)/100000L,format=fmt),/append

         widget_control,sp_imif_expa(7),$
             set_val=string(pck(22:25),format=fmt)

         widget_control,sp_imif_expa(8),$
             set_val=string(pck(26:29),format=fmt)

         widget_control,sp_imif_expa(8),$
             set_val=string(pck(30:33),format=fmt),/append

         widget_control,sp_imif_expa(9),$
             set_val=string(pck(34:37),format=fmt)

         widget_control,sp_imif_expa(9),$
             set_val=string(pck(38:41),format=fmt),/append

         widget_control,sp_imif_expa(10),$
             set_val=string(pck(42:45),format=fmt)

         widget_control,sp_imif_expa(10),$
             set_val=string(pck(46:49),format=fmt),/append

;
;  convert to millisec
;
         pck(50:67) = (pck(50:67)*64L)/1000L
         widget_control,sp_imif_expa(11),$
             set_val=string(pck(50:67),format=fmt1)

         widget_control,sp_imif_expa(12),$
             set_val=string(pck(68:69),format=fmt)

      END
     
  '81'x : BEGIN

         if special_format eq 1 then begin

            widget_control,sp_imif_expa(13),$
                set_val=string(packet(0:3),format=fmt)
   
            widget_control,sp_imif_expa(14),$
                set_val=string(packet(4:7),format=fmt)
   
            widget_control,sp_imif_expa(15),$
                set_val=string(packet(8:9),format=fmt)
   
            widget_control,sp_imif_expa(16),$
                set_val=string(packet(10),format=fmt)
   
            widget_control,sp_imif_expa(17),$
                set_val=string(packet(11:26),format=fmt1)
   
            widget_control,sp_imif_expa(18),$
                set_val=string(packet(27:42),format=fmt1)
   
            widget_control,sp_imif_expa(19),$
                set_val=string(packet(43:44),format=fmt)
   
            widget_control,sp_imif_expa(20),$
                set_val=string(packet(45),format=fmt)
   
         endif else begin

            hexout,sp_imif_expa(13),packet(0:3)
            hexout,sp_imif_expa(14),packet(4:7)
            hexout,sp_imif_expa(15),packet(8:9)
            hexout,sp_imif_expa(16),packet(10)
            hexout,sp_imif_expa(17),packet(11:26),format='(4(4(2z2.2,2x),/))'
            hexout,sp_imif_expa(18),packet(27:42),format='(4(4(2z2.2,2x),/))'
            hexout,sp_imif_expa(19),packet(43:44)
            hexout,sp_imif_expa(20),packet(45)

         endelse

;
;  right hand side of display
;  ===============
;
         if special_format eq 1 then begin

            widget_control,sp_imif_expb(0),$
                set_val=string(packet(51:52),format=fmt)
   
            widget_control,sp_imif_expb(1),$
                set_val=string(packet(49:50),format=fmt)
   
            widget_control,sp_imif_expb(2),$
                set_val=string(packet(53:54),format=fmt)
   
            widget_control,sp_imif_expb(3),$
                set_val=string(packet(55:56),format=fmt)
   
            widget_control,sp_imif_expb(4),$
                set_val=string(packet(57:58),format=fmt)

;
;  switch to 32 bit integers
;   
            pck = long(packet(59:86),0,14)

            widget_control,sp_imif_expb(5),$
                set_val=string(pck(0),pck(6),format=fmt)
   
            widget_control,sp_imif_expb(6),$
                set_val=string(pck(1),pck(7),format=fmt)
   
            widget_control,sp_imif_expb(7),$
                set_val=string(pck(2),pck(8),format=fmt)
   
            widget_control,sp_imif_expb(8),$
                set_val=string(pck(3),pck(9),format=fmt)
   
            widget_control,sp_imif_expb(9),$
                set_val=string(pck(4),pck(10),format=fmt)
   
            widget_control,sp_imif_expb(10),$
                set_val=string(pck(5),pck(11),format=fmt)
   
            widget_control,sp_imif_expb(11),$
                set_val=string((pck(12)*64L)/100000L,pck(6),format=fmt)
   
            mm = ['Mirror','Slit position','OPS l','OPS r','Slit number',$
                  'Door', 'None']
            widget_control,sp_imif_expb(12),set_val=mm(pck(13))
   
;
;  32 bit integers again
;   
            pck = (long(packet(89:104),0,8)*64L)/100000L
            widget_control,sp_imif_expb(13),$
                set_val=string(pck(0:3),format=fmt)
            widget_control,sp_imif_expb(13),$
                set_val=string(pck(4:7),format=fmt),/append
      
            widget_control,sp_imif_expb(14),$
                set_val=string(fix(byte(packet(105))),format=fmt)

;
;  32 bit integers again
;
            pck = long(packet(107:140),0,17)
            
;
;  to 0.1 seconds from 64Lus units
;
            pck(10) = (pck(10) * 64L) / 100000L
      
            widget_control,sp_imif_expb(15),$
                set_val=string(pck(0:15),format=fmt1)
   
            widget_control,sp_imif_expb(16),$
                set_val=string((pck(16)*64L)/100000L,format=fmt)

         endif else begin

            hexout,sp_imif_expb(0),packet(51:52)
            hexout,sp_imif_expb(1),packet(49:50)
            hexout,sp_imif_expb(2),packet(53:54)
            hexout,sp_imif_expb(3),packet(55:56)
            hexout,sp_imif_expb(4),packet(57:58)
;
;  switch to 32 bit integers
;   
            pck = long(packet(59:86),0,14)
      
            widget_control,sp_imif_expb(5),$
                set_val=string(pck(0),pck(6),form=fmt)
   
            widget_control,sp_imif_expb(6),$
                set_val=string(pck(1),pck(7),form=fmt)
   
            widget_control,sp_imif_expb(7),$
                set_val=string(pck(2),pck(8),form=fmt)
   
            widget_control,sp_imif_expb(8),$
                set_val=string(pck(3),pck(9),form=fmt)
   
            widget_control,sp_imif_expb(9),$
                set_val=string(pck(4),pck(10),form=fmt)
   
            widget_control,sp_imif_expb(10),$
                set_val=string(pck(5),pck(11),form=fmt)
   
            widget_control,sp_imif_expb(11),$
                set_val=string((pck(12)*64L)/100000L,pck(6),form=fmt)
   
            mm = ['Mirror','Slit position','OPS l','OPS r','Slit number',$
                  'Door','None']
            widget_control,sp_imif_expb(12),set_val=mm(pck(13))
   
;
;  32 bit integers again
;   
            pck = (long(packet(89:104),0,8)*64L)/100000L
            widget_control,sp_imif_expb(13),$
                set_val=string(pck(0:3),format=fmt)
            widget_control,sp_imif_expb(13),$
                set_val=string(pck(4:7),format=fmt),/append
      
            hexout,sp_imif_expb(14),fix(byte(packet(105)))

;
;  32 bit integers again
;
            pck = long(packet(107:140),0,17)
;
;  convert to 0.1 seconds from 64L us units
;
            pck(10) = (pck(10) * 64L) / 100000L
      
      
            widget_control,sp_imif_expb(15),$
                set_val=string(pck(0:15),format=fmt1)
   
            widget_control,sp_imif_expb(16),$
                set_val=string((pck(16)*64L)/100000L,format=fmt)
         endelse

;
;  translate backup modes
;   
         dec2bin,packet(47),out,/quiet
         stat = ['OFF','ON']
         loop = ['Open','Closed']
         for i=0,6 do begin
            if i eq 1 then begin
               widget_control,sp_imif_mode(i),set_val=loop(out(15-i))
            endif else begin
               widget_control,sp_imif_mode(i),set_val=stat(out(15-i))
            endelse
         endfor

      END

  ELSE : widget_control,msg_widg, /append, $
                        set_val='Invalid special IMIF packet counter' 

  ENDCASE

END
