;+
; Project     : SOHO - CDS     
;                   
; Name        : GAS_EVENT
;               
; Purpose     : Processes events from the GAS_MENU.
;               
; Explanation : Any events originating within the widgets realized by 
;               GAS_MENU are handled by this routine.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ev  -  the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with GAS_MENU in EGSE calibration routines.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 20-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 20-Dec-93
;-            

PRO gas_event, ev

;
;  COMMON blocks for widget id's
;
@MainWidgets.com
@GAS_Details.com
      
;
;  interpret type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  might have been a button
;
if (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_UVALUE=value
 
;
;  Done (ie exit) request received
; 
   IF (value EQ 'Done') THEN BEGIN
      if gasid ne 'None'   and $
            gascurrent ne 0.0 and $
             gasvoltage ne 0   and $
              gaspressure ne 0 then begin
         calhdr = {calhdrdef,gas_id: ' ',gas_voltage: 0,gas_current: 0.0,$
                             gas_pressure: 0}
         calhdr.gas_id       = gasid
         calhdr.gas_current  = gascurrent
         calhdr.gas_voltage  = gasvoltage 
         calhdr.gas_pressure = gaspressure
      endif else begin
         calhdr = 0
         bell
         flash_msg, msg_widg,'Warning: gas details incomplete.'
      endelse
      WIDGET_CONTROL, gas_base, /destroy
      widget_control, gas_but_widg, sensitive=1
   ENDIF

;
;  was defining the Gas with the PDM
;
   if value eq 'Argon' or $
         value eq 'Neon'  or $
            value eq 'Helium' then begin
      widget_control,gas_exp_awidg(0),set_value='  '+value
      gasid = value
      gasvoltage = 400
      widget_control,gas_exp_awidg(1),set_v=string(fix(gasvoltage))
      gascurrent = 2.0
      widget_control,gas_exp_awidg(2),set_v=string(gascurrent,form='(f5.2)')
      if value eq 'Argon'  then gaspressure = 42
      if value eq 'Neon'   then gaspressure = 68
      if value eq 'Helium' then gaspressure = 200
      widget_control,gas_exp_awidg(3),set_v=string(fix(gaspressure))
   endif

endif

;
;  or it might have been one of the editable text widgets
;
IF (type EQ 'WIDGET_TEXT') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_UVALUE=uvalue, get_val=value
   value = value(0)
;
;  read the voltage
;
   if uvalue eq 'Gas_voltage' then begin
      if valid_num(value) then begin
         widget_control,gas_exp_awidg(1),set_v=string(fix(value))
         gasvoltage=value
      endif else begin
         bell
         flash_msg,gas_exp_awidg(1),'Invalid voltage'
         widget_control,gas_exp_awidg(1),set_v='0'
      endelse
   endif

;
;  read the current
;
   if uvalue eq 'Gas_current' then begin
      if valid_num(value) then begin
         widget_control,gas_exp_awidg(2),set_v=string(value,form='(f5.2)')
         gascurrent = value
      endif else begin
         bell
         flash_msg,gas_exp_awidg(2),'Invalid current'
         widget_control,gas_exp_awidg(2),set_v='0.0'
      endelse
   endif
;
;  read the pressure
;
   if uvalue eq 'Gas_pressure' then begin
      if valid_num(value) then begin
         widget_control,gas_exp_awidg(3),set_v=string(fix(value))
         gaspressure = value
      endif else begin
         bell
         flash_msg,gas_exp_awidg(3),'Invalid pressure'
         widget_control,gas_exp_awidg(3),set_v='0'
      endelse
   endif


ENDIF
END
