;+
; Project     : SOHO - CDS     
;                   
; Name        : GAS_MENU
;               
; Purpose     : Defines the calibration GAS details window.
;               
; Explanation : Creates the widgets which form the window within which
;               he calibrated source GAS details are entered/displayed.
;               
; Use         : gas_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE calibration programs only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 20-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 20-Dec-93
;-            

PRO gas_menu

;
;  COMMON blocks for widget id communication
; 
@GAS_Details.com
@MainWidgets.com

;
;  guard against trigger happy users
;
if xregistered('gas') then begin
  widget_control,msg_widg,set_val='Steady with the trigger!',/append
  return
endif

gas_exp_awidg = lonarr(5)
;
;  create main base
;
gas_base = WIDGET_BASE(title='Source GAS details',  /FRAME, /COLUMN,$
                       group_leader = main_base, xoffset=500)

;
;  and subsidiary ones
;
menu_base  = WIDGET_BASE(gas_base, /ROW)
info_base  = WIDGET_BASE(gas_base, /ROW)
info_abase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
m1_widg       = WIDGET_BASE(menu_base, /ROW)


;
;  'Done' button to exit
;
doneid = widget_button(m1_widg, value='Done', uvalue='Done')

;
;  pull down menu for gas id
;
XPDmenu, ['"Gas ID"  {',$
                '"Argon"',$
                '"Neon"',$
                '"Helium"','}'],$
             info_abase,base=gasid_base

              
;
;  widgets for display of gas details
;

a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='GAS identification:')
gas_exp_awidg(0) = WIDGET_TEXT(a1,XSIZE=12,YSIZE=1,value=gasid)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Gas voltage (volts): ')
gas_exp_awidg(1) = WIDGET_TEXT(a2,XSIZE=12,YSIZE=1,/editable,$
                               value=string(gasvoltage,form='(2x,i5)'),$
                               uvalue='Gas_voltage')


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Gas current (amps): ')
gas_exp_awidg(2) = WIDGET_TEXT(a3,XSIZE=12,YSIZE=1,/editable,$
                               value=string(gascurrent,form='(2x,f6.3)'),$
                               uvalue='Gas_current')

a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Gas pressure (Pascals): ')
gas_exp_awidg(3) = WIDGET_TEXT(a4,XSIZE=12,YSIZE=1,/editable,$
                               value=string(gaspressure,form='(2x,i5)'),$
                               uvalue='Gas_pressure')


;
;  make it all appear
;
WIDGET_CONTROL, gas_base, /realize

end
