;+
; Project     : SOHO - CDS     
;                   
; Name        : GIS_MENU
;               
; Purpose     : Defines and realises the GIS analysis window.
;               
; Explanation : Defines and creates the GIS analysis widget within the
;               EGSE science analysis programs.
;               
; Use         : Only from within EGSE science analysis
;    
; Inputs      : Only via COMMON blocks.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use from MAIN_MENU in EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Changed to use of "Done" button.  CDP, 28-Oct-93
;               Update exposure details widget, CDP, 2-Nov-93
;               Major update of display, CDP.  13-Dec-93
;
; Version     : Version 4, 13-Dec-93
;-            

PRO gis_menu

;
;  Load COMMON blocks for variable communication
;
@GISWidgets.com
@MainWidgets.com
@Images.com
@GISData.com

;
;  trap double clicking
;
if xregistered('gis') then return

;
;  arrays to hold individual widget id's
;
gis_exp_awidg = lonarr(10)
gis_exp_bwidg = lonarr(10)   

;
;  main widget
;
gis_base = WIDGET_BASE(title='GIS analyser',  /FRAME, /COLUMN, $
                       group_leader = main_base)

;
;  subordinate bases
;
menu_base  = WIDGET_BASE(gis_base, /ROW)
info_base  = WIDGET_BASE(gis_base, /ROW)
info_abase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
info_bbase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
info_cbase = WIDGET_BASE(info_abase, /COLUMN)
info_dbase = WIDGET_BASE(info_bbase, /COLUMN)
gis_msg    = WIDGET_BASE(gis_base,/frame,/row)


image_base = WIDGET_BASE(gis_base, /FRAME, /COLUMN)

m1_widg = WIDGET_BASE(menu_base, /ROW)
gis_ana_widg = WIDGET_BASE(menu_base, /ROW)
m2_widg = WIDGET_BASE(menu_base, /ROW)
gis_view_widg = WIDGET_BASE(menu_base, /ROW)
line_widg = widget_base(menu_base, /row)

;
;  create "Done" button
;
doneid = widget_button(m1_widg, value='Done')

;
;  create the pulldown menus
;
XPDmenu, ['"Analyse" {','"Subtract a-b"       anal_SUBAB',$
                        '"Enlarge A"          anal_ENLGA',$
                        '"Enlarge B"          anal_ENLGB',$
                        '"Fit profile in A" {',$
                                            '"Gauss only"     anal_PROFA0',$
                                            '"Gauss + cons"   anal_PROFA1',$
                                            '"Gauss + linear" anal_PROFA2',$
                                            '"Gauss + quad"   anal_PROFA3',$
                                            '}',$
                        '"Fit profile in B" {',$
                                            '"Gauss only"     anal_PROFB0',$
                                            '"Gauss + cons"   anal_PROFB1',$
                                            '"Gauss + linear" anal_PROFB2',$
                                            '"Gauss + quad"   anal_PROFB3',$
                                            '}'],gis_ana_widg

XPDmenu, ['"View" {','"Select A"','"Select B"','"Synthetic data"','}'], gis_view_widg

XPDmenu, ['"Plot axes" {','"By pixel"              PIX',$
                          '"By wavelength"         WAV',$
                          '"Linear counts"         LIN',$
                          '"Logarithmic counts"    LOG','}'], gis_view_widg

XPDmenu, ['"Hardcopy" {','"Window A"','"Window B"','}'],m1_widg


XPDmenu, ['"Spectral Lines" {','"Display First Order"   LINES_F',$
                               '"Display Second Order"  LINES_S',$
                               '"Display All"           LINES_A',$
                               '"Display OFF"           LINES_O','}'],line_widg


;
;  create information widgets for exposure 'A'
;
a0 = WIDGET_LABEL(info_abase, VALUE='GIS exposure A properties')

a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Exposure number :  ')
gis_exp_awidg(0) = WIDGET_TEXT(a1,XSIZE=12,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='UT start time   :  ')
gis_exp_awidg(1) = WIDGET_TEXT(a2,XSIZE=12,YSIZE=1)


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Integration time:  ')
gis_exp_awidg(2) = WIDGET_TEXT(a3,XSIZE=12,YSIZE=1)


a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='OPS L coordinate:  ')
gis_exp_awidg(3) = WIDGET_TEXT(a4,XSIZE=12,YSIZE=1)


a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='OPS R coordinate:  ')
gis_exp_awidg(4) = WIDGET_TEXT(a5,XSIZE=12,YSIZE=1)


;
;  and the same for exposure 'B'
;
b0 = WIDGET_LABEL(info_bbase, VALUE='GIS exposure B properties')

b1  = WIDGET_BASE(info_bbase, /ROW)
b11 = WIDGET_LABEL(b1, VALUE='Exposure number :  ')
gis_exp_bwidg(0) = WIDGET_TEXT(b1,XSIZE=12,YSIZE=1)


b2  = WIDGET_BASE(info_bbase, /ROW)
b21 = WIDGET_LABEL(b2, VALUE='UT start time   :  ')
gis_exp_bwidg(1) = WIDGET_TEXT(b2,XSIZE=12,YSIZE=1)


b3  = WIDGET_BASE(info_bbase, /ROW)
b31 = WIDGET_LABEL(b3, VALUE='Integration time:  ')
gis_exp_bwidg(2) = WIDGET_TEXT(b3,XSIZE=12,YSIZE=1)


b4  = WIDGET_BASE(info_bbase, /ROW)
b41 = WIDGET_LABEL(b4, VALUE='OPS L coordinate:  ')
gis_exp_bwidg(3) = WIDGET_TEXT(b4,XSIZE=12,YSIZE=1)


b5  = WIDGET_BASE(info_bbase, /ROW)
b51 = WIDGET_LABEL(b5, VALUE='OPS R coordinate:  ')
gis_exp_bwidg(4) = WIDGET_TEXT(b5,XSIZE=12,YSIZE=1)

;
;  create the GIS plot choice buttons for A
;

agis_buttons1 = widget_base(info_cbase,/row)
agb_list = ['GIS1','GIS2','GIS3','GIS4','All']
agis_b_uval = ['aGISB1','aGISB2','aGISB3','aGISB4','aGISB5']
agis_buttons2 = widget_base(agis_buttons1,/column)
agis_b_ids = lonarr(5)

xmenu,agb_list,agis_buttons2,buttons=agis_b_ids,title='Display GIS bands.',$
      uvalue=agis_b_uval,/row,/nonexclusive

;
;  if first time in then set display choice to 'ALL'
;
if total(gis_data_str.agis_plot_choice) eq 0 then begin
   gis_data_str.agis_plot_choice(4) = 1
endif

;
;  indicate current choice of GIS band to plot
;
for i=0,4 do widget_control,agis_b_ids(i),$
                    set_button=gis_data_str.agis_plot_choice(i)

;
;  create the GIS plot choice buttons for B
;

bgis_buttons1 = widget_base(info_dbase,/row)
agb_list = ['GIS1','GIS2','GIS3','GIS4','All']
bgis_b_uval = ['bGISB1','bGISB2','bGISB3','bGISB4','bGISB5']
bgis_buttons2 = widget_base(bgis_buttons1,/column)
bgis_b_ids = lonarr(5)

xmenu,agb_list,bgis_buttons2,buttons=bgis_b_ids,title='Display GIS bands.',$
      uvalue=bgis_b_uval,/row,/nonexclusive

;
;  if first time in then assume display mode 'ALL'
;
if total(gis_data_str.bgis_plot_choice) eq 0 then begin
   gis_data_str.bgis_plot_choice(4) = 1
endif

;
;  indicate current choice of GIS band to plot
;
for i=0,4 do widget_control,bgis_b_ids(i),$
                            set_button=gis_data_str.bgis_plot_choice(i)


;
;  message window
;
dum = widget_label(gis_msg,val='Messages: ')
gis_msg_widg = widget_text(gis_msg,xsize=120,ysize=1)


;
; make base to keep GIS A-image and label together 
;
i1 = WIDGET_BASE(image_base, /COLUMN)
dummy_widg = WIDGET_LABEL(i1, VALUE = 'GIS plot A')
gis_awidg = widget_draw(i1, XSIZE=1024, YSIZE=256, uvalue='GPLOT_A',$
                        /button_events)

;
; make base to keep GIS B-image and label together 
;
k1 = WIDGET_BASE(image_base, /COLUMN)
dummy_widg = WIDGET_LABEL(i1, VALUE = 'GIS plot B')
gis_bwidg = WIDGET_DRAW(k1, XSIZE=1024, YSIZE=256, uvalue='GPLOT_B',$
                        /button_events)


;
;  realise the whole thing
;
WIDGET_CONTROL, gis_base, MAP=0
WIDGET_CONTROL, gis_base, /REALIZE

;
; plot empty data sets to initialise plot window
;
plot_gis, dummy_buf,/init
gis_data_str.gis_select = 'B'
plot_gis, dummy_buf,/init
gis_data_str.gis_select = 'A'

end


