;+
; Project     : SOHO - CDS     
;                   
; Name        : GIS_SYNTH
;               
; Purpose     : To load synthetic GIS data into the calibration program.
;               
; Explanation : Loads output from gis_dummy into gis data storage arrays.
;               
; Use         : Only within EGSE calibration software.
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : GISData
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Jan-94
;               
; Modified    : 
;
; Version     : Version 1, 12-Jan-94
;-            

pro gis_synth

@GISData.com
@Packets.com

;
;  test data for GIS
;
temp = intarr(8192)
gis_plot = intarr(500,7,5)
gis_date_time = strarr(5)
gis_exphdr = replicate(exphdr,5)
gisrasterhdr.numdatawindows = 7
gis_data_str.gis_exp = 4

for i=0,6 do begin
   gisrasterhdr.giswin(i).start = (i+1)*1000
   gisrasterhdr.giswin(i).length = 500
endfor

for i=0,4 do begin
   gis_exphdr(i).exposurenumber = i
   gis_exphdr(i).exposurestart = [i,i,i,i,i,i]
   temp = 1000.*(i+1)*sin(6.28*findgen(8192)/400.)  + 1000.*(i+1)
   for j=0,6 do begin
      gis_plot(*,j,i) = temp(gisrasterhdr.giswin(j).start:$
                             gisrasterhdr.giswin(j).start+499)
   endfor
endfor

x = findgen(500)-250.
for i=0,499 do begin
   gis_plot(i,4,2) = 1000.*exp(-x(i)*x(i)/5000.)
endfor

;
;  this is the only bit that matters
;
temp = indgen(4,2048)

fil = concat_dir('$CDS_PLAN_TECH','gis_dummy_image')
openr,lun,fil,/get_lun,error=err
if err eq 0 then begin
   readu,lun,temp
   free_lun,lun
endif

gis_data_str.exp_in_a = 0
gis_data_str.exp_in_b = 0
for i=0,3 do begin
   gis_data_str.curr_a_data(i*2048:i*2048+2047) = temp(i,*)
   gis_data_str.curr_b_data(i*2048:i*2048+2047) = temp(i,*)
endfor

end
