;+
; Project     : SOHO - CDS     
;                   
; Name        : HANDLE_TM_ERROR
;               
; Purpose     : Handle i/o errors in telemetry reception.
;               
; Explanation : When an i/o error occurs in the telemetry receipt, this routine
;               stops the background routine WORKPROC which was receiving the
;               data, closes the input logical unit and displays an error
;               message in the information widget. The new state of the 
;               data acquisition (ie stopped) is communicated back via
;               variables in the Mode common block. The only difference
;               between this and HANDLE_IO_ERR appears to be that this 
;               routine ouputs a user message rather than the system error
;               message.
;               
; Use         : handle_tm_error, widget_base, msd_widg, unit, msg
;    
;               Normally reserved for internal use within EGSE science analysis
;
; Inputs      : widget_base - the id of the widget with which WORKPORC was
;                             registered.
;               msg_widg    - the id of the widget for messages
;               unit        - the unit to which the telemetry was attached
;                             before the error occurred.
;               msg         - user message to be displayed
;               
; Opt. Inputs : None 
;               
; Outputs     : None 
;               
; Opt. Outputs: None 
;               
; Keywords    : None 
;
; Calls       : None 
;               
; Restrictions: For EGSE science analysis internal use only.
;               
; Side effects: None 
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : 
;
; Version     : Version 1, 7-Oct-93
;-            

PRO handle_tm_error, widget_base, msg_widg, unit, msg


;
;  COMMON block for communication of data taking status
;
@Mode.com

;
; close the attched unit (file or pipe to C program 
;
close,unit

;
;  unregister WORKPROC ie stop it running as a background task of the main
;  widget
;
XBackRegister, /UNREGISTER, "workproc", widget_base

;
;  send back message about reason for failure
;
WIDGET_CONTROL, msg_widg, /append, SET_VALUE=msg

;
;  and state the obvious
;
WIDGET_CONTROL, msg_widg, SET_VALUE='Data taking stopped because of error',$
              /append

;
;  set flag to indicate we have stopped, these are sent back in COMMON
;
sci_pause = 0
sci_going = 0

;
;  reenable analysis widgets now that data taking cannot be affected
;
ctrl_analysis,1


end
