;+
; Project     : SOHO - CDS     
;                   
; Name        : HEADER_G_EVENT
;               
; Purpose     : Processes widget events from the GIS packet header menu.
;               
; Explanation : Any widget events originating in the routine HEADER_GIS_MENU
;               which displays the header information of GIS telemetry packets
;               is dealt with by this routine.  The options are limited at
;               present to closing the widget and changing the format of the
;               data displayed (either hexadecimal or decimal).
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the structure of the event generated.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for interal use of EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-oct-93
;               
; Modified    : Put in 'DONE' button instead of file/close, CDP, 27-Oct-93
;
; Version     : Version 2, 27-Oct-93
;-            

PRO header_g_event, ev

;
;  COMMON blocks for communication of variables
;
@MainWidgets.com
@HeaderWidgets.com
@Packets.com

;
; find out type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  event should only have been generated by a button
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  done ie exit
; 
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, header_map_base, SENSITIVE=1
      WIDGET_CONTROL, header_g_base, /destroy
      header_select = 0
   ENDIF

;
;  switch the format to be used for displaying the output
;
   IF (value EQ 'Decimal') then begin
      header_format = 1 
      widget_control,header_format_gw,set_value='Decimal'
   endif

   IF (value EQ 'Hex') then begin
      header_format = 2 
      widget_control,header_format_gw,set_value='Hex'
   endif


endif

end
