;+
; Project     : SOHO - CDS     
;                   
; Name        : HEADER_VDS_MENU
;               
; Purpose     : Defines and realises the VDS header information window. 
;               
; Explanation : One of the options available within the EGSE science analysis
;               program is to monitor the header information of VDS science
;               packets as they are received in the telemetry.  This program
;               defines and realises the widgets within which the VDS header
;               information is displayed.
;               
; Use         : Only called from MAIN_MENU
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for internal use in EGSE science analysis
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-Oct-93
;               
; Modified    : Change time output to date/time string  21/10/93  CDP
;               Change to accommodate v3.0 of packet format 27/10/93  CDP
;
; Version     : Version 3, 27-Oct-93
;-            


PRO header_vds_menu

;
;  COMMON blocks for communication
; 
@HeaderWidgets.com
@MainWidgets.com

;
;  trap double clicks
;
if xregistered('header_v') then return



;
;  storage for id's of individual text widgets
;
header_v_exp = lonarr(31)

;
;  set up main widget
;
header_v_base = WIDGET_BASE(title='VDS Packet header ', group=main_base, $
                            /FRAME, /COLUMN, XSIZE=650, XOFFSET=600)

;
;  and subsidiary ones
;
menu_base  = WIDGET_BASE(header_v_base, /ROW)
 
info_base  = WIDGET_BASE(header_v_base, /ROW)
info_abase = WIDGET_BASE(info_base, /COLUMN, /FRAME, SPACE=1)


m1_widg = WIDGET_BASE(menu_base, /column)
header_v_ana_widg = WIDGET_BASE(menu_base, /ROW)
m2_widg = WIDGET_BASE(menu_base, /ROW)
header_v_view_widg = WIDGET_BASE(menu_base, /ROW)

butt_widg = widget_base(m1_widg,/row)
;
;  create Done button
;
doneid = widget_button(butt_widg,value='Done')

;
;  form the pulldown menu for format change
;
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],butt_widg

;
;  and the text window to display current format setting
;
f1 =  widget_base(m1_widg,/column)
f11 = widget_label(f1,val='Current format: ')
header_format_vw = widget_text(f1,xsize=10,ysize=1,value='Decimal')

;
;  and the text window to display packet selection 
;
f2 =  widget_base(m1_widg,/column)
f22 = widget_label(f2,val='Current packet selection: ')
header_select_vw = widget_text(f2,xsize=35,ysize=1,value=' ')

;
;  and the text windows to display data windows definition
;
w_widg = WIDGET_BASE(m1_widg, /row)
header_v_w = lonarr(32)
w1 =  widget_base(w_widg,/column,space=1)
w11 = widget_label(w1,val='Window')
for i=0,31 do begin
   winnum = string(i+1,format='(i2)')
   header_v_w(i) = widget_text(w1,xsize=5,ysize=1,value=winnum)
endfor
;
;  X start positions
;
header_v_w_sx = lonarr(32)
wsx =  widget_base(w_widg,/column,space=1)
wssx = widget_label(wsx,val='XStart')
for i=0,31 do begin
   header_v_w_sx(i) = widget_text(wsx,xsize=7,ysize=1,value=' ')
endfor

;
;  X length
;
header_v_w_lx = lonarr(32)
wlx =  widget_base(w_widg,/column,space=1)
wllx = widget_label(wlx,val='XLength')
for i=0,31 do begin
   header_v_w_lx(i) = widget_text(wlx,xsize=7,ysize=1,value=' ')
endfor

;
;  Y start positions
;
header_v_w_sy = lonarr(32)
wsy =  widget_base(w_widg,/column,space=1)
wssy = widget_label(wsy,val='Ystart')
for i=0,31 do begin
   header_v_w_sy(i) = widget_text(wsy,xsize=7,ysize=1,value=' ')
endfor

;
;  Y length
;
header_v_w_ly = lonarr(32)
wly =  widget_base(w_widg,/column,space=1)
wlly = widget_label(wly,val='YLength')
for i=0,31 do begin
   header_v_w_ly(i) = widget_text(wly,xsize=7,ysize=1,value=' ')
endfor

;
;  form all the individual text widgets to display the header information
;
a0 = WIDGET_LABEL(info_abase, VALUE='VDS Header information')

a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Application ID (Hex):     ')
header_v_exp(0) = WIDGET_TEXT(a1,XSIZE=10,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Length:                   ')
header_v_exp(1) = WIDGET_TEXT(a2,XSIZE=10,YSIZE=1)


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Science Packet ID (Hex):  ')
header_v_exp(2) = WIDGET_TEXT(a3,XSIZE=10,YSIZE=1)


a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Science data pkt counter: ')
header_v_exp(3) = WIDGET_TEXT(a4,XSIZE=10,YSIZE=1)


a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Study ID:                 ')
header_v_exp(4) = WIDGET_TEXT(a5,XSIZE=10,YSIZE=1)

a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='Data compression scheme:  ')
header_v_exp(5) = WIDGET_TEXT(a6,XSIZE=10,YSIZE=1)

a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='Data ext. window ID (hex):')
header_v_exp(6) = WIDGET_TEXT(a7,XSIZE=10,YSIZE=1)

a8  = WIDGET_BASE(info_abase, /ROW)
a81 = WIDGET_LABEL(a8, VALUE='Sequence ID (hex):        ')
header_v_exp(7) = WIDGET_TEXT(a8,XSIZE=10,YSIZE=1)

a9  = WIDGET_BASE(info_abase, /ROW)
a91 = WIDGET_LABEL(a9, VALUE='Raster positions (m:s):   ')
header_v_exp(8) = WIDGET_TEXT(a9,XSIZE=10,YSIZE=1)

a10 = WIDGET_BASE(info_abase, /ROW)
a101 = WIDGET_LABEL(a10, VALUE='OPS L Coordinate (hex):   ')
header_v_exp(9) = WIDGET_TEXT(a10,XSIZE=10,YSIZE=1)

a11  = WIDGET_BASE(info_abase, /ROW)
a111 = WIDGET_LABEL(a11, VALUE='OPS R Coordinate (hex):   ')
header_v_exp(10) = WIDGET_TEXT(a11,XSIZE=10,YSIZE=1)

a12  = WIDGET_BASE(info_abase, /ROW)
a121 = WIDGET_LABEL(a12, VALUE='Slit Position:            ')
header_v_exp(11) = WIDGET_TEXT(a12,XSIZE=10,YSIZE=1)

a13  = WIDGET_BASE(info_abase, /ROW)
a131 = WIDGET_LABEL(a13, VALUE='Slit number:              ')
header_v_exp(12) = WIDGET_TEXT(a13,XSIZE=10,YSIZE=1)

a14  = WIDGET_BASE(info_abase, /ROW)
a141 = WIDGET_LABEL(a14, VALUE='Mirror Position:          ')
header_v_exp(13) = WIDGET_TEXT(a14,XSIZE=10,YSIZE=1)

a15  = WIDGET_BASE(info_abase, /ROW)
a151 = WIDGET_LABEL(a15, VALUE='Exposure time (secs):     ')
header_v_exp(14) = WIDGET_TEXT(a15,XSIZE=10,YSIZE=1)

a16  = WIDGET_BASE(info_abase, /ROW)
a161 = WIDGET_LABEL(a16, VALUE='Study counter:            ')
header_v_exp(15) = WIDGET_TEXT(a16,XSIZE=10,YSIZE=1)

a17  = WIDGET_BASE(info_abase, /ROW)
a171 = WIDGET_LABEL(a17, VALUE='Raster counter:           ')
header_v_exp(16) = WIDGET_TEXT(a17,XSIZE=10,YSIZE=1)

a18  = WIDGET_BASE(info_abase, /ROW)
a181 = WIDGET_LABEL(a18, VALUE='Data compression option:  ')
header_v_exp(17) = WIDGET_TEXT(a18,XSIZE=10,YSIZE=1)

a19  = WIDGET_BASE(info_abase, /ROW)
a191 = WIDGET_LABEL(a19, VALUE='Data orientation:         ')
header_v_exp(18) = WIDGET_TEXT(a19,XSIZE=10,YSIZE=1)

a20  = WIDGET_BASE(info_abase, /ROW)
a201 = WIDGET_LABEL(a20, VALUE='Science proc stat (bits): ')
header_v_exp(19) = WIDGET_TEXT(a20,XSIZE=10,YSIZE=1)

a21  = WIDGET_BASE(info_abase, /ROW)
a211 = WIDGET_LABEL(a21, VALUE='Bin factor x/y:           ')
header_v_exp(20) = WIDGET_TEXT(a21,XSIZE=10,YSIZE=1)

a22  = WIDGET_BASE(info_abase, /ROW)
a221 = WIDGET_LABEL(a22, VALUE='Exposure start (date):    ')
header_v_exp(21) = WIDGET_TEXT(a22,XSIZE=10,YSIZE=1)

a23  = WIDGET_BASE(info_abase, /ROW)
a231 = WIDGET_LABEL(a23, VALUE='Exposure start (UT time): ')
header_v_exp(22) = WIDGET_TEXT(a23,XSIZE=10,YSIZE=1)

a24  = WIDGET_BASE(info_abase, /ROW)
a241 = WIDGET_LABEL(a24, VALUE='Exposure number:          ')
header_v_exp(23) = WIDGET_TEXT(a24,XSIZE=10,YSIZE=1)

a25  = WIDGET_BASE(info_abase, /ROW)
a251 = WIDGET_LABEL(a25, VALUE='Sun sensor pitch:         ')
header_v_exp(24) = WIDGET_TEXT(a25,XSIZE=10,YSIZE=1)

a26  = WIDGET_BASE(info_abase, /ROW)
a261 = WIDGET_LABEL(a26, VALUE='Sun sensor yaw:           ')
header_v_exp(25) = WIDGET_TEXT(a26,XSIZE=10,YSIZE=1)

a27  = WIDGET_BASE(info_abase, /ROW)
a271 = WIDGET_LABEL(a27, VALUE='Solar X:                  ')
header_v_exp(26) = WIDGET_TEXT(a27,XSIZE=10,YSIZE=1)

a28  = WIDGET_BASE(info_abase, /ROW)
a281 = WIDGET_LABEL(a28, VALUE='Solar Y:                  ')
header_v_exp(27) = WIDGET_TEXT(a28,XSIZE=10,YSIZE=1)

a29  = WIDGET_BASE(info_abase, /ROW)
a291 = WIDGET_LABEL(a29, VALUE='Event status:             ')
header_v_exp(28) = WIDGET_TEXT(a29,XSIZE=10,YSIZE=1)

a30  = WIDGET_BASE(info_abase, /ROW)
a301 = WIDGET_LABEL(a30, VALUE='Event level:              ')
header_v_exp(29) = WIDGET_TEXT(a30,XSIZE=10,YSIZE=1)

a31  = WIDGET_BASE(info_abase, /ROW)
a311 = WIDGET_LABEL(a31, VALUE='Science counter:          ')
header_v_exp(30) = WIDGET_TEXT(a31,XSIZE=10,YSIZE=1)   

;
;  realize (ie make appear) the top and embedded widgets
;
WIDGET_CONTROL, header_v_base, /realize

end
