;+
; Project     : SOHO - CDS           
;                                                                   
; Name        : MAIN_EVENT
;                                                   
; Purpose     : Services the widget events from MAIN_MENU.
;                                                   
; Explanation : The EGSE science analysis package is controlled from the
;               top level widget set up in MAIN_MENU.  This routine services
;               all the events generated from within that widget.
;                                                   
; Use         : Only used by XMANAGER to service MAIN_MENU
;       
; Inputs      : ev  -  structure of event generated
;                                                   
; Opt. Inputs : None
;                                                   
; Outputs     : None
;                                                   
; Opt. Outputs: None
;                                                   
; Keywords    : None
;
; Calls       : None
;                                                   
; Restrictions: Only internal use in EGSE science analysis
;                                                   
; Side effects: None
;                                                   
; Category    : EGSE
;                                                   
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;                                                   
; Modified    : To handle changed Done button and Save variables option, CDP
;               27-Oct-93
;               Calibration version, CDP, 16-Dec-93
;
; Version     : Version 3, 16-Dec-93
;-                                       

PRO main_event, ev

;
;  Pick up all the COMMON blocks for communication of variables
;
@VDSData.com
@GISData.com
@Rawscience.com
@MainWidgets.com
@VDSWidgets.com
@HeaderWidgets.com
@SpecialWidgets.com
@GISWidgets.com
@IO_units.com
@Mode.com
@Packets.com
@Images.com
@ReviewWidgets.com
@RawData.com
@CalFits.com
@GAS_Details.com
@CalSeq.com
@Monitor.com
@Check_Setup.com
@Posn_Details.com

;
;  WORKPROC is the name of the routine to be registered as a background
;  task and which actually performs the telemetry reception.
;
workprocname = "workproc"


;
;  determine the type of widget event to be serviced
;
type = TAG_NAMES(ev, /structure)


;
;  if it is a button then retrieve the user value (careful it is called
;  plain 'value'!)
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_UVALUE=value


;
;  begin to act depending on the identification of the widget
;

;
;  if a top level DONE was requested, everything dies
;                 ====

   if (value EQ 'Done') then begin
      on_ioerror, going
      if n_elements(replay_unit) gt 0 then close,replay_unit
      if n_elements(realtime_unit) gt 0 then close,realtime_unit
      going:
      WIDGET_CONTROL, /destroy, ev.top
   endif 
;
;  request was to START receipt of telemetry
;                 =====

   IF (value EQ 'Start') THEN BEGIN


;
;  check have some gas details
;
      if datatype(calhdr,1) ne 'Structure' then  begin
         bell
         flash_msg,msg_widg,'Gas details not defined - do it now!'
         return
      endif


;
;  if we are already running then ignore and and point it out
;
      if sci_going then begin
         bell
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_V="Data acquisition already started."
      endif else begin
;
; actions are different for different ingest modes..
; here REPLAY mode 	
;      =====

         IF (sci_mode EQ 0) THEN Begin

;
;  if input was just paused rather than stopped restart it by restarting
;  workproc in the background.
;  **** NB this mode is NOT IMPLEMENTED yet ****
;
            IF (sci_pause EQ 1) THEN BEGIN
               XBACKREGISTER, workprocname, ev.top
; 
; disable the analysis routines because of system overheads
;

               ctrl_analysis, 0

;
;  encourage user
;                      
               WIDGET_CONTROL, msg_widg, /append, $
                               SET_VALUE=systime()+" Data acquisition resumed"

;
;  set current mode in COMMON variable
;
               sci_pause = 0
               RETURN
            ENDIF
   

;
;  start replay mode was requested so we need some data files, check they
;  are defined, if so, open the first
;
            file_seq_no = 0
            num_data_files = n_elements(file_name)
            if num_data_files gt 0 then begin
               break_file,file_name(file_seq_no),disk,dir,rfile,rext
               widget_control,rep_widg,set_val=rfile+rext
               replay_unit = 1
               OPENR, replay_unit, file_name(file_seq_no), ERROR = ioerr
                     
               IF (ioerr NE 0) THEN BEGIN
                  WIDGET_CONTROL, msg_widg, /append, $
                                  SET_VALUE=!ERR_STRING
                  return
               ENDIF 
            endif else begin

;
;  if no data files defined, warn and exit
;
               WIDGET_CONTROL, msg_widg, /append, $
                               SET_V='No data files defined'
               return
            endelse 

;
;  were we meant to skip to a particular packet?
;
            widget_control,spacket_widg,get_value=skip_pack
            if valid_num(skip_pack(0),/integer) then begin
              widget_control,msg_widg, /append, $
                             set_val='Skipping to packet '+skip_pack(0)
              point_lun,replay_unit,long(skip_pack(0))*306L
            endif else begin
              bell
              widget_control,msg_widg, /append, $
                 set_val='** Error - invalid packet skip requested. **'
                 skip_pack = 0
                 widget_control,spacket_widg,set_val='0'
            endelse
         ENDIF ELSE BEGIN
;
; REALTIME  mode selected so set the C program read_science going to pipe
; ========  the telemetry.
;
            WIDGET_CONTROL, msg_widg, /append, $
                            SET_V='Starting read_science'
            SPAWN, 'read_science',UNIT=realtime_unit,/NOSHELL
            skip_pack = 0
         ENDELSE

;
; In either mode we should now be ready so make XMANAGER start calling 
; the WORKPROC routine
;
         XBackRegister, workprocname, ev.top

;
;  Disable analysis widgets because of system overheads
;
         ctrl_analysis, 0
    
;                        
; and send message to operator
;
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_VALUE=systime()+" Data acquisition started"

;
;  as an indicator that all is well, the number of packets received is 
;  displayed in a widget
;
         packet_no = LONG(skip_pack(0))
         WIDGET_CONTROL, packet_widg, SET_VALUE=STRING(packet_no)

;
;  set flag to tell the world we are up and running
;
         sci_going = 1
;
;  and clear out the packet statistics variable and clear display 
;
         review_stats(*) = 0
         if reviewing then for i=0,26 do widget_control,review_expa(i),set_v=' '
      endelse
   ENDIF

;
; STOP was requested so stop XMANAGER calling the workproc
; ====

   IF (value EQ 'Stop') THEN BEGIN

;
;  double check we were going in the first place
;
     if sci_going then begin
        XBackRegister, /UNREGISTER, workprocname, ev.top 

;
;  science input was going but was last packet seen?  If not then store data
;  anyway as a safeguard if we have all relevant information.
;
        if (last_pkt_id eq '22'x) and not last_packet then begin
          if check_headers('VDS') then begin
            WIDGET_CONTROL, msg_widg, /append, $
                SET_VALUE="Performing safety dump of data to VDS array"
            dcmp_win    = VDSrasterhdr.VDSwin(0:VDSrasterhdr.NumDataWindows-1)
            scheme      = VDSrasterhdr.Scihead.DataCompScheme 
            option      = VDSrasterhdr.Scihead.DataCompOption
            detector    = 0
            print,'Decompressing VDS data with...'
            print,'Scheme/Data comp method: ',scheme
            print,'Option/Data comp parameter: ',option
            print,'Data orientation: ',vds_orientation
            buff16_sz = n_elements(sci_buffer)/2
            sci_buff16 = dcmpdata(fix(sci_buffer,0,buff16_sz),dcmp_win,$
                                  detector,scheme,option,vds_orientation)
            VDS_Ext_image, sci_buff16, VDSrasterhdr, vds_data_str.vds_exp, $
                           msg_widg
            if vds_display then begin
               vds_data_str.exp_in_a = vds_data_str.vds_exp
               vds_data_str.curr_a_img = $
                            vds_deselect(VDSrasterhdr,vds_data_str.exp_in_a - $
                                                      vds_data_str.first_in_mem)
               Plot_VDS, vds_awidg, vds_data_str.curr_a_img
            endif
          endif else begin
            bell
            widget_control,msg_widg,/append,$
               set_val='Insufficient header information to retrieve data array.'
          endelse
        endif
;
;  enough GIS info?
;
        if (last_pkt_id eq '21'x) and not last_packet then begin
          if check_headers('GIS') then begin
            WIDGET_CONTROL, msg_widg, /append, $
                         SET_VALUE="Performing safety dump of data to GIS array"

            dcmp_win = replicate({StartX:0,StartY:0,LengthX:0,LengthY:0},$
                                 GISrasterhdr.NumDataWindows)
            for i=0,GISrasterhdr.NumDataWindows-1 do begin
               dcmp_win(i).StartX  = GISrasterhdr.GISwin(i).Start
               dcmp_win(i).StartY  = 0
               dcmp_win(i).LengthX = GISrasterhdr.GISwin(i).Length
               dcmp_win(i).LengthY = 1
            endfor
            scheme = GISrasterhdr.Scihead.DataCompScheme 
            option = GISrasterhdr.Scihead.DataCompOption
            vds_orientation = 0
            detector = 1
            print,'Decompressing GIS data with...'
            print,'Scheme/Data comp method: ',scheme
            print,'Option/Data comp parameter: ',option
            print,'Data orientation: ',vds_orientation
            buff16_sz = n_elements(sci_buffer)/2
            sci_buff16 = dcmpdata(fix(sci_buffer,0,buff16_sz),dcmp_win,detector,$
                                  scheme,option,vds_orientation)
      
            GIS_Ext_plot, sci_buff16, GISrasterhdr, gis_plot, $
                                           gis_data_str.gis_exp, msg_widg       
            if gis_display then begin
               Plot_GIS, $
              gis_deselect(gisrasterhdr,gis_plot,gis_data_str.gis_exp,msg_widg)
            endif
          endif else begin
            bell
            widget_control,msg_widg,/append,$
               set_val='Insufficient header information to retrieve data array.'
          endelse
        endif

;
; Safe to enable analysis again
;
        ctrl_analysis, 1

;
; Message to operator
;
        WIDGET_CONTROL, msg_widg, /append, $
                        SET_VALUE=systime()+" Data acquisition stopped"
;
;  set flags in COMMON
;
        sci_pause    = 0
        sci_going    = 0
        last_sci_cnt = 0

;
;  close the appropriate unit
;
        if (sci_mode EQ 0) THEN begin
           if n_elements(replay_unit) gt 0 then CLOSE,replay_unit
           file_seq_no = num_data_files + 1
           widget_control,rep_widg,set_val=' '
        endif else begin  
           if n_elements(realtime_unit) gt 0 then CLOSE, realtime_unit 
        endelse          
     endif else begin

;
;  not actually receiving data (according to sci_going) so inform
;
        WIDGET_CONTROL, msg_widg, /append, $
                        SET_V="Data acquisition NOT started yet!"
     endelse

;
;  set all header reception flags
;
     have_v_rst_hdr = 0
     have_v_exp_hdr = 0
     have_g_rst_hdr = 0
     have_g_exp_hdr = 0

  ENDIF


;
;  want to SELECT data files
;          ======
  
   IF (value EQ 'Select TM datafiles') THEN BEGIN
      cds_files_in,file_name
      file_seq_no = 0
      num_data_files = n_elements(file_name)
   endif

;
;  want to REVIEW data files (science packets)
;          ======
  
   IF (strmid(value,0,6)  EQ 'Review') THEN BEGIN
      review_tm_menu, value
      widget_control,rev_control_base,sensitive=0
      reviewing = 1
      XMANAGER,"review_tm", review_base
   endif

;
;  want VDS display and analysis
;       ===

   IF (value EQ 'VDS') THEN BEGIN
          vds_menu
          vds_display = 1
          WIDGET_CONTROL, vds_base, MAP=1
          if vds_data_str.exp_in_a  ge 0 then begin
             Plot_VDS, vds_awidg,vds_data_str.curr_a_img
             Update_Expinfo, VDS_exphdr(vds_data_str.exp_in_a), $
                             VDSrasterhdr, vds_exp_awidg
          endif else begin
             if vds_data_str.vds_exp ge 0 then begin
                vds_data_str.exp_in_a = vds_data_str.vds_exp
                vds_data_str.curr_a_img = $
                      vds_deselect(VDSrasterhdr,vds_data_str.exp_in_a - $
                                                vds_data_str.first_in_mem)
                Plot_VDS, vds_awidg,vds_data_str.curr_a_img
                Update_Expinfo, VDS_exphdr(vds_data_str.exp_in_a), $
                                VDSrasterhdr, vds_exp_awidg
             endif
          endelse
          XMANAGER, "vds",vds_base
   ENDIF

;
;  want to display and analyse GIS data
;                              ===

   IF (value EQ 'GIS') THEN BEGIN
       gis_menu
       gis_display = 1
       WIDGET_CONTROL, gis_base, MAP=1
       if gis_data_str.exp_in_a ge 0 then begin
          Plot_GIS,gis_data_str.curr_a_data
          Update_expinfo, $
               GIS_exphdr(gis_data_str.exp_in_a), GISrasterhdr, gis_exp_awidg
       endif else begin   
          if gis_data_str.gis_exp ge 0 then begin
             gis_data_str.exp_in_a = gis_data_str.gis_exp
             gis_data_str.curr_a_data = $
               gis_deselect(gisrasterhdr,gis_plot,gis_data_str.gis_exp,msg_widg)
             Plot_GIS,gis_data_str.curr_a_data
             Update_expinfo, $
                  GIS_exphdr(gis_data_str.gis_exp), GISrasterhdr, gis_exp_awidg
          endif
       endelse
       XMANAGER, "gis",gis_base
   ENDIF

;
;  want GAS details
;       ===

   IF (value EQ 'GAS') THEN BEGIN
          WIDGET_CONTROL, gas_but_widg, SENSITIVE=0
          gas_menu
          WIDGET_CONTROL, gas_base, MAP=1
          XMANAGER, "gas",gas_base
   ENDIF

;
;  want POSITION details
;       ========

   IF (value EQ 'POSN') THEN BEGIN
          WIDGET_CONTROL, posn_but_widg, SENSITIVE=0
          posn_menu
          WIDGET_CONTROL, posn_base, MAP=1
          XMANAGER, "posn",posn_base
   ENDIF

;
;  want to CHECK SETUP
;          ===========

   IF (value EQ 'CHECK') THEN BEGIN
          WIDGET_CONTROL, check_widg, SENSITIVE=0
          check_set_menu
          WIDGET_CONTROL, cal_set_base, MAP=1
          XMANAGER, "check_set",cal_set_base
   ENDIF

;
;  want Calibration Sequence details
;       ====================

   IF (value EQ 'SEQ') THEN BEGIN
          cal_seq_menu
          WIDGET_CONTROL, cal_seq_base, MAP=1
          XMANAGER, "cal_seq",cal_seq_base
   ENDIF

;
;  want display of VDS RASTER header information only
;                  === ======

   IF value eq 'Raster_VDS' then begin
          header_select = -2
          header_vds_menu
          WIDGET_CONTROL,header_select_vw,set_val='Raster header only'
          WIDGET_CONTROL, header_v_base, MAP=1
          WIDGET_CONTROL, header_map_base, SENSITIVE=0
          XMANAGER, "header_v",header_v_base
   ENDIF

;
;  want display of VDS raster header information plus exposure updates
;                  === ======                         ========

   IF value eq 'Expose_VDS' then begin
          header_select = -1
          header_vds_menu
          WIDGET_CONTROL,header_select_vw,$
                         set_val='Raster header + exposure update'
          WIDGET_CONTROL, header_v_base, MAP=1
          WIDGET_CONTROL, header_map_base, SENSITIVE=0
          XMANAGER, "header_v",header_v_base
   ENDIF

;
;  want display of GIS RASTER header information only
;                  === =====

   IF value eq 'Raster_GIS' then begin
          header_select = 1
          header_gis_menu
          WIDGET_CONTROL,header_select_gw,$
                         set_val='Raster header only'
          WIDGET_CONTROL, header_g_base, MAP=1
          WIDGET_CONTROL,header_map_base,SENSITIVE=0
          XMANAGER, "header_g",header_g_base
   ENDIF

;
;  want display of GIS RASTER header information plus EXPOSURE updates
;                  === ======                         ========
   IF value eq 'Expose_GIS' then begin
          header_select = 2
          header_gis_menu
          WIDGET_CONTROL,header_select_gw,$
                         set_val='Raster header + exposure update'
          WIDGET_CONTROL, header_g_base, MAP=1
          WIDGET_CONTROL,header_map_base,SENSITIVE=0
          XMANAGER, "header_g",header_g_base
   ENDIF

;
;  want display of contents of special "DEFERRED" packet
;                                       ========

   IF value eq 'SP_DEF' then begin
       sp_request = '02'x
       sp_def_menu
       WIDGET_CONTROL, sp_def_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_def",sp_def_base
   ENDIF

;
;  want display of contents of special "IEF" packet
;                                       ===

   IF value eq 'SP_IEF' then begin
       sp_request = '0E'x
       sp_ief_menu
       WIDGET_CONTROL, sp_ief_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_ief",sp_ief_base
   ENDIF

;
;  want display of contents of special "HEALTH" packet
;                                       ======

   IF value eq 'SP_HM' then begin
       sp_request = '08'x
       sp_health_menu
       WIDGET_CONTROL, sp_health_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_health",sp_health_base
   ENDIF


;
;  want display of contents of special "IMIF (MCU support)" packet
;                                       ===================

   IF value eq 'SP_MCU' then begin
       sp_request = '01'x
       sp_imif_menu
       WIDGET_CONTROL, sp_imif_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_imif",sp_imif_base
   ENDIF

;
;  want display of contents of special "IMIF interface module" packet
;                                       ======================

   IF value eq 'SP_IMIF' then begin
       sp_request = '09'x
       sp_imifim_menu
       WIDGET_CONTROL, sp_imifim_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_imifim",sp_imifim_base
   ENDIF


;
;  want display of contents of special "ERROR" module packet
;                                       =====

   IF value eq 'SP_ERR' then begin
       sp_request = '07'x
       sp_err_menu
       WIDGET_CONTROL, sp_err_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_err",sp_err_base
   ENDIF


;
;  want display of contents of special "RASTER TABLE" packet
;                                       ============

   IF value eq 'SP_RT' then begin
       sp_request = '04'x
       sp_gen_menu,'Raster Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "LINE LIST TABLE" packet
;                                       ===============

   IF value eq 'SP_LL' then begin
       sp_request = '03'x
       sp_gen_menu,'Data Extraction Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF


;
;  want display of contents of special "SEQUENCE TABLE" packet
;                                       ==============

   IF value eq 'SP_ST' then begin
       sp_request = '05'x
       sp_gen_menu,'Sequence Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "HARDWARE TABLE" packet
;                                       ==============

   IF value eq 'SP_HARD' then begin
       sp_request = '0a'x
       sp_gen_menu,'VDS Hardware Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "MODE TABLE" packet
;                                       ==========

   IF value eq 'SP_MT' then begin
       sp_request = '0b'x
       sp_gen_menu,'Mode Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "ENGINEERING TABLE" packet
;                                       =================

   IF value eq 'SP_ET' then begin
       sp_request = '0c'x
       sp_gen_menu,'Engineering Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "SEQUENCE CONTROLLER TABLE" packet
;                                       =========================

   IF value eq 'SP_SC' then begin
       sp_request = '0d'x
       sp_gen_menu,'Sequence Controller Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "CDS HOUSEKEEPING TABLE" packet
;                                       ======================

   IF value eq 'SP_HK' then begin
       sp_request = '06'x
       sp_gen_menu,'CDS Housekeeping Table Dump'
       WIDGET_CONTROL, sp_gen_base, MAP=1
       WIDGET_CONTROL, sp_map_base, SENSITIVE=0
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  switch on reception of RAW GIS data
;                         =======
;
   if value eq 'RAW_GIS' then begin
      raw_gis_request = 1
      raw_gis_menu
      WIDGET_CONTROL, raw_gis_base, MAP=1
      WIDGET_CONTROL, raw_map_base, SENSITIVE=0
      XMANAGER, "raw_gis",raw_gis_base
   endif

;
;  switch on reception of RAW VDS data
;                         =======
;
   if value eq 'RAW_VDS' then begin
      raw_vds_request = 1
      raw_vds_menu
      WIDGET_CONTROL, raw_vds_base, MAP=1
      WIDGET_CONTROL, raw_map_base, SENSITIVE=0
      XMANAGER, "raw_vds",raw_vds_base
   endif

;
;  switch on Monitor VDS mode
;            =======
;
   if value eq 'MON_VDS' then begin
      v_monitor_mode = 1
      mon_menu
      WIDGET_CONTROL, mon_map_base, SENSITIVE=0
      XMANAGER, "mon", mon_base
   endif

;
;  switch on Monitor GIS mode
;            =======
;
   if value eq 'MON_GIS' then begin
      g_monitor_mode = 1
      mon_menu
      WIDGET_CONTROL, mon_map_base, SENSITIVE=0
      XMANAGER, "mon", mon_base
   endif

;
;  switch on Monitor mechanisms mode
;            =======
;
   if value eq 'MON_MEC' then begin
      m_monitor_mode = 1
      mon_menu
      WIDGET_CONTROL, mon_map_base, SENSITIVE=0
      XMANAGER, 'mon', mon_base
   endif

;
;  request change to REPLAY mode
;                    ======

   IF (value EQ 'Replay') THEN BEGIN 
;
;  if we are still running then warn and ignore
;
      if sci_going then begin
         for i=0,1 do WIDGET_CONTROL, mode_widg(i),SET_BUTTON=0
         WIDGET_CONTROL, mode_widg(1),SET_BUTTON=1
         bell,3
         WIDGET_CONTROL, msg_widg, /append, set_val=' '
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_V="Please STOP acquisition before changing modes."
      endif else begin
         sci_mode = 0
         for i=0,1 do WIDGET_CONTROL, mode_widg(i),SET_BUTTON=0
         WIDGET_CONTROL, mode_widg(0),SET_BUTTON=1
      endelse
   ENDIF

;
;  request change to REALTIME mode
;                    ========

   IF (value EQ 'Realtime') THEN BEGIN       
;
;  if we are still running then warn and ignore
;
      if sci_going then begin
         for i=0,1 do WIDGET_CONTROL, mode_widg(i),SET_BUTTON=0
         WIDGET_CONTROL, mode_widg(0),SET_BUTTON=1
         bell,3
         WIDGET_CONTROL, msg_widg, /append, set_val=' '
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_V="Please STOP acquisition before changing modes."
      endif else begin
         sci_mode = 1
         for i=0,1 do WIDGET_CONTROL, mode_widg(i),SET_BUTTON=0
         WIDGET_CONTROL, mode_widg(1),SET_BUTTON=1
      endelse
   ENDIF

;
;  request change to FITS WRITING mode
;                    ============

   IF (value EQ 'FITS_ON') THEN BEGIN       
      writing_fits = 1
      for i=0,1 do WIDGET_CONTROL, fits_widg(i),SET_BUTTON=0
      WIDGET_CONTROL, fits_widg(0),SET_BUTTON=1
      widget_control,fitsfile_widg,set_val=cal_fits_file
   ENDIF

;
;  request change to Non-FITS WRITING mode
;                    ================

   IF (value EQ 'FITS_OFF') THEN BEGIN       
      writing_fits = 0
      for i=0,1 do WIDGET_CONTROL, fits_widg(i),SET_BUTTON=0
      WIDGET_CONTROL, fits_widg(1),SET_BUTTON=1
      widget_control,fitsfile_widg,set_val=' '
   ENDIF

;
;  requested a SAVE of IDL variables
;              ====

   IF (value EQ 'Save variables') THEN BEGIN
      Save_IDL, msg_widg
   ENDIF
  

ENDIF

END


