;+
; Project     : SOHO - CDS     
;                   
; Name        : MAIN_MENU
;               
; Purpose     : Defines the EGSE science analyser main window. 
;               
; Explanation : 
;               
; Use         : Only called from SCI_ANA
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only internal use in EGSE science analysis package
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Changed close down to a 'Done' button and put 'Save' under
;               Control PDM.  CDP, 27-Oct-93
;               Add reception of Raw GIS/VDS data, CDP, 16-Dec-1993
;
;
; Version     : Version 3, 16-Dec-93
;-            
 
PRO main_menu


;
;  main COMMON variables
;
@MainWidgets.com
@GISData.com
@VDSData.com
@CalFits.com
@GAS_Details.com
@Check_Setup.com
@Posn_Details.com

;
;  individual mode/FITS button widget id's
;
mode_widg = LONARR(2)
fits_widg = lonarr(2)

;
;  define main widget
;
main_base = WIDGET_BASE (TITLE='Science Data Analyser', /FRAME, /COLUMN)
menu_base = WIDGET_BASE (main_base, /ROW)
button_base = widget_base(main_base,/column,space=100)
file_base   = widget_base(main_base,/row,space=100)

;
;  create the exit "DONE" button
;
doneid = widget_button(menu_base, value='EXIT', uvalue='Done')

;
;  and the various pulldown menus
;
XPDmenu, ['"Control" {',$
             '"Start"',$
             '"Stop"',$
             '"Save variables"',$
             '"Select TM datafiles"','}'],$
                 menu_base, BASE=control_base

XPDmenu, ['"Review contents" {',$
             '"All"          Review_all','}'],$
                 menu_base, BASE=rev_control_base


XPDmenu, ['"HeaderInfo"{',$
          '"VDS-raster header only"          Raster_VDS',     $
          '"VDS-update with exposure "       Expose_VDS',     $
          '"GIS-raster header only"          Raster_GIS',     $
          '"GIS-update with exposure"        Expose_GIS','}'],$
                 menu_base,BASE=header_map_base

XPDmenu, ['"View specials"{',$
          '"Deferred"              SP_DEF', $
          '"MCU backup        "    SP_MCU',$ 
          '"Data Extraction table" SP_LL',  $
          '"Raster table"          SP_RT',  $  
          '"Sequence table"        SP_ST',  $
          '"CDS h/k table"         SP_HK',  $
          '"Error module"          SP_ERR', $
          '"Health module"         SP_HM',  $
          '"IMIF interface module" SP_IMIF',$
          '"VDS Hardware table"    SP_HARD',$
          '"Mode table"            SP_MT',  $
          '"Engineering table"     SP_ET',  $
          '"Seq. cont. table"      SP_SC',  $
          '"IEF table"             SP_IEF','}'],$
                 menu_base,BASE=sp_map_base

XPDmenu, ['"Raw Data" {',$
             '"GIS"       RAW_GIS',$
             '"VDS"       RAW_VDS','}'],$
                 menu_base, BASE=raw_map_base

XPDmenu, ['"Monitor" {',$
             '"GIS"       MON_GIS',$
             '"VDS"       MON_VDS',$
             '"Mechanisms" MON_MEC','}'],$
                 menu_base, BASE=mon_map_base

;
;  form buttons to display data
;
vdsid  = widget_button(menu_base, value='View VDS', uvalue='VDS')
gisid  = widget_button(menu_base, value='View GIS', uvalue='GIS')

;
;  button to define gas characteristics
;
gas_but_widg  = widget_button(menu_base, value='Gas details', uvalue='GAS')

;
;  button to define source location
;
posn_but_widg  = widget_button(menu_base,value='Source location',uvalue='POSN')

;
;  button to obtain selection of calibration sequence
;
seqid  = widget_button(menu_base, value='Sequence details', uvalue='SEQ')





;
;  second layer..............
;
;  buttons to determine the acquisition mode
;
button1_base = widget_base(button_base,/row,space=100)
XMENU, ["Replay","Realtime"], button1_base, BUTTON=mode_widg, $
      BASE=input_rt_widg, /EXCLUSIVE,/frame,/no_release,$
      uvalue=['Replay','Realtime'],title='Telemetry input mode.'


;
;  button to switch FITS writing on/off
;
XMENU, ["On","Off"], button1_base, BUTTON=fits_widg, $
      BASE=input_rt_widg, /EXCLUSIVE,/frame,/no_release,$
      uvalue=['FITS_ON','FITS_OFF'],title='Writing to FITS files.


;
;  button to check setup
;
check_widg  = widget_button(button1_base, value='Check setup', uvalue='CHECK')


;
;  create text widgets to hold current replay file name (if any) and
;  current FITS output file.
;
rep_base = widget_base(file_base,/column,/frame)
rep_lab  = widget_label(rep_base,val=' Current replay file.')
rep_widg = widget_text(rep_base,xsize=15,ysize=1,val=' ')

fits_base = widget_base(file_base,/column,/frame)
fits_lab = widget_label(fits_base,value='Current FITS data file')
fitsfile_widg = widget_text(fits_base,xsize=15,ysize=1,val=' ')





select_base= WIDGET_BASE(main_base, /FRAME, /ROW)
text_base  = WIDGET_BASE(select_base, /column)


  
;
; make packet number widget
;
p_base = widget_base(text_base,/row)
w3 = WIDGET_BASE(p_base, /ROW)
dummy_widg = WIDGET_LABEL(w3, VALUE='Packets received:    ')
packet_widg = WIDGET_TEXT(w3, XSIZE = 12, YSIZE=1)
                        
;
;  make start packet widget
;
w4 = WIDGET_BASE(p_base,/row)
sp_widg = WIDGET_LABEL(w4, VALUE='Start Packet: ')
spacket_widg = WIDGET_TEXT(w4, XSIZE = 6, YSIZE=1,/editable)
widget_control,spacket_widg,set_val='0'
   
;
;  make current packet id widget
;
w5 = WIDGET_BASE(p_base,/row)
sp_widg = WIDGET_LABEL(w5, VALUE='Current Packet ID: ')
cpacket_widg = WIDGET_TEXT(w5, XSIZE = 2, YSIZE=1)
widget_control,cpacket_widg,set_val=' '
   
;
; make message window widget
;
w2 = WIDGET_BASE(main_base, /ROW, /FRAME, YOFFSET=-100)
dummy_widg = WIDGET_LABEL(w2, VALUE=' Messages   : ')
msg_widg = WIDGET_TEXT(w2, XSIZE = 80, YSIZE=30, /scroll)

;
;  realise the main widget to make it all happen
;
WIDGET_CONTROL, /REALIZE , main_base

;
; set default to replay mode and to write FITS files
;
WIDGET_CONTROL, mode_widg(0), SET_BUTTON=1
WIDGET_CONTROL, fits_widg(0), SET_BUTTON=1

WIDGET_CONTROL, main_base, /CLEAR_EVENT


;
;  set it all going
;
XMANAGER, 'main', main_base
   

END

