;+
; Project     : SOHO - CDS     
;                   
; Name        : PLOT_VDS
;               
; Purpose     : Display an image of the VDS data.
;               
; Explanation : 
;               
; Use         : plot_vds, win_widg, img [, /size]
;    
; Inputs      : win_widg  -  widget id of the plotting window
;               img       -  array holding the VDS data
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : full  - if set the complete VDS array (1024x1024) is
;                       displayed, else (0:1023,disp_start:disp_end)
;
; Calls       : None
;               
; Restrictions: For use within EGSE science analysis
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Change default image area plotted, CDP, 26-Oct-93
;               Add line displays if requested, CDP, 7-Jan-93
;               Update and generalize display start/end Y-coord. CDP 8-Mar-94
;
; Version     : Version 4, 8-Mar-94
;-            

PRO Plot_VDS, win_widg, img, SIZE=FULL

;
;  common for line plotting flag and widgets
;
@Cal_Lines.com
@VDSWidgets.com
@VDSData.com

;
;  Calculate non-zero stats and put in info widget
;
n = where(vds_data_str.curr_a_img gt 0)
if n(0) eq -1 then begin
   widget_control,vds_exp_awidg(4),set_val='(0,0)'
endif else begin
   maxi = max(vds_data_str.curr_a_img(n))
   mini = min(vds_data_str.curr_a_img(n))
   widget_control,vds_exp_awidg(4),set_val=fmt_vect([mini,maxi])
endelse

n = where(vds_data_str.curr_b_img gt 0)
if n(0) eq -1 then begin
   widget_control,vds_exp_bwidg(4),set_val='(0,0)'
endif else begin
   maxi = max(vds_data_str.curr_b_img(n))
   mini = min(vds_data_str.curr_b_img(n))
   widget_control,vds_exp_bwidg(4),set_val=fmt_vect([mini,maxi])
endelse


;
;  find window in use and set focus to it
;
WIDGET_CONTROL, win_widg, GET_VALUE = window
WSET, window

;
;  temporary store for scaled image
;
scaled_img = img

;
;  scale data from min to max
;
Scale_Image, scaled_img

;
;  and display that required
;
if KEYWORD_SET(FULL) then begin
    TV, scaled_img
endif else begin
    TV,scaled_img(0:1023,vds_disp_yst:vds_disp_yend) 
endelse

;
;  show lines if wanted
;
if disp_vds_lines then show_vds_lines


END
