;+
; Project     : SOHO - CDS     
;                   
; Name        : POSN_EVENT
;               
; Purpose     : Processes events from the POSN_MENU.
;               
; Explanation : Any events originating within the widgets realized by 
;               POSN_MENU are handled by this routine.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ev  -  the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with POSN_MENU in EGSE calibration routines.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 1-Mar-94
;               
; Modified    : 
;
; Version     : Version 1, 1-Mar-94
;-            

PRO posn_event, ev

;
;  COMMON blocks for widget id's
;
@MainWidgets.com
@Posn_Details.com
      
;
;  interpret type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  might have been a button
;
if (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_UVALUE=value
 
;
;  Done (ie exit) request received
; 
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, posn_base, /destroy
      widget_control, posn_but_widg, sensitive=1
   ENDIF

endif

;
;  or it might have been one of the editable text widgets
;
IF (type EQ 'WIDGET_TEXT') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_UVALUE=uvalue, get_val=value
   value = value(0)
;
;  read the Horizontal position
;
   if uvalue eq 'Hor_posn' then begin
      if valid_num(value) then begin
         widget_control,posn_exp_awidg(0),set_v=string(value,form='(2x,f7.2)')
         cal_hor_posn = value
      endif else begin
         bell
         flash_msg,posn_exp_awidg(0),' Invalid '
         widget_control,posn_exp_awidg(0),$
                        set_val=string(cal_hor_posn,form='(2x,f7.2)')
      endelse
   endif
;
;  read the Vertical position
;
   if uvalue eq 'Vert_posn' then begin
      if valid_num(value) then begin
         widget_control,posn_exp_awidg(1),set_v=string(value,form='(2x,f7.2)')
         cal_vert_posn = value
      endif else begin
         bell
         flash_msg,posn_exp_awidg(1),' Invalid '
         widget_control,posn_exp_awidg(1),$
                        set_val=string(cal_vert_posn,form='(2x,f7.2)')
      endelse
   endif

ENDIF
END
