;+
; Project     : SOHO - CDS     
;                   
; Name        : RAW_GIS_EVENT
;               
; Purpose     : Handles events from RAW_GIS_MENU widgets.
;               
; Explanation : Any event generated by the widgets in the display
;               of raw GIS data is handled by this routine.
;               
; Use         : Only called by XMANAGER.
;    
; Inputs      : ev - the structure associated with the event.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for EGSE/sci_ana use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 16-Dec-93
;-            

PRO raw_gis_event, ev

;
;  COMMON blocks for communication of widget id's and counter.
;
@MainWidgets.com
@RawData.com
@Packets.com
      
;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  it should only have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  request to finish/exit from the widget
; 
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, raw_map_base, SENSITIVE=1
      widget_control, raw_gis_base, /destroy
      raw_gis_request = 0
      raw_gis_dump = 0
      if n_elements(raw_gis_unit) gt 0 then free_lun,raw_gis_unit
   ENDIF

;
;  change display format to decimal..
;
   IF (value EQ 'Decimal') then begin
      raw_format = 1 
      widget_control,raw_gformat_def,set_value='Decimal'
   endif

;
;  change display format to hexadecimal..
;
   IF (value EQ 'Hex') then begin
      raw_format = 2 
      widget_control,raw_gformat_def,set_value='Hex'
   endif

ENDIF

;
;  start dump of data
;
   if (value eq 'Dump ON') then begin
      get_utc,ut
      raw_gis_file = concat_dir('$CDS_CAL_RAW',$
                                'raw_gis_'+strmid(utc2str(ut),0,16))
      raw_gis_dump = 1
      on_ioerror, mess_err
      openw,raw_gis_unit,raw_gis_file,/get_lun
      widget_control, raw_gis_file_def, set_val=raw_gis_file
      return
mess_err:
      bell
      flash_msg, msg_widg, 'Error opening Raw GIS data file.'
      return
   endif

;
;  end dump of raw GIS data
;
   if (value eq 'Dump OFF') then begin
      raw_gis_dump = 0
      if n_elements(raw_gis_unit) gt 0 then free_lun,raw_gis_unit
      widget_control, raw_gis_file_def, set_val='None'
   endif


;
;  start/restart display to screen
;
   if (value eq 'Display ON') then raw_gis_display = 1

;
;  halt display to screen
;
   if (value eq 'Display OFF') then raw_gis_display = 0

      
END
