;+
; Project     : SOHO - CDS     
;                   
; Name        : READ_SCI_CNT()
;               
; Purpose     : Read the science packet counter (2 bytes).
;               
; Explanation : Following the 20-byte packet header in the exposure or 
;               science data packets there is a science packet counter 
;               (2-bytes). This routine simply reads those two bytes in
;               preparation for reading the exposure header information or
;               the science data.  
;               
; Use         : counter = read_sci_cnt( unit, instrument)
;    
; Inputs      : unit       -  logical unit from which to read data
;               instrument -  the instrument id indicating which detector
;                             is in use - needed to determine which display
;                             to use.
;               
; Opt. Inputs : None
;               
; Outputs     : Function value returned is the counter (-1 on error).
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use within EGSE sci_ana program.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 18-Oct-93
;               
; Modified    : Cut call to dec2bin to test for last packet, CDP, 28-Oct-93
;               Cater for IDL5.2 hex bug, CDP, 1-6-99
;
; Version     : Version 3, 1-Jun-99
;-            

FUNCTION read_sci_cnt, unit, inst

;
;  COMMON block for widget and flag variables communication
;
@HeaderWidgets.com

;
;  initialise the output
;
counter = FIX(0)

;
; on i/o error return value -1
;
ON_IOERROR, ERR_sci_count

;
;  read the counter from current data unit
;   
READU,unit,counter 
   
;
;  byteswap the value
;
counter = ByteSwap(Counter) 

;
;  is it the last? (MSB will be set)
;
last = 0
if (counter and '8000'xl) eq '8000'xl then last = 1
   

;
;  display format either decimal or hex
;
if header_format eq 1 then fmt = '(6x,i4)' else fmt = '(6x,z4)'

;
;  GIS display requested
;
if header_select gt 0 and (inst eq '11'xl or inst eq '21'xl) then begin
   if last then begin
      outc = string(counter+32768,' -last',format='(i4,a)')
      widget_control,header_g_exp(28),set_value=outc
   endif else begin
      widget_control,header_g_exp(28),set_value=string(counter,format=fmt)
   endelse
endif

if header_select lt 0 and (inst eq '12'xl or inst eq '22'xl) then begin
   if last then begin
      outc = string(counter+32768,' -last',format='(i4,a)')
      widget_control,header_v_exp(30),set_value=outc
   endif else begin
      widget_control,header_v_exp(30),set_value=string(counter,format=fmt)
   endelse
endif

;
;  success and error returns
;
RETURN,counter
ERR_sci_count: RETURN,-1

END
