;+
; Project     : SOHO - CDS     
;                   
; Name        : REVIEW_TM_EVENT
;               
; Purpose     : Processes widget events from the file review menu.
;               
; Explanation : Any widget events originating in the routine REVIEW_TM_MENU
;               which displays the data file packet statistics 
;               is dealt with by this routine.  The options are limited at
;               present to closing the widget.
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the structure of the event generated.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for interal use of EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 19-oct-93
;               
; Modified    : To detect "Done" button instead of "file/close".  CDP 28-Oct-93
;               Detect "Reset" button and act.  CDP 15-Nov-93
;               Include widget 19 for new packet id='09'x. CDP 30-Nov-93
;               Include raw data for GIS and VDS, CDP, 16-Dec-1993
;
;
; Version     : Version 5, 16-Dec-93
;-            

PRO review_tm_event, ev

;
;  COMMON blocks for communication of variables
;
@MainWidgets.com
@ReviewWidgets.com

;
; find out type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  event should only have been generated by a button
;
if (type EQ 'WIDGET_BUTTON') then begin

   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  close, ie destroy the whole widget
; 
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, review_base, /destroy
      widget_control, rev_control_base, sensitive=1
      reviewing = 0
   ENDIF

;
;  Reset button 
;
   if (value eq 'Reset') then begin
      for i=0,26 do begin
         widget_control, review_expa(i), set_val=' '
      endfor
   endif

endif

end

