;+
; Project     : SOHO - CDS     
;                   
; Name        : REVIEW_TM_MENU
;               
; Purpose     : Defines and realises the telemetry review widget. 
;               
; Explanation : One of the options available within the EGSE science analysis
;               program is to monitor the statistics of the incoming packets,
;               ie show some statistics of the variety of packets being
;               received.  This procedure defines and realizes the widget
;               which displays the statistics.
;               
; Use         : Only called from MAIN_MENU
;    
; Inputs      : selection  -  the general packet selection to be considered.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for internal use in EGSE science analysis
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 19-Oct-93
;               
; Modified    : Give it a "Reset" button.  CDP 15-Nov-93
;               Include raw data boxes, CDP, 16-Dec-1993
;               Display any current counts on entry.  CDP, 8-Feb-94
;
; Version     : Version 4, 8-Feb-94
;-            

PRO review_tm_menu, selection


;
;  COMMON blocks for communication
; 
@ReviewWidgets.com
@MainWidgets.com

;
;  trap double clicks
;
if xregistered('review_tm') then return



;
;  select title
;
if selection eq 'Review_science' then $
                 title = 'Telemetry statistics for VDS/GIS packets'
if selection eq 'Review_specials' then $
                 title = 'Telemetry statistics for special science packets'
if selection eq 'Review_all' then $
                 title = 'Telemetry statistics for all science/special packets'

;
;  get the main base
;
review_base = widget_base(title=title,/frame,/column,group=main_base,$
                          xoffset=500,xsize=600)
;
;  array to hold individual text widget id's
;
review_expa = lonarr(27)

;
;  subsidiary bases
;
menu_base        = WIDGET_BASE(review_base, /ROW)
info_base        = WIDGET_BASE(review_base, /ROW)
info_abase       = WIDGET_BASE(info_base,   /COLUMN, /FRAME, SPACE=1)
info_bbase       = WIDGET_BASE(info_base,   /COLUMN, /FRAME, SPACE=1)
m1_widg          = WIDGET_BASE(menu_base,   /COLUMN)

;
;  buttons to close and reset widgets
;  
b_widg = widget_base(m1_widg, /ROW)
doneid  = widget_button(b_widg, value='Done')
resetid = widget_button(b_widg, value='Reset')

;
;  define the individual text widgets
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Engineering A:............')
review_expa(0) = WIDGET_TEXT(a1,XSIZE=7,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Engineering B:............')
review_expa(1) = WIDGET_TEXT(a2,XSIZE=7,YSIZE=1)
   
a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='GIS raster header:........')
review_expa(2) = WIDGET_TEXT(a3,XSIZE=7,YSIZE=1)
   
a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='VDS raster header:........')
review_expa(3) = WIDGET_TEXT(a4,XSIZE=7,YSIZE=1)
   
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Abort:....................')
review_expa(4) = WIDGET_TEXT(a5,XSIZE=7,YSIZE=1)
   
a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='GIS exposure header:......')
review_expa(5) = WIDGET_TEXT(a6,XSIZE=7,YSIZE=1)
   
a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='VDS exposure header:......')
review_expa(6) = WIDGET_TEXT(a7,XSIZE=7,YSIZE=1)
   
a8  = WIDGET_BASE(info_abase, /ROW)
a81 = WIDGET_LABEL(a8, VALUE='GIS science:..............')
review_expa(7) = WIDGET_TEXT(a8,XSIZE=7,YSIZE=1)
   
a9  = WIDGET_BASE(info_abase, /ROW)
a91 = WIDGET_LABEL(a9, VALUE='VDS science:..............')
review_expa(8) = WIDGET_TEXT(a9,XSIZE=7,YSIZE=1)
   
a10  = WIDGET_BASE(info_abase, /ROW)
a101 = WIDGET_LABEL(a10, VALUE='Primary proc. memory dump:')
review_expa(9) = WIDGET_TEXT(a10,XSIZE=7,YSIZE=1)
   
a11  = WIDGET_BASE(info_abase, /ROW)
a111 = WIDGET_LABEL(a11, VALUE='Secondary proc mem dump:..')
review_expa(10) = WIDGET_TEXT(a11,XSIZE=7,YSIZE=1)
   
a12  = WIDGET_BASE(info_abase, /ROW)
a121 = WIDGET_LABEL(a12, VALUE='Raw VDS data:.............')
review_expa(11) = WIDGET_TEXT(a12,XSIZE=7,YSIZE=1)
   
a13  = WIDGET_BASE(info_abase, /ROW)
a131 = WIDGET_LABEL(a13, VALUE='Raw GIS data:.............')
review_expa(12) = WIDGET_TEXT(a13,XSIZE=7,YSIZE=1)
   

;
;  right hand side display 
;
   
b1  = WIDGET_BASE(info_bbase, /ROW)
b11 = WIDGET_LABEL(b1, VALUE='Special MCU backup:.............')
review_expa(13) = WIDGET_TEXT(b1,XSIZE=7,YSIZE=1)
   
b2  = WIDGET_BASE(info_bbase, /ROW)
b21 = WIDGET_LABEL(b2, VALUE='Special deferred:...............')
review_expa(14) = WIDGET_TEXT(b2,XSIZE=7,YSIZE=1)
   
b3  = WIDGET_BASE(info_bbase, /ROW)
b31 = WIDGET_LABEL(b3, VALUE='Special data extraction list:...')
review_expa(15) = WIDGET_TEXT(b3,XSIZE=7,YSIZE=1)
   
b4  = WIDGET_BASE(info_bbase, /ROW)
b41 = WIDGET_LABEL(b4, VALUE='Special raster table:...........')
review_expa(16) = WIDGET_TEXT(b4,XSIZE=7,YSIZE=1)
   
b5  = WIDGET_BASE(info_bbase, /ROW)
b51 = WIDGET_LABEL(b5, VALUE='Special sequence table:.........')
review_expa(17) = WIDGET_TEXT(b5,XSIZE=7,YSIZE=1)
   
b6  = WIDGET_BASE(info_bbase, /ROW)
b61 = WIDGET_LABEL(b6, VALUE='Special CDS hk  table:..........')
review_expa(18) = WIDGET_TEXT(b6,XSIZE=7,YSIZE=1)
   
b7  = WIDGET_BASE(info_bbase, /ROW)
b71 = WIDGET_LABEL(b7, VALUE='Special error table:............')
review_expa(19) = WIDGET_TEXT(b7,XSIZE=7,YSIZE=1)
   
b8  = WIDGET_BASE(info_bbase, /ROW)
b81 = WIDGET_LABEL(b8, VALUE='Special health table:...........')
review_expa(20) = WIDGET_TEXT(b8,XSIZE=7,YSIZE=1)
   
b9  = WIDGET_BASE(info_bbase, /ROW)
b91 = WIDGET_LABEL(b9, VALUE='Special IMIF interface module:..')
review_expa(21) = WIDGET_TEXT(b9,XSIZE=7,YSIZE=1)
   
b10  = WIDGET_BASE(info_bbase, /ROW)
b101 = WIDGET_LABEL(b10, VALUE='Special VDS hardware list:......')
review_expa(22) = WIDGET_TEXT(b10,XSIZE=7,YSIZE=1)
   
b11  = WIDGET_BASE(info_bbase, /ROW)
b111 = WIDGET_LABEL(b11, VALUE='Special mode table:.............')
review_expa(23) = WIDGET_TEXT(b11,XSIZE=7,YSIZE=1)
   
b12  = WIDGET_BASE(info_bbase, /ROW)
b121 = WIDGET_LABEL(b12, VALUE='Special engineering table:......')
review_expa(24) = WIDGET_TEXT(b12,XSIZE=7,YSIZE=1)
   
b13  = WIDGET_BASE(info_bbase, /ROW)
b131 = WIDGET_LABEL(b13, VALUE='Special seq controller table:...')
review_expa(25) = WIDGET_TEXT(b13,XSIZE=7,YSIZE=1)
   
b14  = WIDGET_BASE(info_bbase, /ROW)
b141 = WIDGET_LABEL(b14, VALUE='Special IEF table:..............')
review_expa(26) = WIDGET_TEXT(b14,XSIZE=7,YSIZE=1)

;
;  set it going 
;
WIDGET_CONTROL, review_base, /realize

;
;  load any current values
;
for i=0,26 do begin
   if review_stats(i) gt 0 then begin
      widget_control,review_expa(i),set_val=string(review_stats(i),form='(i5)')
   endif
endfor
  
end

