;+
; Project     : SOHO - CDS     
;                   
; Name        : SAVE_IDL
;               
; Purpose     : Save IDL variables to a file.
;               
; Explanation : The science related variables are saved to a file from
;               where they can be 'restored' in a subsequent IDL session.
;               The variables saved are the VDS/GIS data arrays and their
;               headers.
;
; Use         : 
;    
; Inputs      : msg_widg   -     Widget id for the message window widget
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only within EGSE sci_ana program.
;               
; Side effects: Large file is written to current directory.
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 22-Oct-93
;               
; Modified    : For new data structure, CDP, 16-Dec-1993
;
; Version     : Version 2, 16-Dec-93
;-            

PRO Save_IDL, msg_widg

;
;  COMMON blocks holding the images
;
@Images.com
@Packets.com
@GISData.com
@VDSData.com

 
;
;  on error give a warning message in the message widget
;
ON_IOERROR, ERR_save

;
;  nothing to save
;
IF ((vds_data_str.vds_exp LT 0) AND (gis_data_str.gis_exp LT 0)) THEN BEGIN
    WIDGET_CONTROL, msg_widg, /append, $
                    SET_VALUE="No VDS or GIS exposures available"
    bell,2
    RETURN
ENDIF
    
;
;  set up save file in current directory - needs to be more flexible!
;
save_file = "./Science.dat"
WIDGET_CONTROL, msg_widg, /append, SET_VALUE="Save in progress ..Wait"

;
; extract the GIS data
;
IF (gis_data_str.gis_exp GE 0) THEN BEGIN
     gis = gis_plot
     gis_hdr = GIS_exphdr
ENDIF ELSE BEGIN
     gis = 0
     gis_hdr = 0
ENDELSE

;
;  and the VDS data arrays
;
IF (vds_data_str.vds_exp GE 0) THEN BEGIN
     vds = vds_image 
     vds_hdr = VDS_exphdr
ENDIF ELSE BEGIN
     vds = 0 
     vds_hdr = 0
ENDELSE
 
;
;  do the save
;  
SAVE, vds,gis, VDSrasterhdr, GISrasterhdr, vds_hdr, gis_hdr, FILENAME=save_file
 
;
;  inform
;
msg = "Save completed. File = " + save_file 
WIDGET_CONTROL,msg_widg, /append, SET_VALUE=msg

RETURN

;
;  here on error to inform user
;
ERR_save:  WIDGET_CONTROL, msg_widg, /append, SET_VALUE=!ERR_STRING
    

END



