;+
; Project     : SOHO - CDS     
;                   
; Name        : SCALE_IMAGE
;               
; Purpose     : Scale VDS image using min and max values in image. 
;               
; Explanation : Scales the input image using BYTSCL with the lower limit set
;               to zero and with the maximum set to the maximum value in the 
;               array. The input array is overwritten with the scaled array.
;               
; Use         : scale_image, image
;    
; Inputs      : image - the image to be scaled.
;               
; Opt. Inputs : None
;               
; Outputs     : image - the scaled version of the input.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: Overwrites the input image, requires message widget defined
;               
; Category    : EGSE
;               
; Prev. Hist. : Original by Arnulf, Oct-92
;
; Written     : FM EGSE version by C D Pike, RAL, 22-Oct-93
;               
; Modified    : Set lower limit of scaling to zero, not min positive value
;               and trim max value to 4000. CDP, 4-Nov-93
;               Revert back to using only positive values.  CDP, 17-Feb-94
;               Put in choice of background elimination by scaling. 
;                                             CDP, 12-Mar-94
;
; Version     : Version 4, 12-Mar-94
;-            

PRO Scale_Image, in_image

;
;  COMMON for message widget
;
@MainWidgets.com
@VDSData.com

;
;  get scaling
;
if vds_back_sub then begin
   n = where(in_image gt 0)
   if n(0) eq -1 then begin
      min_data = 0
   endif else begin
      h = histogram(in_image(n))
      min_data = where(h eq max(h))
      min_data = min_data(0) + min(in_image(n))
   endelse
endif else begin
   min_data = 0
endelse

max_data = max(in_image < 4000)

;
;  scale image and overwrite input 
;   
in_image = bytscl(in_image, min=min_data, max=max_data)
   
;
;  write details to message widget
;
;widget_control,msg_widg, /append, $
;               set_v=string('VDS image min,max =',mindata,', ',maxdata,$
;               format='(a,i6,a,i6)')


END
