;+
; Project     : SOHO - CDS     
;                   
; Name        : SHOW_VDS_LINES
;               
; Purpose     : To display the VDS calibration lines.
;
; Explanation : Superimposes on a VDS image display the outline of the
;               expected calibration line positions.               
;               
; Use         : show_vds_lines
;    
; Inputs      : ab - which image display area to use. 
;                    others all done via common
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : cal_lines
;               
; Restrictions: EGSE - calibration only
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-Jan-93
;               
; Modified    : 
;
; Version     : Version 1, 7-Jan-93
;-            

pro show_vds_lines, ab

;
;  common for data communication
;
@Cal_Lines.com
@VDSWidgets.com

;
;  get number of lines to plot
;
nl = where(vds_lines.id ne ' ')
if nl(0) eq -1 then return else nl = n_elements(nl)


;
;  make marker line
;
mark = dash_line(bytarr(1,128))

;
;  set up window to use (as requested, or use current)
;
if n_params() eq 1 then begin
   if ab eq 'A' then begin
      widget_control, vds_awidg, get_val=wind
   endif else begin
      widget_control, vds_bwidg, get_val=wind
   endelse
   wset,wind
endif

;
;  mark positions of lines (mark +/- 10 pixels of line centre)
;
for i=0,nl-1 do begin
   tv,mark,vds_lines(i).x_pos-10,vds_lines(i).y_pos
   tv,mark,vds_lines(i).x_pos+10,vds_lines(i).y_pos
endfor

end
