;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_DEF_EVENT
;               
; Purpose     : Processes events from widgets in SP_DEF_MENU.
;               
; Explanation : When a Deferred command table dump is seen in the telemetry
;               and that display is enabled, the packet contents are dumped
;               to a display widget realized by sp_disp_menu.  This routine
;               handles events from that widget.  At the moment only two events
;               are possible, to close the widget or to change the display
;               format from hex to decimal and vice versa.
;               
; Use         : Only called by XMANAGER
;    
; Inputs      : ev - the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use with sp_def_menu
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Oct-93
;               
; Modified    : To recognise 'Done' button, CDP, 28-Oct-93
;
; Version     : Version 2, 28-Oct-93
;-            

PRO sp_def_event, ev

;
;  COMMON blocks for widgets id's etc.
;
@MainWidgets.com
@SpecialWidgets.com
@Packets.com
      
;
;  determine type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  only a button event is meaningful 
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  Done (ie exit) was requested
; 
   if (value EQ 'Done') then begin
      WIDGET_CONTROL, sp_map_base, sensitive=1
      WIDGET_CONTROL, sp_def_base, /destroy
      sp_request = -1
   endif

;
;  change of format to decimal was requestred
;
   if (value EQ 'Decimal') then begin
      special_format = 1 
      widget_control,sp_format_def,set_value='Decimal'
   endif

;
;  change of format to hexadecimal was requested
;
   if (value EQ 'Hex') then begin
      special_format = 2 
      widget_control,sp_format_def,set_value='Hex'
   endif

endif

end



