;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_ERR_EVENT
;               
; Purpose     : Processes events from SP_ERR_MENU widgets.
;               
; Explanation : All events generated by the sp_err_menu program are processed
;               with this routine.
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use within EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Oct-93
;               
; Modified    : To detect new 'Done' button, CDP, 28-Oct-93
;
; Version     : Version 2, 28-Oct-93
;-            

PRO sp_err_event, ev

;
;  COMMON blocks for communication
;
@MainWidgets.com
@SpecialWidgets.com
@Packets.com
      
;
;  determine type of event that has occurred
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  if it was a button then handle accordingly
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value

;
;  finish by closing down widget
;  
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, sp_map_base, SENSITIVE=1
      widget_control,sp_err_base,/destroy
      sp_request = -1
   ENDIF

;
;  switch to Decimal format
;
   IF (value EQ 'Decimal') then begin
      special_format = 1 
      widget_control,sp_format_err,set_value='Decimal'
   endif

;
;  switch to Hexadecimal format
;
   IF (value EQ 'Hex') then begin
      special_format = 2 
      widget_control,sp_format_err,set_value='Hex'
   endif


ENDIF

END


