;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_ERR_MENU
;               
; Purpose     : Defines the error module dump widgets.
;               
; Explanation : When a dump of the error module packet is required, this 
;               routine set up the display widgets required to receive and 
;               display the information.
;               
; Use         : sp_err_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only within the EGSE science analysis
;               
; Side effects: Widget is realised.
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Oct-93
;               
; Modified    : To insert 'Done' button in place of 'file/close' menu.
;               CDP, 28-Oct-93
;
; Version     : Version 2, 28-Oct-93
;-            

PRO sp_err_menu

;
;  COMMON block for widget id's etc
; 
@SpecialWidgets.com
@MainWidgets.com

;
;  trap double clicks
;
if xregistered('sp_err') then return


;
;  array to hold individual text widget id's
;
sp_err_exp = lonarr(1)

;
;  form the top widget and put it over on the right
;
sp_err_base = WIDGET_BASE(title='ERROR module special packet', group=main_base,$
                          /FRAME, /COLUMN, XOFFSET=700)

;
;  subsidiary bases
;
menu_base        = WIDGET_BASE(sp_err_base, /ROW)
info_base        = WIDGET_BASE(sp_err_base, /ROW)
info_abase       = WIDGET_BASE(info_base,   /COLUMN, /FRAME, SPACE=1)
m1_widg          = WIDGET_BASE(menu_base,   /COLUMN)

;
;  'Done' button to close widget
;
doneid = widget_button(m1_widg, value='Done')

;
;  pull down menu to change display format
;  
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],m1_widg

;
;  inform of current format
;
f1 =  widget_base(m1_widg,/row)
f11 = widget_label(f1,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_err = widget_text(f1,xsize=40,ysize=1,value=curr_fmt)

;
;  label the main information widget
;
a0 = WIDGET_LABEL(info_abase, VALUE='ERROR module special packet.')

;
;  define the text widget
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Errors (header/argument):')
sp_err_exp(0) = WIDGET_TEXT(a1,XSIZE=25,YSIZE=32)


;
;  set it going only keep under wraps until required
;
WIDGET_CONTROL, sp_err_base, map=0
WIDGET_CONTROL, sp_err_base, /realize
  
end

