;+
; Project     : SOHO - CDS     
;                   
; Name        : SWAP_SCIHEAD
;               
; Purpose     : Swaps bytes and displays science header data.
;               
; Explanation : The integer variables in the science header structure require
;               byte swapping to make them intelligible.  If header displays
;               are turned on then the information is also pumped to the
;               appropriate widget.
;               
; Use         : swap_scihead, Header, Instrument  
;    
; Inputs      : header     -  the data structure of type SciHeaderDef within
;                             the VDS or GIS raster structures (see 
;                             sci_ana.pro for definitions).
;
;               instrument -  the instrument involved (1/GIS, 2/VDS)
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use within EGSE sci_ana program
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 25-Oct-93
;               
; Modified    : For name changes in v3.0 of packet format, 27-Oct-93
;               Force some displays always hex, mask bits in slit position.
;                                               CDP, 8-Feb-94
;               Do correct decode of slit position, CDP, 2-mar-94
;
; Version     : Version 4, 2-Mar-94
;-            

PRO swap_scihead, Header, Instrument  

;
;  COMMON blocks for widget id's
;
@HeaderWidgets.com

;
; Byte swap all two byte values
;
Header.Scihead.DataExtWindowID = ByteSwap (Header.Scihead.DataExtWindowID)
Header.Scihead.SequenceID      = ByteSwap (Header.Scihead.SequenceID)
Header.Scihead.OPSLCoordinate  = ByteSwap (Header.Scihead.OPSLCoordinate)
Header.Scihead.OPSRCoordinate  = ByteSwap (Header.Scihead.OPSRCoordinate)
Header.Scihead.SlitPosition    = ByteSwap (Header.Scihead.SlitPosition)
;
;  decode slit position
;
slitpos_decode, Header.Scihead.SlitPosition, slitbits, slitpos
Header.Scihead.SlitPosition = slitpos

Header.Scihead.ExposureTime    = ByteSwap (Header.Scihead.ExposureTime)
Header.Scihead.StudyCounter    = ByteSwap (Header.Scihead.StudyCounter)
Header.Scihead.RasterCounter   = ByteSwap (Header.Scihead.RasterCounter)
Header.Scihead.DataCompOption  = ByteSwap (Header.Scihead.DataCompOption)
Header.Scihead.SciProcStatus   = ByteSwap (Header.Scihead.SciProcStatus)

;
;  form total number of exposures from number of mirror/slit positions
;  (Kludge included to avoid zero values)
;
total_exp = (Header.Scihead.RasterLengthM > 1) * $
            (Header.Scihead.RasterLengthS > 1)

;
;  load the individual widget id's according to which header display
;  is active
;
if header_select gt 0 then h = header_g_exp 
if header_select lt 0 then h = header_v_exp

;
;  if current instrument and header display request agree then send 
;  information to individual widgets
;
if (instrument eq 1 and header_select gt 0) or  $
   (instrument eq 2 and header_select lt 0) then begin

;
;  this group to be always in hex
; 
   hexout,h(06),    Header.Scihead.DataExtWindowID
   hexout,h(07),    Header.Scihead.SequenceID
   hexout,h(09),    Header.Scihead.OPSLCoordinate
   hexout,h(10),    Header.Scihead.OPSRCoordinate

;
;  this always formatted to string
;
   widget_control,h(08),$
          set_val=' '+fmt_vect([Header.Scihead.RasterLengthM,$
                            Header.Scihead.RasterLengthS],delim=':')

;
;  select display format
;  
   if header_format eq 2 then begin
      hexout,h(04),fix(Header.Scihead.StudyID)
      hexout,h(05),fix(Header.Scihead.DataCompScheme)
      hexout,h(11),    Header.Scihead.SlitPosition
      hexout,h(12),fix(Header.Scihead.SlitNumber)
      hexout,h(13),fix(Header.Scihead.MirrorPosition)
      hexout,h(14),    Header.Scihead.ExposureTime/10
      hexout,h(15),    Header.Scihead.StudyCounter
      hexout,h(16),    Header.Scihead.RasterCounter
      hexout,h(17),    Header.Scihead.DataCompOption
   endif else begin
      fmt = '(5x,i5)'  
      widget_control,h(04),$
             set_val=string(fix(Header.Scihead.StudyID),form=fmt)
      widget_control,h(05),$
             set_val=string(fix(Header.Scihead.DataCompScheme),form=fmt)
      widget_control,h(11),$
             set_val=string((Header.Scihead.SlitPosition),form=fmt)
      widget_control,h(12),$
             set_val=string(fix(Header.Scihead.SlitNumber),form=fmt)
      widget_control,h(13),$
             set_val=string(fix(Header.Scihead.MirrorPosition),form=fmt)
      widget_control,h(14),$
             set_val=string(float(unsign(Header.Scihead.ExposureTime))/10.0,$
                            form='(4x,f6.1)')
      widget_control,h(15),$
             set_val=string(unsign(Header.Scihead.StudyCounter),form=fmt)
      widget_control,h(16),$
             set_val=string(unsign(Header.Scihead.RasterCounter),form=fmt)
      widget_control,h(17),$
             set_val=string(unsign(Header.Scihead.DataCompOption),form=fmt)
   endelse
endif

END
