;+
; Project     : SOHO - CDS     
;                   
; Name        : VDS_DESELECT()
;               
; Purpose     : Loads the VDS data windows into a full (1024,1024) array.
;               
; Explanation : The VDS data are normally stored in an array of dimensions
;               (xlength, ylength, windows, exposure).  This routine deselects
;               those data into a full (1024,1024) array for ease of use.
;               
; Use         : image = vds_deselect(VDSrasterhdr, exp_no)
;    
; Inputs      : VDSrasterhdr  -  raster header structure
;               exp_no        -  exposure number to extract
;              
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns an integer array (1024,1024)
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use within EGSE sci_ana programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 13-Dec-93
;               
; Modified    : Bugs for new structure, CDP, 13-Jan-94
;
; Version     : Version 2, 13-Jan-94
;-            

Function vds_deselect, vdsrasterhdr, exp_no

;
;  common for VDS image data and details
;
@VDSData.com

;
;  make sure we have valid parameters first
;
if (vdsrasterhdr.NumDataWindows le 0) or (exp_no lt 0) then return,0


;
;  create clear array to be used for output
;
image = intarr(1024,1024)

;
; loop for each window definition. 
;
for j = 0, vdsrasterhdr.NumDataWindows-1 do begin

   StartX  = vdsrasterhdr.VDSWin(J).StartX
   StartY  = vdsrasterhdr.VDSWin(J).StartY
   LengthX = vdsrasterhdr.VDSWin(J).LengthX
   LengthY = vdsrasterhdr.VDSWin(J).LengthY
   
;
;  .. and insert it into output array
;
   image(StartX, 1024-StartY-LengthY) = vds_image(0:LengthX-1,*,j,exp_no)
  
endfor

;
;  return with deselected image
;
return,image

END
