;+
; Project     : SOHO - CDS     
;                   
; Name        : VDS_EVENT
;               
; Purpose     : Processes events from the VDS_MENU.
;               
; Explanation : Any events originating within the widgets realized by 
;               VDS_MENU are handled by this routine.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ev  -  the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with VDS_MENU in EGSE sci_ana routines.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 26-Oct-93
;               
; Modified    : To recognise 'Done' button, CDP, 28-Oct-93
;               To include statistics, CDP, 10-Nov-93
;               To include message line, CDP, 9-Dec-1993
;               To include handling of profile plots, CDP, 4-Jan-94
;               To generalize plotting Y-coord limits, CDP, 8-Mar-94
;
; Version     : Version 5, 8-Mar-94
;-            

PRO vds_event, ev

;
;  COMMON blocks for widget id's
;
@MainWidgets.com
@VDSWidgets.com
@Images.com
@Packets.com
@VDSData.com
@Profiles.com
@Cal_Lines.com

      
;
;  interpret type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  could be from the draw widgets as a request to plot a profile
;  or just to browse the wavelength/intensity space
;
if (type eq 'WIDGET_DRAW') then begin
   widget_control,ev.id,get_uvalue=uv
   if uv eq 'IMAGE_A' then begin
      pdata = vds_data_str.curr_a_img(*,vds_disp_yst:vds_disp_yend)
   endif
   if uv eq 'IMAGE_B' then begin
      pdata = vds_data_str.curr_b_img(*,vds_disp_yst:vds_disp_yend)
   endif
   if plotting_prof then begin
      if ev.release eq 0 then begin
         prof_x = ev.x
         prof_y = ev.y
         plot_prof,pdata,strmid(uv,6,1)
      endif
   endif else begin
      if ev.y gt 149 then sp = 'N1' else sp = 'N2'
      if disp_vds_lines then begin
         distx = abs(vds_lines.x_pos - ev.x)
         disty = (ev.y gt 149) * 128 + 22
         lhit = where(distx lt 10 and vds_lines.y_pos eq disty)
         lhit = lhit(0)
         if lhit ge 0 then begin
            if vds_lines(lhit).order eq 2 then begin
              otxt = ' (second order)'
            endif else begin
              otxt = ' '
            endelse
            ltxt = 'Line is:  '+vds_lines(lhit).id + $
                 '  Wavelength = '+$
                 string(vds_lines(lhit).lam,form='(f6.2)')+' A. '+otxt+ $
                 '  Intensity = '+string(pdata(ev.x,ev.y),form='(i6)')
         endif else begin
            wave = pix2wave(sp,ev.x,/limit)
            ltxt = 'Pixel: '+fmt_vect([ev.x,ev.y+vds_disp_yst])+$
                   '   Wavelength: '+ $
                    string(wave,form='(f7.3)')+' A.   '+$
                   'Intensity: '+string(pdata(ev.x,ev.y),form='(i6)')
         endelse
      endif else begin
         wave = pix2wave(sp,ev.x,/limit)
         ltxt = 'Pixel: '+fmt_vect([ev.x,ev.y+vds_disp_yst])+$
                '   Wavelength: '+ $
                 string(wave,form='(f7.3)')+' A.   '+$
                'Intensity: '+string(pdata(ev.x,ev.y),form='(i6)')
      endelse
      widget_control,vds_msg_widg,set_val=ltxt
   endelse
endif

;
;  or could have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  Done (ie exit) request received
; 
   IF (value EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, vds_base, /destroy
      vds_display = 0
      plotting_prof = 0
      prof_area = 0
      last_window = ' '
   ENDIF

;
;  calculate and load synthetic data
;
   if (value eq 'Synthetic data') then begin
      flash_msg,vds_msg_widg,'Reading synthetic data, please wait....'
      vds_data_str.curr_a_img = vds_synth()
      vds_data_str.curr_b_img = vds_data_str.curr_a_img
      widget_control, vds_msg_widg, set_val = ' '
      plot_vds,vds_awidg,vds_data_str.curr_a_img
      plot_vds,vds_bwidg,vds_data_str.curr_b_img
   endif
;
;  request to zoom the "A" or "B" image
;
  
   IF ((value EQ "Zoom A") OR $
       (value EQ "Zoom B")) THEN BEGIN
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=0 
      WIDGET_CONTROL,vds_msg_widg, /append, SET_VALUE=$
                     "Left button for zoom center "
      WIDGET_CONTROL,vds_msg_widg, /append, SET_VALUE=$
                     "Middle for new zoom factor, Right to quit"   
      
      IF (value EQ "Zoom A") THEN $
         WIDGET_CONTROL,vds_Awidg, GET_VALUE=window $
      ELSE $
         WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window

      WSET,window
      ZOOM
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=1    
   ENDIF

;
;  request to turn ON/OFF LINE display
;                  ===========
  
   if strmid(value,0,7) eq "Display" then begin
      if strmid(value,8,3) ne 'OFF' then begin
         if disp_vds_lines and strmid(value,8,1) ne 'A' then begin 
            disp_vds_lines = 0
            plot_vds,vds_awidg,vds_data_str.curr_a_img
            disp_vds_lines = 1
         endif
         if disp_vds_lines and strmid(value,8,1) ne 'A' then begin
            disp_vds_lines = 0
            plot_vds,vds_bwidg,vds_data_str.curr_b_img
            disp_vds_lines = 1
         endif
         disp_vds_lines = 1
         rd_vds_lines,strmid(value,8,1)
;
;  if error, will have turned off request flag so test again
;
         if disp_vds_lines then begin
            if max(vds_data_str.curr_a_img) gt 0 then begin
               WIDGET_CONTROL,vds_Awidg, GET_VALUE=window 
               WSET,window
               show_vds_lines, 'A'
            endif
            if max(vds_data_str.curr_b_img) gt 0 then begin
               WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window 
               WSET,window
               show_vds_lines, 'B'
            endif
         endif
      endif else begin
         disp_vds_lines = 0
         plot_vds,vds_awidg,vds_data_str.curr_a_img
         plot_vds,vds_bwidg,vds_data_str.curr_b_img
      endelse
   endif


;
;  request for cursor defined STATISTICS in the "A" or "B" image
;
  
   IF ((value EQ "Box cursor in A") OR $
       (value EQ "Box cursor in B")) THEN BEGIN
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=0 
      WIDGET_CONTROL,vds_msg_widg, SET_VALUE=$
                     "Left button for box position "+ $
                     "Middle for box size, Right to exit."   
      
      if (value EQ "Box cursor in A") then begin
         WIDGET_CONTROL,vds_Awidg, GET_VALUE=window 
      endif else begin 
         WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window
      endelse

      WSET,window
;
;  set starting values for box cursor and call it
;
      sx = 20 & sy = 20 & px = 512 & py = 150
      select_box,sx,sy,px,py,/init
;
;  add display offset in Y
;
      py = py + vds_disp_yst
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=1    

;
;  find out which exposure we are dealing with
;  and collect and display the statistics
;
      if (value EQ "Box cursor in A") then begin
         vds_stats,vds_data_str.curr_a_img,sx,sy,px,py,average,sigma,vmax,vmin
      endif else begin 
         vds_stats,vds_data_str.curr_b_img,sx,sy,px,py,average,sigma,vmax,vmin
      endelse

   ENDIF

;
;  All data in image
;

   if (value EQ "All image A") THEN BEGIN
      vds_stats, vds_data_str.curr_a_img, /all
   endif

   if (value EQ "All image B") THEN BEGIN
      vds_stats, vds_data_str.curr_b_img, /all
   endif


;
;  single point cursor
;

   if ((value EQ "Single point cursor in A") OR $
       (value EQ "Single point cursor in B")) THEN BEGIN

      if (value EQ "Single point cursor in A") then begin
         WIDGET_CONTROL,vds_Awidg, GET_VALUE=window 
      endif else begin 
         WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window
      endelse

      WSET,window
 
;
;  collect and display the statistics of the single point
;
      cursor,x,y,3,/dev

;
;  allow for standard display of central part of image
;
      y = y + vds_disp_yst

;
;  find out which exposure we are dealing with
;  and display statistics
;
      if (value EQ "Single point cursor in A") then begin
         vds_stats,vds_data_str.curr_a_img,1,1,x,y,average,sigma,vmax,vmin
      endif else begin 
         vds_stats,vds_data_str.curr_b_img,1,1,x,y,average,sigma,vmax,vmin
      endelse

   endif

;
;  request to plot PROFILES of displayed images
;
   IF (value EQ "Profile") THEN BEGIN
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=0    
      prof_menu,strmid(value,8,1)
   ENDIF

;
;  request to SUBTRACT the images
;

   IF (value EQ "Subtract A-B") THEN BEGIN
;
; Get exposure number displayed in A
;
;
;  subtract and display
;
      sub_image = vds_data_str.curr_a_img - vds_data_str.curr_b_img
      Scale_Image, sub_image

      title = STRCOMPRESS(STRING("Subtracted image A-B"))
      SLIDE_IMAGE, sub_image, REGISTER=1, CONGRID=0, TITLE=title
      
   ENDIF


;
;  adjust LOOK-UP TABLE
;
   IF (value EQ "Colours") THEN BEGIN 
      XLOADCT   
   ENDIF


;
;  new selection of EXPOSURE for image "B"
;
   IF (value EQ "Select B") THEN BEGIN
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN
      Update_ExpInfo, VDS_exphdr(exp_no), VDSrasterhdr, vds_exp_bwidg
      vds_data_str.exp_in_b = exp_no
      vds_data_str.curr_b_img = vds_deselect(vdsrasterhdr,$
                                vds_data_str.exp_in_b-vds_data_str.first_in_mem)
      Plot_VDS, vds_bwidg, vds_data_str.curr_b_img
      prof_area = 0
      last_window = ' '
   ENDIF


;
;  new selection of EXPOSURE for image "A"
;
   IF (value EQ "Select A") THEN BEGIN
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN
      Update_ExpInfo, VDS_exphdr(exp_no), VDSrasterhdr, vds_exp_awidg
      vds_data_str.exp_in_a = exp_no
      vds_data_str.curr_a_img = vds_deselect(vdsrasterhdr,$
                                vds_data_str.exp_in_a-vds_data_str.first_in_mem)
      Plot_VDS, vds_awidg, vds_data_str.curr_a_img
      prof_area = 0
      last_window = ' '
   ENDIF

;
;  HARDCOPY requested
;
   if value eq 'Postscript' then begin
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN

;      set_plot,'ps'
;      device,bits_per_pixel=8,/landscape
;      tvscl,vds_image(*,*,exp_no)
;      tvout,100,60,'VDS data taken: '+VDS_date_time(exp_no)
;      tvout,100,10,'Plotted at:     '+systime()
;      device,/close
;      set_plot,'x'
;      spawn,'lpr -Dpostscript idl.ps'

      set_plot,'ps'
      temp = vds_deselect(vdsrasterhdr, exp_no-vds_data_str.first_in_mem)
      temp(where(temp eq 0)) = max(temp) & temp(0,0) = 0
      exptv,temp
      temp = 0
      tvout,100,60,'VDS data taken: '+VDS_date_time(exp_no)
      tvout,100,10,'Plotted at:     '+systime()
;
;   to be replaced by PS when it works
;
      device,/close
      set_plot,'x'
      spawn,'lpr -Dpostscript idl.ps'

;      psplot,que=getenv('PSLASER')
      widget_control,vds_msg_widg,$
             set_val='Print job spawned to '+getenv('PSLASER'),/append
      bell
   endif

;
;  display of FULL VDS image area requested
;
   IF (value EQ "Full VDS") THEN BEGIN
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN;
      full_image = vds_deselect(vdsrasterhdr,exp_no-vds_data_str.first_in_mem)
      Scale_Image, full_image
      title = STRCOMPRESS(STRING("Full VDS Image from exposure number",exp_no))
      SLIDE_IMAGE, full_image, REGISTER=1, CONGRID=0, TITLE=title
  ENDIF


;
;  switch BACKGROUND subtraction ON
;         ==========

   if value eq 'ON' then begin
      for i=0,1 do widget_control,back_widg(i),set_button=0
      widget_control,back_widg(0),set_button=1
      vds_back_sub = 1
      widget_control, vds_awidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_awidg, vds_data_str.curr_a_img
      widget_control, vds_bwidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_bwidg, vds_data_str.curr_b_img
   endif

;
;  switch BACKGROUND subtraction OFF
;         ==========

   if value eq 'OFF' then  begin
      for i=0,1 do widget_control,back_widg(i),set_button=0
      widget_control,back_widg(1),set_button=1
      vds_back_sub = 0
      widget_control, vds_awidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_awidg, vds_data_str.curr_a_img
      widget_control, vds_bwidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_bwidg, vds_data_str.curr_b_img
   endif


ENDIF

END
