;+
; Project     : SOHO - CDS     
;                   
; Name        : VDS_MENU
;               
; Purpose     : Defines the science analyser VDS analyse window.
;               
; Explanation : Creates the widgets which form the window within which
;               some rudimentary analysis and display of VDS images is
;               possible.
;               
; Use         : vds_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE sci_ana programs only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, oct-92
;
; Written     : FM version by C D Pike, RAL, 27-Oct-93
;               
; Modified    : To use a 'Done' button, CDP, 28-Oct-93
;               Update exposure details widget, CDP, 2-Nov-93
;               To incluse statistics option.  CDP, 5-Nov-93
;               Add 'all' image stats, CDP, 17-Feb-94
;               Update enlarged display, CDP, 8-Mar-94
;
; Version     : Version 5, 8-Mar-94
;-            

PRO vds_menu

;
;  COMMON blocks for widget id communication
; 
@VDSWidgets.com
@VDSData.com
@MainWidgets.com

;
;  trap double clicks
;
if xregistered('vds') then return



vds_exp_awidg = lonarr(5)
vds_exp_bwidg = lonarr(5)   
vds_exp_swidg = lonarr(5)  
back_widg     = lonarr(2)
 

;
;  create main base
;
vds_base = WIDGET_BASE(title='VDS analyser',  /FRAME, /COLUMN,$
                       group_leader = main_base)

;
;  and subsidiary ones
;
menu_base  = WIDGET_BASE(vds_base, /ROW)
info_base  = WIDGET_BASE(vds_base, /ROW)
info_abase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
info_bbase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
info_stats = WIDGET_BASE(info_base, /COLUMN, /FRAME)
info_back  = WIDGET_BASE(info_base, /COLUMN, /FRAME)
image_base = WIDGET_BASE(vds_base, /FRAME, /COLUMN)
vds_msg    = WIDGET_BASE(vds_base,/frame,/row)


m1_widg       = WIDGET_BASE(menu_base, /ROW)
vds_ana_widg  = WIDGET_BASE(menu_base, /ROW)
m2_widg       = WIDGET_BASE(menu_base, /ROW)
vds_view_widg = WIDGET_BASE(menu_base, /ROW)  
stats_widg    = WIDGET_BASE(menu_base, /ROW)  
line_widg     = WIDGET_BASE(menu_base, /ROW)  
 

;
;  'Done' button to exit
;
doneid = widget_button(m1_widg, value='Done')

;
;  pull-down menus for control
;

XPDmenu, ['"Analyse" {','"Subtract A-B"',$
                        '"Zoom A"','"Zoom B"',$
                        '"Profile"','}'],vds_ana_widg

XPDmenu, ['"View" {','"Select A"','"Select B"','"Full VDS"',$
          '"Synthetic data"','}'], vds_view_widg

XPDmenu, ['"Customize" {','"Colours"','}'],m2_widg

XPDmenu, ['"Hardcopy" {','"Postscript"', '}'],m1_widg

XPDmenu, ['"Statistics" {','"Box cursor in A"',$
                           '"Box cursor in B"',$
                           '"All image A"',$
                           '"All image B"',$
                           '"Single point cursor in A"',$
                           '"Single point cursor in B"','}'],stats_widg

XPDmenu, ['"Spectral Lines" {','"Display First Order"',$
                               '"Display Second Order"',$
                               '"Display All"',$
                               '"Display OFF"','}'],line_widg


;
;  widgets for display of exposure "A" details
;
a0 = WIDGET_LABEL(info_abase, VALUE='VDS exposure A properties')

a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Exposure number :  ')
vds_exp_awidg(0) = WIDGET_TEXT(a1,XSIZE=17,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='UT start time   :  ')
vds_exp_awidg(1) = WIDGET_TEXT(a2,XSIZE=17,YSIZE=1)


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Int. time (secs):  ')
vds_exp_awidg(2) = WIDGET_TEXT(a3,XSIZE=17,YSIZE=1)


a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='OPS L/R coords:    ')
vds_exp_awidg(3) = WIDGET_TEXT(a4,XSIZE=17,YSIZE=1)


a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Exposure (min,max):')
vds_exp_awidg(4) = WIDGET_TEXT(a5,XSIZE=17,YSIZE=1)

;
;  and the same for the "B" exposure
;

b0 = WIDGET_LABEL(info_bbase, VALUE='VDS exposure B properties')

b1  = WIDGET_BASE(info_bbase, /ROW)
b11 = WIDGET_LABEL(b1, VALUE='Exposure number :  ')
vds_exp_bwidg(0) = WIDGET_TEXT(b1,XSIZE=17,YSIZE=1)


b2  = WIDGET_BASE(info_bbase, /ROW)
b21 = WIDGET_LABEL(b2, VALUE='UT start time   :  ')
vds_exp_bwidg(1) = WIDGET_TEXT(b2,XSIZE=17,YSIZE=1)


b3  = WIDGET_BASE(info_bbase, /ROW)
b31 = WIDGET_LABEL(b3, VALUE='Int. time (secs):  ')
vds_exp_bwidg(2) = WIDGET_TEXT(b3,XSIZE=17,YSIZE=1)


b4  = WIDGET_BASE(info_bbase, /ROW)
b41 = WIDGET_LABEL(b4, VALUE='OPS L/R coords:    ')
vds_exp_bwidg(3) = WIDGET_TEXT(b4,XSIZE=17,YSIZE=1)


b5  = WIDGET_BASE(info_bbase, /ROW)
b51 = WIDGET_LABEL(b5, VALUE='Exposure (min,max):')
vds_exp_bwidg(4) = WIDGET_TEXT(b5,XSIZE=17,YSIZE=1)

;
;  widgets for display of exposure statistical details
;
c0 = WIDGET_LABEL(info_stats, VALUE='VDS exposure statistics')

c1  = WIDGET_BASE(info_stats, /ROW)
c11 = WIDGET_LABEL(c1, VALUE='Cursor centre:      ')
vds_exp_swidg(0) = WIDGET_TEXT(c1,XSIZE=12,YSIZE=1)


c2  = WIDGET_BASE(info_stats, /ROW)
c21 = WIDGET_LABEL(c2, VALUE='Cursor size:        ')
vds_exp_swidg(1) = WIDGET_TEXT(c2,XSIZE=12,YSIZE=1)


c3  = WIDGET_BASE(info_stats, /ROW)
c31 = WIDGET_LABEL(c3, VALUE='Average value:      ')
vds_exp_swidg(2) = WIDGET_TEXT(c3,XSIZE=12,YSIZE=1)


c4  = WIDGET_BASE(info_stats, /ROW)
c41 = WIDGET_LABEL(c4, VALUE='Standard deviation: ')
vds_exp_swidg(3) = WIDGET_TEXT(c4,XSIZE=12,YSIZE=1)


c5  = WIDGET_BASE(info_stats, /ROW)
c51 = WIDGET_LABEL(c5, VALUE='(Min,Max):          ')
vds_exp_swidg(4) = WIDGET_TEXT(c5,XSIZE=12,YSIZE=1)

;
;  buttons for background subtraction option
;
b1_base = widget_base(info_back,/row)
xmenu,['ON','OFF'],b1_base,button=back_widg,base=b_widg,/exclusive,$
                            /no_release,/frame,$
                            title='Automatic background subtraction'

;
; Make base to keep VDS A-image and label together 
;
imageA = WIDGET_BASE(image_base, /COLUMN)
dummy_widg = WIDGET_LABEL(imageA, VALUE = 'VDS image A')
vds_awidg = widget_draw(imageA, XSIZE=1024, YSIZE=300, uvalue='IMAGE_A', $
                        /button_events)

;
; make base to keep VDS B-image and label together 
;
imageB = WIDGET_BASE(image_base, /COLUMN)
dummy_widg = WIDGET_LABEL(imageB, VALUE = 'VDS image B')
vds_bwidg = widget_draw(imageB, XSIZE=1024, YSIZE=300, uvalue='IMAGE_B', $
                         /button_events)

;
;  message window
;
dum = widget_label(vds_msg,value='Messages:  ')
vds_msg_widg = widget_text(vds_msg,xsize=120,ysize=1)


;
;  make it all appear
;
WIDGET_CONTROL, vds_base, /realize

;
;  set default to automatic background subtraction OFF
;
if vds_back_sub then begin
   widget_control,back_widg(0),set_button=1
endif else begin
   widget_control,back_widg(1),set_button=1
endelse
end
