;+
; Project     : SOHO - CDS     
;                   
; Name        : CDHS_TIME
;               
; Purpose     : Calculate hex numbers to be uploaded to set CDHS time.
;               
; Explanation : The on board time is kept in TAI ie seconds since 1/1/58. This
;               routine calculates the hex representation of that number to
;               be uploaded after the CDHS is powered up.  Only for lab. test
;               use.
;               
; Use         : cdhs_time, utc
;    
; Inputs      : utc  -  string representation of date/time in agreed format
;                       eg '1993-10-22T10:10:12.123Z' or some acceptable
;                       abbreviation.
;               
; Opt. Inputs : None
;               
; Outputs     : Procedure prints the hex values for manual entry to command
;               stream.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Oct-93
;               
; Modified    : 
;
; Version     : Version 1, 22-Oct-93
;-            

pro cdhs_time,input

;
;  convert date/time string --> UTC (internal) --> TAI seconds --> hex
;
dec2hex,long(utc2tai(str2utc(input))),out,/quiet

;
;  readable output
;
print,strmid(out,0,2),' ',strmid(out,2,2),$
                      ' ',strmid(out,4,2),' ',strmid(out,6,2)

end
