;+
; Project     : SOHO - CDS     
;                   
; Name        : CHECK_FOR_LAST
;               
; Purpose     : Check if packet is the last one in an exposure.
;               
; Explanation : The last packet in any exposure is indicated by having the 
;               MSB of the packet counter set.  This procedure checks for that
;               and sets a flag if it is the last packet.
;               
; Use         : check_for_last, sci_counter, last_packet
;    
; Inputs      : sci_counter  - the 2-byte packet counter
;                             
; Opt. Inputs : None
;               
; Outputs     : last_packet  - set to 1 if this is the last packet, 0 otherwise
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with EGSE sci_ana program
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 2-Nov-93
;               
; Modified    : Cater for IDL5.2 hex bug.  CDP, 1-6-99
;
; Version     : Version 2, 1-6-99
;-            

pro check_for_last, sci_counter, last_packet

last_packet = 0
;
;  check MSB, if it was set, lose that bit and set flag
;
if (sci_counter and '8000'xl) eq '8000'xl then begin
   sci_counter = sci_counter and '7fff'xl
   last_packet = 1
endif

end
