;+
; Project     : SOHO - CDS     
;                   
; Name        : CHECK_HEADERS
;               
; Purpose     : Check if raster/exposure packets have been received.
;               
; Explanation : Check if the raster and exposure header packet flags indicate
;               that those packets have been received.
;               
; Use         : status = check_headers(instrument)
;    
; Inputs      : instrument -  the instrument ('VDS' or 'GIS').
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns 1 if both packet types have been seen or
;               0 if either or both have not.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 4-Nov-93
;               
; Modified    : 
;
; Version     : Version 1, 4-Nov-93
;-            

function check_headers, instrument

;
;  COMMON block for flags
;
@Packets.com

;
;  VDS headers
;
if instrument eq 'VDS' then return,(have_v_rst_hdr and have_v_exp_hdr)

;
;  GIS headers
; 
if instrument eq 'GIS' then return,(have_g_rst_hdr and have_g_exp_hdr)

end
