;+
; Project     : SOHO - CDS     
;                   
; Name        : DCS_EDIT
;               
; Purpose     : Creates list of DCS entries to be deleted..
;               
; Explanation : When the DCS contents are to be edited, this routine
;               displays the current contents and allows the user to select
;               entries to be deleted.  The Perl script DCS_DELETE must
;               then be run on the EGSE to perform the deletion.
;               
; Use         : dcs_edit
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : LOOK - does the display but cannot fiddle
;
; Calls       : None
;               
; Restrictions: Generally only to be run by MASTER account.  Requires 
;               CDS_CP_TTCFILES_W to be defined.  Works on the file created
;               by STM when the deferred command store is dumped eg in Perl
;               script DFLOAD.  
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 15-Dec-95
;               
; Modified    : Change error message format.  CDP, 27-May-97
;               Resized main base widget.     CDP, 3-Jul-97
;               Included extended SHOW_DCS interpretation.  CDP, 17-Jan-98
;
; Version     : Version 4, 17-Jan-98
;-            

PRO dcs_edit_event, ev

;
;  common for widget IDs
;
common dsc_edit_com, dcs_ebase, dcs_elist_id, dcs_ehc_id, edit_list, $
                     num_edit, tbdel, only_looking

;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  was it a button?
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 

;
;  Restart from scratch
; 
   if (value EQ 'Reset Selection') then begin
      tbdel = ''
      widget_control, dcs_elist_id, set_value=edit_list
      bell
      print,' '
      print,'Selection reset.'
      print,' '
   endif

;
;  request for Hardcopy plot
; 
   if (value EQ 'Hardcopy') then begin
      widget_control, dcs_ebase,/hourglass
      get_utc,utc
      widget_control, dcs_ehc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      if not only_looking then begin
         spawn,'xwd -name "Deferred Command Store Editor" '+$
         ' | xpr  -gray 3 -width 4 -height 6 -header "Deferred Command Store"'+$
         ' | lpr'
      endif else begin
         spawn,'xwd -name "Deferred Command Store Editor (READ ONLY MODE)" '+$
         ' | xpr  -gray 3 -width 4 -height 6 -header "Deferred Command Store"'+$
         ' | lpr'
      endelse
      widget_control, dcs_ehc_id,set_val='Hardcopy'
   endif

;
;  Request to finish and write out editing values
; 
   if (value EQ 'Done') then begin
      widget_control, dcs_ebase, /destroy
      outfile = concat_dir('$CDS_CP_TTCFILES_W','dcs_edit.times')
      if n_elements(tbdel) gt 1 then begin
         openw,lun,outfile,/get_lun,error=err
         if err ne 0 then begin
            bell
            print,'Unable to open output file: ',outfile
            return
         endif
         tbdel = tbdel(rem_dup(tbdel))
         print,' '
         print,' Selection to be deleted:'
         print,' '
         print_str,tbdel(1:*)
         printf,lun,'# TIMES TO BE DELETED FROM THE DEFERRED COMMAND STORE'
         get_utc,utc
         utc = anytim2cal(utc)
         printf,lun,'# Created '+utc
         printf,lun,'#' 
         printf,lun,'#' 
         for i=1,n_elements(tbdel)-1 do begin
            time = (str2arr(tbdel(i),'  '))(1)
            time = '"'+anytim2cal(time,form=11,/msec)+'"'
            printf,lun,time
         endfor
         free_lun,lun
      endif else begin
         bell
         print,'No editing selections written.'
      endelse
   endif

;
;  Request to exit without doing anything
; 
   if (value EQ 'QUIT') then begin
      widget_control, dcs_ebase, /destroy
      if not only_looking then begin
         print,' '
         print,' No editing selections written.'
         print,' '
      endif
   endif

endif      

;
;  or was it a INDEX input from the list itself
;
if type eq 'WIDGET_LIST' then begin
   if not only_looking then begin
      hit = edit_list(ev.index)
      hits = strtrim(str2arr(strtrim(hit,2),'  '),2)
      if (strpos(hits(0),')') eq (strlen(hits(0))-1)) and $
                                (strlen(hits(0)) gt 0)  then begin
         print,'To be deleted: '+hit
         tbdel = [tbdel,hit]
      endif else begin
         bell
         print,'Cannot delete that!'
      endelse
   endif
endif
END




;
;  Main routine
;  ============


PRO dcs_edit, look=look

;
;  common for widget IDs
;
common dsc_edit_com, dcs_ebase, dcs_elist_id, dcs_ehc_id, edit_list, $
                     num_edit, tbdel, only_looking


;
;  read only mode?
;
if keyword_set(look) then only_looking=1 else only_looking=0

;
;  Unless just looking, user must have correct evar setup
;
if not only_looking then begin
   if getenv('CDS_CP_TTCFILES_W') eq '' then begin
      bell
      print,'$CDS_CP_TTCFILES_W is not defined'
      return
   endif

;
;  even if it is, check have write privilege for output file
;
   outfile = concat_dir('$CDS_CP_TTCFILES_W','dcs_edit.times')
   openw,lun,outfile,/get_lun,error=err
   if err ne 0 then begin
      bell
      print,'Unable to open output file: ',outfile
      return
   endif else begin
      free_lun,lun
   endelse
endif

;
; prepare the DCS contents
;
dcsf = ''
show_dcs,/quiet,/keep,file=dcsf
if dcsf eq 'Error' then begin
   xack, 'No DCS dump file available.'
   return
endif

dcsfile = 'current_dcs'
vms=(!version.os eq 'VMS')
if vms then home='sys$login' else home=getenv('HOME')
dcsfile=concat_dir(home,dcsfile)

;
;  top level widget id
;
tit = 'Deferred Command Store Editor' 
if only_looking then tit = tit + ' (READ ONLY MODE)

dcs_ebase = WIDGET_BASE(title=tit, /FRAME, /COLUMN,xsize=800,ysize=900)

;
;  create master button base
;
dummy = widget_base(dcs_ebase,/frame,/row)

;
;  create 'DONE' button
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"
if not only_looking then begin
   doneid = widget_button(dummy,value='Done', uvalue='Done', font=cfont)
endif

;
;  create 'Reset' button
;
if not only_looking then begin
   renewid = widget_button(dummy,value='Reset Selection', uvalue='Reset', $
                           font=cfont)
endif

;
;  create 'HARDCOPY' button
;
dcs_ehc_id = widget_button(dummy,value='Hardcopy', uvalue='Hardcopy', $
                           font=cfont)

;
;  create 'QUIT' button
;
quitid = widget_button(dummy,value='QUIT', uvalue='QUIT', font=cfont)


;
;  if all Ok then read the DCS dump file
;  
edit_list = rd_ascii(dcsfile)
edit_list = strtrim(edit_list,2)
num_edit = n_elements(edit_list)
expand_list = ''
blank = ' '
for i=0,59 do blank=blank+' ' 

for i=0,num_edit-1 do begin
   expand_list = [expand_list,edit_list(i)]
   bit = str2arr(edit_list(i),'  ')
   if n_elements(bit) ge 3 then begin
      if strmid(bit(2),0,3) eq 'Run' then begin
         widget_control, dcs_ebase,/hour
         nn = n_elements(expand_list)
         expand_list(nn-1) = strmid(expand_list(nn-1),0,60)+' \'
         time = str2utc(bit(1),/dmy)
         get_detail,time,det
         if det.study_id ne -1 then begin
            ts = tai2utc(det.date_obs)
            te = tai2utc(det.date_end)
            list_detail, ts, te, det1, n
            more_det = strarr(n)
            for j=0,n-1 do begin
               ts = anytim2cal(tai2utc(det1(j).date_obs))+'     '
               more_det(j) = blank+'\ Study: '+$
                                fmt_vect([det1(j).study_id,det1(j).studyvar])+$
                                ' @ '+ts
            endfor
            expand_list = [expand_list,more_det]
         endif
      endif
   endif
endfor

;
;  reset list
;
edit_list = expand_list
num_edit = n_elements(edit_list)

edit_list = ['Loaded contents of DCS were: ','  ',edit_list,'   ',' ======  END ======']

;
;  list widget for display of contents
;
dcs_elist_id = widget_list(dcs_ebase, value=edit_list, ysize=40, xsize=100)

;
;  set up to be deleted list
;
tbdel = ''

;
;  realize (ie make appear) it all
;
WIDGET_CONTROL, dcs_ebase, /realize

;
;  and start it running
;
xmanager,"dcs_edit",dcs_ebase,event_handler='dcs_edit_event'

end
