;+
; Project     : SOHO - CDS     
;                   
; Name        : DCS_EVENT
;               
; Purpose     : Handles events from DCS_MENU widgets.
;               
; Explanation : Any event generated by the widgets in the display
;               of the DCS is handled by this routine.
;               
; Use         : Only called by XMANAGER.
;    
; Inputs      : ev - the structure associated with the event.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for EGSE/stm use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 6-Jun-95
;               
; Modified    : 
;
; Version     : Version 1, 6-Jun-95
;-            

PRO dcs_event, ev

;
;  COMMON blocks for communication of widget id's and counter.
;
@MainWidgets.com
@Base_Offsets.com
      
;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  it should only have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 

;
;  request for renew of listing
; 
   if (value EQ 'Renew') then begin

      show_dcs,/quiet,/keep
      dcsfile = 'current_dcs'
      vms=(!version.os eq 'VMS')
      if vms then home='sys$login' else home=getenv('HOME')
      dcsfile=concat_dir(home,dcsfile)
      dcs_pointer = 0
      mess = rd_ascii(dcsfile)
      mess = strpad(mess,65,/after)

      np = where(strpos(mess,')') ge 0)
      n = n_elements(np)
      if n eq bk4nis then begin
         mess(np(0)) = mess(np(0)) + '<-- NEXT'
      endif else begin
         k = 0
         for i=0,n_elements(mess)-1 do begin
            if (strpos(mess(i),')') ge 0) then begin
               k = k + 1
               if ((n-k) eq bk4nis) and (bk4nis ne 0) then begin
                  mess(i) = mess(i) + '<-- CURRENT'
                  dcs_pointer = i
               endif
            endif
         endfor
      endelse
      p = (0 > (dcs_pointer-5)) < (n_elements(mess)-15)

      if bk4nis eq 0 then begin
         mess = [mess,'  ',$
               '*** Final command is either in progress or has finished ***']
  
           p = n_elements(mess) - 15
      endif
      mess = ['Loaded contents of DCS were: ','  ',mess,'   ',$
              ' ======  END ======']

      widget_control, dcs_list_id, set_value=mess
      widget_control, dcs_list_id, set_list_top = p
   endif

;
;  request for hardcopy plot
; 
   if (value EQ 'Hardcopy') then begin
      widget_control, dcs_base,/hourglass
      get_utc,utc
      widget_control, dcs_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "Deferred Command Store Contents" '+$
         ' | xpr  -gray 3 -width 4 -height 6 -header "Deferred Command Store"'+$
         ' | lpr'
      widget_control, dcs_hc_id,set_val='Hardcopy'
   endif

;
;  request to finish/exit from the widget
; 
   if (value EQ 'Done') then begin
      widget_control,dcs_base, tlb_get_offset=boff
      widget_control,dcs_base, tlb_get_size = bsize
      dcs_menu_off = [boff,bsize]
      tp_offsets, /write
      monitor_dcs = 0
      widget_control, dcs_base, /destroy
   endif

endif      
END
