;+
; Project     : SOHO - CDS     
;                   
; Name        : DCS_MENU
;               
; Purpose     : Defines the widgets used in a DCS listing.
;               
; Explanation : When a display of the DCS contents is requested,
;               this routine defines and realizes the widgets.
;               
; Use         : dcs_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE STM program only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 6-Jun-95
;               
; Modified    : Check errpr message if dump file not exist.  CDP, 12-Jun-95
;
; Version     : Version 2, 12-Jun-95
;-            

PRO dcs_menu

;
;  COMMON blocks for widget id's etc.
;
@MainWidgets.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('dcs') then return


;
; prepare the DCS contents
;
dcsf = ''
show_dcs,/quiet,/keep,file=dcsf
if dcsf eq 'Error' then begin
   flash_msg,msg_widg,'No DCS dump file available',/append
   return
endif

dcsfile = 'current_dcs'
vms=(!version.os eq 'VMS')
if vms then home='sys$login' else home=getenv('HOME')
dcsfile=concat_dir(home,dcsfile)

;
;  switch on monitoring flag
;
monitor_dcs = 1

;
;  get base widget position and size
;
tp_offsets

;
;  top level widget id
;
tit = 'Deferred Command Store Contents' 


dcs_base = WIDGET_BASE(title=tit, group = main_base, $
                       /FRAME, /COLUMN, $
                       xsize=dcs_menu_off(2),ysize=dcs_menu_off(3), $
                       xoffset=dcs_menu_off(0),yoffset=dcs_menu_off(1))

;
;  create master button base
;
dummy = widget_base(dcs_base,/frame,/row)

;
;  create 'DONE' button
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"
doneid = widget_button(dummy,value='Done', uvalue='Done', font=cfont)


;
;  create 'Read again' button
;
renewid = widget_button(dummy,value='Renew', uvalue='Renew', font=cfont)

;
;  create 'HARDCOPY' button
;
dcs_hc_id = widget_button(dummy,value='Hardcopy', uvalue='Hardcopy', font=cfont)


;
;  if all Ok then read the DCS dump file
;  
mess = rd_ascii(dcsfile)
mess = strpad(mess,65,/after)
np = where(strpos(mess,')') ge 0)
n = n_elements(np)
dcs_pointer = 0

if n eq bk4nis then begin
   mess(np(0)) = mess(np(0)) + '<-- NEXT'
endif else begin
   k = 0
   for i=0,n_elements(mess)-1 do begin
      if (strpos(mess(i),')') ge 0) then begin
         k = k + 1
         if ((n-k) eq bk4nis) and (bk4nis ne 0) then begin
            mess(i) = mess(i) + '<-- CURRENT'
            dcs_pointer = i
         endif
      endif
   endfor
endelse
p = (0 > (dcs_pointer-5)) < (n_elements(mess)-15)

if bk4nis eq 0 then begin
   mess = [mess,'  ',$
           '*** Final command is either in progress or has finished ***']
   p = n_elements(mess) - 15
endif
mess = ['Loaded contents of DCS were: ','  ',mess,'   ',' ======  END ======']

;
;  list widget for display of contents
;
dcs_list_id = widget_list(dcs_base, value=mess, ysize=40)

;
;  realize (ie make appear) it all
;
WIDGET_CONTROL, dcs_base, /realize
widget_control, dcs_list_id, set_list_top = p

;
;  and start it running
;
xmanager,"dcs",dcs_base

end
