;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_HEALTH
;               
; Purpose     : Display contents of a health module dump.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               format id '08'x, the contents relate to a dump of the health
;               module and they can be displayed in the appropriate
;               widget by this routine. The widgets used are set up in the
;               routine SP_HEALTH_MENU.
;               
; Use         : disp_health, packet, counter
;    
; Inputs      : packet  - an int(141) array containing packet data, read by the
;                         routine read_sp_body
;
;               counter - special packet counter (byte). If it has the MSB set
;                         it is the last packet in the dump.
;
; Opt. Inputs : None
;               
; Outputs     : Variable needed between receipt of packets are kept in common.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               Uses internal COMMON block for passing the number of packets
;               received in the dump so far and for the widget id's within
;               which to display the results.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-Oct-93
;               
; Modified    : New packet format.  CDP, 12-Jan-94
;
; Version     : Version 2, 12-Jan-94
;-            

PRO disp_health, packet, sp_pkt_counter

;
;  COMMON block for communication of widget id's and counter
;
@SpecialWidgets.com
@Health.com

;
;  output format can be hex or decimal
;
if special_format eq 1 then begin
   fmt = '(2x,i3,3x,a3,4x,i6,1x,a17,3x,i6)' 
   fmtca = '(1x,i4,5x,i4)'
endif else begin
   fmt =  '(2x,i3,3x,a3,4x,i6,1x,a17,5x,z4.4)'
   fmtca = '(1x,z4.4,5x,z4.4)'
endelse

;
;  if this is the first packet in the dump, then store the subsystem
;  information
;


case sp_pkt_counter of

   0: begin
         subsys = strarr(139)
         widget_control,sp_health_exp(0),$
                        set_val=string(unsign(packet(0)),$
                                       unsign(packet(1)),form=fmtca)
         ss = packet(2:140)

         n = where(ss eq 0)
         if n(0) ge 0 then subsys(n) = 'VDS'

         n = where(ss eq 1)
         if n(0) ge 0 then subsys(n) = 'GIS'

         n = where(ss eq 2)
         if n(0) ge 0 then subsys(n) = 'MCU'

         n = where(ss eq 3)
         if n(0) ge 0 then subsys(n) = 'EPS'

         n = where(ss eq 255)
         if n(0) ge 0 then subsys(n) = 'NAS'

      end

   1: begin
         widget_control,sp_health_exp(1),$
                        set_val=string(unsign(packet(0)),$
                                       unsign(packet(1)),form=fmtca)
         offset = packet(2:140)
      end

   2: begin
         mask = strarr(139)
         widget_control,sp_health_exp(2),$
                        set_val=string(unsign(packet(0)),$
                                       unsign(packet(1)),form=fmtca)
         for i=2,140 do begin
            dec2bin,packet(i),out,/quiet
            mask(i-2) = string(out,format='(8i1,1x,8i1)')
         endfor
      end
         
'83'x: begin
         widget_control,sp_health_exp(3),$
                        set_val=string(unsign(packet(0)),$
                                       unsign(packet(1)),form=fmtca)
         maxval = packet(2:140)
         widget_control,sp_health_exp(4),set_val=' '
         widget_control,sp_health_exp(4),set_val=' ',/append
         widget_control,sp_health_exp(4),set_val=' ',/append
         widget_control,sp_health_exp(4),/append,$
            set_val=' Item  Subsys  Offset      Bit Mask         Max'
         for i=0,138 do begin
            if (i mod 10) eq 0 then begin
               widget_control,/append,sp_health_exp(4),set_v = ' '
            endif
            widget_control,/append,sp_health_exp(4),$
               set_val=string(i,subsys(i),offset(i),mask(i),unsign(maxval(i)),$
                              format=fmt)
         endfor
      end
else: begin
         bell
         widget_control, msg_widg, /append, $
                         set_val='Illegal health packet counter'
      end
endcase
   
end
