;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_IEF
;               
; Purpose     : Display contents of an IEF table dump.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               format id '0e'x, the contents relate to a dump of the IEF
;               table and they can be displayed in the appropriate
;               widget by this routine. The widgets used are set up in the
;               routine SP_IEF_MENU.
;               
; Use         : disp_ief, packet, counter
;    
; Inputs      : packet  - an int(141) array containing packet data, read by the
;                         routine read_sp_body
;
;               counter - special packet counter (byte). If it has the MSB set
;                         it is the last packet in the dump. There is only one
;                         packet involved in this dump.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : HEXOUT - formatting for hexadecimal output
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 15-Oct-93
;               
; Modified    : To update output format, use hexout, CDP 28-oct-93
;
; Version     : Version 2, 28-Oct-93
;-            

PRO disp_ief, packet, sp_pkt_counter

;
;  load COMMON blocks for widgets identifications
;
@SpecialWidgets.com
@MainWidgets.com

;
;  check output format requested
;
if special_format eq 1 then fmt  = '(4(1x,i6))'  else fmt  = '(4(1x,z4))'

;
;  this dump comes in a single special packet identified by the packet counter
;  '80'x
;
CASE (sp_pkt_counter) OF

  '80'x : BEGIN 

         if special_format eq 1 then begin
            widget_control,sp_ief_exp(0),set_val=string(packet(0:3),format=fmt)
            widget_control,sp_ief_exp(1),set_val=string(packet(4:7),format=fmt)
            widget_control,sp_ief_exp(2),set_val=string(packet(8),format=fmt)
            widget_control,sp_ief_exp(5),set_val=string(packet(10:11),form=fmt)
            widget_control,sp_ief_exp(6),set_val=string(packet(12),format=fmt)
            widget_control,sp_ief_exp(7),set_val=string(byte(packet(14)),form=fmt)
         endif else begin
            hexout,sp_ief_exp(0),packet(0:3)
            hexout,sp_ief_exp(1),packet(4:7)
            hexout,sp_ief_exp(2),packet(8)
            hexout,sp_ief_exp(5),packet(10:11)
            hexout,sp_ief_exp(6),packet(12)
            hexout,sp_ief_exp(7),fix(byte(packet(14)))
         endelse

         lsb = byte(packet(9))
         dec2bin,lsb,bits,/quiet
         widget_control,sp_ief_exp(3),set_val=string(bits,format='(8i1)')

         msb = byte(byteswap(packet(9)))
         dec2bin,msb,bits,/quiet
         widget_control,sp_ief_exp(4), set_val=string(bits,format='(8i1)')


         w0 = byte(byteswap(packet(14)))
         w1 = byte(packet(15))
         w2 = byte(byteswap(packet(15)))
         dec2bin,w0,b0,/quiet
         dec2bin,w1,b1,/quiet
         dec2bin,w2,b2,/quiet
         widget_control,sp_ief_exp(8),$
             set_val=string(b0,b1,b2,format='(8i1,3x,8i1,3x,8i1)')

         if special_format eq 1 then begin
            widget_control,sp_ief_exp(09),$
                   set_val=string(unsign(packet(16:19)),format=fmt)
            widget_control,sp_ief_exp(11),$
                   set_val=string(unsign(packet(24:27)),format=fmt)
            widget_control,sp_ief_exp(12),$
                   set_val=string(unsign(packet(28:31)),format=fmt)
            widget_control,sp_ief_exp(13),$
                   set_val=string(unsign(packet(32:35)),format=fmt)
            widget_control,sp_ief_exp(14),$
                   set_val=string(byte(packet(36:39)),format=fmt)
            widget_control,sp_ief_exp(15),$
                   set_val=string(byte(byteswap(packet(36:39))),format=fmt)
            widget_control,sp_ief_exp(16),$
                   set_val=string(unsign(packet(42:45)),format=fmt)
            widget_control,sp_ief_exp(17),$
                   set_val=string(unsign(packet(46:49)),format=fmt)
            widget_control,sp_ief_exp(18),$
                   set_val=string(byte(packet(50:53)),format=fmt)
            widget_control,sp_ief_exp(19),$
                   set_val=string(byte(byteswap(packet(50:53))),format=fmt)
            widget_control,sp_ief_exp(20),$
                   set_val=string(unsign(packet(56:59)),format=fmt)
            widget_control,sp_ief_exp(21),$
                   set_val=string(unsign(packet(60:63)),format=fmt)
            widget_control,sp_ief_exp(22),$
                   set_val=string(byte(packet(64:67)),format=fmt)
            widget_control,sp_ief_exp(23),$
                   set_val=string(byte(byteswap(packet(64:67))),format=fmt)
         endif else begin
            hexout,sp_ief_exp(09),unsign(packet(16:19))
            hexout,sp_ief_exp(10),unsign(packet(20:23))
            hexout,sp_ief_exp(11),unsign(packet(24:27))
            hexout,sp_ief_exp(12),unsign(packet(28:31))
            hexout,sp_ief_exp(13),unsign(packet(32:35))
            hexout,sp_ief_exp(14),fix(byte(packet(36:39)))
            hexout,sp_ief_exp(15),fix(byte(byteswap(packet(36:39))))
            hexout,sp_ief_exp(16),unsign(packet(42:45))
            hexout,sp_ief_exp(17),unsign(packet(46:49))
            hexout,sp_ief_exp(18),fix(byte(packet(50:53)))
            hexout,sp_ief_exp(19),fix(byte(byteswap(packet(50:53))))
            hexout,sp_ief_exp(20),unsign(packet(56:59))
            hexout,sp_ief_exp(21),unsign(packet(60:63))
            hexout,sp_ief_exp(22),fix(byte(packet(64:67)))
            hexout,sp_ief_exp(23),fix(byte(byteswap(packet(64:67))))
         endelse
      END

  ELSE : widget_control,msg_widg, /append, $
                        set_val='Invalid special IEF packet counter' 

  ENDCASE

END
