;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_IMIFIM
;               
; Purpose     : Display contents of an IMIF interface module dump.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               format id '09'x, the contents relate to a dump of the IMIF
;               interface module and they can be displayed in the appropriate
;               widget by this routine. The widgets used are set up in the
;               routine SP_IMIFIM_MENU.
;               
; Use         : disp_imifim, packet
;    
; Inputs      : packet  - an int(141) array containing packet data, read by the
;                         routine read_sp_body
;
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 30-Nov-93
;               
; Modified    : Change way modes are displayed, CDSP, 2-Feb-94
;               Include new backup mode displays, CDP, 8-Feb-94
;
; Version     : Version 3, 8-Feb-94.
;-            

PRO disp_imifim, packet

;
;  load COMMON blocks for widgets identifications
;
@SpecialWidgets.com
@MainWidgets.com

;
;  check output format requested
;
if special_format eq 1 then begin
   fmt  = '(4(1x,i6))' 
endif else begin
   fmt  = '(4(1x,z4))'
endelse


;
;  string array for output of modes (forced by bug in widget control which
;  insists on rolling text lines off top of widget even when there is room to
;  fit them in
;
text = strarr(11)


pck = LONG ( packet, 2, 7 )

dec2bin,pck(0),bits,/quiet

if bits(31) eq 1 then begin
   text(0) = 'MCU backup mode ENABLED'
endif else begin
   text(0) = 'MCU backup mode DISABLED'
endelse

if bits(30) eq 1 then begin
   text(1) = 'MCU power ON'
endif else begin
   text(1) = 'MCU power OFF'
endelse

if bits(29) eq 1 then begin
   text(2) = 'VDS power ON'
endif else begin
   text(2) = 'VDS power OFF'
endelse

if bits(28) eq 1 then begin
   text(3) = 'GIS power ON'
endif else begin
   text(3) = 'GIS power OFF'
endelse

if bits(27) eq 1 then begin
   text(4) = 'Send VDS heartbeat mode ENABLED'
endif else begin
   text(4) = 'Send VDS heartbeat mode DISABLED'
endelse

if bits(26) eq 1 then begin
   text(5) = 'Send VDS eng. req. mode ENABLED'
endif else begin
   text(5) = 'Send VDS eng. req. mode DISABLED'
endelse

if bits(25) eq 1 then begin
   text(6) = 'QCM request in progress'
endif else begin
   text(6) = 'QCM request NOT in progress'
endelse

if bits(24) eq 1 then begin
   text(7) = 'VDS memory dump in progress'
endif else begin
   text(7) = 'VDS memory dump NOT in progress'
endelse

if bits(23) eq 1 then begin
   text(8) = 'GIS raw data dump in progress'
endif else begin
   text(8) = 'GIS raw data dump NOT in progress'
endelse

if bits(22) eq 1 then begin
   text(9) = 'Send GIS heartbeat mode ENABLED'
endif else begin
   text(9) = 'Send GIS heartbeat mode DISABLED'
endelse

if bits(21) eq 1 then begin
   text(10) = 'Send GIS eng. req. mode ENABLED'
endif else begin
   text(10) = 'Send GIS eng. req. mode DISABLED'
endelse



;
;  now display them
;
widget_control,sp_imifim_expa(0),set_val=string(text,format='(11(a,/))')


widget_control,sp_imifim_expa(1),$
    set_val=string(pck(1),format=fmt)

widget_control,sp_imifim_expa(2),$
    set_val=string(pck(2),format=fmt)

widget_control,sp_imifim_expa(3),$
    set_val=string(pck(3),format=fmt)

widget_control,sp_imifim_expa(4),$
    set_val=string(pck(4),format=fmt)

widget_control,sp_imifim_expa(5),$
    set_val=string(pck(5),format=fmt)

widget_control,sp_imifim_expa(6),$
    set_val=string(pck(6),format=fmt)

END
