;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_RAW_GIS
;               
; Purpose     : Display raw GIS data.
;               
; Explanation : When a special packet is detected in the CDS telemetry with the
;               ID indicating a raw GIS data dump, the data are displayed
;               with this routine.
;               
; Use         : disp_raw_gis
;    
; Inputs      : The input data RAW_GIS_DATA come in via the Common block.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 16-Dec-93
;-            

PRO disp_raw_gis

;
;  Common block for widget id's
;
@RawData.com

;
;  extract the counter from the first 4 bytes
;
counter = long(raw_gis_data(0:3),0,1)

;
;  and display it
;
widget_control,raw_gis_exp(0),set_v=string(counter,form='(i6)')

;
;  now the data
;
raw = fix(raw_gis_data,4,120)


;
;  and display it
;
if raw_gis_display then begin

   for i=0,19 do begin
      if raw_format eq 1 then begin
        
         widget_control,raw_gis_exp(1),/append,$
                          set_val=string(raw(i*6:i*6+5),format='(6(1x,i6))')
      endif else begin
         hexout,raw_gis_exp(1),raw(i*6:i*6+5),/append
      endelse
   endfor

;
;  put out spacer
;
   widget_control,raw_gis_exp(1),set_val=' ',/append
   widget_control,raw_gis_exp(1),set_val='-----------------------',/append
   widget_control,raw_gis_exp(1),set_val=' ',/append

endif

;
;  was hardcopy wanted?
;
if raw_gis_dump then begin
   for i=0,1 do begin
      writeu,raw_gis_unit,raw(i*60:i*60+59)
   endfor
endif


end
