;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_RAW_VDS
;               
; Purpose     : Display raw VDS data.
;               
; Explanation : When a packet is detected in the CDS telemetry with the
;               ID indicating a raw VDS data dump, the data are displayed
;               with this routine.
;               
; Use         : disp_raw_vds
;    
; Inputs      : The input data RAW_VDS_DATA come in via the Common block.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Restricted to use within the EGSE science analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 16-Dec-93
;-            

PRO disp_raw_vds

;
;  Common block for widget id's
;
@RawData.com

;
;  extract the counter from the first 4 bytes
;
counter = long(raw_vds_data(0:3),0,1)

;
;  decide on output format
;
if raw_format eq 1 then begin
   fmt = '(16(1x,i3))'
endif else begin
   fmt = '(16(1x,z2.2))'
endelse

;
;  and display it
;
widget_control,raw_vds_exp(0),set_v=string(counter,form='(i6)')

;
;  now the data
;
raw = raw_vds_data(4:259)

for i=0,15 do begin
   widget_control,raw_vds_exp(1),/append,$
                       set_val=string(raw(i*16:i*16+15),format=fmt)
endfor

;
;  put out spacer
;
widget_control,raw_vds_exp(1),set_val=' ',/append
widget_control,raw_vds_exp(1),set_val='-----------------------',/append
widget_control,raw_vds_exp(1),set_val=' ',/append


;
;  was hardcopy wanted?
;
if raw_vds_dump then writeu,raw_vds_unit,raw


end
