;+
; Project     : SOHO - CDS     
;                   
; Name        : DISP_VDS_HDR
;               
; Purpose     : Display the various VDS packet header information.
;               
; Explanation : The information read from the various packets (raster,
;               exposure, science data) is stored in the structures
;               PacketHeader, VDSrasterhdr and ExpHdr.  This routine 
;               displays that information in the header display widgets.
;               
; Use         : disp_vds_hdr, structure
;    
; Inputs      : structure  - one of the three basic structures containing
;                            information to be displayed.  The information
;                            displayed depends on which structure is given
;                            as input.
;                          
; Opt. Inputs : None
;               
; Outputs     : None

; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use within EGSE sci_ana program only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None, pulls together output functions of various procedures
;               used in previous versions.
;
; Written     : C D Pike, RAL, 12-Aug-94
;               
; Modified    : Fix bug in counter format.  CDP, 10-Jan-95
;               Trap invalid sun sensor values.  CDP, 26-may-95
;               Added message to main window.  CDP, 26-Jun-95
;               Use vds_tick for exposure time calculation.  CDP, 21-Nov-95
;               Eliminate use of exposure time from header - done
;               from EngA packet.              CDP, 27-Feb-96
;
; Version     : Version 6, 27-Feb-96
;-            

pro disp_vds_hdr, str

;
;  COMMON block for information display widgets and orientation
;
@HeaderWidgets.com
@Images.com
@MainWidgets.com
@VDSData.com

;
;  determine which structure it is
;
first = (tag_names(str))(0)


;
;  act according to structure form
;
case first of
;
;  general packet header (first 20 bytes)
;
   'MSGID':  begin 
                out = string(str.AP_ID,format='(6x,2z2,$)')
                widget_control, header_v_exp(0),set_value=out


                out = string(fix(str.ID),$
                             fix(str.STREAMPACKETCOUNTER),$
                             format="(z4,'/',i4)")
                widget_control, header_v_exp(1),set_value=out
             end

;
;  science packet counter
;
   'COUNT':  begin
                if str.LAST then begin
                   outc = string(str.count,' -last',format='(i4,a)')
                   widget_control,header_v_exp(18),set_value=outc
                endif else begin
                   widget_control,header_v_exp(18),$
                                    set_value=string(str.count,format='(i4)')
                endelse
             end
      
;
;  VDS raster packet
;
 'SCIHEAD':  begin
               if header_format eq 2 then begin
                 a = string(fix(str.Scihead.StudyID),form='(z4.4)')
                 b = string(fix(str.Scihead.SequenceID),form='(z4.4)')
                 c = string(fix(str.Scihead.DataExtWindowID),form='(z4.4)')
               endif else begin
                 a = strtrim(string(fix(str.Scihead.StudyID),f='(i3)'),2)
                 b = strtrim(string(fix(str.Scihead.SequenceID),f='(i6)'),2)
                 c = strtrim(string(fix(str.Scihead.DataExtWindowID),f='(i6)'),2)
               endelse 
               widget_control,header_v_exp(2),set_val=fmt_vect([a,b,c],del='/')


               if header_format eq 2 then begin
                 a = fmt_hex(str.Scihead.OPSLCoordinate)
                 b = fmt_hex(str.Scihead.OPSRCoordinate)
               endif else begin
                 a = strtrim(string(str.Scihead.OPSLCoordinate,f='(i6)'),2)
                 b = strtrim(string(str.Scihead.OPSRCoordinate,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(5),set_val=fmt_vect([a,b],del='/')
               
               widget_control,header_v_exp(4),$
                       set_val=' '+fmt_vect([str.Scihead.RasterLengthM,$
                                             str.Scihead.RasterLengthS],$
                                             delim=':')

               if header_format eq 2 then begin
                  a = fmt_hex(fix(str.Scihead.DataCompScheme))
                  b = fmt_hex(str.Scihead.DataCompOption)
               endif else begin
                  a = strtrim(string(fix(str.Scihead.DataCompScheme),f='(i6)'),2)
                  b = strtrim(string(str.Scihead.DataCompOption,f='(i6)'),2)
               endelse

               if n_elements(vds_orientation) gt 0 then begin
                  if vds_orientation eq 1 then c = 'Col' else c = 'Row'
               endif else begin
                  c = ' '
               endelse
               widget_control,header_v_exp(3),set_val=fmt_vect([a,b,c],del='/')

               if header_format eq 2 then begin
                  a = fmt_hex(fix(str.Scihead.SlitNumber))
                  b = fmt_hex(str.Scihead.SlitPosition)
               endif else begin
                  a = strtrim(string(fix(str.Scihead.SlitNumber),f='(i6)'),2)
                  b = strtrim(string(str.Scihead.SlitPosition,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(6),set_val=fmt_vect([a,b],del='/')

               if header_format eq 2 then begin
                  hexout,header_v_exp(7),fix(str.Scihead.MirrorPosition)
                  hexout,header_v_exp(8),0
               endif else begin
                  widget_control,header_v_exp(7),$
                       set_val=string(fix(str.Scihead.MirrorPosition),f='(i4)')
                  widget_control,header_v_exp(8), set_val=''
               endelse

               if header_format eq 2 then begin
                  a = fmt_hex(str.Scihead.StudyCounter)
                  b = fmt_hex(str.Scihead.RasterCounter)
               endif else begin
                  a = strtrim(string(str.Scihead.StudyCounter,f='(i6)'),2)
                  b = strtrim(string(str.Scihead.RasterCounter,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(9),set_val=fmt_vect([a,b],del='/')
               widget_control,msg_widg,/append,$
                              set_val='Study: '+a+', Raster: '+b
 
               dec2bin,str.scihead.SciProcStatus,bits,/quiet
               widget_control,header_v_exp(10),$
                                   set_val=string(bits(8:15),format='(1x,8i1)')

;
;  display windows
;

               for i=0,23 do begin
                  widget_control,header_v_w_sx(i),set_val=' '
                  widget_control,header_v_w_lx(i),set_val=' '
                  widget_control,header_v_w_sy(i),set_val=' '
                  widget_control,header_v_w_ly(i),set_val=' '
               endfor

               for i=0,str.numdatawindows-1 do begin
                  widget_control,header_v_w_sx(i),$
                            set_val=string(str.VDSWin(i).StartX,format='(i4)')
                  widget_control,header_v_w_lx(i),$
                            set_val=string(str.VDSWin(i).LengthX,format='(i4)')
                  widget_control,header_v_w_sy(i),$
                            set_val=string(str.VDSWin(i).StartY,format='(i4)')
                  widget_control,header_v_w_ly(i),$
                            set_val=string(str.VDSWin(i).LengthY,format='(i4)')
               endfor

             end

;
;  Exposure header
;
   'SOLARX': begin

               if header_format eq 2 then begin
                 a = fmt_hex(str.OPSLCoordinate)
                 b = fmt_hex(str.OPSRCoordinate)
               endif else begin
                 a = strtrim(string(str.OPSLCoordinate,f='(i6)'),2)
                 b = strtrim(string(str.OPSRCoordinate,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(5),set_val=fmt_vect([a,b],del='/')
;                             ===============
               
;
;  slit number is not in exposure header, so read it back from the widget
;
               widget_control,header_v_exp(6),get_val=value
               value = strtrim(value,2)
               slash = strpos(value,'/')-1
               value = fix(strmid(value,1,slash(0)))
               if header_format eq 2 then begin
                  a = fmt_hex(value)
                  b = fmt_hex(str.SlitPosition)
               endif else begin
                  a = strtrim(string(value,f='(i6)'),2)
                  b = strtrim(string(str.SlitPosition,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(6),set_val=fmt_vect([a,b],del='/')
;                             ===============

               if header_format eq 2 then begin
                  hexout,header_v_exp(7),fix(str.MirrorPosition)
;                        ===============
               endif else begin
                  widget_control,header_v_exp(7),$
                     set_val=string(fix(str.MirrorPosition),f='(i4)')
               endelse

               if header_format eq 2 then begin
                 a = fmt_hex(str.StudyCounter)
                 b = fmt_hex(str.RasterCounter)
               endif else begin
                 a = strtrim(string(str.StudyCounter,f='(i6)'),2)
                 b = strtrim(string(str.RasterCounter,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(9),set_val=fmt_vect([a,b],del='/')
;                             ===============
               
               fmt_cdhs_time, str, date, time
               widget_control,header_v_exp(11),set_val=date
               widget_control,header_v_exp(12),set_val=time
               if n_elements(total_exp) gt 0 then begin
                  widget_control,header_v_exp(13),$
                       set_val = fmt_vect([str.ExposureNumber+1,total_exp],$
                                                                     delim='/')
               endif

               if str.SunSensorPitch eq -32768 or $
                     str.SunSensorYaw eq -32768 then begin
                  widget_control, header_v_exp(14), set_val='Invalid'
               endif else begin
                  if header_format eq 2 then begin
                    a = fmt_hex(str.SunSensorPitch)
                    b = fmt_hex(str.SunSensorYaw)
                  endif else begin
                    a = strtrim(string(str.SunSensorPitch,f='(i6)'),2)
                    b = strtrim(string(str.SunSensorYaw,f='(i6)'),2)
                  endelse
                  widget_control,header_v_exp(14),set_val=fmt_vect([a,b],del='/')
               endelse
;                                ================
               
               if header_format eq 2 then begin
                  a = fmt_hex(str.SolarX)
                  b = fmt_hex(str.SolarY)
               endif else begin
                  a = strtrim(string(str.SolarX,f='(i6)'),2)
                  b = strtrim(string(str.SolarY,f='(i6)'),2)
               endelse
               widget_control,header_v_exp(15),set_val=fmt_vect([a,b],del='/')
;                             ================

               
               case str.EventStatus of
                 1: widget_control,header_v_exp(16),set_v='Recogn.. enabled'
                 2: widget_control,header_v_exp(16),set_v='Event detected'
                 4: widget_control,header_v_exp(16),set_v='Solar coords valid'
                 else: widget_control,header_v_exp(16),set_v='N/A'
               endcase

               if header_format eq 2 then begin
                  hexout,header_v_exp(17),str.EventLevel
               endif else begin
                  widget_control,header_v_exp(17),$
                          set_val=string(fix(str.Eventlevel),f='(i5)')
               endelse

             end
     else:
endcase


end
