;+
; Project     : SOHO - CDS     
;                   
; Name        : EXP_SELECT
;               
; Purpose     : Select exposure to be displayed.
;               
; Explanation : This module presents an X-dialog box in which the
;               operator is asked to select an exposure to be displayed. This
;               routine only operates within the EGSE science analysis
;               package.              
;               
; Use         : 
;    
; Inputs      : instrument -  either 'VDS' or 'GIS'
;               
; Opt. Inputs : None
;               
; Outputs     : exp_no - Selected exposure
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only with display programs within the EGSE science
;               analysis programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : Original EM version by Arnulf, October 92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Update to cater for cycling exposure store, CDP, 14-Dec-93
;
; Version     : Version 2, 14-Dec-93
;-            

PRO exp_select, instrument, exp_no


;
;  Common for message widget id and VDS data details
;
@MainWidgets.com
@VDSData.com
@GISData.com

;
;  get range of exposures in memory
;
if instrument eq 'VDS' then begin
   first = vds_data_str.first_in_mem
   last  = vds_data_str.last_in_mem
endif else begin
   first = 0
   last = gis_data_str.gis_exp
endelse

;
;  set up the display/interaction widgets
;
main_exp_base = WIDGET_BASE (TITLE='Exposure Select', /FRAME, /COLUMN)
text_base = WIDGET_BASE (main_exp_base, /COLUMN)
menu_base = WIDGET_BASE (main_exp_base)


;
; Make the exposure select widget
;
w0  = WIDGET_BASE (text_base, /ROW, /FRAME) 
w01 = WIDGET_LABEL(w0, VALUE="Number of exposures in memory: ")
w02 = WIDGET_TEXT (w0, VALUE=STRCOMPRESS(last-first+1), XSIZE=4, YSIZE=1)

;
; Make exposure select widget
;
IF (last-first EQ 0) THEN $
    w1 = WIDGET_LABEL(text_base, VALUE="Only one exposure available") $ 
ELSE IF (last-first LE -1) THEN $
    w1 = WIDGET_LABEL(text_base, VALUE="No exposures available") $
ELSE $
    w1 = WIDGET_SLIDER(text_base, /DRAG, /FRAME, MINIMUM=first, MAXIMUM=last)

;
; Make cancel and confirm buttons
;
b1 = WIDGET_BUTTON (menu_base, VALUE=" CANCEL ")
b2 = WIDGET_BUTTON (menu_base, VALUE=" OK ", XOFFSET=160)

;
;  realize the widgets
;
WIDGET_CONTROL, /REALIZE , main_exp_base

;
;  get an answer from the user
;
answer = 0 
WHILE (answer EQ 0) DO BEGIN

  ev = WIDGET_EVENT(main_exp_base)
  type = TAG_NAMES(ev, /STRUCTURE)

  IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
 
     answer = 1
     WIDGET_CONTROL, ev.id, GET_VALUE=value

     IF (value EQ " CANCEL ") THEN BEGIN
        WIDGET_CONTROL, /DESTROY,ev.top 
        exp_no = -1
     ENDIF

     IF (value EQ " OK ") THEN BEGIN
        IF (last-first LE -1) THEN $  
           exp_no = -1 $
        ELSE IF (last-first EQ 0) THEN $
           exp_no = 0 $
        ELSE $
           WIDGET_CONTROL, w1, GET_VALUE=exp_no
        
           WIDGET_CONTROL,msg_widg, /append, $
            set_v=string('Exposure no: ',exp_no,' selected',format='(a,i3,a)')
           WIDGET_CONTROL, /DESTROY,ev.top 
       
     ENDIF
  ENDIF
ENDWHILE

END

