;+
; Project     : SOHO - CDS     
;                   
; Name        : FMT_CDHS_TIME
;               
; Purpose     : Create date/time strings from exposure header information.
;               
; Explanation : The start time of an exposure is recorded in 6 bytes of the
;               exposure header packet.  This routine decodes those bytes
;               into date and time strings.
;               
; Use         : fmt_cdhs_time, ExpHdr, date, time
;    
; Inputs      : ExpHdr  -  the exposure header packet structure
;               
; Opt. Inputs : None
;               
; Outputs     : date -  the start date as a string
;               time -  the UT start time as a string
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 2-Nov-93
;               
; Modified    : To use single 6-byte variable instead of original 3x2byte.
;               CDP, 17-Dec-93
;               Return blanks if time=0.  CDP< 27-Jan-95
;
; Version     : Version 3, 27-Jan-95
;-            

pro fmt_cdhs_time, ExpHdr, date, time

;
;  pick the 6-bytes
;
b6 = Exphdr.ExposureStart

;
; intercept zero time
;
if total(b6) eq 0 then begin
   date = ' '
   time = ' '
endif else begin

;
;  format complete string
;
   dt = utc2str(tai2utc(obt2tai(b6)))

;
;  extract date/time individually
;
   date = strmid(dt,0,10)
   time = strmid(dt,11,10)

endelse

end
