;+
; Project     : SOHO - CDS     
;                   
; Name        : FMT_HEX()
;               
; Purpose     : Formats an unsigned 16 bit integer for hexadecimal output.
;               
; Explanation : Many 16 bit numbers in the CDS telemetry are held in IDL as
;               signed INT 16-bit numbers but are actually meant to be treated
;               as unsigned integers.  Printing them out in hex format will
;               give an error for those where the sign bit is set.  This 
;               routine avoids that messiness.
;               
; Use         : IDL> nice = fmt_hex(int16 [, format=format])     
;    
; Inputs      : int16      - the IDL 16-bit integer
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : format - character string specifying the format for the output
;                        default is z2.2
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Util, numerical
;               
; Prev. Hist. : Originally from HEXOUT but without the output to widgets
;
; Written     : C D Pike, RAL, 12-Aug-94
;               
; Modified    : 
;
; Version     : Version 1, 12-Aug-94
;-            

function fmt_hex, int16, format=format     

;
;  byteswap to get display order correct
;
bs16 = int16
byteorder,bs16,/ntohs

;
;  pick up format required, or use default
;
if not keyword_set(format) then fmt = '(6(z2.2,2x))' else fmt = format

;
;  convert output to byte array and then output that in hex format
;  
ans = string( byte(bs16,0,2*n_elements(bs16)),format=fmt)
remchar,ans,' '

return,ans

end

