;+
; Project     : SOHO - CDS     
;                   
; Name        : GIS_EVENT
;               
; Purpose     : Processes events from the EGSE GIS analysis menu. 
;               
; Explanation : This module is called by the IDL XMANAGER when an event
;               originates in the GIS_MENU program. 
;               
; Use         : Only called by XMANAGER
;    
; Inputs      : ev - structure describing the event
;
;               Variables found in following COMMON blocks are also
;               required:
;
;               MainWidgets  Main window wdigets
;               GISWidgets   GIS analyse window widgets
;               Images       Decoded VDS images and GIS plot 
;               Packets      Raw science header packets
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct 93
;               
; Modified    : To detect "Done" button instead of "File/close". CDP, 28-Oct-93
;               Major update of display, CDP.  13-Dec-93
;               Include base widget posn/size saving.  CDP, 24-Jan-95
;               Use ps/psplot.  CDP, 26-Jan-95
;
; Version     : Version 5, 26-Jan-95
;-            

PRO gis_event, ev

;
;  Include the required COMMON blocks
;
@MainWidgets.com
@GISWidgets.com
@GISData.com
@Images.com
@Packets.com
@CalFits.com
@Base_Offsets.com

      
;
;  determine type of event - can only be 'button'
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  if type was from DRAW widget then return pixel/wavelength and intensity
;  but only if just one band plotted.
;
if type eq 'WIDGET_DRAW' then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value, get_uvalue = uvalue
   if (uvalue eq 'GPLOT_A' or $
        uvalue eq 'GPLOT_B') and (ev.press eq 1) then begin

      ok = 0
      if uvalue eq 'GPLOT_A' then begin
         if total(gis_data_str.agis_plot_choice(0:3)) eq 1 then ok = 1
         xpos = (float(ev.x)/float(gad.x_vsize) - $
                 float(gax.s(0)))/float(gax.s(1))
         b = where(gis_data_str.agis_plot_choice eq 1) & b = b(0)+1
         data = gis_data_str.curr_a_data
      endif else begin
         if total(gis_data_str.bgis_plot_choice(0:3)) eq 1 then ok = 1
         xpos = (float(ev.x)/float(gbd.x_vsize) - $
                 float(gbx.s(0)))/float(gbx.s(1))
         b = where(gis_data_str.bgis_plot_choice eq 1) & b = b(0)+1
         data = gis_data_str.curr_b_data
      endelse

      if ok then begin
         if gis_data_str.gis_plot_wave then begin
            npix = wave2pix('GIS'+string(b,form='(i1)'), xpos, /limit)
         endif else begin
            npix = fix(xpos)
         endelse
         data_val = data((b-1)*2048 + npix)
         if gis_data_str.gis_plot_wave then begin
            widget_control, gis_msg_widg, $
                      set_val=string('Wavelength: ',xpos, '  Data value: ',$
                                   data_val,form='(a,f6.2,a,i5)')
         endif else begin
            widget_control, gis_msg_widg, $
                      set_val=string('Pixel: ',fix(xpos), '  Data value: ',$
                                      data_val,form='(a,i4,a,i5)')
         endelse
      endif
   endif
endif
;
;  if it was a button event, then retrieve its value and act accordingly
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value, get_uvalue = uvalue

;
;  exit requested
;  
   IF (value EQ 'Done') THEN BEGIN
      widget_control,gis_base, tlb_get_offset=boff
      widget_control,gis_base, tlb_get_size = bsize
      gis_menu_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, gis_base, /destroy
      gis_display  = 0
      return
   ENDIF


;
;  switch to image B requested, so get exposure wanted and plot it
;            =======
;
   IF (value EQ "Select B") THEN BEGIN
      Exp_Select, "GIS", exp_no 
      gis_data_str.exp_in_b = exp_no
      IF (exp_no EQ -1) THEN  RETURN
      Update_ExpInfo, GIS_exphdr(exp_no), GISrasterhdr, gis_exp_bwidg
      gis_data_str.gis_select = 'B'
      gis_data_str.curr_b_data = $
                             gis_deselect(GISrasterhdr,gis_plot,exp_no,msg_widg)
      plot_gis, gis_data_str.curr_b_data 
      return
   ENDIF

;
;  switch to image A requested, so get exposure wanted and plot it
;            =======
;
   IF (value EQ "Select A") THEN BEGIN
      Exp_Select, "GIS", exp_no 
      gis_data_str.exp_in_a = exp_no
      IF (exp_no EQ -1) THEN  RETURN
      Update_ExpInfo, GIS_exphdr(exp_no), GISrasterhdr, gis_exp_awidg
      gis_data_str.gis_select = 'A'
      gis_data_str.curr_a_data = $
                             gis_deselect(GISrasterhdr,gis_plot,exp_no,msg_widg)
      plot_gis, gis_data_str.curr_a_data 
      return
   ENDIF

;
;  Hardcopy of window A to postscript
;              ========

   IF (value EQ "Window A") THEN BEGIN
      gis_data_str.gis_select = 'A'
      exp_no = gis_data_str.exp_in_a
      IF (exp_no EQ -1) THEN  RETURN
      temp = gis_deselect(GISrasterhdr,gis_plot,exp_no,msg_widg)
      ps
      plot_gis,gis_data_str.curr_a_data, $
                              xmin=gis_data_str.agis_last_x(0),$
                              xmax=gis_data_str.agis_last_x(1)
      xyouts,0.,0.01,'Data taken: '+GIS_date_time(exp_no)+ $
                     ' Plotted at: '+systime(),/normal
      xyouts,0.87,0.01,'Exposure #'+ $
                        string(gis_data_str.exp_in_a,form='(i3)'),/normal
      psplot
      widget_control, gis_msg_widg, set_val='GIS plot on print queue.'
      bell
      return
   ENDIF

;
;  Hardcopy of window B to postscript
;              ========

   IF (value EQ "Window B") THEN BEGIN
      gis_data_str.gis_select = 'B'
      exp_no = gis_data_str.exp_in_a
      IF (exp_no EQ -1) THEN  RETURN
      temp = gis_deselect(GISrasterhdr,gis_plot,exp_no,msg_widg)
      ps
      plot_gis,gis_data_str.curr_b_data, $
                              xmin=gis_data_str.bgis_last_x(0),$
                              xmax=gis_data_str.bgis_last_x(1)
      xyouts,0.,0.01,'Data taken: '+GIS_date_time(exp_no)+ $
                     ' Plotted at: '+systime(),/normal
      xyouts,0.87,0.01,'Exposure #'+ $
                        string(gis_data_str.exp_in_b,form='(i3)'),/normal

      psplot
      widget_control, gis_msg_widg, set_val='GIS plot on print queue.'
      bell
      return
   ENDIF


;
;  change of which band to display in plot A
;
   if strmid(uvalue,0,5) eq 'aGISB' then begin
      gis_data_str.gis_select = 'A'
      band = fix(strmid(uvalue,5,1)) - 1

      if band eq 4 then begin
         gis_data_str.agis_last_x = [0.,0.]
         for i=0,3 do widget_control,agis_b_ids(i),set_button=0 
         widget_control,agis_b_ids(4),set_button=1
         gis_data_str.agis_plot_choice(*) = 0 
         gis_data_str.agis_plot_choice(4) = 1
         if gis_data_str.exp_in_a  eq -1 then begin
            plot_gis, dummy, /init
         endif else begin
            plot_gis, gis_data_str.curr_a_data
         endelse
      endif else begin
         for i=0,3 do begin
            if band eq i then begin
               gis_data_str.agis_last_x = [0.,0.]
               if gis_data_str.agis_plot_choice(i) eq 1 then begin
                  gis_data_str.agis_plot_choice(i)=0
               endif else begin
                  gis_data_str.agis_plot_choice(i)=1
                  gis_data_str.agis_plot_choice(4)=0
                  widget_control,agis_b_ids(4),set_button=0
               endelse
            endif
         endfor
         if total(gis_data_str.agis_plot_choice(0:3)) eq 4 or $
               total(gis_data_str.agis_plot_choice(0:3)) eq 0 then begin
            for i=0,3 do widget_control,agis_b_ids(i),set_button=0 
            widget_control,agis_b_ids(4),set_button=1
            gis_data_str.agis_plot_choice(*) = 0 
            gis_data_str.agis_plot_choice(4) = 1
         endif   
         if gis_data_str.exp_in_a eq -1 then begin
            plot_gis, dummy, /init
         endif else begin
            plot_gis, gis_data_str.curr_a_data
         endelse
      endelse
   endif

;
;  change of which band to display in plot B
;
   if strmid(uvalue,0,5) eq 'bGISB' then begin
      gis_data_str.gis_select = 'B'
      band = fix(strmid(uvalue,5,1)) - 1

      if band eq 4 then begin
         gis_data_str.bgis_last_x = [0.,0.]
         for i=0,3 do widget_control,bgis_b_ids(i),set_button=0 
         widget_control,bgis_b_ids(4),set_button=1
         gis_data_str.bgis_plot_choice(*) = 0 
         gis_data_str.bgis_plot_choice(4) = 1
         if gis_data_str.exp_in_b eq -1 then begin
            plot_gis, dummy, /init
         endif else begin
            plot_gis, gis_data_str.curr_b_data
         endelse
      endif else begin
         for i=0,3 do begin
            if band eq i then begin
               gis_data_str.bgis_last_x = [0.,0.]
               if gis_data_str.bgis_plot_choice(i) eq 1 then begin
                  gis_data_str.bgis_plot_choice(i)=0
               endif else begin
                  gis_data_str.bgis_plot_choice(i)=1
                  gis_data_str.bgis_plot_choice(4)=0
                  widget_control,bgis_b_ids(4),set_button=0
               endelse
            endif
         endfor
         if total(gis_data_str.bgis_plot_choice(0:3)) eq 4 or $
               total(gis_data_str.bgis_plot_choice(0:3)) eq 0 then begin
            for i=0,3 do widget_control,bgis_b_ids(i),set_button=0 
            widget_control,bgis_b_ids(4),set_button=1
            gis_data_str.bgis_plot_choice(*) = 0 
            gis_data_str.bgis_plot_choice(4) = 1
         endif   
         if gis_data_str.exp_in_b eq -1 then begin
            plot_gis, dummy, /init
         endif else begin
            plot_gis, gis_data_str.curr_b_data
         endelse
      endelse
   endif

;
;  Analyse menu
;
   if strmid(uvalue,0,5) eq 'anal_' then begin

      mode = strmid(uvalue,5,5)

;
;  select and setup display A or B
;
      if strmid(mode,4,1) eq 'A' then begin
         ok = total(gis_data_str.agis_plot_choice(0:3))
         if ok ne 1 then begin
            flash_msg,gis_msg_widg,$
                     'Display only one GIS band first.'
            return
         endif
         gis_data_str.gis_select = 'A'
         widget_control,gis_awidg,get_val=window
         wset, window    
         if gis_data_str.exp_in_a eq -1 then begin
            plot_gis,dum,/init
            data = indgen(8192)
         endif else begin
            if total(gis_data_str.agis_last_x) gt 0 then begin
               plot_gis,gis_data_str.curr_a_data,$
                        xmin=gis_data_str.agis_last_x(0),$
                        xmax=gis_data_str.agis_last_x(1)
            endif else begin
               plot_gis,gis_data_str.curr_a_data
            endelse
            data = gis_data_str.curr_a_data
         endelse
         band = where(gis_data_str.agis_plot_choice(0:3) eq 1)
         band = band(0)
         
      endif else begin

         ok = total(gis_data_str.bgis_plot_choice(0:3))
         if ok ne 1 then begin
            flash_msg,gis_msg_widg,$
                     'Display only one GIS band first.'
            return
         endif
         gis_data_str.gis_select = 'B'
         widget_control,gis_bwidg,get_val=window
         wset, window    
         if gis_data_str.exp_in_b eq -1 then begin
            plot_gis,dum,/init
            data = indgen(8192)
         endif else begin
            if total(gis_data_str.bgis_last_x) gt 0 then begin
               plot_gis,gis_data_str.curr_b_data,$
                        xmin=gis_data_str.bgis_last_x(0),$
                        xmax=gis_data_str.bgis_last_x(1)
            endif else begin
               plot_gis,gis_data_str.curr_b_data
            endelse
            data = gis_data_str.curr_b_data
         endelse
         band = where(gis_data_str.bgis_plot_choice(0:3) eq 1) 
         band = band(0)
      endelse

;
;  now the individual actions
;

      case 1 of

        mode eq 'SUBAB': begin
                    flash_msg,gis_msg_widg,'Not yet implemented.'
                 end

        mode eq 'ENLGA': begin
                    bell
                    widget_control,gis_msg_widg,set_val=$
                                'Mark region to enlarge using 2 cursor clicks.'
                    cursor,x,y,3,/data  & gis_data_str.agis_last_x(0) = x
                    oplot,[x,x],[1,100000],linestyle=1
                    cursor,x,y,3,/data  & gis_data_str.agis_last_x(1) = x
                    oplot,[x,x],[1,100000],linestyle=1
                    gis_data_str.agis_last_x = $
                       gis_data_str.agis_last_x(sort(gis_data_str.agis_last_x))
                    pix = gis_data_str.agis_last_x
                    if gis_data_str.gis_plot_wave then begin
                       pix = wave2pix('GIS'+string(band+1,form='(a,i1)'),$
                                            gis_data_str.agis_last_x, /limit)
                    endif
                    if n_elements(pix) lt 2 then begin
                       return
                    endif else begin
                       gis_data_str.agis_last_x = pix
                    endelse

                    plot_gis,data,xmin=gis_data_str.agis_last_x(0),$
                                            xmax=gis_data_str.agis_last_x(1)

                    widget_control,gis_msg_widg,set_val=' '
                 end

        mode eq 'ENLGB': begin
                    bell
                    widget_control,gis_msg_widg,set_val=$
                                'Mark region to enlarge using 2 cursor clicks.'
                    cursor,x,y,3,/data  & gis_data_str.bgis_last_x(0) = x
                    oplot,[x,x],[1,100000],linestyle=1
                    cursor,x,y,3,/data  & gis_data_str.bgis_last_x(1) = x
                    oplot,[x,x],[1,100000],linestyle=1
                    gis_data_str.bgis_last_x = $
                       gis_data_str.bgis_last_x(sort(gis_data_str.bgis_last_x))
                    pix = gis_data_str.bgis_last_x
                    if gis_data_str.gis_plot_wave then begin
                       pix = wave2pix('GIS'+string(band+1,form='(a,i1)'),$
                                         gis_data_str.bgis_last_x, /limit)
                    endif

                    if n_elements(pix) lt 2 then begin 
                       widget_control,gis_msg_widg,set_val='Error in wave2pix'
                       return
                    endif else begin
                       gis_data_str.bgis_last_x = pix
                    endelse

                    plot_gis,data,xmin=gis_data_str.bgis_last_x(0),$
                                            xmax=gis_data_str.bgis_last_x(1)

                    widget_control,gis_msg_widg,set_val=' '
                 end


        mode eq 'PROFA' or mode eq 'PROFB': begin
                    k = strmid(uvalue,10,1)
                    bell
                    widget_control,gis_msg_widg,set_val=$
                                'Mark region to fit using 2 cursor clicks.'
                    xfit = fltarr(2)
                    cursor,x,y,3,/data  & xfit(0) = x
                    oplot,[x,x],[1,100000],linestyle=1
                    cursor,x,y,3,/data  & xfit(1) = x
                    oplot,[x,x],[1,100000],linestyle=1
                    xfit = xfit(sort(xfit))
                    if gis_data_str.gis_plot_wave then begin
                       xfit = wave2pix('GIS'+string(band+1,form='(a,i1)'),$
                                       xfit, /limit)
                    endif
                    if n_elements(xfit) lt 2 then begin
                       widget_control,gis_msg_widg,set_val='Error in wave2pix'
                       return
                    endif
                    xfit = indgen(xfit(1)-xfit(0)+1) + xfit(0) - 1
                    ydata = data(band*2048+xfit(0):band*2048+xfit(n_elements(xfit)-1))
                    yfit = cds_gauss(xfit,ydata,coeff,k)
                    if n_elements(yfit) gt 1 then begin
                       x_unit = ' Central pixel: '
                       if gis_data_str.gis_plot_wave then begin
                          xfit = pix2wave('GIS'+string(band+1,form='(a,i1)'),$
                                          xfit, /limit)
                          coeff(1) = pix2wave('GIS'+string(band+1,$
                                                   form='(a,i1)'),coeff(1), /limit)
                          x_unit = ' Central wavelength: '
                       endif
                       oplot,xfit,yfit,thick=2
   
                       text1 = string('Fitted profile  -->  Height: ',$
                                     float(coeff(0)),form='(a,f7.1)')
                       text2 = string(x_unit,float(coeff(1)),' Sigma: ',$
                                     float(coeff(2)),form='(a,f6.1,a,f6.2)')
                       if k gt 0 then begin
                          text3 = string(' Background terms: ',float(coeff(3:k+2)),$
                                         format='(a,3(f7.2,2x))')
                       endif else begin
                          text3 = ' '
                       endelse
                       widget_control,gis_msg_widg,set_val=text1+text2+text3
                    endif else begin
                       widget_control,gis_msg_widg,set_val='Error on fit.'
                    endelse
                 end   

        else:
      endcase
   endif


;
;  switch mode of plotting on X-AXIS
;
   if uvalue eq 'PIX' or uvalue eq 'WAV' then begin
      if uvalue eq 'WAV' then gis_data_str.gis_plot_wave = 1
      if uvalue eq 'PIX' then gis_data_str.gis_plot_wave = 0
      sa = gis_data_str.gis_select
      gis_data_str.gis_select = 'A'
      if gis_data_str.exp_in_a eq -1 then begin
         plot_gis,dummy,/init
      endif else begin
         plot_gis,gis_data_str.curr_a_data
      endelse
      gis_data_str.gis_select = 'B'
      if gis_data_str.exp_in_b eq -1 then begin
         plot_gis,dummy,/init
      endif else begin
         plot_gis,gis_data_str.curr_b_data
      endelse
      gis_data_str.gis_select = sa
   endif


;
;  switch mode of plotting on Y-AXIS
;
   if uvalue eq 'LOG' or uvalue eq 'LIN' then begin
      if uvalue eq 'LIN' then gis_data_str.gis_plot_linear = 1
      if uvalue eq 'LOG' then gis_data_str.gis_plot_linear = 0
      sa = gis_data_str.gis_select
      gis_data_str.gis_select = 'A'
      if gis_data_str.exp_in_a eq -1 then begin
         plot_gis,dummy,/init
      endif else begin
         plot_gis,gis_data_str.curr_a_data
      endelse
      gis_data_str.gis_select = 'B'
      if gis_data_str.exp_in_b eq -1 then begin
         plot_gis,dummy,/init
      endif else begin
         plot_gis,gis_data_str.curr_b_data
      endelse
      gis_data_str.gis_select = sa
   endif


ENDIF

END
