;+
; Project     : SOHO - CDS     
;                   
; Name        : HANDLE_IO_ERR
;               
; Purpose     : Handle i/o errors in telemetry reception.
;               
; Explanation : When an i/o error occurs in the telemetry receipt, this routine
;               stops the background routine WORKPROC which was receiving the
;               data, closes the input logical unit and displays an error
;               message in the information widget. The new state of the 
;               data acquisition (ie stopped) is communicated back via
;               variables in the Mode common block.
;               
; Use         : handle_io_err, widget_base, msd_widg, unit
;    
;               Normally reserved for internal use within EGSE science analysis
;
; Inputs      : widget_base - the id of the widget with which WORKPORC was
;                             registered.
;               msg_widg    - the id of the widget for messages
;               dummy_label - the ID of the dummy widget that controls
;                             workproc
;               unit        - the unit to which the telemetry was attached
;                             before the error occurred.
;               
; Opt. Inputs : None 
;               
; Outputs     : None 
;               
; Opt. Outputs: None 
;               
; Keywords    : None 
;
; Calls       : None 
;               
; Restrictions: For EGSE science analysis internal use only.
;               
; Side effects: None 
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Update error message.  CDP, 18-Jan-95
;               Cut out use of ctrl_analysis.  CDP, 25-May-95
;               Change from use of XBAckRegister.  CDP, 19-Jun-98
;
; Version     : Version 4, 19-Jun-98
;-            

PRO handle_io_err, widget_base, msg_widg, dummy_label, unit


;
;  COMMON block for communication of data taking status
;
@Mode.com

;
; close the attched unit (file or pipe to C program) 
;
close,unit

;
;  unregister WORKPROC ie stop it running as a background task of the main
;  widget
;
;XBackRegister, /UNREGISTER, "workproc", widget_base
widget_control, dummy_label, /destroy

;
;  and state the obvious
;
WIDGET_CONTROL, msg_widg, SET_VALUE='Data taking stopped because',/append
WIDGET_CONTROL, msg_widg, SET_VALUE=!err_string,/append

;
;  set flag to indicate we have stopped, these are sent back in COMMON
;
sci_pause = 0
sci_going = 0

;
;  set buttons to correct state
;
widget_control, start_base, sens=1
widget_control, stop_base, sens=0


;
;  reenable analysis widgets now that data taking cannot be affected
;
;ctrl_analysis,1


end
