;+
; Project     : SOHO - CDS
;
; Name        : HEAD_ENGINEER
;
; Purpose     : Create Engineering data header for raw GIS dumps.
;
; Explanation : Packages various engineering parameters which are then
;               written at the head of the raw and PHS data dump files.
;
; Use         : Called by PROCESS_RAW_GIS
;
; Inputs      : eng - the array of engineering data created in process_raw_gis
;                     and other parameters via common block.
;
; Opt. Inputs : None
;
; Outputs     : Function returns a 512 byte array containing the header.
;
; Opt. Outputs: None
;
; Keywords    : None
;
; Calls       : None
;
; Restrictions: None
;
; Side effects: None
;
; Category    : Telemetry, GIS
;
; Prev. Hist. : Original by E Alam, 12 Jan 1994
;
; Written     : Updated for new format, CDP, 12-Oct-95
;
; Modified    : Include RawData common for filament parameters. CDP, 23-Oct-95
;		Convert it all to ASCII, ERB MSSL/UCL, 23-Oct-95
;
; Version     : Version 2.1, 23-Oct-95
;-

FUNCTION HEAD_ENGINEER, ENG

;
;  common for communication
;
@RawData.com

;
; Create Eng Average Values by calling AVG_ENG_GIS
; 


A_ENG = (ENG)

;
; Create HEADER TEMPLATE with Mnemonics for each avgd Eng value (BYTE ARRAY) 
; & ASCII SPACES (x20)
; 


HEAD = BYTARR(512)
HEAD(*) = 32 
HEAD(0) = BYTE(string('Comment'))

HEAD(80) = BYTE(string('Detector No.', A_ENG(1)))
       

;
; Fill Template
; 

HEAD(160) = BYTE(string(FORMAT="('BUGHV',I1,'   ',I)", A_ENG(1), A_ENG(0) ))

HEAD(180) = BYTE(string(FORMAT="('BUGMCPB',I1,' ',I)", A_ENG(1), A_ENG(2) ))

HEAD(200) = BYTE(string(format="('BIGMCP',I1,'  ',I)", A_ENG(1), A_ENG(3) ))

HEAD(240) = BYTE(string(format="('BKGRCD',I1,' ', I)", A_ENG(1), $
					ISHFT(LONG(A_ENG(4)), 8) + A_ENG(5) ))
;
;  HEAD(195:196) = A_ENG(4:5) - 16 BIT counters ABOVE
;

HEAD(280) = BYTE(string(format="('BKGULCD',I1,I)", A_ENG(1), $
					ISHFT(LONG(A_ENG(6)), 8) + A_ENG(7) ))
;
;  HEAD(206:207) = A_ENG(6:7) - 16 BIT counters ABOVE
;

HEAD(320) = BYTE(string(format="('BKGLDLD',I1,' ',I)", A_ENG(1), A_ENG(8) ))

HEAD(340) = BYTE(string(format="('BKGHV',I1,'L  ',I)", A_ENG(1), A_ENG(9) ))

;
;  add in the other parameters starting at byte 400
;
head(400) = byte(string('FIL_ID  ', fil_sel))

head(420) = byte(string('FIL_CURR', fil_curr))

head(440) = byte(string('SLIT_NUM', slit_num))

head(460) = byte(string('SLIT_POS', slit_pos))

head(480) = byte(string('MIRR_POS', mirr_pos))


RETURN, HEAD

END

 
