;+
; Project     : SOHO - CDS     
;                   
; Name        : HEADER_G_EVENT
;               
; Purpose     : Processes widget events from the GIS packet header menu.
;               
; Explanation : Any widget events originating in the routine HEADER_GIS_MENU
;               which displays the header information of GIS telemetry packets
;               is dealt with by this routine.  The options are limited at
;               present to closing the widget and changing the format of the
;               data displayed (either hexadecimal or decimal).
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the structure of the event generated.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for interal use of EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-oct-93
;               
; Modified    : Put in 'DONE' button instead of file/close, CDP, 27-Oct-93
;               Include redisplay on format change.  CDP, 18-Aug-94
;
; Version     : Version 3, 18-Aug-94
;-            

PRO header_g_event, ev

;
;  COMMON blocks for communication of variables
;
@MainWidgets.com
@HeaderWidgets.com
@Packets.com
@Base_Offsets.com

;
; find out type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  event should only have been generated by a button
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  done ie exit
; 
   IF (value EQ 'Done') THEN BEGIN
      widget_control,header_g_base, tlb_get_offset=boff
      widget_control,header_g_base, tlb_get_size = bsize
      gis_header_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, header_g_base, /destroy
      header_select = 0
   ENDIF

;
;  Hardcopy
; 
   IF (value EQ 'Hardcopy') then begin
      widget_control, header_g_base,/hourglass 
      get_utc,utc
      widget_control, gis_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "GIS Packet header" '+$
            ' | xpr  -gray 3 -width 4 -height 6 -header "GIS Packet header"'+$
            ' | lpr'
      widget_control, gis_hc_id,set_val='Hardcopy'
   ENDIF

;
;  switch the format to be used for displaying the output
;
   if value eq 'Decimal' or value eq 'Hex' then begin

      if (value EQ 'Decimal') then begin
         header_format = 1 
         widget_control,header_format_gw,set_value='Decimal'
      endif
    
      if (value EQ 'Hex') then begin
         header_format = 2 
         widget_control,header_format_gw,set_value='Hex'
      endif

;
;  redisplay values
;
      if n_elements(packet_header) gt 0 then disp_gis_hdr, packet_header
      if n_elements(GISrasterhdr) gt 0 then disp_gis_hdr, GISrasterhdr
      if n_elements(scnt_str) gt 0 then disp_gis_hdr, scnt_str
      if n_elements(ExpHdr) gt 0 then disp_gis_hdr, ExpHdr
   endif   
   


endif

end
