;+
; Project     : SOHO - CDS     
;                   
; Name        : HEADER_V_EVENT
;               
; Purpose     : Processes widget events from the VDS packet header menu.
;               
; Explanation : Any widget events originating in the routine HEADER_VDS_MENU
;               which displays the header information of VDS telemetry packets
;               is dealt with by this routine.  The options are limited at
;               present to closing the widget and changing the format of the
;               data displayed (either hexadecimal or decimal).
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the structure of the event generated.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for interal use of EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-oct-93
;               
; Modified    : Use Done button instead of file/close.  27-Oct-93, CDP
;               Add redisplay on format change.  CDP 18-Aug-94
;               Add Hardcopy button.  CDP, 27-Jan-95
;
; Version     : Version 4, 27-Jan-95
;-            

PRO header_v_event, ev

;
;  COMMON blocks for communication of variables
;
@MainWidgets.com
@HeaderWidgets.com
@Packets.com
@Base_Offsets.com


;
; find out type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  event should only have been generated by a button
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  Done, ie exit from widget
; 
   IF (value EQ 'Done') THEN BEGIN
      widget_control,header_v_base, tlb_get_offset=boff
      widget_control,header_v_base, tlb_get_size = bsize
      vds_header_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, header_v_base, /destroy
      header_select = 0
   ENDIF

;
;  Hardcopy
; 
   IF (value EQ 'Hardcopy') then begin
      widget_control, header_v_base,/hourglass 
      get_utc,utc
      widget_control, vds_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "VDS Packet header" '+$
            ' | xpr  -gray 3 -width 4 -height 6 -header "VDS Packet header"'+$
            ' | lpr'
      widget_control, vds_hc_id,set_val='Hardcopy'
   ENDIF

;
;  switch the format to be used for displaying the output
;
   if value eq 'Decimal' or value eq 'Hex' then begin
 
      IF (value EQ 'Decimal') then begin
         header_format = 1 
         widget_control,header_format_vw,set_value='Decimal'
      endif

      IF (value EQ 'Hex') then begin
         header_format = 2 
         widget_control,header_format_vw,set_value='Hex'
      endif

;
;  redisplay values
;
      if n_elements(packet_header) gt 0 then disp_vds_hdr, packet_header
      if n_elements(VDSrasterhdr) gt 0 then disp_vds_hdr, VDSrasterhdr
      if n_elements(scnt_str)    gt 0 then disp_vds_hdr, scnt_str
      if n_elements(ExpHdr)     gt 0 then disp_vds_hdr, ExpHdr
   endif   

endif

end
