;+
; Project     : SOHO - CDS     
;                   
; Name        : HEADER_VDS_MENU
;               
; Purpose     : Defines and realises the VDS header information window. 
;               
; Explanation : One of the options available within the EGSE science analysis
;               program is to monitor the header information of VDS science
;               packets as they are received in the telemetry.  This program
;               defines and realises the widgets within which the VDS header
;               information is displayed.
;               
; Use         : Only called from MAIN_MENU
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for internal use in EGSE science analysis
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 7-Oct-93
;               
; Modified    : Change time output to date/time string  21/10/93  CDP
;               Change to accommodate v3.0 of packet format 27/10/93  CDP
;               Put in scroll to accommodate IDLv3.5  25/7/94 CDP
;               Reorganise to accommodate without scrolling. CDP 12-Aug-94
;               Add Hardcopy button.  CDP, 27-jan-95
;               Rename Done button widget ID.  CDP, 30-Jun-95
;               Updated layout for IDL v4.  CDP, 20-Aug-96
;
; Version     : Version 7, 20-Aug-96
;-            


PRO header_vds_menu

;
;  COMMON blocks for communication
; 
@HeaderWidgets.com
@MainWidgets.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('header_v') then return



;
;  storage for id's of individual text widgets
;
header_v_exp = lonarr(31)


;
;  get base widget position and size
;
tp_offsets


;
;  set up main widget
;
header_v_base = WIDGET_BASE(title='VDS Packet header', group=main_base, $
                            /FRAME, /row, $
                            xsize=vds_header_off(2),ysize=vds_header_off(3), $
                            xoffset=vds_header_off(0),yoffset=vds_header_off(1))


;
;  and subsidiary ones
;

menu_base   = WIDGET_BASE(header_v_base, /column)
button_widg = WIDGET_BASE(menu_base, /row)
fmt_widg    = widget_base(menu_base, /column)
info_abase  = WIDGET_BASE(header_v_base, /COLUMN, /FRAME, SPACE=1)

;
;  get larger font
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  create Done button
;
vds_h_done = widget_button(button_widg,value='Done',font=cfont)

;
;  form the pulldown menu for format change
;
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],button_widg

;
;  and the text window to display current format setting
;
f1 =  widget_base(fmt_widg,/column)
f11 = widget_label(f1,val='Current format: ')
if header_format eq 2 then format = 'Hex' else format = 'Decimal'
header_format_vw = widget_text(f1,xsize=10,ysize=1,value=format)

;
;  create 'Hardcopy' button....
;
vds_hc_id = widget_button(button_widg, value='Hardcopy', font=cfont)


;
;  and the text windows to display data windows definition
;
w_widg = WIDGET_BASE(menu_base, /row, /scroll, space=10, y_scroll_size=600,$
                                                        x_scroll_size=315)
header_v_w = lonarr(24)
w1 =  widget_base(w_widg,/column,space=1)
w11 = widget_label(w1,val='Win#')
for i=0,23 do begin
   winnum = string(i+1,format='(i2)')
   header_v_w(i) = widget_text(w1,xsize=2,ysize=1,value=winnum)
endfor

;
;  X start positions
;
header_v_w_sx = lonarr(24)
wsx =  widget_base(w_widg,/column,space=1)
wssx = widget_label(wsx,val='XStart')
for i=0,23 do begin
   header_v_w_sx(i) = widget_text(wsx,xsize=4,ysize=1,value=' ')
endfor

;
;  X length
;
header_v_w_lx = lonarr(24)
wlx =  widget_base(w_widg,/column,space=1)
wllx = widget_label(wlx,val='XLen')
for i=0,23 do begin
   header_v_w_lx(i) = widget_text(wlx,xsize=4,ysize=1,value=' ')
endfor

;
;  Y start positions
;
header_v_w_sy = lonarr(24)
wsy =  widget_base(w_widg,/column,space=1)
wssy = widget_label(wsy,val='Ystart')
for i=0,23 do begin
   header_v_w_sy(i) = widget_text(wsy,xsize=4,ysize=1,value=' ')
endfor

;
;  Y length
;
header_v_w_ly = lonarr(24)
wly =  widget_base(w_widg,/column,space=1)
wlly = widget_label(wly,val='YLen')
for i=0,23 do begin
   header_v_w_ly(i) = widget_text(wly,xsize=4,ysize=1,value=' ')
endfor

;
;  form all the individual text widgets to display the header information
;


a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Application ID (Hex):')
header_v_exp(0) = WIDGET_TEXT(a1,XSIZE=10,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Science Pkt ID (hex)/counter:')
header_v_exp(1) = WIDGET_TEXT(a2,XSIZE=10,YSIZE=1)


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Study/Seq/DEW IDs:')
header_v_exp(2) = WIDGET_TEXT(a3,XSIZE=18,YSIZE=1)

a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Comp method/option/orient:')
header_v_exp(3) = WIDGET_TEXT(a4,XSIZE=16,YSIZE=1)


a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Raster positions (m:s):')
header_v_exp(4) = WIDGET_TEXT(a5,XSIZE=10,YSIZE=1)

a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='OPS L/R Coordinate:')
header_v_exp(5) = WIDGET_TEXT(a6,XSIZE=15,YSIZE=1)

a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='Slit #/Position:')
header_v_exp(6) = WIDGET_TEXT(a7,XSIZE=12,YSIZE=1)

a8  = WIDGET_BASE(info_abase, /ROW)
a81 = WIDGET_LABEL(a8, VALUE='Mirror Position:')
header_v_exp(7) = WIDGET_TEXT(a8,XSIZE=10,YSIZE=1)

a9  = WIDGET_BASE(info_abase, /ROW)
a91 = WIDGET_LABEL(a9, VALUE='Exposure time (secs):')
header_v_exp(8) = WIDGET_TEXT(a9,XSIZE=10,YSIZE=1)

a10  = WIDGET_BASE(info_abase, /ROW)
a101 = WIDGET_LABEL(a10, VALUE='Study/raster counter:')
header_v_exp(9) = WIDGET_TEXT(a10,XSIZE=14,YSIZE=1)

a11  = WIDGET_BASE(info_abase, /ROW)
a111 = WIDGET_LABEL(a11, VALUE='Science proc stat (bits):')
header_v_exp(10) = WIDGET_TEXT(a11,XSIZE=10,YSIZE=1)

a12  = WIDGET_BASE(info_abase, /ROW)
a121 = WIDGET_LABEL(a12, VALUE='Exposure start (date):')
header_v_exp(11) = WIDGET_TEXT(a12,XSIZE=10,YSIZE=1)

a13  = WIDGET_BASE(info_abase, /ROW)
a131 = WIDGET_LABEL(a13, VALUE='Exposure start (time):')
header_v_exp(12) = WIDGET_TEXT(a13,XSIZE=10,YSIZE=1)

a14  = WIDGET_BASE(info_abase, /ROW)
a141 = WIDGET_LABEL(a14, VALUE='Exposure number:')
header_v_exp(13) = WIDGET_TEXT(a14,XSIZE=10,YSIZE=1)

a15  = WIDGET_BASE(info_abase, /ROW)
a151 = WIDGET_LABEL(a15, VALUE='Sun sensor pitch/yaw:')
header_v_exp(14) = WIDGET_TEXT(a15,XSIZE=15,YSIZE=1)

a16  = WIDGET_BASE(info_abase, /ROW)
a161 = WIDGET_LABEL(a16, VALUE='Solar X/Y:')
header_v_exp(15) = WIDGET_TEXT(a16,XSIZE=15,YSIZE=1)

a17  = WIDGET_BASE(info_abase, /ROW)
a171 = WIDGET_LABEL(a17, VALUE='Event status:')
header_v_exp(16) = WIDGET_TEXT(a17,XSIZE=20,YSIZE=1)

a18  = WIDGET_BASE(info_abase, /ROW)
a181 = WIDGET_LABEL(a18, VALUE='Event level:')
header_v_exp(17) = WIDGET_TEXT(a18,XSIZE=10,YSIZE=1)

a19  = WIDGET_BASE(info_abase, /ROW)
a191 = WIDGET_LABEL(a19, VALUE='Science counter:')
header_v_exp(18) = WIDGET_TEXT(a19,XSIZE=10,YSIZE=1)

;
;  let world know we exist
;
header_select = -1

;
;  realize (ie make appear) the top and embedded widgets
;
WIDGET_CONTROL, header_v_base, /realize

end
