;+
; Project     : SOHO - CDS     
;                   
; Name        : MON_EVENT
;               
; Purpose     : Handles events from MON_MENU widgets.
;               
; Explanation : Any event generated by the widgets in the display
;               of monitor data is handled by this routine.
;               
; Use         : Only called by XMANAGER.
;    
; Inputs      : ev - the structure associated with the event.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for EGSE/sci_ana use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 10-Jan-94
;               
; Modified    : Handle 'Reset' button and Hardcopy, CDP, 1-Mar-94
;               Correct bug in hardcopy handling.  CDP, 26-May-95
;
; Version     : Version 3, 26-May-95
;-            

PRO mon_event, ev

;
;  COMMON blocks for communication of widget id's and counter.
;
@MainWidgets.com
@Monitor.com
@Base_Offsets.com
      
;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  it should only have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  request to reset the counters and plot
; 
   if (value EQ 'Reset') then begin
      vds_monitor(*) = 0
      gis_monitor(*) = 0
      opsl_monitor(*) = 0
      opsr_monitor(*) = 0
      slitn_monitor(*) = 0
      slitp_monitor(*) = 0
      mirrp_monitor(*) = 0
      opsl_count = -1
      opsr_count = -1
      slitn_count = -1
      slitp_count = -1
      mirrp_count = -1
      vm_count = -1
      gm_count = -1
      widget_control, mon_draw, get_val=wind
      wset, wind
      if not m_monitor_mode then begin
         !p.multi = 0
         plot,[0,19],[0,1],/nodata,xtit='Exposure number.',ytit='Total count.'
      endif
   endif

;
;  request for hardcopy plot
; 
   if (value EQ 'Hardcopy') then begin
      if (m_monitor_mode and (slitp_count ge 0)) or $
            (g_monitor_mode and (gm_count ge 0)) or $
               (v_monitor_mode and (vm_count ge 0))   then begin
         plot_monitor,/hard
         widget_control,msg_widg,/append,$
                        set_val=systime()+' >> Hardcopy sent to printer...'
      endif else begin
         bell
         widget_control,msg_widg,/append,$
                        set_val='No data to plot hardcopy of.'
      endelse
   endif

;
;  request to finish/exit from the widget
; 
   if (value EQ 'Done') then begin
      widget_control,mon_base, tlb_get_offset=boff
      widget_control,mon_base, tlb_get_size = bsize
      mon_menu_off = [boff,bsize]
      tp_offsets, /write
      widget_control, mon_base, /destroy
      v_monitor_mode = 0 
      g_monitor_mode = 0
      m_monitor_mode = 0
      vds_monitor(*) = 0
      gis_monitor(*) = 0
      opsl_monitor(*) = 0
      opsr_monitor(*) = 0
      slitn_monitor(*) = 0
      slitp_monitor(*) = 0
      mirrp_monitor(*) = 0
      opsl_count  = -1
      opsr_count  = -1
      slitn_count = -1
      slitp_count = -1
      mirrp_count = -1
      vm_count = -1
      gm_count = -1
   endif

endif      
END
