;+
; Project     : SOHO - CDS     
;                   
; Name        : NEW_DCS_OPS
;               
; Purpose     : Allows updating of OPS values in DCS
;               
; Explanation : When the DCS OPS entries are to be edited, this routine
;               displays the current contents and allows the user to select
;               entries to be updated with new pointing values.  The Perl 
;               script NEW_OPS_LOAD must then be run on the EGSE to perform 
;               the change.
;               
; Use         : new_dcs_ops
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Generally only to be run by MASTER account.  Requires 
;               CDS_CP_TTCFILES_W to be defined.  Works on the file created
;               by STM when the deferred command store is dumped eg in Perl
;               script DFLOAD.  
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 2-Jun-98
;               
; Modified    : 
;
; Version     : Version 1, 2-Jun-98
;-            

PRO new_dcs_ops_event, ev

;
;  common for widget IDs
;
common dsc_ops_com, dcs_ebase, dcs_elist_id, dcs_ehc_id, edit_list, $
                     num_edit, tbdel

;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  was it a button?
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 

;
;  Restart from scratch
; 
   if (value EQ 'Reset Selection') then begin
      tbdel = ''
      widget_control, dcs_elist_id, set_value=edit_list
      bell
      print,' '
      print,'Selection reset.'
      print,' '
   endif

;
;  request for Hardcopy plot
; 
   if (value EQ 'Hardcopy') then begin
      widget_control, dcs_ebase,/hourglass
      get_utc,utc
      widget_control, dcs_ehc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "OPS Command Editor" '+$
      ' | xpr  -gray 3 -width 4 -height 6 -header "Deferred Command Store"'+$
      ' | lpr'
      widget_control, dcs_ehc_id,set_val='Hardcopy'
   endif

;
;  Request to finish and write out editing values
; 
   if (value EQ 'Done') then begin
      widget_control, dcs_ebase, /destroy
      outfile = concat_dir('$CDS_CP_TTCFILES_W','dcs_edit.times')
      nopsfile = concat_dir('$CDS_CP_TTCFILES_W','new_dcs_ops.pos')
      if n_elements(tbdel) gt 1 then begin
         openw,lun,outfile,/get_lun,error=err
         if err ne 0 then begin
            bell
            print,'Unable to open output file: ',outfile
            return
         endif
         openw,lunops,nopsfile,/get_lun,error=err
         if err ne 0 then begin
            bell
            print,'Unable to open new OPS file: ',nopsfile
            return
         endif
         tbdel = tbdel(rem_dup(tbdel))
         printf,lun,'# TIMES TO BE DELETED FROM THE DEFERRED COMMAND STORE'
         get_utc,utc
         utc = anytim2cal(utc)
         printf,lun,'# Created '+utc
         printf,lun,'#' 
         printf,lun,'#'

;  
;  Make sure kill duplicate DCS deletions
;   
         time = strarr(n_elements(tbdel))
         for i=0,n_elements(time)-1 do begin       
            time(i) = (str2arr(tbdel(i),'  '))(0)
         endfor
         time = time(rem_dup(time))
         for i=1,n_elements(time)-1 do begin
            printf,lun,time(i)
         endfor

;
;  write the DCS commands for new OPS pointings
;  (keep only the latest of any duplicates)
;
         tc = str_pick(tbdel,'','0x')
         order = long(str_pick(tbdel,'-->'))
         nn = rem_dup(tc,order)
         tbdel = tbdel(nn)
         tbdel = str_pick(tbdel,'','-->')
         for i=1,n_elements(tbdel)-1 do begin
            printf,lunops,tbdel(i)
         endfor
         free_lun,lun
         free_lun,lunops
      endif else begin
         bell
         print,'No editing selections written.'
      endelse
;
;  report back
;
   text = rd_ascii(outfile)
   print,' '
   print_str,text
   print,' '
   print,'-------------------------------------'

   text = rd_ascii(nopsfile)
   print,' '
   print,'New commands to be uplinked....'
   print_str,text
   print,' '
   print,'-------------------------------------'

   

   endif

;
;  Request to exit without doing anything
; 
   if (value EQ 'QUIT') then begin
      widget_control, dcs_ebase, /destroy
      print,' '
      print,' No editing selections written.'
      print,' '
   endif

endif      

;
;  or was it a INDEX input from the list itself
;
if type eq 'WIDGET_LIST' then begin

   hit = edit_list(ev.index)
   get_utc,utc
   tai = long(anytim2tai(utc))
   if strpos(hit,'(OPS') ge 0 then begin
      hit = edit_list([ev.index-1,ev.index,ev.index+1])
      nh = where(strpos(hit,'(OPS left') ge 0 or $
                 strpos(hit,'(OPS right') ge 0, count)
      if count gt 0 then begin
         xyok = 0
         while not xyok do begin
            xinput,text,'Enter the new solar X,Y values',/modal,ysize=1
            text = strcompress(strtrim(text,2))
            case 1 of
               strpos(text,',') ge 0: begin
                                         text = fix(str2arr(text,','))
                                         if n_elements(text) eq 2 then begin
                                            xyok = 1
                                         endif else begin
                                            xyok = 0
                                         endelse
                                      end
               strpos(text,' ') ge 0: begin
                                         text = fix(str2arr(text,' '))
                                         if n_elements(text) eq 2 then begin
                                            xyok = 1
                                         endif else begin
                                            xyok = 0
                                         endelse
                                      end
               else: begin
                        if text eq '' or text eq ' ' then begin
                           bell
                           print,'Selection ignored'
                           xyok = 1
                           nh = -1
                        endif else begin
                           bell
                           xack,'Must give 2 values, separated by comma or space',$
                                /modal,/stop_icon
                           xyok = 0
                        endelse
                     end
            endcase
         endwhile
         if n_elements(nh) eq 2 then begin
            xpos = text(0)
            ypos = text(1)
            newlr = cdsxy2lr(xpos,ypos)
            hit(nh(0)) = strcompress(hit(nh(0)))
            fred = str2arr(hit(nh(0)),delim=' ')
            fred0 = anytim2cal(fred(1)+' '+fred(2),f=11,/msec)
            dec2hex,newlr(0),out,/qu
            fred0 = '"'+fred0+'"'+'   CB5SIC "CBMOPSLP 0x0'+out+'"'
            fred0 = fred0 + ' --> '+trim(tai)

            hit(nh(1)) = strcompress(hit(nh(1)))
            fred = str2arr(hit(nh(1)),delim=' ')
            fred1 = anytim2cal(fred(1)+' '+fred(2),f=11,/msec)
            dec2hex,newlr(1),out,/qu
            fred1 = '"'+fred1+'"'+'   CB5SIC "CBMOPSRP 0x0'+out+'"'
            fred1 = fred1 + ' --> '+trim(tai)
            
            tbdel = [tbdel,fred0,fred1]
            tbdel = tbdel(rem_dup(tbdel))
         endif
      endif else begin
         bell
         print,'Cannot edit that - not an OPS command!'
      endelse
   endif else begin
      bell
      print,'Cannot edit that - not an OPS command'
   endelse
endif
END




;
;  Main routine
;  ============


PRO new_dcs_ops

;
;  common for widget IDs
;
common dsc_ops_com, dcs_ebase, dcs_elist_id, dcs_ehc_id, edit_list, $
                     num_edit, tbdel


;
;  user must have correct evar setup
;
if getenv('CDS_CP_TTCFILES_W') eq '' then begin
   bell
   print,'$CDS_CP_TTCFILES_W is not defined'
   return
endif

;
;  even if it is, check have write privilege for output file
;
outfile = concat_dir('$CDS_CP_TTCFILES_W','dcs_edit.times')
openw,lun,outfile,/get_lun,error=err
if err ne 0 then begin
   bell
   print,'Unable to open output file: ',outfile
   return
endif else begin
   free_lun,lun
endelse

;
; prepare the DCS contents
;
dcsf = ''
show_dcs,/quiet,/keep,file=dcsf
if dcsf eq 'Error' then begin
   xack, 'No DCS dump file available.'
   return
endif

dcsfile = 'current_dcs'
vms=(!version.os eq 'VMS')
if vms then home='sys$login' else home=getenv('HOME')
dcsfile=concat_dir(home,dcsfile)

;
;  top level widget id
;
tit = 'DCS Pointing Editor' 

dcs_ebase = WIDGET_BASE(title=tit, /FRAME, /COLUMN,xsize=800,ysize=900)

;
;  create master button base
;
dummy = widget_base(dcs_ebase,/frame,/row)

;
;  create 'DONE' button
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"
doneid = widget_button(dummy,value='Done', uvalue='Done', font=cfont)

;
;  create 'Reset' button
;
renewid = widget_button(dummy,value='Reset Selection', uvalue='Reset', $
                           font=cfont)

;
;  create 'HARDCOPY' button
;
dcs_ehc_id = widget_button(dummy,value='Hardcopy', uvalue='Hardcopy', $
                           font=cfont)

;
;  create 'QUIT' button
;
quitid = widget_button(dummy,value='QUIT', uvalue='QUIT', font=cfont)


;
;  if all Ok then read the DCS dump file
;  
edit_list = rd_ascii(dcsfile)
edit_list = strtrim(edit_list,2)
num_edit = n_elements(edit_list)
expand_list = ''
blank = ' '
for i=0,59 do blank=blank+' ' 

for i=0,num_edit-1 do begin
   expand_list = [expand_list,edit_list(i)]
   bit = str2arr(edit_list(i),'  ')
   if n_elements(bit) ge 3 then begin
      if strmid(bit(2),0,3) eq 'Run' then begin
         widget_control, dcs_ebase,/hour
         nn = n_elements(expand_list)
         expand_list(nn-1) = strmid(expand_list(nn-1),0,60)+' \'
         time = str2utc(bit(1),/dmy)
         get_detail,time,det
         if det.study_id ne -1 then begin
            ts = tai2utc(det.date_obs)
            te = tai2utc(det.date_end)
            list_detail, ts, te, det1, n
            more_det = strarr(n)
            for j=0,n-1 do begin
               ts = anytim2cal(tai2utc(det1(j).date_obs))+'     '
               more_det(j) = blank+'\ Study: '+$
                                fmt_vect([det1(j).study_id,det1(j).studyvar])+$
                                ' @ '+ts
            endfor
            expand_list = [expand_list,more_det]
         endif
      endif
   endif
endfor

;
;  reset list
;
edit_list = expand_list
num_edit = n_elements(edit_list)

edit_list = ['Loaded contents of DCS were: ','  ',edit_list,'   ',' ======  END ======']

;
;  list widget for display of contents
;
dcs_elist_id = widget_list(dcs_ebase, value=edit_list, ysize=40, xsize=100)

;
;  set up to be deleted list
;
tbdel = ''

;
;  realize (ie make appear) it all
;
WIDGET_CONTROL, dcs_ebase, /realize

;
;  and start it running
;
xmanager,"dcs_edit",dcs_ebase,event_handler='new_dcs_ops_event'

end
