;+
; Project     : SOHO - CDS     
;                   
; Name        : OPS_PLAN_EVENT
;               
; Purpose     : Handles events from OPS_PLAN_MENU widgets.
;               
; Explanation : Any event generated by the widgets in the display
;               of the OPS_PLAN is handled by this routine.
;               
; Use         : Only called by XMANAGER.
;    
; Inputs      : ev - the structure associated with the event.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for EGSE/stm use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 6-Jun-95
;               
; Modified    : Fix a bug when no plan to list.  CDP, 11-Nov-96
;
; Version     : Version 2, 11-Nov-96
;-            

PRO ops_plan_event, ev

;
;  COMMON blocks for communication of widget id's and counter.
;
@MainWidgets.com
@Base_Offsets.com
      
;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  it should only have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 

;
;  request for renew of listing
; 
   if (value EQ 'Renew') then begin
      file = ''
      show_plan, file=file, /detail,/summ,/quiet,/keep,/now
      mess = rd_ascii(file)
      if n_elements(mess) gt 1 then begin
         mess = mess(1:*)
         widget_control, ops_plan_list_id, set_value=mess
      endif else begin
         bell
         widget_control, ops_plan_list_id, /append, $
            set_val='No plan to list'
      endelse
   endif

;
;  request for hardcopy plot
; 
   if (value EQ 'Hardcopy') then begin
      widget_control, ops_plan_base,/hourglass
      get_utc,utc
      widget_control, ops_plan_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "Current Operations Plan" '+$
         ' | xpr  -gray 3 -width 4 -height 6 -header "Current Operations Plan"'+$
         ' | lpr'
      widget_control, ops_plan_hc_id,set_val='Hardcopy'
   endif

;
;  request to finish/exit from the widget
; 
   if (value EQ 'Done') then begin
      widget_control,ops_plan_base, tlb_get_offset=boff
      widget_control,ops_plan_base, tlb_get_size = bsize
      ops_plan_menu_off = [boff,bsize]
      tp_offsets, /write
      widget_control, ops_plan_base, /destroy
   endif

endif      
END
