;+
; Project     : SOHO - CDS     
;                   
; Name        : PHA_EVENT
;               
; Purpose     : Handles events from PHA_MENU widgets.
;               
; Explanation : Any event generated by the widgets in the display
;               of pha data is handled by this routine.
;               
; Use         : Only called by XMANAGER.
;    
; Inputs      : ev - the structure associated with the event.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for STM use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 11-Oct-95
;               
; Modified    : Put total counts on hardcopy plot.   CDP, 13-Nov-95
;
; Version     : Version 2, 13-Nov-95
;-            

PRO pha_event, ev

;
;  COMMON blocks for communication of widget id's and counter.
;
@MainWidgets.com
@Base_Offsets.com
@PHA_data.com
      
;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  it should only have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 

;
;  request for hardcopy plot
; 
   if (value EQ 'Hardcopy') then begin
         ps
         h = histogram(pha,min=1)
         plot,h,psym=10,title='GIS PHA data' 
         nz = where(pha eq 0, cz)
         np = n_elements(pha) - cz
         xyouts,10,0.8*max(h),/data,chars=1.5,$
               'Total # of counts: '+strtrim(string(np),2)+$
               ' (zero: '+strtrim(string(cz),2)+')'
         psplot                                    
   endif

;
;  request to finish/exit from the widget
; 
   if (value EQ 'Done') then begin
      widget_control,pha_base, tlb_get_offset=boff
      widget_control,pha_base, tlb_get_size = bsize
      pha_menu_off = [boff,bsize]
      tp_offsets, /write
      widget_control, pha_base, /destroy
   endif

endif      
END
