;+
; Project     : SOHO - CDS     
;                   
; Name        : PLOT_PROF
;               
; Purpose     : Plot profile of VDS data.
;               
; Explanation : From within the stm program it is possible to plot a 
;               profile of one of the VDS images displayed.  This routine
;               does the plotting within the widget defined by prof_menu.
;               
; Use         : plot_prof, data
;    
; Inputs      : data -  data array of the displayed data.
;               ab   -  which window was it in (A or B).
;
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : In Profiles.com are the other plotting parameters.
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 4-Jan-94
;               
; Modified    : Allow for data array (1024,300).  CDP, 24-Feb-95
;               Allow for data array (1024,320).  CDP, 01-Mar-96
;
; Version     : Version 3, 01-Mar-96
;-            

pro plot_prof, data, ab

;
;  common block for profile details
;
@Profiles.com
@VDSWidgets.com
@VDSData.com

;
;  which draw widget window was last used?
;
if last_window eq 'A' or last_window eq 'B' then begin
   if last_window eq 'A' then begin
      widget_control, vds_awidg, get_value=window
      maxval = maxvala
   endif else begin
      widget_control, vds_bwidg, get_value=window
      maxval = maxvalb
   endelse
   wset,window


;
;  put back previous area data (if used already)
;
   if n_elements(prof_area) gt 1 then begin
      temp = bytscl(prof_area,min=0,max=maxval)
      tv, temp, prof_x1, prof_y1
   endif
;
;  first time in so calculate the maxima to be used for scaling profile areas
;
endif else begin
   maxvala = max(vds_data_str.curr_a_img)
   maxvalb = max(vds_data_str.curr_b_img)
endelse


;
;  which draw widget window to use this time?
;
if ab eq 'A' then begin
   widget_control, vds_awidg, get_value=window
   last_window = 'A'
endif else begin
   widget_control, vds_bwidg, get_value=window
   last_window = 'B'
endelse
wset,window

;
;  extract data to plot
;
if not pvert then begin
   prof_x1 = prof_x - plen/2 
   prof_x2 = prof_x + plen/2 - (1 - (plen mod 2))
   prof_y1 = prof_y - pwid/2 
   prof_y2 = prof_y + pwid/2 - (1 - (pwid mod 2))
   prof_x1 = 0 > prof_x1
   prof_x2 = 1023 < prof_x2
   prof_y1 = 0 > prof_y1
   prof_y2 = 319 < prof_y2
   pxarr = indgen(prof_x2-prof_x1+1)+prof_x1
endif else begin
   prof_x1 = prof_x - pwid/2 
   prof_x2 = prof_x + pwid/2 - (1 - (pwid mod 2))
   prof_y1 = prof_y - plen/2 
   prof_y2 = prof_y + plen/2 - (1 - (plen mod 2))
   prof_x1 = 0 > prof_x1
   prof_x2 = 1023 < prof_x2
   prof_y1 = 0 > prof_y1
   prof_y2 = 319 < prof_y2
   pxarr = indgen(prof_y2-prof_y1+1)+prof_y1
endelse
prof_area = data(prof_x1:prof_x2,prof_y1:prof_y2)

;
;  perform averaging in appropriate direction
;
if not pvert then begin
   pline = fix(sum_col(prof_area)/float(pwid)) 
endif else begin
   pline = fix(sum_row(prof_area)/float(pwid))
endelse

;
;  draw the outline of the profile area
;
device,get_g=mode
device,set_g=6
horiz = bytarr(prof_x2-prof_x1+1,1) + 255
vert =  bytarr(1,prof_y2-prof_y1+1) + 255
tv,horiz,prof_x1,prof_y1
if prof_y2 ne prof_y1 then tv,horiz,prof_x1,prof_y2
tv,vert,prof_x1,prof_y1
if prof_x2 ne prof_x1 then tv,vert,prof_x2,prof_y1
device,set_g=mode
   
;
;  select widget in which to draw profile
;
widget_control, pdraw, get_value=window
wset,window

;
;  and plot it
;
plot, pxarr, pline, xtitle='Pixel', ytitle='Counts', psym=10

end
