;+
; Project     : SOHO - CDS     
;                   
; Name        : PLOT_VDS
;               
; Purpose     : Display an image of the VDS data.
;               
; Explanation : 
;               
; Use         : plot_vds, win_widg, img [, /size]
;    
; Inputs      : win_widg  -  widget id of the plotting window
;               img       -  array holding the VDS data
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : full  - if set the complete VDS array (1024x1024) is
;                       displayed, else (0:1023,disp_start:disp_end)
;
; Calls       : None
;               
; Restrictions: For use within EGSE science analysis
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 7-Oct-93
;               
; Modified    : Change default image area plotted, CDP, 26-Oct-93
;               Add line displays if requested, CDP, 7-Jan-93
;               Update and generalize display start/end Y-coord. CDP 8-Mar-94
;               Update displayed portion to include offsets. CDP, 24-Feb-95
;               Rearrange offsets.   CDP, 17-Oct-95
;               Use vds_centre.      CDP, 20-Oct-95
;               Use default extraction windows defined by state db
;               (in vds_sp in Images.com)  CDP, 01-Mar-96
;
; Version     : Version 8, 01-Mar-96
;-            

PRO Plot_VDS, win_widg, img, SIZE=FULL

;
;  common for line plotting flag and widgets
;
@VDSWidgets.com
@VDSData.com
@Images.com

;
;  Calculate non-zero stats and put in info widget
;
n = where(vds_data_str.curr_a_img gt 0)
if n(0) eq -1 then begin
   widget_control,vds_exp_awidg(4),set_val='(0,0)'
endif else begin
   maxi = max(vds_data_str.curr_a_img(n))
   mini = min(vds_data_str.curr_a_img(n))
   widget_control,vds_exp_awidg(4),set_val=fmt_vect([mini,maxi])
endelse

n = where(vds_data_str.curr_b_img gt 0)
if n(0) eq -1 then begin
   widget_control,vds_exp_bwidg(4),set_val='(0,0)'
endif else begin
   maxi = max(vds_data_str.curr_b_img(n))
   mini = min(vds_data_str.curr_b_img(n))
   widget_control,vds_exp_bwidg(4),set_val=fmt_vect([mini,maxi])
endelse


;
;  find window in use and set focus to it
;
WIDGET_CONTROL, win_widg, GET_VALUE = window
WSET, window

;
;  temporary store for scaled image
;
scaled_img = img

;
;  scale data from min to max
;
Scale_Image, scaled_img

;
;  and display that required
;
if KEYWORD_SET(FULL) then begin
    TV, scaled_img
endif else begin
;
;  upper band 300A
;
    y0 = vds_sp.n1_cen_s - (vds_sp.nis_ht-1)/2
    y1 = y0 + 159
    TV,scaled_img(0:1023,y0:y1),0,160 
;
;  lower band 500A
;
    y0 = vds_sp.n2_cen_s - (vds_sp.nis_ht-1)/2
    y1 = y0 + 159
    TV,scaled_img(0:1023,y0:y1),0,0 
endelse



END
