;+
; Project     : SOHO - CDS     
;                   
; Name        : PROF_MENU
;               
; Purpose     : Sets up the widgets for profile plots within sci_ana.
;               
; Explanation : This routines initialises the widgets to control and display
;               the profiles plots of the VDS images displayed in the sci_ana
;               or calibration programs.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ab  -  which display is involved
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE sci_ana routines.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 4-Jan-94
;               
; Modified    : 
;
; Version     : Version 1, 4-Jan-94
;-            

PRO prof_menu, ab


;
;  COMMON blocks for widget id's
;
@VDSWidgets.com
@VDSData.com
@Profiles.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('prof') then return


;
;  flag to indicate should process events from image draw widget
;
plotting_prof = 1

;
;  set window being used
;
if ab eq 'A' then begin
   WIDGET_CONTROL,vds_Awidg, GET_VALUE=window 
   WSET,window
endif else begin 
   WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window
   WSET,window
endelse


;
;  get base widget position and size
;
tp_offsets

;
;  create widget base and draw widget
;
prof_base = widget_base(/column,group_leader=vds_base,$
                        xsize=prof_menu_off(2),ysize=prof_menu_off(3), $
                        xoffset=prof_menu_off(0),yoffset=prof_menu_off(1))


pdraw = widget_draw(prof_base,xsize=500,ysize=250,/frame)

;
;  profile length slider
;
plen  = 50
pl1 = widget_base(prof_base,/column, space=1)
pdummy = widget_slider(pl1,min=1,max=1024,$
                       uvalue='PLEN',value=plen, /suppress, /drag)
pl1a = widget_base(pl1,/row,/frame)
pl2 = widget_label(pl1a,value='Profile length = ')
plen_widg = widget_text(pl1a,xsize=5,ysize=1,value='50')

;
;  profile width slider
;
pwid = 1
pw1 = widget_base(prof_base,/column, space=1)
pdummy = widget_slider(pw1,min=1,max=100,$
                       uvalue='PWID',value=pwid, /suppress, /drag)
pw1a = widget_base(pw1,/row,/frame)
pw2 = widget_label(pw1a,value='Profile width = ')
pwid_widg = widget_text(pw1a,xsize=5,ysize=1,value='1')

;
;  vertical/horizontal buttons
;
pvert = 0
plen_fac = 1
p1base = widget_base(prof_base,/row)
xmenu,['Vertical','Horizontal'],/excl,/no_rel,p1base,buttons=pbuttons,$
      uvalue=['PVERT','PHOR'],/row
widget_control,pbuttons(1),/set_button

;
;  Done button
;
pbut = widget_base(p1base,/row)
xpdmenu, ['"Fit profile" {', $
                        '"Gaussian only"            GAUSS0',$
                        '"Gaussian + constant"      GAUSS1',$
                        '"Gaussian + linear"        GAUSS2',$
                        '"Gaussian + quadratic"     GAUSS3','}'], pbut
                                    
pdummy = widget_button(pbut,value='Done',uvalue='DONE')

;
;  set it all going
;
widget_control,prof_base,/realize
xmanager,'prof',prof_base


end
