;+
; Project     : SOHO - CDS     
;                   
; Name        : RAW_GIS_MENU
;               
; Purpose     : Defines the widgets used in a raw GIS data dump.
;               
; Explanation : When a display of raw GIS data is requested,
;               this routine defines and realizes the display widgets.
;               
; Use         : raw_gis_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE sci_ana only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Dec-93
;               
; Modified    : 
;
; Version     : Version 1, 16-Dec-93
;-            

PRO raw_gis_menu

;
;  COMMON blocks for widget id's etc.
;
@MainWidgets.com
@RawData.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('raw_gis') then return


;
;  individual widget id's for output text widgets
;
raw_gis_exp = lonarr(2)

;
;  get base widget position and size
;
tp_offsets

;
;  top level widget id
;
raw_gis_base = WIDGET_BASE(title='Raw GIS data', group = main_base, $
                          /FRAME, /COLUMN, $
                          xsize=gis_raw_off(2),ysize=gis_raw_off(3), $
                          xoffset=gis_raw_off(0),yoffset=gis_raw_off(1))



;
;  subordinate widgets
;
menu_base  = WIDGET_BASE(raw_gis_base, /ROW)
info_base  = WIDGET_BASE(raw_gis_base, /column)
info_cbase = WIDGET_BASE(info_base, /row)
info_bbase = WIDGET_BASE(info_base, /row)
info_abase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
m1_widg = WIDGET_BASE(menu_base, /row)

;
;  set larger font
;        
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  create 'DONE' button
;
doneid = widget_button(m1_widg,value='Done',font=cfont)

;
;  pull-down menu for format choice
;
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],info_cbase

;
;  indicate current format choice
;
f1 =  widget_base(info_cbase,/column)
f11 = widget_label(f1,val='Current format: ')
if raw_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
raw_gformat_def = widget_text(f1,xsize=10,ysize=1,value=curr_fmt)


;
;  pull-down menu for dump to file choice
;
XPDmenu, ['"Dump to file" {','"Dump ON"','"Dump OFF"', '}'],info_bbase,$
         font=cfont


;
;  pull-down menu for dump to screen choice
;
XPDmenu, ['"Display on screen" {','"Display ON"','"Display OFF"', '}'],$
         info_bbase,font=cfont

;
;  indicate status of file dump
;
ff1 =  widget_base(info_bbase,/column)
ff11 = widget_label(ff1,val='Dumping to file: ')

;
;  on entry, set file name to undefined
;
raw_gis_file = '' & text = 'None'
raw_gis_file_def = widget_text(ff1,xsize=25,ysize=1,value=text,font=cfont)

;
;  widgets for display of header information
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Packet counter :     ')
raw_gis_exp(0) = WIDGET_TEXT(a1,XSIZE=10,YSIZE=1)

a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Raw data:     ')
raw_gis_exp(1) = WIDGET_TEXT(a2,XSIZE=40,YSIZE=30,/scroll)


;
;  realize (ie make appear) it all
;
WIDGET_CONTROL, raw_gis_base, /realize

end
