;+
; Project     : SOHO - CDS     
;                   
; Name        : READ_PKT_HEADER()
;               
; Purpose     : Read science packet header which contains ID.
;               
; Explanation : The EGSE STM task assumes it is receiving only science
;               stream packets from the telemetry stream.  In order to decide
;               on the action necessary to interpret these packets, it first
;               reads 20 bytes from the packet.  These bytes include the 
;               packet ID.  For a definition of the 20 bytes see the structure
;               PacketHeaderDef in stm.pro.  The ID definitions are given
;               in the latest "CDS science data stream packet format"
;               document by DJ Parker. 
;               
; Use         : status = read_pkt_header( input_mode, unit, header_str)
;    
; Inputs      : input_mode  -  mode switch (1 = realtime, else replay mode)
;               unit        -  logical unit from which data are read
;                          
; Opt. Inputs : None
;               
; Outputs     : header_str  -  20 byte structure of form PacketHeaderDef
;                              defined in sci_ana.pro
;               function returns a value -1 for i/o errors
;                                         0 for no realtime data available
;                                         1 for success0

; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use within science telemetry monitor program only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 18-Oct-93
;               
; Modified    : For v3.0 of packet definition, CDP 27-Oct-93
;               To include writing of packet ID when id = '21'x or '22'x
;                                              CDP 12-Nov-93
;               Cut out all writing of info - transferred to disp_xxx_hdr
;                                              CDP, 11-Aug-94
;               Simplified by making realtime read from current tm file
;                                              CDP, 5-Jan-95
;		Version 6, William Thompson, GSFC, 6 June 1995
;			Check to make sure that there is a complete packet
;			before reading the header.
;               Use tm_enough for available data checking.  CDP, 8-Jun-95
;
;
; Version     : Version 7, 8 June 1995
;-            

 FUNCTION read_pkt_header, input_mode, unit, packet_header


;
;  COMMON block for information display widgets
;
@HeaderWidgets.com

;
;  return function value .ne. 1 on i/o error
;
ON_IOERROR, ERR_packet_hdr

;
;  If there aren't at least 306 bytes left to be read in the file, then signal
;  an error.
;
;point_lun, -unit, pnt
;stat = fstat(unit)
;tm_size = tm_get_size(stat.name)
;if (tm_size-pnt) lt 306 then goto, err_packet_hdr


;
;  try new routine
;
enough  = tm_enough(unit, 306)
if not enough then goto, err_packet_hdr

;
; Both input modes simply read from a file now
;
readu, unit, packet_header



;
;  success and error returns
;
return,1
ERR_packet_hdr: 
if input_mode eq 1 then return,0  else return,-1

end

