;+
; Project     : SOHO - CDS     
;                   
; Name        : READ_SCI_CNT()
;               
; Purpose     : Read the science packet counter (2 bytes).
;               
; Explanation : Following the 20-byte packet header in the exposure or 
;               science data packets there is a science packet counter 
;               (2-bytes). This routine simply reads those two bytes in
;               preparation for reading the exposure header information or
;               the science data and determines whether it is the last 
;               science packet in this exposure.  
;               
; Use         : counter = read_sci_cnt( unit, instrument)
;    
; Inputs      : unit       -  logical unit from which to read data
;               instrument -  the instrument id indicating which detector
;                             is in use - needed to determine which display
;                             to use.
;               
; Opt. Inputs : None
;               
; Outputs     : Function value returned is a structure containing the 
;               counter (-1 on error) and last packet flag.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use within EGSE sci_ana program.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 18-Oct-93
;               
; Modified    : Cut call to dec2bin to test for last packet, CDP, 28-Oct-93
;               Change output to structure and cut writing to display.
;                                                            CDP, 12-Aug-94
;
; Version     : Version 3, 12-Aug-94
;-            

FUNCTION read_sci_cnt, unit, inst

;
;  COMMON block for widget and flag variables communication
;
@HeaderWidgets.com
@Packets.com

;
;  initialise the output
;
counter = FIX(0)

;
; on i/o error return value -1
;
ON_IOERROR, ERR_sci_count

;
;  read the counter from current data unit
;   
READU,unit,counter 
   
;
;  byteswap the value
;
counter = ByteSwap(Counter) 

;
;  is it the last? (MSB will be set)
;
check_for_last, counter, last
   

;
;  success and error returns
;
scnt_str.count = counter
scnt_str.last = last
return,scnt_str

ERR_sci_count: 
scnt_str.count = -1
scnt_str.last = 0
return,scnt_str

END
