;+
; Project     : SOHO - CDS     
;                   
; Name        : READ_SP_BODY()
;               
; Purpose     : Read the body of a special packet.
;               
; Explanation : Read the general body of any special packet - 282 bytes
;               Note that the 2 bytes containing the special packet format ID 
;               and the special packet counter have already been read (from 
;               the 284 packet bytes) by read_sp_id.  The checksum (2bytes) 
;               is read separately at the end.
;
;               
; Use         : packet = read_sp_body(unit, checksum)
;    
; Inputs      : unit   - the logical unit from which to read data
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns an INT(141) array of data
;               checksum - the integer checksum value
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only within EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Oct-93
;               
; Modified    : Version 1, C D Pike, RAL, 12-Oct-93
;		Version 2, William Thompson, GSFC, 12 November 1993.
;			Added /NTOHS to BYTEORDER for platform independence.
;
; Version     : Version 2, 12 November 1993.
;-            

function read_sp_body, unit, checksum

;
;  set up out array and variable
;
packet   = intarr(141)
checksum = fix(0)

;
;  on error return array of -1s
;
on_ioerror, err_body

;
;  attempt to read the data and byteswap it
;
readu,unit,packet
byteorder,packet,/ntohs

;
;  read the checksum bytes
;
readu,unit,checksum
byteorder, checksum, /ntohs

;
;  success and error returns
;
return, packet
err_body: packet(*) = -1 & checksum = -1 & return, packet

end
