;+
; Project     : SOHO - CDS     
;                   
; Name        : READ_SP_ID()
;               
; Purpose     : Read format id. and packet counter in special packet.
;               
; Explanation : In a special packet in the science data stream, the two bytes
;               following the 20-byte packet header contain the special format
;               ID and the special packet counter.  The various id's are 
;               defined in the latest version of "Software design for special
;               telemetry module in CDHS" by MK Carter.
;               
; Use         : bytes = read_sp_id(unit)
;    
; Inputs      : unit - the current unit from which to read data
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns a 2-byte array. [-1,-1] is returned on
;               i/o error.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only relevant for use in EGSE sci_ana program.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 18-Oct-93
;               
; Modified    : 
;
; Version     : Version 1, 18-Oct-93
;-            

function read_sp_id, unit

;
;  form output array
;
id_counter = bytarr(2)

;
;  return array of -1s on error
;
on_ioerror, err_special

;
;  read from predefined unit
;
readu,unit,id_counter

;
;  return with value or error value
;
return, id_counter
err_special: id_counter = byte([-1,-1]) & return, id_counter

end
