;+
; Project     : SOHO - CDS     
;                   
; Name        : REORIENT
;               
; Purpose     : Reorient VDS data from spectral to spatial format.
;               
; Explanation : The on board CDS software can transmit the VDS data in either
;               spectral or spatial orientation.  This routine switches the
;               science data buffer from spectral to spatial mode.
;               
; Use         : reorient, data, windows
;    
; Inputs      : data  - the data buffer to be reorientated
;               windows -  a structure giving the data windows with which
;                          the data were extracted.  It has the form:
;                          {StartX:0, StartY:0, LengthX:0, LengthY:0}
;                          For the GIS, tags StartY and LengthY are set to
;                          0 and 1.
; Opt. Inputs : None
;               
; Outputs     : data - as above for input.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Restrictions: None
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : Original by M K Carter, RAL
;
; Written     : EGSE version by C D Pike, RAL 7-Oct-93
;               
; Modified    : 
;
; Version     : Version 1, 7-Oct-93
;-            

PRO reorient, exposure, windows_st

;
; word position in data array
;
pos = 0L  

;
; loop through exposure re-orienting windows
;

FOR i = 0, N_ELEMENTS(windows_st)-1 DO BEGIN

   isx  = windows_st(i).LengthX
   isy  = windows_st(i).LengthY
   area = LONG(isx)*LONG(isy)

;   window = FIX(exposure(pos:pos+area-1),0,isy,isx)
   window = FIX(exposure(pos:pos+area-1),0,isx,isy)
   window = TRANSPOSE(window)

   exposure(pos:pos+area-1) = FIX ( window, 0, area)

   pos = pos + area

ENDFOR

END 
