;+
; Project     : SOHO - CDS     
;                   
; Name        : REVIEW_TM_EVENT
;               
; Purpose     : Processes widget events from the file review menu.
;               
; Explanation : Any widget events originating in the routine REVIEW_TM_MENU
;               which displays the data file packet statistics 
;               is dealt with by this routine.  
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the structure of the event generated.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for interal use of EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 19-oct-93
;               
; Modified    : To detect "Done" button instead of "file/close".  CDP 28-Oct-93
;               Detect "Reset" button and act.  CDP 15-Nov-93
;               Include widget 19 for new packet id='09'x. CDP 30-Nov-93
;               Include raw data for GIS and VDS, CDP, 16-Dec-1993
;               Cater for hardcopy.  CDP, 27-Jan-95
;               Make Reset button zero out counts.  CDP, 5-Apr-95
;
; Version     : Version 7, 5-Apr-95           
;-            

PRO review_tm_event, ev

;
;  COMMON blocks for communication of variables
;
@MainWidgets.com
@ReviewWidgets.com
@Base_Offsets.com

;
; find out type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  event should only have been generated by a button
;
if (type EQ 'WIDGET_BUTTON') then begin

   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  close, ie destroy the whole widget
; 
   IF (value EQ 'Done') THEN BEGIN
      widget_control,review_base, tlb_get_offset=boff
      widget_control,review_base, tlb_get_size = bsize
      review_menu_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, review_base, /destroy
      reviewing = 0
   ENDIF

;
;  Reset button 
;
   if (value eq 'Reset') then begin
      for i=0,22 do begin
         review_stats(i) = 0
         widget_control, review_expa(i), set_val=' '
      endfor
   endif

;
;  Hardcopy
; 
   if (value EQ 'Hardcopy') then begin
      widget_control, review_base,/hourglass 
      get_utc,utc
      widget_control, review_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "Telemetry statistics" '+$
         ' | xpr  -gray 3 -width 4 -height 6 -header "Telemetry statistics"'+$
         ' | lpr'
      widget_control, review_hc_id,set_val='Hardcopy'
   endif

endif

end

