;+
; Project     : SOHO - CDS     
;                   
; Name        : REVIEW_TM_MENU
;               
; Purpose     : Defines and realises the telemetry review widget. 
;               
; Explanation : One of the options available within the EGSE science analysis
;               program is to monitor the statistics of the incoming packets,
;               ie show some statistics of the variety of packets being
;               received.  This procedure defines and realizes the widget
;               which displays the statistics.
;               
; Use         : Only called from MAIN_MENU
;    
; Inputs      : selection  -  the general packet selection to be considered.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for internal use in EGSE science analysis
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 19-Oct-93
;               
; Modified    : Give it a "Reset" button.  CDP 15-Nov-93
;               Include raw data boxes, CDP, 16-Dec-1993
;               Display any current counts on entry.  CDP, 8-Feb-94
;               Add hardcopy button.  CDP. 27-Jan-95
;               Increased number box size.  CDP, 3-Feb-95
;               Trim box names.             CDP, 16-May-95
;
; Version     : Version 7, 16-May-95
;-            

PRO review_tm_menu


;
;  COMMON blocks for communication
; 
@ReviewWidgets.com
@MainWidgets.com
@Base_Offsets.com

;
;  trap double clicks
;
if xregistered('review_tm') then return


;
;  get base widget position and size
;
tp_offsets


;
;  get the main base
;
title = 'Telemetry statistics'

review_base = widget_base(title=title,/frame,/column,group=main_base,$
                          xsize=review_menu_off(2),ysize=review_menu_off(3), $
                          xoffset=review_menu_off(0),yoffset=review_menu_off(1))



;
;  array to hold individual text widget id's
;
review_expa = lonarr(23)

;
;  subsidiary bases
;
menu_base        = WIDGET_BASE(review_base, /ROW)
info_base        = WIDGET_BASE(review_base, /ROW)
info_abase       = WIDGET_BASE(info_base,   /COLUMN, /FRAME, SPACE=1)
info_bbase       = WIDGET_BASE(info_base,   /COLUMN, /FRAME, SPACE=1)
m1_widg          = WIDGET_BASE(menu_base,   /COLUMN)

;
;  buttons to close and reset widgets
;  
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"
b_widg = widget_base(m1_widg, /ROW)
doneid  = widget_button(b_widg, value='Done', font=cfont)
resetid = widget_button(b_widg, value='Reset', font=cfont)
review_hc_id = widget_button(b_widg, value='Hardcopy', font=cfont)

;
;  define the individual text widgets
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1,   VALUE='Engineering A:...')
review_expa(0) = WIDGET_TEXT(a1,XSIZE=10,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2,   VALUE='Engineering B:...')
review_expa(1) = WIDGET_TEXT(a2,XSIZE=10,YSIZE=1)
   
a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3,   VALUE='GIS raster hdr:..')
review_expa(2) = WIDGET_TEXT(a3,XSIZE=10,YSIZE=1)
   
a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4,   VALUE='VDS raster hdr:..')
review_expa(3) = WIDGET_TEXT(a4,XSIZE=10,YSIZE=1)
   
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5,   VALUE='Abort:...........')
review_expa(4) = WIDGET_TEXT(a5,XSIZE=10,YSIZE=1)
   
a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6,   VALUE='GIS exp. header:.')
review_expa(5) = WIDGET_TEXT(a6,XSIZE=10,YSIZE=1)
   
a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7,   VALUE='VDS exp. header:.')
review_expa(6) = WIDGET_TEXT(a7,XSIZE=10,YSIZE=1)
   
a8  = WIDGET_BASE(info_abase, /ROW)
a81 = WIDGET_LABEL(a8,   VALUE='GIS science:.....')
review_expa(7) = WIDGET_TEXT(a8,XSIZE=10,YSIZE=1)
   
a9  = WIDGET_BASE(info_abase, /ROW)
a91 = WIDGET_LABEL(a9,   VALUE='VDS science:.....')
review_expa(8) = WIDGET_TEXT(a9,XSIZE=10,YSIZE=1)
   
a10  = WIDGET_BASE(info_abase, /ROW)
a101 = WIDGET_LABEL(a10, VALUE='Pri. mem. dump:..')
review_expa(9) = WIDGET_TEXT(a10,XSIZE=10,YSIZE=1)
   
a11  = WIDGET_BASE(info_abase, /ROW)
a111 = WIDGET_LABEL(a11, VALUE='Sec. mem. dump:..')
review_expa(10) = WIDGET_TEXT(a11,XSIZE=10,YSIZE=1)
   
a12  = WIDGET_BASE(info_abase, /ROW)
a121 = WIDGET_LABEL(a12, VALUE='Raw VDS data:....')
review_expa(11) = WIDGET_TEXT(a12,XSIZE=10,YSIZE=1)
   
a13  = WIDGET_BASE(info_abase, /ROW)
a131 = WIDGET_LABEL(a13, VALUE='Raw GIS data:....')
review_expa(12) = WIDGET_TEXT(a13,XSIZE=10,YSIZE=1)
   

;
;  right hand side display 
;
   
b1  = WIDGET_BASE(info_bbase, /ROW)
b11 = WIDGET_LABEL(b1,   VALUE='MCU backup:........')
review_expa(13) = WIDGET_TEXT(b1,XSIZE=10,YSIZE=1)
   
b2  = WIDGET_BASE(info_bbase, /ROW)
b21 = WIDGET_LABEL(b2,   VALUE='Deferred:..........')
review_expa(14) = WIDGET_TEXT(b2,XSIZE=10,YSIZE=1)
   
b3  = WIDGET_BASE(info_bbase, /ROW)
b31 = WIDGET_LABEL(b3,   VALUE='Data extr. list:...')
review_expa(15) = WIDGET_TEXT(b3,XSIZE=10,YSIZE=1)
   
b4  = WIDGET_BASE(info_bbase, /ROW)
b41 = WIDGET_LABEL(b4,   VALUE='Raster table:......')
review_expa(16) = WIDGET_TEXT(b4,XSIZE=10,YSIZE=1)
   
b5  = WIDGET_BASE(info_bbase, /ROW)
b51 = WIDGET_LABEL(b5,   VALUE='Sequence table:....')
review_expa(17) = WIDGET_TEXT(b5,XSIZE=10,YSIZE=1)
   
b8  = WIDGET_BASE(info_bbase, /ROW)
b81 = WIDGET_LABEL(b8,   VALUE='Health table:......')
review_expa(18) = WIDGET_TEXT(b8,XSIZE=10,YSIZE=1)
   
b9  = WIDGET_BASE(info_bbase, /ROW)
b91 = WIDGET_LABEL(b9,   VALUE='IMIF module:.......')
review_expa(19) = WIDGET_TEXT(b9,XSIZE=10,YSIZE=1)
   
b10  = WIDGET_BASE(info_bbase, /ROW)
b101 = WIDGET_LABEL(b10, VALUE='VDS h/w list:......')
review_expa(20) = WIDGET_TEXT(b10,XSIZE=10,YSIZE=1)
   
b11  = WIDGET_BASE(info_bbase, /ROW)
b111 = WIDGET_LABEL(b11, VALUE='Mode table:........')
review_expa(21) = WIDGET_TEXT(b11,XSIZE=10,YSIZE=1)
   
b14  = WIDGET_BASE(info_bbase, /ROW)
b141 = WIDGET_LABEL(b14, VALUE='Event flag parms:..')
review_expa(22) = WIDGET_TEXT(b14,XSIZE=10,YSIZE=1)

;
;  set it going 
;
WIDGET_CONTROL, review_base, /realize

;
;  load any current values
;
for i=0,22 do begin
   if review_stats(i) gt 0 then begin
      widget_control,review_expa(i),set_val=string(review_stats(i),form='(i5)')
   endif
endfor
  
end

