;+
; Project     : SOHO - CDS     
;                   
; Name        : SCALE_IMAGE
;               
; Purpose     : Scale VDS image using min and max values in image. 
;               
; Explanation : Scales the input image using BYTSCL with the lower limit set
;               to zero and with the maximum set to the maximum value in the 
;               array. The input array is overwritten with the scaled array.
;               
; Use         : scale_image, image
;    
; Inputs      : image - the image to be scaled.
;               
; Opt. Inputs : None
;               
; Outputs     : image - the scaled version of the input.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: Overwrites the input image, requires message widget defined
;               
; Category    : EGSE
;               
; Prev. Hist. : Original by Arnulf, Oct-92
;
; Written     : FM EGSE version by C D Pike, RAL, 22-Oct-93
;               
; Modified    : Set lower limit of scaling to zero, not min positive value
;               and trim max value to 4000. CDP, 4-Nov-93
;               Revert back to using only positive values.  CDP, 17-Feb-94
;               Put in choice of background elimination by scaling. 
;                                             CDP, 12-Mar-94
;               Reworked to try and get better display.  CDP, 27-Apr-96
;               Improved data handling efficiency.  WTT, 29-Jul-96
;
; Version     : Version 6, 29-Jul-96
;-            

PRO Scale_Image, in_image

 
;
;  COMMON for message widget
;
@MainWidgets.com
@VDSData.com

;
;  common for local convenience
;
common vds_scale_com, back


if n_elements(back) eq 0 then begin
   back = cp_get_entry('VDS_BACK',indgen(4,4))
   if n_elements(back) ne 16 then begin
      back = intarr(4,4)
   endif else begin
      back = fix(rotate(back.active,4))
   endelse
endif

av = fltarr(4)
for i=0,3 do begin
   xst = back(i,0)
   xend = xst + back(i,2)-1
   yst = back(i,1)
   yend = yst + back(i,3)-1
   av(i) = average(sigrange(in_image(xst:xend,yst:yend)))
endfor

n = where(in_image le 0, count)
if count gt 0 then in_image(n) = -1

a1 = in_image(0:511,512:1023)
w = where(a1 gt 0, count)
if count gt 0 then begin
	a1(w) = sigrange(a1(w),missing=-1) - av(0)
	in_image(0:511,512:1023) = a1
endif

a1 = in_image(512:1023,512:1023)
w = where(a1 gt 0, count)
if count gt 0 then begin
	a1(w) = sigrange(a1(w),missing=-1) - av(1)
	in_image(512:1023,512:1023) = a1
endif

a1 = in_image(0:511,0:511)
w = where(a1 gt 0, count)
if count gt 0 then begin
	a1(w) = sigrange(a1(w),missing=-1) - av(2)
	in_image(0:511,0:511) = a1
endif

a1 = in_image(512:1023,0:511)
w = where(a1 gt 0, count)
if count gt 0 then begin
	a1(w) = sigrange(a1(w),missing=-1) - av(3)
	in_image(512:1023,0:511) = a1
endif

im1 = in_image(*,0:511)
n = where(im1 gt 0,count)
if count gt 0 then begin
   min_data = min(im1(n))
   max_data = max(im1(n))
endif else begin
   min_data = 0
   max_data = 4000
endelse
 
;  scale image and overwrite input 
;   
in_image(*,0:511) = bytscl(im1, min=min_data, max=max_data)
   
im1 = in_image(*,512:1023)
n = where(im1 gt 0,count)
if count gt 0 then begin
   min_data = min(im1(n))
   max_data = max(im1(n))
endif else begin
   min_data = 0
   max_data = 4000
endelse
 
;  scale image and overwrite input 
;   
in_image(*,512:1023) = bytscl(im1, min=min_data, max=max_data)
   
end
