;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_DEF_EVENT
;               
; Purpose     : Processes events from widgets in SP_DEF_MENU.
;               
; Explanation : When a Deferred command table dump is seen in the telemetry
;               and that display is enabled, the packet contents are dumped
;               to a display widget realized by sp_disp_menu.  This routine
;               handles events from that widget.  At the moment only two events
;               are possible, to close the widget or to change the display
;               format from hex to decimal and vice versa.
;               
; Use         : Only called by XMANAGER
;    
; Inputs      : ev - the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use with sp_def_menu
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Oct-93
;               
; Modified    : To recognise 'Done' button, CDP, 28-Oct-93
;               Add hardcopy button.  CDP, 27-Jan-95
;
; Version     : Version 3, 27-Jan-95
;-            

PRO sp_def_event, ev

;
;  COMMON blocks for widgets id's etc.
;
@MainWidgets.com
@SpecialWidgets.com
@Packets.com
@Base_Offsets.com
      
;
;  determine type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  only a button event is meaningful 
;
if (type EQ 'WIDGET_BUTTON') then begin
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  Done (ie exit) was requested
; 
   if (value EQ 'Done') then begin
      widget_control,sp_def_base, tlb_get_offset=boff
      widget_control,sp_def_base, tlb_get_size = bsize
      sp_def_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, sp_def_base, /destroy
      sp_request = -1
   endif

;
;  Hardcopy
; 
   IF (value EQ 'Hardcopy') then begin
      widget_control, sp_def_base,/hourglass 
      get_utc,utc
      widget_control, def_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "Deferred special packet" '+$
         ' | xpr  -gray 3 -width 4 -height 6 -header "Deferred special packet"'+$
         ' | lpr'
      widget_control, def_hc_id,set_val='Hardcopy'
   ENDIF

;
;  change of format to decimal was requestred
;
   if (value EQ 'Decimal') then begin
      special_format = 1 
      widget_control,sp_format_def,set_value='Decimal'
   endif

;
;  change of format to hexadecimal was requested
;
   if (value EQ 'Hex') then begin
      special_format = 2 
      widget_control,sp_format_def,set_value='Hex'
   endif

endif

end



