;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_DEF_MENU
;               
; Purpose     : Defines the deferred command table dump.
;               
; Explanation : A special packet with the format id = '02'x is a dump of the
;               deferred command store.  Those packets can be displayed in
;               the widget realized by this procedure.
;               
; Use         : sp_def_menu
;    
; Inputs      : None - all variables communicated by COMMON
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use in EGSE sci_ana program
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Oct-93
;               
; Modified    : Add hardcopy button.  CDP, 27-Jan-95
;               Enlarge time display boxes. CDP, 20-Apr-95
;               Update layout for IDL v4.  20-Aug-96
;                                                  
; Version     : Version 4, 20-Aug-96
;-            

PRO sp_def_menu

;
;  COMMON blocks for variables
; 
@SpecialWidgets.com
@MainWidgets.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('sp_def') then return


;
;  array to hold id's of text widgets where packet info is displayed.
;
sp_def_exp = lonarr(9)


;
;  get base widget position and size
;
tp_offsets

;
;  get main widget
;
sp_def_base = WIDGET_BASE(title='Deferred special packet', group=main_base, $
                          /FRAME, /row, SPACE=1, $
                          xsize=sp_def_off(2),ysize=sp_def_off(3), $
                          xoffset=sp_def_off(0),yoffset=sp_def_off(1))


;
; ... and subsidiary ones
;
menu_base  = WIDGET_BASE(sp_def_base, /ROW)
info_abase = WIDGET_BASE(sp_def_base, /COLUMN, /FRAME)
m1_widg    = WIDGET_BASE(menu_base, /COLUMN)
button_widg= WIDGET_BASE(m1_widg, /row)

;
;  get larger font
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  the "Done" button
;
doneid = widget_button(button_widg, value='Done', font=cfont)


;
;  the change of format menu
;
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],button_widg

;
;  the "Hardcopy" button
;
def_hc_id = widget_button(button_widg, value='Hardcopy', font=cfont)

;
;  display current chosen format
;
f1 =  widget_base(m1_widg,/row)
f11 = widget_label(f1,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_def = widget_text(f1,xsize=10,ysize=1,value=curr_fmt)

;
; create all the individual widgets that will hold the specific parameters
; derived from the packets
;
a1  = WIDGET_BASE(m1_widg, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Store enabled/disabled flag: ', font=cfont)
sp_def_exp(0) = WIDGET_TEXT(a1,XSIZE=10,YSIZE=1)


a2  = WIDGET_BASE(m1_widg, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Spacecraft time (UT): ', font=cfont)
sp_def_exp(1) = WIDGET_TEXT(a2,XSIZE=24,YSIZE=1)


a3  = WIDGET_BASE(m1_widg, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Start of store: ', font=cfont)
sp_def_exp(2) = WIDGET_TEXT(a3,XSIZE=10,YSIZE=1)


a4  = WIDGET_BASE(m1_widg, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='End of store: ', font=cfont)
sp_def_exp(3) = WIDGET_TEXT(a4,XSIZE=10,YSIZE=1)

a5  = WIDGET_BASE(m1_widg, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Space left in store (words): ', font=cfont)
sp_def_exp(4) = WIDGET_TEXT(a5,XSIZE=10,YSIZE=1)

a6  = WIDGET_BASE(m1_widg, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='Number of commands in store: ', font=cfont)
sp_def_exp(5) = WIDGET_TEXT(a6,XSIZE=10,YSIZE=1)

a7  = WIDGET_BASE(m1_widg, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='Earliest time in store: ', font=cfont)
sp_def_exp(6) = WIDGET_TEXT(a7,XSIZE=24,YSIZE=1)

a8  = WIDGET_BASE(m1_widg, /ROW)
a81 = WIDGET_LABEL(a8, VALUE='Latest time in store: ', font=cfont)
sp_def_exp(7) = WIDGET_TEXT(a8,XSIZE=24,YSIZE=1)

;
;  general label
;
a0 = WIDGET_LABEL(info_abase, VALUE='Deferred special packet',/frame,font=cfont)

;
;  this last widget will hold the 'body' of the dump
;
a9   = WIDGET_BASE(info_abase, /ROW)
;a91 = WIDGET_LABEL(a9, VALUE='Contents dump:      ', font=cfont)
sp_def_exp(8) = WIDGET_TEXT(a9,XSIZE=40,YSIZE=40,/scroll)

;
;  realize the widget - ie create and display it
;
WIDGET_CONTROL, sp_def_base, /realize


end
