;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_GEN_EVENT
;               
; Purpose     : Handles events from SP_GEN_MENU widgets.
;               
; Explanation : Any event generated by the widgets in the general display
;               of a special packet dump is handled by this routine.
;               
; Use         : Only called by XMANAGER.
;    
; Inputs      : ev - the structure associated with the event.
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for EGSE/sci_ana use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 25-Oct-93
;               
; Modified    : Add hardcopy button.  CDP, 27-Jan-95
;               Initialise widget base ID when done.  CDP, 18-Jun-98
;                                                  
; Version     : Version 3, 18-Jun-98
;-            

PRO sp_gen_event, ev

;
;  COMMON blocks for communication of widget id's and counter.
;
@MainWidgets.com
@SpecialWidgets.com
@Packets.com
@Base_Offsets.com
      
;
;  decode type of event 
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  it should only have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  request to finish/exit from the widget
; 
   IF (value EQ 'Done') THEN BEGIN
      widget_control,sp_gen_base, tlb_get_offset=boff
      widget_control,sp_gen_base, tlb_get_size = bsize
      sp_gen_off = [boff,bsize]
      tp_offsets, /write
      widget_control, sp_gen_base, /destroy
      sp_gen_base = -1
      sp_request = -1
   ENDIF

;
;  Hardcopy
; 
   IF (value EQ 'Hardcopy') then begin
      widget_control, sp_gen_base,/hourglass 
      get_utc,utc
      widget_control, gen_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "General table dump" '+$
            ' | xpr  -gray 3 -width 4 -height 6 -header "General table dump"'+$
            ' | lpr'
      widget_control, gen_hc_id,set_val='Hardcopy'
   ENDIF


;
;  change display format to decimal..
;
   IF (value EQ 'Decimal') then begin
      special_format = 1 
      widget_control,sp_format_def,set_value='Decimal'
   endif

;
;  change display format to hexadecimal..
;
   IF (value EQ 'Hex') then begin
      special_format = 2 
      widget_control,sp_format_def,set_value='Hex'
   endif

ENDIF

END
