;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_GEN_MENU
;               
; Purpose     : Defines the widgets used in a general table dump.
;               
; Explanation : When a display of one of the general table dumps is requested,
;               this routine defines and realizes the display widgets.
;               
; Use         : sp_gen_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE sci_ana only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 25-Oct-93
;               
; Modified    : To include output of Study ID.  CDP 4-Nov-93
;               Add hardcopy button.  CDP, 27-Jan-95
;               Use valid value for sp_gen_base rather than 
;               Xregistered as flag of widget existence following
;               change to workproc running method.  CDP, 18-Jun-98
;
; Version     : Version 4, 18-Jun-98
;-            

PRO sp_gen_menu

;
;  COMMON blocks for widget id's etc.
;
@SpecialWidgets.com
@MainWidgets.com
@Base_Offsets.com


;
;  trap attempts to reload it (change title if appropriate)
;
if sp_gen_base gt 0 then begin
   widget_control,sp_gen_title,set_val=gen_title
   return
endif


;
;  individual widget id's for output text widgets
;
sp_gen_exp = lonarr(5)


;
;  get base widget position and size
;
tp_offsets

;
;  top level widget id
;
sp_gen_base = WIDGET_BASE(title='General table dump', group = main_base, $
                          /FRAME, /COLUMN, $
                          xsize=sp_gen_off(2),ysize=sp_gen_off(3), $
                          xoffset=sp_gen_off(0),yoffset=sp_gen_off(1))

;
;  subordinate widgets
;
menu_base   = WIDGET_BASE(sp_gen_base, /column)
button_widg = WIDGET_BASE(menu_base, /row, space=20)
fmt_widg    = WIDGET_BASE(menu_base, /row)
info_abase  = WIDGET_BASE(sp_gen_base, /column, /FRAME)

;
;  set larger font
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  create 'DONE' button
;
doneid = widget_button(button_widg,value='Done',font=cfont)

;
;  pull-down menu for format choice
;
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],button_widg

;
;  create 'hardcopy' button
;
gen_hc_id = widget_button(button_widg,value='Hardcopy',font=cfont)

;
;  indicate current format choice
;
f1 = widget_label(fmt_widg,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_def = widget_text(fmt_widg,xsize=10,ysize=1,value=curr_fmt)

;
;  widgets for display of header information
;
sp_gen_title = WIDGET_LABEL(info_abase, VALUE=gen_title,/frame,font=cfont)
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Table index :     ',font=cfont)
sp_gen_exp(0) = WIDGET_TEXT(a1,XSIZE=10,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Table ID:         ',font=cfont)
sp_gen_exp(1) = WIDGET_TEXT(a2,XSIZE=10,YSIZE=1)


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Study ID:         ',font=cfont)
sp_gen_exp(2) = WIDGET_TEXT(a3,XSIZE=10,YSIZE=1)

a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Table length:     ',font=cfont)
sp_gen_exp(3) = WIDGET_TEXT(a4,XSIZE=10,YSIZE=1)


;
;  .. and then the general body of the packet
;
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Contents:         ',font=cfont)
sp_gen_exp(4) = WIDGET_TEXT(a5,XSIZE=30,YSIZE=22,/scroll)

;
;  realize (ie make appear) it all
;
WIDGET_CONTROL, sp_gen_base, /realize

end
