;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_HEALTH_MENU
;               
; Purpose     : Define widget layout for health module dump.
;               
; Explanation : When a display of the contents of a health module dump
;               are requested, this routine sets up the display widgets.
;               
; Use         : sp_health_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for EGSE sci_ana use.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 25-Oct-93
;               
; Modified    : To insert a 'Done' button instead of 'file/close' menu.
;               CDP, 28-Oct-93
;               Change to new packet format, CDP, 12-Jan-94
;               Add hardcopy button. CDP, 27-Jan-95
;
; Version     : Version 4, 27-Jan-95
;-            

PRO sp_health_menu

;
;  COMMON for widget id's etc.
; 
@SpecialWidgets.com
@MainWidgets.com
@Health.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('sp_health') then return



;
;  get base widget position and size
;
tp_offsets

;
;  main widget
;
sp_health_base = WIDGET_BASE(title='Health special packet', group=main_base, $
                             /FRAME, /column, SPACE=1, $
                             xsize=sp_health_off(2),ysize=sp_health_off(3), $
                             xoffset=sp_health_off(0),yoffset=sp_health_off(1))

;
;  get larger font
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  ..and subsidiary ones
;
menu_base  = WIDGET_BASE(sp_health_base, /row, space=15)
fmt_base   = WIDGET_BASE(sp_health_base, /row)
info_abase = WIDGET_BASE(sp_health_base, /COLUMN, /FRAME)

;
;  widgets ids for text widgets
;
sp_health_exp = lonarr(5)

;
;  create done/exit button
;
doneid = widget_button(menu_base, value='Done', font=cfont)

;
;  pull down menu for choice of format
;
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],menu_base

;
;  create hardcopy button
;
health_hc_id = widget_button(menu_base, value='Hardcopy', font=cfont)

;
;  display current format choice
;
f1 =  widget_base(fmt_base,/row)
f11 = widget_label(f1,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_health = widget_text(f1,xsize=10,ysize=1,value=curr_fmt)

;
;  widgets to contain the commands and actions ( the first 2 elements of
;  each packet)
;
a0 =  WIDGET_LABEL(info_abase, VALUE='Command/action', font=cfont)
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='0', font=cfont)
sp_health_exp(0) = WIDGET_TEXT(a1,XSIZE=15,YSIZE=1)

a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='1', font=cfont)
sp_health_exp(1) = WIDGET_TEXT(a2,XSIZE=15,YSIZE=1)

a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='2', font=cfont)
sp_health_exp(2) = WIDGET_TEXT(a3,XSIZE=15,YSIZE=1)

a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='3', font=cfont)
sp_health_exp(3) = WIDGET_TEXT(a4,XSIZE=15,YSIZE=1)

;
;  and room for the contents
;
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Data ', font=cfont)
sp_health_exp(4) = WIDGET_TEXT(a5,XSIZE=50,YSIZE=30,/scroll)

;
;  realize (ie make it appear) the display
;
WIDGET_CONTROL, sp_health_base, /realize

end
