;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_IEF_MENU
;               
; Purpose     : Defines and realises the IEF table dump widget.
;               
; Explanation : When a dump of an IEF (Inter-instrument Event Flag) packet is 
;               required, this routine set up the display widgets required to
;               receive and display the information.
;               
; Use         : sp_ief_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only within the EGSE science analysis
;               
; Side effects: Widget is realised.
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 15-Oct-93
;               
; Modified    : To use 'Done' button in place of 'file/close' menu
;               CDP, 28-Oct-93
;               Add hardcopy button.  CDP, 27-Jan-95
;
; Version     : Version 3, 27-Jan-95
;-            

PRO sp_ief_menu

;
;  COMMON block for widget id's etc
; 
@SpecialWidgets.com
@MainWidgets.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('sp_ief') then return


;
;  array to hold individual text widget id's
;
sp_ief_exp = lonarr(24)


;
;  get base widget position and size
;
tp_offsets

;
;  form the top widget
;
sp_ief_base = WIDGET_BASE(title='Solar event flag parameters', $
                          group=main_base, $
                          /FRAME, /row,$
                          xsize=sp_ief_off(2),ysize=sp_ief_off(3), $
                          xoffset=sp_ief_off(0),yoffset=sp_ief_off(1))


;
;  subsidiary bases
;
menu_base        = WIDGET_BASE(sp_ief_base, /ROW, space=20)
fmt_base         = WIDGET_BASE(sp_ief_base, /ROW)
info_abase       = WIDGET_BASE(sp_ief_base,   /COLUMN, /FRAME, SPACE=1,$
                               /scroll, x_scroll_size=530,y_scroll_size=400)

;
;  get larger font
;
cfont = "-adobe-helvetica-bold-r-normal--0-120-75-75-p-0-iso8859-1"
cfont2= "-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  'Done' button to close widget
;
doneid = widget_button(menu_base, value='Done',font=cfont2)

;
;  pull down menu to change display format
;  
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],menu_base

;
;  'Hardcopy' button 
;
ief_hc_id = widget_button(menu_base, value='Hardcopy',font=cfont2)

;
;  inform of current format
;
f1 =  widget_base(fmt_base,/row)
f11 = widget_label(f1,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_ief = widget_text(f1,xsize=40,ysize=1,value=curr_fmt)

;
;  define the individual text widgets
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='ERA upper limits: ',font=cfont)
sp_ief_exp(0) = WIDGET_TEXT(a1,XSIZE=40,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='ERA lower limits: ',font=cfont)
sp_ief_exp(1) = WIDGET_TEXT(a2,XSIZE=40,YSIZE=1)
   
a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Discriminator level: ',font=cfont)
sp_ief_exp(2) = WIDGET_TEXT(a3,XSIZE=40,YSIZE=1)
   
a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Event type: ',font=cfont)
sp_ief_exp(3) = WIDGET_TEXT(a4,XSIZE=40,YSIZE=1)
   
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Mode pointing/centroid: ',font=cfont)
sp_ief_exp(4) = WIDGET_TEXT(a5,XSIZE=40,YSIZE=1)
   
a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='Slit centre band A/B: ',font=cfont)
sp_ief_exp(5) = WIDGET_TEXT(a6,XSIZE=40,YSIZE=1)
   
a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='Central row: ',font=cfont)
sp_ief_exp(6) = WIDGET_TEXT(a7,XSIZE=40,YSIZE=1)
   
a8  = WIDGET_BASE(info_abase, /ROW)
a81 = WIDGET_LABEL(a8, VALUE='Number of IIF windows: ',font=cfont)
sp_ief_exp(7) = WIDGET_TEXT(a8,XSIZE=40,YSIZE=1)
   
a9  = WIDGET_BASE(info_abase, /ROW)
a91 = WIDGET_LABEL(a9, VALUE='Pixel offset windows 0/1/2: ',font=cfont)
sp_ief_exp(8) = WIDGET_TEXT(a9,XSIZE=40,YSIZE=1)
   
a10  = WIDGET_BASE(info_abase, /ROW)
a101 = WIDGET_LABEL(a10, VALUE='Coords data window 0: ',font=cfont)
sp_ief_exp(9) = WIDGET_TEXT(a10,XSIZE=40,YSIZE=1)
   
a11  = WIDGET_BASE(info_abase, /ROW)
a111 = WIDGET_LABEL(a11, VALUE='Coords data window 1: ',font=cfont)
sp_ief_exp(10) = WIDGET_TEXT(a11,XSIZE=40,YSIZE=1)
   
a12  = WIDGET_BASE(info_abase, /ROW)
a121 = WIDGET_LABEL(a12, VALUE='Coords data window 2: ',font=cfont)
sp_ief_exp(11) = WIDGET_TEXT(a12,XSIZE=40,YSIZE=1)
   
a13  = WIDGET_BASE(info_abase, /ROW)
a131 = WIDGET_LABEL(a13, VALUE='ERA expected val. window 0: ',font=cfont)
sp_ief_exp(12) = WIDGET_TEXT(a13,XSIZE=40,YSIZE=1)
   
a14  = WIDGET_BASE(info_abase, /ROW)           
a141 = WIDGET_LABEL(a14, VALUE='Deviations from ERA, window 0: ',font=cfont)
sp_ief_exp(13) = WIDGET_TEXT(a14,XSIZE=40,YSIZE=1)
   
a15  = WIDGET_BASE(info_abase, /ROW)
a151 = WIDGET_LABEL(a15, VALUE='Direct wts for ERAs window 0: ',font=cfont)
sp_ief_exp(14) = WIDGET_TEXT(a15,XSIZE=40,YSIZE=1)
   
a16  = WIDGET_BASE(info_abase, /ROW)
a161 = WIDGET_LABEL(a16, VALUE='Differential wts for ERAs window 0: ',font=cfont)
sp_ief_exp(15) = WIDGET_TEXT(a16,XSIZE=40,YSIZE=1)
   
a17  = WIDGET_BASE(info_abase, /ROW)
a171 = WIDGET_LABEL(a17, VALUE='ERA expected val. window 1: ',font=cfont)
sp_ief_exp(16) = WIDGET_TEXT(a17,XSIZE=40,YSIZE=1)
   
a18  = WIDGET_BASE(info_abase, /ROW)
a181 = WIDGET_LABEL(a18, VALUE='Deviations from ERA, window 1: ',font=cfont)
sp_ief_exp(17) = WIDGET_TEXT(a18,XSIZE=40,YSIZE=1)
   
a19  = WIDGET_BASE(info_abase, /ROW)
a191 = WIDGET_LABEL(a19, VALUE='Direct wts for ERAs window 1: ',font=cfont)
sp_ief_exp(18) = WIDGET_TEXT(a19,XSIZE=40,YSIZE=1)
   
a20  = WIDGET_BASE(info_abase, /ROW)
a201 = WIDGET_LABEL(a20, VALUE='Differential wts for ERAs window 1: ',font=cfont)
sp_ief_exp(19) = WIDGET_TEXT(a20,XSIZE=40,YSIZE=1)
   
a21  = WIDGET_BASE(info_abase, /ROW)
a211 = WIDGET_LABEL(a21, VALUE='ERA expected val. window 2: ',font=cfont)
sp_ief_exp(20) = WIDGET_TEXT(a21,XSIZE=40,YSIZE=1)

a22  = WIDGET_BASE(info_abase, /ROW)
a221 = WIDGET_LABEL(a22, VALUE='Deviations from ERA, window 2: ',font=cfont)
sp_ief_exp(21) = WIDGET_TEXT(a22,XSIZE=40,YSIZE=1)

a23  = WIDGET_BASE(info_abase, /ROW)
a231 = WIDGET_LABEL(a23, VALUE='Direct wts for ERAs window 2: ',font=cfont)
sp_ief_exp(22) = WIDGET_TEXT(a23,XSIZE=40,YSIZE=1)

a24  = WIDGET_BASE(info_abase, /ROW)
a241 = WIDGET_LABEL(a24, VALUE='Differential wts for ERAs window 2: ',font=cfont)
sp_ief_exp(23) = WIDGET_TEXT(a24,XSIZE=40,YSIZE=1)


;
;  set it going 
;
;WIDGET_CONTROL, sp_ief_base, map=0
WIDGET_CONTROL, sp_ief_base, /realize
  
end

