;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_IMIF_EVENT
;               
; Purpose     : Processes events from SP_IMIF_MENU widgets.
;               
; Explanation : All events generated by the sp_imif_menu program are processed
;               with this routine.
;               
; Use         : Only for use by XMANAGER
;    
; Inputs      : ev - the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use within EGSE science analysis.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Oct-93
;               
; Modified    : To detect new 'Done' button, CDP, 28-Oct-93
;               Add hardcopy button.  CDP, 27-jan-95
;
; Version     : Version 3, 27-Jan-95
;-            

PRO sp_imif_event, ev

;
;  COMMON blocks for communication
;
@MainWidgets.com
@SpecialWidgets.com
@Packets.com
@Base_Offsets.com
      
;
;  determine type of event that has occurred
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  if it was a button then handle accordingly
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value

;
;  finish by destroying widget
;  
   IF (value EQ 'Done') THEN BEGIN
      widget_control,sp_imif_base, tlb_get_offset=boff
      widget_control,sp_imif_base, tlb_get_size = bsize
      sp_imif_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, sp_imif_base, /destroy
      sp_request = -1
   ENDIF

;
;  Hardcopy
; 
   IF (value EQ 'Hardcopy') then begin
      widget_control, sp_imif_base,/hourglass 
      get_utc,utc
      widget_control, imif_hc_id, set_val=strmid(anytim2cal(utc,f=1),0,15)
      spawn,'xwd -name "Special packet (MCU backup)" '+$
        ' | xpr  -gray 3 -width 4 -height 6 -header "Special packet (MCU backup)"'+$
         ' | lpr'
      widget_control, imif_hc_id,set_val='Hardcopy'
   ENDIF

;
;  switch to Decimal format
;
   IF (value EQ 'Decimal') then begin
      special_format = 1 
      widget_control,sp_format_imif,set_value='Decimal'
   endif

;
;  switch to Hexadecimal format
;
   IF (value EQ 'Hex') then begin
      special_format = 2 
      widget_control,sp_format_imif,set_value='Hex'
   endif


ENDIF

END


