;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_IMIF_MENU
;               
; Purpose     : Defines and realises the MCU backup dump widgets.
;               
; Explanation : When a dump of an MCU backup packet is 
;               required, this routine sets up the display widgets required to
;               receive and display the information.
;               
; Use         : sp_imif_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None              
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only within the EGSE science analysis
;               
; Side effects: Widget is realised.
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Oct-93
;               
; Modified    : For updated packet format  CDP, 14-Oct-1993
;               To include a 'Done' button. CDP, 28-Oct-93
;               Reworked for new packet definition.  CDP 30/Nov/93
;               Changed name.  CDP  12-Jan-94
;               Add hardcopy button.  CDP, 27-Jan-95
;
; Version     : Version 6, 27-Jan-95
;-            

PRO sp_imif_menu

;
;  COMMON block for widget id's etc
; 
@SpecialWidgets.com
@MainWidgets.com
@Base_Offsets.com



;
;  trap double clicks
;
if xregistered('sp_imif') then return


;
;  array to hold individual text widget id's
;
sp_imif_expa = lonarr(21)
sp_imif_expb = lonarr(24)
sp_imif_mode = lonarr(7)

;
;  get base widget position and size
;
tp_offsets

;
;  form the top widget and put it over on the right
;
sp_imif_base = WIDGET_BASE(title='Special packet (MCU backup)', $
                           group=main_base, /FRAME, /column, $
                           xsize=sp_imif_off(2),ysize=sp_imif_off(3), $
                           xoffset=sp_imif_off(0),yoffset=sp_imif_off(1))

;
;  subsidiary bases
;
menu_base        = WIDGET_BASE(sp_imif_base, /row, space=20)
fmt_base         = WIDGET_BASE(sp_imif_base, /row)
info_base        = WIDGET_BASE(sp_imif_base, /row,/scroll,$
                               x_scroll_size=300,$
                               y_scroll_size=800)

info_abase       = WIDGET_BASE(info_base,   /COLUMN, /FRAME, SPACE=1)

;
;  set larger font
;
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  create 'Done' button
;
doneid = widget_button(menu_base, value='Done',font=cfont)

;
;  pull down menu to change display format
;  
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],menu_base

;
;  create 'Hardcopy' button
;
imif_hc_id = widget_button(menu_base, value='Hardcopy',font=cfont)

;
;  inform of current format
;
f11 = widget_label(fmt_base,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_imif = widget_text(fmt_base,xsize=10,ysize=1,value=curr_fmt)

;
;  define the individual text widgets
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Pointing calculation mode: ',font=cfont)
sp_imif_expa(0) = WIDGET_TEXT(a1,XSIZE=36,YSIZE=1)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='OPS left/right zero posn.: ',font=cfont)
sp_imif_expa(1) = WIDGET_TEXT(a2,XSIZE=36,YSIZE=1)
   
a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='OPS K/R/LTHETA/LPHI: ',font=cfont)
sp_imif_expa(2) = WIDGET_TEXT(a3,XSIZE=36,YSIZE=1)
   
a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Pitch zero/fac0/fac1: ',font=cfont)
sp_imif_expa(3) = WIDGET_TEXT(a4,XSIZE=36,YSIZE=1)
   
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Yaw zero/fac0/fac1: ',font=cfont)
sp_imif_expa(4) = WIDGET_TEXT(a5,XSIZE=36,YSIZE=1)
   
a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='Backup heater cycle time (100 msec): ',font=cfont)
sp_imif_expa(5) = WIDGET_TEXT(a6,XSIZE=36,YSIZE=1)
   
a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='Initial backup heater mark times (100 msec): ',font=cfont)
sp_imif_expa(6) = WIDGET_TEXT(a7,XSIZE=36,YSIZE=2)
   
a8  = WIDGET_BASE(info_abase, /ROW)
a81 = WIDGET_LABEL(a8, VALUE='Power available: ',font=cfont)
sp_imif_expa(7) = WIDGET_TEXT(a8,XSIZE=36,YSIZE=1)
   
a9  = WIDGET_BASE(info_abase, /ROW)
a91 = WIDGET_LABEL(a9, VALUE='Backup heater power reqs: ',font=cfont)
sp_imif_expa(8) = WIDGET_TEXT(a9,XSIZE=36,YSIZE=2)
   
a10  = WIDGET_BASE(info_abase, /ROW)
a101 = WIDGET_LABEL(a10, VALUE='Backup heater sensors: ',font=cfont)
sp_imif_expa(9) = WIDGET_TEXT(a10,XSIZE=36,YSIZE=2)
   
a11  = WIDGET_BASE(info_abase, /ROW)
a111 = WIDGET_LABEL(a11, VALUE='Sensor temps (1/8 Kelvin) ',font=cfont,ysize=2)
sp_imif_expa(10) = WIDGET_TEXT(a11,XSIZE=36,YSIZE=2)
   
a12  = WIDGET_BASE(info_abase, /ROW)
a121 = WIDGET_LABEL(a12, VALUE='Latency times (millisecs): ',font=cfont)
sp_imif_expa(11) = WIDGET_TEXT(a12,XSIZE=36,YSIZE=5)

a13  = WIDGET_BASE(info_abase, /ROW)
a131 = WIDGET_LABEL(a13, VALUE='Solar Feature Track parameters: ',font=cfont)
sp_imif_expa(12) = WIDGET_TEXT(a13,XSIZE=36,YSIZE=1)
   


;
;  second packet
;

a14  = WIDGET_BASE(info_abase, /ROW)
a141 = WIDGET_LABEL(a14, VALUE='Prime power OPS/Mirr/Slit/Door: ',font=cfont)
sp_imif_expa(13) = WIDGET_TEXT(a14,XSIZE=36,YSIZE=1)

a15  = WIDGET_BASE(info_abase, /ROW)
a151 = WIDGET_LABEL(a15, VALUE='Backup power OPS/Mirr/Slit/Door: ',font=cfont)
sp_imif_expa(14) = WIDGET_TEXT(a15,XSIZE=36,YSIZE=1)

a16  = WIDGET_BASE(info_abase, /ROW)
a161 = WIDGET_LABEL(a16, VALUE='Heater mode/power limit: ',font=cfont)
sp_imif_expa(15) = WIDGET_TEXT(a16,XSIZE=36,YSIZE=1)

a17  = WIDGET_BASE(info_abase, /ROW)
a171 = WIDGET_LABEL(a17, VALUE='Backup heater states (initial): ',font=cfont)
sp_imif_expa(16) = WIDGET_TEXT(a17,XSIZE=36,YSIZE=1)

a18  = WIDGET_BASE(info_abase, /ROW)
a181 = WIDGET_LABEL(a18, VALUE='Prime heater temperatures - LOW: ',font=cfont)
sp_imif_expa(17) = WIDGET_TEXT(a18,XSIZE=36,YSIZE=4)
   
a19  = WIDGET_BASE(info_abase, /ROW)
a191 = WIDGET_LABEL(a19, VALUE='Prime heater temperatures - HIGH: ',font=cfont)
sp_imif_expa(18) = WIDGET_TEXT(a19,XSIZE=36,YSIZE=4)
   
a20  = WIDGET_BASE(info_abase, /ROW)
a201 = WIDGET_LABEL(a20, VALUE='QCM1/2 heater: ',font=cfont)
sp_imif_expa(19) = WIDGET_TEXT(a20,XSIZE=36,YSIZE=1)
   
a21  = WIDGET_BASE(info_abase, /ROW)
a211 = WIDGET_LABEL(a21, VALUE='QCM2 acc.: ',font=cfont)
sp_imif_expa(20) = WIDGET_TEXT(a21,XSIZE=36,YSIZE=1)
   
;
;  right hand side display
;
   
   
b1  = WIDGET_BASE(info_abase, /ROW)
b11 = WIDGET_LABEL(b1, VALUE='OPS left/right telemetry value: ',font=cfont)
sp_imif_expb(0) = WIDGET_TEXT(b1,XSIZE=36,YSIZE=1)
   
b2  = WIDGET_BASE(info_abase, /ROW)
b21 = WIDGET_LABEL(b2, VALUE='Mirror/slit telemetry value: ',font=cfont)
sp_imif_expb(1) = WIDGET_TEXT(b2,XSIZE=36,YSIZE=1)
   
b3  = WIDGET_BASE(info_abase, /ROW)           
b31 = WIDGET_LABEL(b3, VALUE='Sun pitch/yaw telemetry value: ',font=cfont)
sp_imif_expb(2) = WIDGET_TEXT(b3,XSIZE=36,YSIZE=1)
   
b4  = WIDGET_BASE(info_abase, /ROW)
b41 = WIDGET_LABEL(b4, VALUE='Solar x/y (WITHOUT mirror/slit): ',font=cfont)
sp_imif_expb(3) = WIDGET_TEXT(b4,XSIZE=36,YSIZE=1)
   
b5  = WIDGET_BASE(info_abase, /ROW)
b51 = WIDGET_LABEL(b5, VALUE='Solar x/y (INCLUDING mirror/slit): ',font=cfont)
sp_imif_expb(4) = WIDGET_TEXT(b5,XSIZE=36,YSIZE=1)
   
b6  = WIDGET_BASE(info_abase, /ROW)
b61 = WIDGET_LABEL(b6, VALUE='Mirror position commanded/current: ',font=cfont)
sp_imif_expb(5) = WIDGET_TEXT(b6,XSIZE=36,YSIZE=1)
   
b7  = WIDGET_BASE(info_abase, /ROW)
b71 = WIDGET_LABEL(b7, VALUE='Slit position commanded/current: ',font=cfont)
sp_imif_expb(6) = WIDGET_TEXT(b7,XSIZE=36,YSIZE=1)
   
b8  = WIDGET_BASE(info_abase, /ROW)
b81 = WIDGET_LABEL(b8, VALUE='OPS left commanded/current: ',font=cfont)
sp_imif_expb(7) = WIDGET_TEXT(b8,XSIZE=36,YSIZE=1)
   
b9  = WIDGET_BASE(info_abase, /ROW)
b91 = WIDGET_LABEL(b9, VALUE='OPS right commanded/current: ',font=cfont)
sp_imif_expb(8) = WIDGET_TEXT(b9,XSIZE=36,YSIZE=1)
   
b10  = WIDGET_BASE(info_abase, /ROW)
b101 = WIDGET_LABEL(b10, VALUE='Slit number commanded/current: ',font=cfont)
sp_imif_expb(9) = WIDGET_TEXT(b10,XSIZE=36,YSIZE=1)
   
b11  = WIDGET_BASE(info_abase, /ROW)
b111 = WIDGET_LABEL(b11, VALUE='Door state commanded/current: ',font=cfont)
sp_imif_expb(10) = WIDGET_TEXT(b11,XSIZE=36,YSIZE=1)
   
b12  = WIDGET_BASE(info_abase, /ROW)
b121 = WIDGET_LABEL(b12, VALUE='Mechanism time: ',font=cfont)
sp_imif_expb(11) = WIDGET_TEXT(b12,XSIZE=36,YSIZE=1)
   
b13  = WIDGET_BASE(info_abase, /ROW)
b131 = WIDGET_LABEL(b13, VALUE='Mechanism moving: ',font=cfont)
sp_imif_expb(12) = WIDGET_TEXT(b13,XSIZE=36,YSIZE=1)
   
b14  = WIDGET_BASE(info_abase, /ROW)
b141 = WIDGET_LABEL(b14, VALUE='Backup heater mark times (current): ',font=cfont)
sp_imif_expb(13) = WIDGET_TEXT(b14,XSIZE=36,YSIZE=2)
   
b15  = WIDGET_BASE(info_abase, /ROW)
b151 = WIDGET_LABEL(b15, VALUE='Backup heater states (current): ',font=cfont)
sp_imif_expb(14) = WIDGET_TEXT(b15,XSIZE=36,YSIZE=1)
   
b16  = WIDGET_BASE(info_abase, /ROW)
b161 = WIDGET_LABEL(b16, VALUE='Solar Feature Tracking parameters: ',font=cfont)
sp_imif_expb(15) = WIDGET_TEXT(b16,XSIZE=36,YSIZE=4)

b17  = WIDGET_BASE(info_abase, /ROW)
b171 = WIDGET_LABEL(b17, VALUE='Internal time : ',font=cfont)
sp_imif_expb(16) = WIDGET_TEXT(b17,XSIZE=36,YSIZE=1)
   
;
;  widgets for backup modes
;
temp_base = lonarr(7)
temp_lab = lonarr(7)

mode_tit = ['Heater:          ',$
            'Loop:            ',$
            'Feature tracking:',$
            'Mirror:          ',$
            'Slit:            ',$
            'OPS Left:        ',$
            'OPS Right:       ']
imif_modes  = WIDGET_BASE(info_abase, /COLUMN, /FRAME)
imif_label  = WIDGET_LABEL(imif_modes, VALUE='Backup modes.',font=cfont)
for i=0,6 do begin
    temp_base(i) = widget_base(imif_modes,/ROW)
    temp_lab(i)  = widget_label(temp_base(i),val=mode_tit(i),font=cfont)
    sp_imif_mode(i) = WIDGET_TEXT(temp_base(i),XSIZE=6,YSIZE=1)
endfor
   

;
;  set it going only keep under wraps until required
;
WIDGET_CONTROL, sp_imif_base, map=0
WIDGET_CONTROL, sp_imif_base, /realize
  
end

