;+
; Project     : SOHO - CDS     
;                   
; Name        : SP_IMIFIM_MENU
;               
; Purpose     : Defines and realises the IMIF interface module dump widgets.
;               
; Explanation : When a dump of an IMIF (interface module) packet is 
;               required, this routine sets up the display widgets required to
;               receive and display the information.
;               
; Use         : sp_imifim_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use only within the EGSE science analysis
;               
; Side effects: Widget is realised.
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Oct-93
;               
; Modified    : Change widget layout, CDP, 2-Feb-1994
;               Include new backup.mode definitions. CDP, 8-Feb-94
;               Add hardcopy button.  CDP, 27-Jan-95
;
; Version     : Version 4, 27-Jan-95
;-            

PRO sp_imifim_menu

;
;  COMMON block for widget id's etc
; 
@SpecialWidgets.com
@MainWidgets.com
@Base_Offsets.com


;
;  trap double clicks
;
if xregistered('sp_imifim') then return


;
;  array to hold individual text widget id's
;
sp_imifim_expa = lonarr(22)
sp_imifim_expb = lonarr(15)

;
;  get base widget position and size
;
tp_offsets

;
;  form the top widget
;
sp_imifim_base = WIDGET_BASE(title='IMIF (interface module) special packet', $
                             group=main_base, /FRAME, /COLUMN,$
                             xsize=sp_imifim_off(2),ysize=sp_imifim_off(3), $
                             xoffset=sp_imifim_off(0),yoffset=sp_imifim_off(1))


;
;  subsidiary bases
;
menu_base        = WIDGET_BASE(sp_imifim_base, /ROW, space=20)
fmt_base         = WIDGET_BASE(sp_imifim_base, /ROW)
info_abase       = WIDGET_BASE(sp_imifim_base,   /COLUMN, /FRAME, SPACE=1)

;
;  get larger font
; 
cfont="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  create 'Done' button
;
doneid = widget_button(menu_base, value='Done',font=cfont)

;
;  pull down menu to change display format
;  
XPDmenu, ['"Format" {','"Decimal"','"Hex"', '}'],menu_base

;
;  create 'Hardcopy' button
;
imifim_hc_id = widget_button(menu_base, value='Hardcopy',font=cfont)

;
;  inform of current format
;
f11 = widget_label(fmt_base,val='Current format: ')
if special_format eq 2 then curr_fmt = 'Hex' else curr_fmt = 'Decimal'
sp_format_imifim = widget_text(fmt_base,xsize=10,ysize=1,value=curr_fmt)

;
;  define the individual text widgets
;
a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Status: ',font=cfont)
sp_imifim_expa(0) = WIDGET_TEXT(a1,XSIZE=40,YSIZE=11)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Number of EPS heartbeats: ',font=cfont)
sp_imifim_expa(1) = WIDGET_TEXT(a2,XSIZE=40,YSIZE=1)
   
a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Number of MCU heartbeats: ',font=cfont)
sp_imifim_expa(2) = WIDGET_TEXT(a3,XSIZE=40,YSIZE=1)
   
a4  = WIDGET_BASE(info_abase, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='Number of VDS heartbeats: ',font=cfont)
sp_imifim_expa(3) = WIDGET_TEXT(a4,XSIZE=40,YSIZE=1)
   
a5  = WIDGET_BASE(info_abase, /ROW)
a51 = WIDGET_LABEL(a5, VALUE='Number of GIS heartbeats: ',font=cfont)
sp_imifim_expa(4) = WIDGET_TEXT(a5,XSIZE=40,YSIZE=1)
   
a6  = WIDGET_BASE(info_abase, /ROW)
a61 = WIDGET_LABEL(a6, VALUE='Extra telemetry delay: ',font=cfont)
sp_imifim_expa(5) = WIDGET_TEXT(a6,XSIZE=40,YSIZE=1)
   
a7  = WIDGET_BASE(info_abase, /ROW)
a71 = WIDGET_LABEL(a7, VALUE='Total command delay: ',font=cfont)
sp_imifim_expa(6) = WIDGET_TEXT(a7,XSIZE=40,YSIZE=2)
   

;
;  set it going 
;
;WIDGET_CONTROL, sp_imifim_base, map=0
WIDGET_CONTROL, sp_imifim_base, /realize
  
end

