	PRO STCNT_OPEN, STCNT_UNIT, STCNT_MAX
;+
; Project     :	SOHO - CDS
;
; Name        :	STCNT_OPEN
;
; Purpose     :	Open the file max_study_counter.dat for update.
;
; Category    :	Class4, CDS, Telemetry
;
; Explanation :	Opens the file $CDS_CP_MISC_W/max_study_counter.dat for update.
;		If the file doesn't exist, then it is created with the dummy
;		value 0.  Called from FITSGEN.
;
;		If the environment variable CDS_CP_MISC_W is not defined, then
;		STCNT_UNIT is set to an undefined value, and the routine
;		returns.
;
;		Normally, one calls STCNT_OPEN once at the beginning of
;		processing telemetry, and then calls STCNT_UPDATE to maintain
;		the value in the file.
;
; Syntax      :	STCNT_OPEN, STCNT_UNIT, STCNT_MAX
;
; Examples    :	
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	STCNT_UNIT = Logical unit number of the opened file.
;		STCNT_MAX  = The current value stored in the file.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	CONCAT_DIR
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	Extracted from FITSGEN.
;
; History     :	Version 1, 29 May 1997, William Thompson, GSFC
;		Version 2, 13 May 1997, William Thompson, GSFC
;			Make sure that STCNT_MAX is a long integer
;
; Contact     :	WTHOMPSON
;-
;
;
	IF !DEBUG EQ 0 THEN ON_ERROR, 2 ELSE ON_ERROR, 0
;
;  Check the calling sequence.
;
	IF N_PARAMS() NE 2 THEN MESSAGE,	$
		'Syntax:  STCNT_OPEN, STCNT_UNIT, STCNT_MAX'
;
;  Test to see if the CDS_CP_MISC_W directory exists.  If not, then undefine
;  STCNT_UNIT.
;
	IF GETENV('CDS_CP_MISC_W') EQ '' THEN BEGIN
	    DELVARX, STCNT_UNIT
	    STCNT_MAX = 0L
	END ELSE BEGIN
;
;  Open the file to keep track of the highest study counter entry, and read in
;  the current value.  If the file doesn't exist yet, then initialize it to
;  contain the value 0.
;
	    STCNT_FILE = CONCAT_DIR('$CDS_CP_MISC_W','max_study_counter.dat')
	    STCNT_MAX = 0L
	    OPENU, STCNT_UNIT, STCNT_FILE, /GET_LUN, ERROR=ERROR
	    IF ERROR NE 0 THEN BEGIN
		OPENW, STCNT_UNIT, STCNT_FILE, /GET_LUN
		PRINTF, STCNT_UNIT, STCNT_MAX
;
;  Do a close and reopen to force a flush to the disk.
;
		CLOSE, STCNT_UNIT
		OPENU, STCNT_UNIT, STCNT_FILE
	    END ELSE READF, STCNT_UNIT, STCNT_MAX
	ENDELSE
;
	END
