;+
; Project     : SOHO - CDS           
;                                                                   
; Name        : STM_EVENT
;                                                   
; Purpose     : Services the widget events from STM_MENU.
;                                                   
; Explanation : The science telemetry monitoring package is controlled from 
;               the top level widget set up in STM_MENU.  This routine 
;               services all the events generated from within that widget.
;                                                   
; Use         : Only used by XMANAGER to service STM_MENU
;       
; Inputs      : ev  -  structure of event generated
;                                                   
; Opt. Inputs : None
;                                                   
; Outputs     : None
;                                                   
; Opt. Outputs: None
;                                                   
; Keywords    : None
;
; Calls       : None
;                                                   
; Restrictions: Only internal use in EGSE science analysis
;                                                   
; Side effects: None
;                                                   
; Category    : Telemetry
;                                                   
; Prev. Hist. : EM version by Arnulf, Oct-92
;               FM version by C D Pike, RAL, 7-Oct-93   
;
; Written     : Operations version. CDP, July-94
;                                                   
; Modified    : Handle PAUSE button.  CDP, 11-Jan-94
;               Desensitise tm file select button during play.  CDP, 22-may-95
;               Cut out use of ctrl_analysis on trial basis.    CDP, 25-may-95
;               Make lookback mode optional.                    CDP, 5-Jun-95
;               Handle the listing of DCS.                      CDP, 6-Jun-95
;               Cut call to xmanager for DCS listing.           CDP, 12-Jun-95
;               Control Done buttons in data/header displays.   CDP, 4-Jul-95
;               Include UT in widget title.                     CDP, 18-Sep-95
;               Include memory dumping.                         CDP, 12-Oct-95
;               Update use of memory dump evar.                 CDP, 20-Oct-95
;               Added ops plan viewer.                          CDP, 15-Nov-95
;               Add auto switch off of memory dumps.            CDP, 28-Nov-95
;               Call bootinfo at end of memory dump.            CDP, 11-Jan-96
;               Not allow manual header display in Data Driven. CDP, 17-Jan-96
;               Use free_lun rather than close                  CDP, 15-Apr-96
;               Changed to not use XBackRegister which was 
;               deleted from IDL v5                             CDP, 16-Jun-98
;               Added check to make science ingest is running
;               before sending TIMER messages.                  RY,  15-Mar-99
;
; Version     : Version 18, 15-Mar-99
;-                                       

PRO stm_event, ev

;
;  Pick up all the COMMON blocks for communication of variables
;
@VDSData.com
@GISData.com
@Rawscience.com
@MainWidgets.com
@VDSWidgets.com
@HeaderWidgets.com
@SpecialWidgets.com
@GISWidgets.com
@IO_units.com
@Mode.com
@Packets.com
@Images.com
@ReviewWidgets.com
@RawData.com
@Monitor.com
@Status.com
@Base_Offsets.com
@PHA_data.com
@Mem_dump.com


;
;  WORKPROC is the name of the routine to be registered as a background
;  task and which actually performs the telemetry reception.
;  (now redundant)
;workprocname = "workproc"


;
;  determine the type of widget event to be serviced
;
type = TAG_NAMES(ev, /structure)


; 
;  trap timer events for workproc to act
;
if (type EQ 'WIDGET_TIMER') then begin
   workproc, ev.top
   if sci_going then widget_control, dummy_label, timer=0.1
   return
endif


;
;  if it is a button then retrieve the user value (careful it is called
;  plain 'value'!)
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_UVALUE=value


;
;  begin to act depending on the identification of the widget
;

;
;  if a top level DONE was requested, everything dies
;                 ====

   if (value EQ 'Done') then begin
      on_ioerror, going
      if n_elements(replay_unit) gt 0 then close,replay_unit
      if n_elements(realtime_unit) gt 0 then close,realtime_unit
      going:
      widget_control,ev.top, tlb_get_offset=boff
      widget_control,ev.top, tlb_get_size = bsize
      stm_menu_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, /destroy, ev.top
      loadct,0
      return
   endif 

;
;  Handle PAUSE/RESTART requests
;         =============
;
   if value eq 'CONT_PAUS' then begin
      if sci_going then begin
         if sci_pause eq 1 then begin
            widget_control, start_base, sens=0
            widget_control, stop_base,  sens=1
            widget_control, pause_base,set_v='Pause'
            widget_control, msg_widg,set_v='Data flow restarted.',/append 
            sci_pause = 0 
         endif else begin       
            widget_control, start_base, sens=0
            widget_control, stop_base,  sens=0
            widget_control, pause_base,set_v='Restart'
            bell
            widget_control, msg_widg,set_v='Data flow PAUSED.',/append 
            sci_pause = 1
            widget_control, main_base, $
                     tlb_set_title='CDS Science Telemetry Monitor'
         endelse
      endif
   endif

;
;  request was to START receipt of telemetry
;                 =====

   IF (value EQ 'CONT_STRT') THEN BEGIN

      catching_up = 0
      to_catchup = 0



;
;  if we are already running then ignore and and point it out
;
      if sci_going then begin
         bell
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_V="Data acquisition already started."
      endif else begin
         first_packet = 1

;
; actions are different for different ingest modes..
; here REPLAY mode 	
;      =====

         IF (sci_mode EQ 0) THEN Begin

;
;  desensitise selection of replay files
;
            widget_control, pbase(1), sens=0


;
;  start replay mode was requested so we need some data files, check they
;  are defined, if so, open the first
;
            file_seq_no = 0
            num_data_files = n_elements(file_name)
            if num_data_files gt 0 then begin
               break_file,file_name(file_seq_no),disk,dir,rfile,rext
               year = fix(strmid(rfile+rext,3,2)) + 1900
               doy = fix(strmid(rfile+rext,6,3))
               date = ' ('+strmid(anytim2cal(doy2utc(doy,year),f=1),0,6)+')'
               widget_control,rep_widg,set_val=rfile+rext+date
               curr_fsize = tm_get_size(file_name(file_seq_no))/306L
               OPENR, replay_unit,file_name(file_seq_no), ERROR=ioerr,/get_lun

                     
               IF (ioerr NE 0) THEN BEGIN
                  WIDGET_CONTROL, msg_widg, /append, $
                                  SET_VALUE=!ERR_STRING
                  curr_fsize = 0L
                  return
               ENDIF 
            endif else begin

;
;  if no data files defined, warn and exit
;
               WIDGET_CONTROL, msg_widg, /append, $
                               SET_V='No data files defined'
               return
            endelse 

;
;  were we meant to skip to a particular packet?
;
            widget_control,spacket_widg,get_value=skip_pack
            if valid_num(skip_pack(0), valnum, /integer) then begin
              widget_control,msg_widg, /append, $
                             set_val='Skipping to packet '+skip_pack(0)
              point_lun,replay_unit,valnum*306L
              skip_pack = valnum
   endif else begin
              bell
              widget_control,msg_widg, /append, $
                 set_val='** Error - invalid packet skip requested. **'
                 skip_pack = 0
                 widget_control,spacket_widg,set_val='0'
            endelse

         ENDIF ELSE BEGIN
;
; REALTIME  mode selected so find the current file and get to it
; ========  
;
;
;  what should the current file be?
;
            curr_file = concat_dir('$CDS_TM_DATA',gt_rt_file())
            if not file_exist(curr_file) then begin
               flash_msg,msg_widg,$
                'No current realtime session in progress ('+curr_file+')'
               return
            endif else begin
               pskip = tm_get_size(curr_file)/306L
               openr,realtime_unit,curr_file,/get_lun,error=err
               if err ne 0 then begin
                  flash_msg,msg_widg, /append, $
                                      'Unable to open current telemetry file.'
                  return
               endif else begin
                  print,'Skipped '+trim(pskip)+' packets'
                  point_lun,realtime_unit,pskip*306L
                  widget_control, msg_widg, $
                                  set_val='Connected to realtime session OK.'
               endelse   
               start_pack = pskip
               skip_pack = 0
            endelse
         ENDELSE

;
; In either mode we should now be ready so make XMANAGER start calling 
; the WORKPROC routine
;
;         XBackRegister, workprocname, ev.top
          dummy_label = widget_base(ev.top)
          widget_control, dummy_label, timer=0.0

;
;  Disable analysis widgets because of system overheads
;
;         ctrl_analysis, 0
    
;                        
; and send message to operator
;
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_VALUE=systime()+" Data acquisition started"

;
;  as an indicator that all is well, the number of packets received is 
;  displayed in a widget
;
         packet_no = long(skip_pack)
         WIDGET_CONTROL, packet_widg, SET_VALUE=STRING(packet_no,form='(i8)')

;
;  set flag to tell the world we are up and running
;
         sci_going = 1
         widget_control, start_base, sens=0
         widget_control, stop_base, sens=1

;
;  and clear out the packet statistics variable and clear display 
;
         review_stats(*) = 0
         if reviewing then for i=0,22 do widget_control,review_expa(i),set_v=' '
      endelse
   ENDIF

;
; STOP was requested so stop XMANAGER calling the workproc
; ====

   IF (value EQ 'CONT_STOP') THEN BEGIN

;
;  double check we were going in the first place
;
     if sci_going then begin
;        XBackRegister, /UNREGISTER, workprocname, ev.top 
         widget_control, dummy_label, /destroy

;
;  science input was going but was last packet seen?  If not then store data
;  anyway as a safeguard if we have all relevant information.
;
        if (last_pkt_id eq '22'x) and not last_packet then begin
          if check_headers('VDS') then begin
            WIDGET_CONTROL, msg_widg, /append, $
                SET_VALUE="Performing safety dump of data to VDS array"
            dcmp_win    = VDSrasterhdr.VDSwin(0:VDSrasterhdr.NumDataWindows-1)
            scheme      = VDSrasterhdr.Scihead.DataCompScheme 
            option      = VDSrasterhdr.Scihead.DataCompOption
            detector    = 0
            print,'Decompressing VDS data with...'
            print,'Scheme/Data comp method: ',scheme
            print,'Option/Data comp parameter: ',option
            print,'Data orientation: ',vds_orientation
            buff16_sz = n_elements(sci_buffer)/2
            sci_buff16 = dcmpdata(fix(sci_buffer,0,buff16_sz),dcmp_win,$
                                  detector,scheme,option,vds_orientation)
            VDS_Ext_image, sci_buff16, VDSrasterhdr, vds_data_str.vds_exp, $
                           msg_widg
            if vds_display then begin
               vds_data_str.exp_in_a = vds_data_str.vds_exp
               vds_data_str.curr_a_img = $
                            vds_deselect(VDSrasterhdr,vds_data_str.exp_in_a - $
                                                      vds_data_str.first_in_mem)
               Plot_VDS, vds_awidg, vds_data_str.curr_a_img
            endif
          endif else begin
            bell
            widget_control,msg_widg,/append,$
               set_val='Insufficient header information to retrieve data array.'
          endelse
        endif
;
;  enough GIS info?
;
        if (last_pkt_id eq '21'x) and not last_packet then begin
          if check_headers('GIS') then begin
            WIDGET_CONTROL, msg_widg, /append, $
                         SET_VALUE="Performing safety dump of data to GIS array"

            dcmp_win = replicate({StartX:0,StartY:0,LengthX:0,LengthY:0},$
                                 GISrasterhdr.NumDataWindows)
            for i=0,GISrasterhdr.NumDataWindows-1 do begin
               dcmp_win(i).StartX  = GISrasterhdr.GISwin(i).Start
               dcmp_win(i).StartY  = 0
               dcmp_win(i).LengthX = GISrasterhdr.GISwin(i).Length
               dcmp_win(i).LengthY = 1
            endfor
            scheme = GISrasterhdr.Scihead.DataCompScheme 
            option = GISrasterhdr.Scihead.DataCompOption
            vds_orientation = 0
            detector = 1
            print,'Decompressing GIS data with...'
            print,'Scheme/Data comp method: ',scheme
            print,'Option/Data comp parameter: ',option
            print,'Data orientation: ',vds_orientation
            buff16_sz = n_elements(sci_buffer)/2
            sci_buff16 = dcmpdata(fix(sci_buffer,0,buff16_sz),dcmp_win,detector,$
                                  scheme,option,vds_orientation)
      
            GIS_Ext_plot, sci_buff16, GISrasterhdr, gis_plot, $
                                           gis_data_str.gis_exp, msg_widg       
            if gis_display then begin
               Plot_GIS, $
              gis_deselect(gisrasterhdr,gis_plot,gis_data_str.gis_exp,msg_widg)
            endif
          endif else begin
            bell
            widget_control,msg_widg,/append,$
               set_val='Insufficient header information to retrieve data array.'
          endelse
        endif

;
; Safe to enable analysis again
; (comment out to test if can live with it)
;
;        ctrl_analysis, 1

;
; Message to operator
;
        WIDGET_CONTROL, msg_widg, /append, $
                        SET_VALUE=systime()+" Data acquisition stopped"
;
;  set flags in COMMON
;
        sci_pause    = 0
        sci_going    = 0
        last_sci_cnt = 0
        last_study_id = 0
        widget_control, stop_base, sens=0
        widget_control, start_base, sens=1
        widget_control, pbase(1), sens=1
       
;
;  close the appropriate unit
;
        if (sci_mode EQ 0) THEN begin
           if n_elements(replay_unit) gt 0 then free_lun, replay_unit
           file_seq_no = num_data_files + 1
        endif else begin  
           if n_elements(realtime_unit) gt 0 then free_lun, realtime_unit 
        endelse          
;
;  back to non-timer title
;
        widget_control, main_base, $
                 tlb_set_title='CDS Science Telemetry Monitor'

     endif else begin

;
;  not actually receiving data (according to sci_going) so inform
;
        WIDGET_CONTROL, msg_widg, /append, $
                        SET_V="Data acquisition NOT started yet!"
     endelse

;
;  set all header reception flags
;
     have_v_rst_hdr = 0
     have_v_exp_hdr = 0
     have_g_rst_hdr = 0
     have_g_exp_hdr = 0

  ENDIF


;
;  want to SELECT data files
;          ======
  
   IF (value EQ 'CONT_GTTM') THEN BEGIN
      cds_files_in,file_name
      file_seq_no = 0
      num_data_files = n_elements(file_name)
      if file_name(file_seq_no) ne '' then begin
         break_file,file_name(file_seq_no),disk,dir,rfile,rext
         year = fix(strmid(rfile+rext,3,2)) + 1900
         doy = fix(strmid(rfile+rext,6,3))
         date = ' ('+strmid(anytim2cal(doy2utc(doy,year),f=1),0,6)+')'
         widget_control,rep_widg,set_val=rfile+rext+date
      endif else begin
         widget_control,rep_widg,set_val=' '
      endelse
   endif

;
;  want to REVIEW data files (science packets)
;          ======
  
   IF (value  eq 'OPTN_REV') THEN BEGIN
      review_tm_menu
      reviewing = 1
      XMANAGER,"review_tm", review_base
   endif

;
;  want VDS display and analysis
;       ===

   IF (value EQ 'OPTN_DSP_VDS') THEN BEGIN
          vds_menu
          vds_display = 1
          WIDGET_CONTROL, vds_base, MAP=1
          if vds_data_str.exp_in_a  ge 0 then begin
             Plot_VDS, vds_awidg,vds_data_str.curr_a_img
             Update_Expinfo, VDS_exphdr(vds_data_str.exp_in_a), $
                             VDSrasterhdr, vds_exp_awidg
          endif else begin
             if vds_data_str.vds_exp ge 0 then begin
                vds_data_str.exp_in_a = vds_data_str.vds_exp
                vds_data_str.curr_a_img = $
                      vds_deselect(VDSrasterhdr,vds_data_str.exp_in_a - $
                                                vds_data_str.first_in_mem)
                Plot_VDS, vds_awidg,vds_data_str.curr_a_img
                Update_Expinfo, VDS_exphdr(vds_data_str.exp_in_a), $
                                VDSrasterhdr, vds_exp_awidg
             endif
          endelse
          XMANAGER, "vds",vds_base
          widget_control,vds_i_done,sens=(ops_mode eq 0)
   ENDIF

;
;  want to display and analyse GIS data
;                              ===

   IF (value eq 'OPTN_DSP_GIS') THEN BEGIN
       gis_menu
       gis_display = 1
       WIDGET_CONTROL, gis_base, MAP=1
       if gis_data_str.exp_in_a ge 0 then begin
          Plot_GIS,gis_data_str.curr_a_data
          Update_expinfo, $
               GIS_exphdr(gis_data_str.exp_in_a), GISrasterhdr, gis_exp_awidg
       endif else begin   
          if gis_data_str.gis_exp ge 0 then begin
             gis_data_str.exp_in_a = gis_data_str.gis_exp
             gis_data_str.curr_a_data = $
               gis_deselect(gisrasterhdr,gis_plot,gis_data_str.gis_exp,msg_widg)
             Plot_GIS,gis_data_str.curr_a_data
             Update_expinfo, $
                  GIS_exphdr(gis_data_str.gis_exp), GISrasterhdr, gis_exp_awidg
          endif
       endelse
       XMANAGER, "gis",gis_base
       widget_control,gis_i_done,sens=(ops_mode eq 0)
   ENDIF

;
;  switch on Display PHA mode
;            =======
;
   if value eq 'OPTN_DSP_PHA' then begin
      pha_menu
      XMANAGER, "pha", pha_base
   endif


;
;  want display of VDS raster header information plus exposure updates
;                  === ======                         ========

   IF value eq 'OPTN_VDS' then begin
      if not ops_mode then begin
          header_vds_menu
          WIDGET_CONTROL, header_v_base, MAP=1
          XMANAGER, "header_v",header_v_base
          if last_header eq 'VDS' then begin
             if n_elements(packet_header) gt 0 then disp_vds_hdr, packet_header
             if n_elements(VDSrasterhdr) gt 0 then disp_vds_hdr, VDSrasterhdr
             if n_elements(scnt_str) gt 0 then disp_vds_hdr, scnt_str
             if n_elements(ExpHdr) gt 0 then disp_vds_hdr, ExpHdr
          endif
          widget_control,vds_h_done,sens=(ops_mode eq 0)
       endif else begin
          bell
          widget_control, msg_widg, set_val='System is in DATA DRIVEN mode'
       endelse
   ENDIF

;
;  want display of GIS RASTER header information plus EXPOSURE updates
;                  === ======                         ========
   IF value eq 'OPTN_GIS' then begin
      if not ops_mode then begin
          header_gis_menu
          WIDGET_CONTROL, header_g_base, MAP=1
          XMANAGER, "header_g",header_g_base
          if last_header eq 'GIS' then begin
            if n_elements(packet_header) gt 0 then disp_gis_hdr, packet_header
            if n_elements(GISrasterhdr) gt 0 then disp_gis_hdr, GISrasterhdr
            if n_elements(scnt_str) gt 0 then disp_gis_hdr, scnt_str
            if n_elements(ExpHdr) gt 0 then disp_gis_hdr, ExpHdr
          endif
          widget_control,gis_h_done,sens=(ops_mode eq 0)
       endif else begin
          bell
          widget_control, msg_widg, set_val='System is in DATA DRIVEN mode'
       endelse
   ENDIF

;
;  want to display contents of Deferred command store
;                              ======================

   IF (value eq 'OPTN_DSP_DCS') THEN BEGIN
       dcs_menu
   ENDIF

;
;  want to display Current Cunning Plan
;                  ====================

   IF (value eq 'OPTN_DSP_PLN') THEN BEGIN
       ops_plan_menu
   ENDIF


;
;  want display of contents of special "DEFERRED" packet
;                                       ========

   IF value eq 'OPTN_SP_DEF' then begin
       sp_request = '02'x
       sp_def_menu
       WIDGET_CONTROL, sp_def_base, MAP=1
       XMANAGER, "sp_def",sp_def_base
   ENDIF

;
;  want display of contents of special "IEF" packet
;                                       ===

   IF value eq 'OPTN_SP_IEF' then begin
       sp_request = '0E'x
       sp_ief_menu
       WIDGET_CONTROL, sp_ief_base, MAP=1
       XMANAGER, "sp_ief",sp_ief_base
   ENDIF

;
;  want display of contents of special "HEALTH" packet
;                                       ======

   IF value eq 'OPTN_SP_HM' then begin
       sp_request = '08'x
       sp_health_menu
       WIDGET_CONTROL, sp_health_base, MAP=1
       XMANAGER, "sp_health",sp_health_base
   ENDIF


;
;  want display of contents of special "IMIF (MCU support)" packet
;                                       ===================

   IF value eq 'OPTN_SP_MCU' then begin
       sp_request = '01'x
       sp_imif_menu
       WIDGET_CONTROL, sp_imif_base, MAP=1
       XMANAGER, "sp_imif",sp_imif_base
   ENDIF

;
;  want display of contents of special "IMIF interface module" packet
;                                       ======================

   IF value eq 'OPTN_SP_IMIF' then begin
       sp_request = '09'x
       sp_imifim_menu
       WIDGET_CONTROL, sp_imifim_base, MAP=1
       XMANAGER, "sp_imifim",sp_imifim_base
   ENDIF


;
;  want display of contents of special "RASTER TABLE" packet
;                                       ============

   IF value eq 'OPTN_SP_RT' then begin
       sp_request = '04'x
       gen_title = 'Raster Table Dump'
       sp_gen_menu
       WIDGET_CONTROL, sp_gen_base, MAP=1
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "LINE LIST TABLE" packet
;                                       ===============

   IF value eq 'OPTN_SP_LL' then begin
       sp_request = '03'x
       gen_title = 'Data Extraction Table Dump'
       sp_gen_menu
       WIDGET_CONTROL, sp_gen_base, MAP=1
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF


;
;  want display of contents of special "SEQUENCE TABLE" packet
;                                       ==============

   IF value eq 'OPTN_SP_ST' then begin
       sp_request = '05'x
       gen_title = 'Sequence Table Dump'
       sp_gen_menu 
       WIDGET_CONTROL, sp_gen_base, MAP=1
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "HARDWARE TABLE" packet
;                                       ==============

   IF value eq 'OPTN_SP_HARD' then begin
       sp_request = '0a'x
       gen_title = 'VDS Hardware Table Dump'
       sp_gen_menu 
       WIDGET_CONTROL, sp_gen_base, MAP=1
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  want display of contents of special "MODE TABLE" packet
;                                       ==========

   IF value eq 'OPTN_SP_MT' then begin
       sp_request = '0b'x
       gen_title = 'Mode Table Dump'
       sp_gen_menu 
       WIDGET_CONTROL, sp_gen_base, MAP=1
       XMANAGER, "sp_gen",sp_gen_base
   ENDIF

;
;  switch on reception of RAW GIS data
;                         =======
;
   if value eq 'OPTN_RAW_GIS' then begin
      raw_gis_request = 1
      raw_gis_menu
      WIDGET_CONTROL, raw_gis_base, MAP=1
      XMANAGER, "raw_gis",raw_gis_base
   endif

;
;  switch on reception of RAW VDS data
;                         =======
;
   if value eq 'OPTN_RAW_VDS' then begin
      raw_vds_request = 1
      raw_vds_menu
      WIDGET_CONTROL, raw_vds_base, MAP=1
      XMANAGER, "raw_vds",raw_vds_base
   endif

;
;  switch on Monitor VDS mode
;            =======
;
   if value eq 'OPTN_MON_VDS' then begin
      v_monitor_mode = 1
      mon_menu
      XMANAGER, "mon", mon_base
   endif

;
;  switch on Monitor GIS mode
;            =======
;
   if value eq 'OPTN_MON_GIS' then begin
      g_monitor_mode = 1
      mon_menu
      XMANAGER, "mon", mon_base
   endif

;
;  switch on Monitor mechanisms mode
;            =======
;
   if value eq 'OPTN_MON_MEC' then begin
      m_monitor_mode = 1
      mon_menu
      XMANAGER, 'mon', mon_base
   endif

;
;  request change to input MODE
;                          ====

   IF (value EQ 'CONT_MODE') then begin 
;
;  if we are still running then warn and ignore
;
      if sci_going then begin
         bell,3
         WIDGET_CONTROL, msg_widg, /append, set_val=' '
         WIDGET_CONTROL, msg_widg, /append, $
                         SET_V="Please STOP acquisition before changing modes."
      endif else begin

;
;  which mode are we in?
;
  
         if sci_mode eq 1 then begin
            widget_control,mode_base,set_val='Replay'
            sci_mode = 0
            widget_control,pbase(0),map=0
            widget_control,pbase(1),map=1
            widget_control,pfbase(0),map=0
            widget_control,pfbase(1),map=1
         endif else begin
            widget_control,mode_base,set_val='Realtime'
            sci_mode = 1
            widget_control,pbase(1),map=0
            widget_control,pbase(0),map=1
            widget_control,pfbase(1),map=0
            widget_control,pfbase(0),map=1
         endelse
      endelse
   ENDIF


;
;  request change DRIVEN mode
;                 ======

   if (value eq 'DRIV_MODE') then begin       
      if ops_mode eq 0 then begin
         widget_control,driven_base,set_val='Data driven'
         ops_mode = 1
      endif else begin
         widget_control,driven_base,set_val='Command driven'
         ops_mode = 0
      endelse
;
;  disable the Done buttons in Data driven mode and v.v.
;
      mode = (ops_mode eq 0)
      if xregistered('vds')      then widget_control,vds_i_done,sens=mode
      if xregistered('header_v') then widget_control,vds_h_done,sens=mode
      if xregistered('gis')      then widget_control,gis_i_done,sens=mode
      if xregistered('header_g') then widget_control,gis_h_done,sens=mode
   endif

;
;  request change to LOOK BACK mode
;                    =========      

   if (value eq 'LBACK_MODE') then begin       
      if lback_mode eq 0 then begin
         widget_control,lookback_base,set_val='Lookback-ON'
         lback_mode = 1
      endif else begin
         widget_control,lookback_base,set_val='Lookback-OFF'
         lback_mode = 0
      endelse
   endif

;
;  request change to MEMORY DUMP mode
;                    ===========      

   if (value eq 'MDUMP_MODE') then begin       
      if mdump_mode eq 0 then begin
         if getenv('CDS_MEM_DUMP_W') eq '' then begin
            bell
            widget_control, msg_widg, /append,$
               set_val='*** Warning: $CDS_MEM_DUMP_W is not defined. '+$
                       'Memory cannot be saved to disk.'
         endif else begin
            widget_control,mdump_base,set_val='Memory dump-ON'
            widget_control, mem_info(1), map=1
            widget_control, mem_info(0), map=0
            mdump_mode = 1

            pmdump_data = lonarr(131072)  ; ie 128k
            smdump_data = lonarr(131072)

            sloc_start = -1L
            ploc_start = -1L
            ploc_end = 200000L
            sloc_end = 200000L
            pcycle = 0
            scycle = 0
            dump_ev = ev
         endelse

      endif else begin

         widget_control,mdump_base,set_val='Memory dump-OFF'
         widget_control, mem_info(1), map=0
         widget_control, mem_info(0), map=1
         mdump_mode = 0
         if getenv('CDS_MEM_DUMP_W') ne '' then begin
            dumppf = concat_dir('$CDS_MEM_DUMP_W','primary.dump')
            dumpsf = concat_dir('$CDS_MEM_DUMP_W','secondary.dump')

            mem = pmdump_data
            if max(mem) eq 0 and min(mem) eq 0 then begin
               bell
               widget_control, msg_widg,$
                   set_v='Primary memory array was empty, NOT dumped to disk',/append 
            endif else begin
               save,/xdr,mem,file=dumppf
               widget_control, msg_widg,set_v='Primary memory array dumped to disk',/append 
               bootinfo, mem, group=main_base
            endelse

            mem = smdump_data
            if max(mem) eq 0 and min(mem) eq 0 then begin
               bell
               widget_control, msg_widg,$
                   set_v='Secondary memory array was empty, NOT dumped to disk',/append 
            endif else begin
               save,/xdr,mem,file=dumppf
               widget_control, msg_widg,set_v='Secondary memory array dumped to disk',/append 
            endelse

            mem = 0
            pmdump_data = 0
            smdump_data = 0
         endif else begin
            widget_control, msg_widg, /append,$
               set_val='*** Warning: CDS_MEM_DUMP_W is not defined. '+$
                       'Memory was NOT saved to disk.'
         endelse
      endelse
   endif

;
;  request for HELP
;              ====
   cfont1="-adobe-courier-bold-r-normal--18-180-75-75-m-110-iso8859-1"
   if strmid(value,0,4) eq 'HELP' then begin
      widg_help,'stm.hlp',font=cfont1,tfont=cfont1,$
                 title='Help for Science Telemetry Monitor.',group=main_base
   endif

ENDIF

   
;
; on all but the 'quit' button the code will fall through to here on each 
; event so code the UT and display if in realtime.
;

widget_control, ev.id, get_uvalue=uvalue
if (uvalue eq 'ut_update') then begin
   if sci_mode eq 1 and sci_going then begin
      get_utc, curr_ut, /ecs
      widget_control,ev.top, $
                  tlb_set_title = 'Science Telemetry Monitor -  <'+$
                                   strmid(curr_ut,0,19)+'>'
   endif 
   widget_control,ev.top, timer = 1.0d0
endif
   

END
