;+
; Project     : SOHO - CDS     
;                   
; Name        : STM_MENU
;               
; Purpose     : Define the operations Science Telemetry Monitor main window. 
;               
; Explanation : 
;               
; Use         : Only called from STM
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only internal use in science telemetry monitor package
;               
; Side effects: None
;               
; Category    : Telemetry
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;               FM version by C D Pike, RAL, 7-Oct-93  
;
; Written     : Operations version started July 94
;               
; Modified    : Added PAUSE button.  CDP, 11-Jan-95
;               Delete unused special packets.  CDP, 27-Jan-95
;               Add optional lookback mode.  CDP, 5-Jun-95
;               Added help message about toggle mode buttons.  CDP, 21-Jun-95
;               Give "start packet' widget a user value.  CDP, 11-Oct-95
;               Include memory dumping.  CDP, 12-Oct-95
;               Added ops plan viewer.   CDP, 15-nov-95
;               Add study title display. CDP, 12-Dec-95
;               Add memory dump % display and call bootinfo.  CDP, 11-Jan-96
;               Update layout for IDL v4.  CDP, 20-Aug-96
;               Adjusted message window size.  CDP, 20-Feb-98
;               And again                     CDP, 16-Jun-98
;
; Version     : Version 13, 16-Jun-98
;-            
 
PRO stm_menu


;
;  main COMMON variables
;
@MainWidgets.com
@Mode.com
@GISData.com
@VDSData.com
@Colours.com
@Base_Offsets.com



;
;  large bold font
;
cfont1="-adobe-courier-bold-r-normal--18-180-75-75-m-110-iso8859-1"
cfont2="-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"

;
;  get base position and size
;
tp_offsets

;
;  define main widget
;
main_base = WIDGET_BASE (TITLE='CDS Science Telemetry Monitor', $
                         /FRAME, /COLUMN,$
                         xsize=stm_menu_off(2),ysize=stm_menu_off(3), $
                         xoffset=stm_menu_off(0),yoffset=stm_menu_off(1))


menu_base = WIDGET_BASE (main_base, /ROW, space=25)

;
;  create the exit "DONE" button
;
doneid = widget_button(menu_base, value='EXIT', uvalue='Done', font=cfont2)

;
;  the START/STOP buttons
;
start_base = widget_button(menu_base,frame=3,uvalue='CONT_STRT',$
                            val='Start',font=cfont2)

stop_base = widget_button(menu_base,frame=3,uvalue='CONT_STOP',$
                            val='Stop',font=cfont2)
sci_going = 0
widget_control,stop_base,sens=0

;
;  the PAUSE button
;
pause_base = widget_button(menu_base,frame=3,uvalue='CONT_PAUS',$
                            val='Pause',font=cfont2)
sci_pause = 0

;
;  help button
;
dummyh   = widget_button(menu_base,value='Help',uvalue='HELP', $
                         frame=3, font=cfont2)


;
;  and the pulldown menu for the display options
;


XPDmenu, ['"Display Options"{',                                              $
                      '"Review"                                OPTN_REV',    $

                      '"Header Info"{',                                      $
                                     '"VDS-raster"             OPTN_VDS',    $
                                     '"GIS-raster"             OPTN_GIS',    $
                                   '}',                                      $

                     '"View specials"{',                                     $
                                 '"Deferred"              OPTN_SP_DEF', $
                                 '"MCU backup        "    OPTN_SP_MCU', $ 
                                 '"Data Extraction table" OPTN_SP_LL',  $
                                 '"Raster table"          OPTN_SP_RT',  $  
                                 '"Sequence table"        OPTN_SP_ST',  $
                                 '"Health module"         OPTN_SP_HM',  $
                                 '"IMIF interface module" OPTN_SP_IMIF',$
                                 '"VDS Hardware table"    OPTN_SP_HARD',$
                                 '"Mode table"            OPTN_SP_MT',  $
                                 '"Solar event flag parameters" OPTN_SP_IEF', $
                                    '}',                                     $

                     '"Raw Data" {',                                         $
                                  '"GIS"                       OPTN_RAW_GIS',$
                                  '"VDS"                       OPTN_RAW_VDS',$
                                '}',                                         $

                     '"Monitor" {',                                          $
                                 '"GIS"                        OPTN_MON_GIS',$
                                 '"VDS"                        OPTN_MON_VDS',$
                                 '"Mechanisms"                 OPTN_MON_MEC',$
                               '}',                                          $
                     '"Display VDS"                            OPTN_DSP_VDS',$
                     '"Display GIS"                            OPTN_DSP_GIS',$
                     '"Display DCS"                            OPTN_DSP_DCS',$
                     '"Display GIS-PHA"                        OPTN_DSP_PHA',$
                     '"Display current PLAN"                   OPTN_DSP_PLN',$
                   '}'],$
   menu_base, BASE=option_base, font=cfont2


;
;  second layer..............
;


info_base= WIDGET_BASE(main_base,/column,space=1,frame=2)

  
info_base_b = widget_base(info_base, /row, spac=40)
;
; make current mode button
;
mode_base = widget_button(info_base_b,frame=3,uvalue='CONT_MODE',$
                          val='Realtime',font=cfont1)
sci_mode = 1

driven_base = widget_button(info_base_b,frame=3,uvalue='DRIV_MODE',$
                            val='Command Driven',font=cfont1)
ops_mode = 0


look_dump = widget_base(info_base_b, /column)  
lookback_base = widget_button(look_dump,frame=3,uvalue='LBACK_MODE',$
                            val='Lookback-OFF',font=cfont1)
lback_mode = 0
mdump_base = widget_button(look_dump,frame=3,uvalue='MDUMP_MODE',$
                            val='Memory dump-OFF',font=cfont1)
mdump_mode = 0


info_base_a = widget_base(info_base, /row)  
dummy_widg =  WIDGET_LABEL(info_base_a, xoffset=100,$
                           value='Toggle buttons to set operational modes',$
                           font=cfont2)


;
;  make memory dump display widget
;
mem_info = lonarr(2)
dummy = WIDGET_BASE(info_base_a)

;
;  create blank level for when in memory dump not in progress
;
mem_info(0) = widget_base(dummy,map=0)

mem_info(1)    = widget_base(dummy,map=0,/row,/frame)
dummy2       = WIDGET_LABEL(mem_info(1), VALUE='Primary memory dump progress: ')
mdump_widg     = WIDGET_TEXT(mem_info(1), xsize=10, ysize=1)
widget_control, mdump_widg, set_val='   None'
                        
;
;  third layer..............
;


packet_base= WIDGET_BASE(main_base,/column)

  
;
; make packet number widget
;
pkt_base = widget_base(packet_base,/row)
dummy = WIDGET_BASE(pkt_base, /ROW)
dummy_widg =  WIDGET_LABEL(dummy, VALUE='Packets received:')
packet_widg = WIDGET_TEXT(dummy, xsize = 15, ysize=1)

;
;  make start packet widget
;
pbase = lonarr(2)
dummy = WIDGET_BASE(pkt_base)

;
;  create blank level for when in real time
;
pbase(0) = widget_base(dummy,map=0)

pbase(1) = widget_base(dummy,map=0,/row)
dummy1   = widget_button(pbase(1),value='Select TM file',uvalue='CONT_GTTM')


;
;  make replay file widget
;
pfbase = lonarr(2)
dummy = WIDGET_BASE(packet_base)

;
;  create blank level for when in real time
;
pfbase(0) = widget_base(dummy,map=0)

pfbase(1)    = widget_base(dummy,map=0,/row)
dummy2       = WIDGET_LABEL(pfbase(1), VALUE='Current file: ')
rep_widg     = WIDGET_TEXT(pfbase(1), xsize=21, ysize=1)
widget_control, rep_widg, set_val='   None'

sp_widg      = WIDGET_LABEL(pfbase(1), VALUE='Start Packet: ')
spacket_widg = WIDGET_TEXT(pfbase(1), xsize=6, ysize=1, /editable, uvalue='dum')
widget_control,spacket_widg,set_val='0'

;
;  make single line for current study description
;
dummy = WIDGET_BASE(main_base, /ROW)
dummy_widg =  WIDGET_LABEL(dummy, VALUE='Current study:')
study_widg = WIDGET_TEXT(dummy, xsize=60, ysize=1,font=cfont2)
                        
   

;
; make message window widget
;
dummy = WIDGET_BASE(main_base, /column, /FRAME, YOFFSET=-100)
dummy_widg = WIDGET_LABEL(dummy, VALUE=' Messages   : ')
msg_widg = WIDGET_TEXT(dummy, XSIZE = 100, YSIZE=15, /scroll)




;
;  realise the main widget to make it all happen
;
WIDGET_CONTROL, /REALIZE , main_base

WIDGET_CONTROL, main_base, /CLEAR_EVENT


;
;  set it all going
;
XMANAGER, 'stm', main_base
   

END

