;+
; Project     : SOHO - CDS     
;                   
; Name        : STM_STAT_MENU
;               
; Purpose     : Defines the status details window.
;               
; Explanation : Creates the widgets which form the window within which
;               the STM status is displayed.
;               
; Use         : stm_stat_menu
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use in EGSE calibration programs only.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 1-Aug-94
;               
; Modified    : 
;
; Version     : Version 1, 1-Aug-94
;-            

PRO stm_stat_menu

;
;  COMMON blocks for widget id communication
; 
@MainWidgets.com
@Status.com
@Mode.com

;
;  guard against trigger happy users
;
if xregistered('stm_stat') then begin
  widget_control,msg_widg,set_val='Steady with the trigger!',/append
  return
endif


;
;  create main base
;
status_base = WIDGET_BASE(title='Current STM status',  /FRAME, /COLUMN,$
                       group_leader = main_base, xoffset=500)

;
;  and subsidiary ones
;
menu_base  = WIDGET_BASE(status_base, /ROW)
info_base  = WIDGET_BASE(status_base, /ROW)
info_abase = WIDGET_BASE(info_base, /COLUMN, /FRAME)
m1_widg    = WIDGET_BASE(menu_base, /ROW)


;
;  'Done' button to exit
;
doneid = widget_button(m1_widg, value='Done', uvalue='Done')

              
;
;  widgets for display of details
;
stat_exp_awidg = lonarr(5)

a1  = WIDGET_BASE(info_abase, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='Data input mode:')
case  sci_mode of 
     0: id = 'Replay'
     1: id = 'Realtime'
  else: id = 'Error'
endcase

stat_exp_awidg(0) = WIDGET_TEXT(a1,XSIZE=12,YSIZE=1,value=id)


a2  = WIDGET_BASE(info_abase, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='Acquisition status: ')
if sci_going then id = 'Receiving telemetry' else id = 'Stopped'
stat_exp_awidg(1) = WIDGET_TEXT(a2,XSIZE=12,YSIZE=1,value=id)


a3  = WIDGET_BASE(info_abase, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='Operational mode: ')
if ops_mode eq 0 then id = 'Command driven' else id = 'Data driven'
stat_exp_awidg(2) = WIDGET_TEXT(a3,XSIZE=15,YSIZE=1,value=id)


;
;  make it all appear
;
WIDGET_CONTROL, status_base, /realize

end
