;+
; Project     : SOHO - CDS     
;                   
; Name        : STM_WARN_DCS
;               
; Purpose     : Warn if DCS has bad status.
;               
; Explanation : The Deferred Command Store holds the key to triggering planned
;               studies.  When the store is dumped (usually by DFLOAD) this
;               routine is called to check the stores status and warn the 
;               operator if all is not well.
;               
; Use         : Called from WORKPROC
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : XACK
;
; Common      : MainWidgets
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Telemetry
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 18-Dec-95
;               
; Modified    : Eliminate the table EMPTY warning.  CDP, 11-Jan-96
;               Kill message if of kind "Unknown".  CDP, 31-May-96
;               Did that again, maybe 'store empty' was a mistake?
;                                                   CDP, 26-Jul-96
;
; Version     : version 4, 26-Jul-96
;-            

pro stm_warn_dcs

;
;  common for communication of status value read in WORKPROC
;
@MainWidgets.com

;
;  anything wrong?
;
bad = 0

;
;  check individual bits and load message if bad
;
warn = strarr(7)
warn(0) = 'Deferred Command Store'

if dcs_status and '01'x then begin
   warn(1) = ''
endif else begin
   bad = 1
   warn(1) = 'Store DISABLED'
endelse

;==========
;if (dcs_status and '02'x) gt 0 then begin
;   bad = 1
;   warn(2) = 'Store EMPTY'
;endif else begin
;   warn(2) = ''
;endelse
;==========

if (dcs_status and '04'x) gt 0 then begin
   warn(3) = 'Store OVERFLOW'
   bad = 1
endif else begin
   warn(3) = ''
endelse

if (dcs_status and '08'x) gt 0 then begin
   warn(4) = 'Store COMMAND INVALID'
   bad = 1
endif else begin
   warn(4) = ''
endelse

if (dcs_status and '10'x) gt 0 then begin
   warn(5) = 'Store INVALID TIME'
   bad = 1
endif else begin
   warn(5) = ''
endelse

;===================
;if (dcs_status and '20'x) gt 0 then begin
;   warn(6) = 'DCS Store UNKNOWN ERROR'
;   widget_control, msg_widg, set_val=warn(6), /append
;endif else begin
;   warn(6) = ''
;endelse
;====================

;
;  if anything wrong then warn
;
if bad then begin
   n = where(warn ne '')
   warn = warn(n)
   xack,warn,group=main_base,/modal,/icon
   dcs_warned = 1
endif else begin
   dcs_warned = 0
endelse

end
