;+
; Project     : SOHO - CDS     
;                   
; Name        : SWAP_SCIHEAD
;               
; Purpose     : Swaps bytes and displays science header data.
;               
; Explanation : The integer variables in the science header structure require
;               byte swapping to make them intelligible.  If header displays
;               are turned on then the information is also pumped to the
;               appropriate widget.
;               
; Use         : swap_scihead, Header 
;    
; Inputs      : header     -  the data structure of type SciHeaderDef within
;                             the VDS or GIS raster structures (see 
;                             stm.pro for definitions).
;
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use within EGSE sci_ana program
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 25-Oct-93
;               
; Modified    : For name changes in v3.0 of packet format. 
;                                                   CDP, 27-Oct-93
;               Force some displays always hex, mask bits in slit position.
;                                                   CDP, 8-Feb-94
;               Do correct decode of slit position, CDP, 2-mar-94
;               Eliminate writing to widgets for operations version.
;                                                   CDP, 12-Aug-94
;               Mask 12 bit OPS values. CDP, 26-May-95
;
;
; Version     : Version 6, 26-May-95
;-            

PRO swap_scihead, Header

;
;  common which holds total number of exposures
;
@HeaderWidgets.com

;
; Byte swap all two byte values
;
Header.Scihead.DataExtWindowID = ByteSwap (Header.Scihead.DataExtWindowID)
Header.Scihead.SequenceID      = ByteSwap (Header.Scihead.SequenceID)
Header.Scihead.OPSLCoordinate  = (ByteSwap (Header.Scihead.OPSLCoordinate)) and 'fff'x
Header.Scihead.OPSRCoordinate  = (ByteSwap (Header.Scihead.OPSRCoordinate)) and 'fff'x
Header.Scihead.SlitPosition    = ByteSwap (Header.Scihead.SlitPosition)
;
;  decode slit position
;
slitpos_decode, Header.Scihead.SlitPosition, slitbits, slitpos
Header.Scihead.SlitPosition = slitpos

Header.Scihead.ExposureTime    = ByteSwap (Header.Scihead.ExposureTime)
Header.Scihead.StudyCounter    = ByteSwap (Header.Scihead.StudyCounter)
Header.Scihead.RasterCounter   = ByteSwap (Header.Scihead.RasterCounter)
Header.Scihead.DataCompOption  = ByteSwap (Header.Scihead.DataCompOption)
Header.Scihead.SciProcStatus   = ByteSwap (Header.Scihead.SciProcStatus)

;
;  form total number of exposures from number of mirror/slit positions
;  (fudge included to avoid zero values). Sent back in common block.
;
total_exp = (Header.Scihead.RasterLengthM > 1) * $
            (Header.Scihead.RasterLengthS > 1)


END
