;+
; Project     : SOHO - CDS     
;                   
; Name        : TM_GET_SIZE()
;               
; Purpose     : Gets the current size of a named file in bytes.
;               
; Explanation : Opens the file and does an fstat.  Needed as a separate
;               routine in STM realtime mode because fstat only records
;               the size when the file was opened, not necessarily its
;               current size.
;               
; Use         : IDL> fs = tm_get_size(file_name)
;    
; Inputs      : file_name - the file in question
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns size of file in bytes.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Telemetry
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 11-Jan-95
;               
; Modified    : 
;
; Version     : Version 1, 11-Jan-95
;-            

function tm_get_size, file

;
;  open file and get its size at that time
;
openr,lun,file,/get_lun
f = fstat(lun)
free_lun,lun

return, f.size

end
