;+
; Project     : SOHO - CDS     
;                   
; Name        : USECAL
;               
; Purpose     : Allows use of the calibration version of telemetry monitor.
;               
; Explanation : Switches the order of the subdirectories in the IDL search 
;               so that the calibration version of the CDS telemetry
;               monitoring software is used (in preference to the operations
;               version cf. USEOPS).
;               
;               Note that this is necessary because although the top level
;               routines have different names (calibration and stm) they use
;               procrdures and functions which have the same names but in some
;               instances behave differently.
;
; Use         : IDL> usecal
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : STR2ARR
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: IDL search path (!path) is rearranged.
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL.   12-Aug-94
;               
; Modified    : 
;
; Version     : Version 1, 12-Aug-94
;-            

pro usecal

;
;  find egse/cal directory in !path
;
ncal = where(strpos(str2arr(!path,delim=':'),'data_anal/egse/cal') ge 0)
ncal = ncal(0)

;
;  find egse/ops directory in !path
;
nops = where(strpos(str2arr(!path,delim=':'),'data_anal/egse/ops') ge 0)
nops = nops(0)


;
;  switch them around if necessary
;
if ncal gt nops then begin
   arr = str2arr(!path,delim=':')
   temp = arr(nops)
   arr(nops) = arr(ncal)
   arr(ncal) = temp
   
;
;  recreate !path
;
   !path = arr(0)
   for i=1,n_elements(arr)-1 do !path = !path + ':' + arr(i)

endif

end

      
