;+
; Project     : SOHO - CDS     
;                   
; Name        : USEOPS
;               
; Purpose     : Allows use of the operations version of telemetry monitor.
;               
; Explanation : Switches the order of the subdirectories in the IDL search 
;               so that the operations version of the CDS telemetry
;               monitoring software is used (in preference to the calibration
;               version cf. USECAL).
;
;               Note that this is necessary because although the top level
;               routines have different names in the two systems (calibration
;               and stm) they use  procedures which have the same names but
;               in some cases are different internally.
;               
;
; Use         : IDL> useops
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : STR2ARR
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: IDL search path (!path) is rearranged.
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL.   12-Aug-94
;               
; Modified    : 
;
; Version     : Version 1, 12-Aug-94
;-            

pro useops

;
;  find egse/cal directory in !path
;
ncal = where(strpos(str2arr(!path,delim=':'),'data_anal/egse/cal') ge 0)
ncal = ncal(0)

;
;  find egse/ops directory in !path
;
nops = where(strpos(str2arr(!path,delim=':'),'data_anal/egse/ops') ge 0)
nops = nops(0)

;
;  switch them around if necessary
;
if nops gt ncal then begin
   arr = str2arr(!path,delim=':')
   temp = arr(ncal)
   arr(ncal) = arr(nops)
   arr(nops) = temp
   
;
;  recreate !path
;
   !path = arr(0)
   for i=1,n_elements(arr)-1 do !path = !path + ':' + arr(i)

endif

end

      
