;+
; Project     : SOHO - CDS     
;                   
; Name        : VDS_DESELECT()
;               
; Purpose     : Loads the VDS data windows into a full (1024,1024) array.
;               
; Explanation : The VDS data are normally stored in an array of dimensions
;               (xlength, ylength, windows, exposure).  This routine deselects
;               those data into a full (1024,1024) array for ease of use.
;               
; Use         : image = vds_deselect(VDSrasterhdr, exp_no)
;    
; Inputs      : VDSrasterhdr  -  raster header structure
;               exp_no        -  exposure number to extract
;              
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns an integer array (1024,1024)
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Only for use within EGSE sci_ana programs.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 13-Dec-93
;               
; Modified    : Bugs for new structure, CDP, 13-Jan-94
;               Calculate offsets for display. CDP, 24-Feb-95
;               Flipped return image to account for redefinition of NIS1
;               being at higher CCD row numbers.  CDP, 17-Oct-95
;               Include use of vds_centre.  CDP, 20-Oct-95
;               Fix bug caused by background windows being used to calculate
;               the vds_offsets.  Background windows are assumed now to occur
;               in the top or bottom quarter of the CCD.  CDP, 09-Nov-95
;
; Version     : Version 6, 09-Nov-95
;-            

Function vds_deselect, vdsrasterhdr, exp_no

;
;  common for VDS image data and details
;
@VDSData.com

;
;  make sure we have valid parameters first
;
if (vdsrasterhdr.NumDataWindows le 0) or (exp_no lt 0) then return,0


;
;  create clear array to be used for output
;
image = intarr(1024,1024)

;
; loop for each window definition. 
;
have_off0 = 0
have_off1 = 0

for j = 0, vdsrasterhdr.NumDataWindows-1 do begin

   StartX  = vdsrasterhdr.VDSWin(J).StartX
   StartY  = vdsrasterhdr.VDSWin(J).StartY
   LengthX = vdsrasterhdr.VDSWin(J).LengthX
   LengthY = vdsrasterhdr.VDSWin(J).LengthY
   
;
;  .. and insert it into output array
;
   image(StartX, 1024-StartY-LengthY) = $
            vds_image(0:LengthX-1,0:LengthY-1,j,exp_no)

   if not have_off0 and (StartY lt (vds_data_str.vds_centre+1)) then begin
      if (LengthY le 120) and (StartY gt 255) then begin
         vds_data_str.vds_offset(0) = StartY - (vds_data_str.vds_centre-119) - $
                                               (120-LengthY)/2
         have_off0 = 1
      endif
   endif
  
   if not have_off1 and (StartY ge (vds_data_str.vds_centre+1)) then begin
      if (LengthY le 120) and (StartY lt 767) then begin
         vds_data_str.vds_offset(1) = StartY - (vds_data_str.vds_centre+1) - $
                                               (120-LengthY)/2
         have_off1 = 1
      endif
   endif


  
endfor
;
;  return with deselected image
;
return,rotate(image,7)

END
