;+
; Project     : SOHO - CDS     
;                   
; Name        : VDS_EVENT
;               
; Purpose     : Processes events from the VDS_MENU.
;               
; Explanation : Any events originating within the widgets realized by 
;               VDS_MENU are handled by this routine.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ev  -  the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with VDS_MENU in EGSE sci_ana routines.
;               
; Side effects: None
;               
; Category    : EGSE
;               
; Prev. Hist. : EM version by Arnulf, Oct-92
;
; Written     : FM version by C D Pike, RAL, 26-Oct-93
;               
; Modified    : To recognise 'Done' button, CDP, 28-Oct-93
;               To include statistics, CDP, 10-Nov-93
;               To include message line, CDP, 9-Dec-1993
;               To include handling of profile plots, CDP, 4-Jan-94
;               To generalize plotting Y-coord limits, CDP, 8-Mar-94
;               Modify message to user of Zoom.  CDP, 22-May-95
;               Add auto-scale option for hardcopy.  CDP, 26-May-95
;               Added extra info to hardcopy plot.  CDP, 21-Jun-95
;               Use TVPRINT for hardcopy.  CDP, 4-Jul-95
;               Adjust definition of VDS offsets.  CDP, 17-Oct-95
;               Start to use vds_centre.  CDP, 20-Oct-95
;
; Version     : Version 11, 20-Oct-95
;-            

PRO vds_event, ev

;
;  COMMON blocks for widget id's
;
@MainWidgets.com
@VDSWidgets.com
@Images.com
@Packets.com
@VDSData.com
@Profiles.com
@Colours.com
@Base_Offsets.com

      
;
;  interpret type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  could be from the draw widgets as a request to plot a profile
;  or just to browse the wavelength/intensity space
;
if (type eq 'WIDGET_DRAW') then begin
   widget_control,ev.id,get_uvalue=uv
   pdata = intarr(1024,320)

;   y1 = (vds_data_str.vds_centre+1) + vds_data_str.vds_offset(1)
;   y2 = y1 + 149
;   y3 = (vds_data_str.vds_centre - 119) + vds_data_str.vds_offset(0) - 30
;   y4 = y3 + 149


   y1 = vds_sp.n2_cen_s - (vds_sp.nis_ht-1)/2
   y2 = y1 + 159
   y3 = vds_sp.n1_cen_s - (vds_sp.nis_ht-1)/2
   y4 = y3 + 159
   if uv eq 'IMAGE_A' then begin
      pdata(*,0:159)   = vds_data_str.curr_a_img(*,y1:y2)
      pdata(*,160:319) = vds_data_str.curr_a_img(*,y3:y4)
   endif
   if uv eq 'IMAGE_B' then begin
      pdata(*,0:159)   = vds_data_str.curr_b_img(*,y1:y2)
      pdata(*,160:319) = vds_data_str.curr_b_img(*,y3:y4)
   endif
   if plotting_prof then begin
      if ev.release eq 0 then begin
         widget_control,prof_base,show=1
         prof_x = ev.x
         prof_y = ev.y
         plot_prof,pdata,strmid(uv,6,1)
      endif
   endif else begin
      if ev.x ge 0 and ev.x le 1023 and ev.y ge 0 and ev.y le 319 then begin
         if ev.y gt 159 then sp = 'N1' else sp = 'N2'
         wave = pix2wave(sp,ev.x,/limit)
         ltxt = 'Wavelength: '+ $
                 string(wave,form='(f7.3)')+' A.   '+$
                'Intensity: '+string(pdata(ev.x,ev.y),form='(i6)')
         widget_control,vds_msg_widg,set_val=ltxt
      endif
   endelse
endif

;
;  or could have been a button
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value
 
;
;  Done (ie exit) request received
; 
   IF (value EQ 'Done') THEN BEGIN
      widget_control,vds_base, tlb_get_offset=boff
      widget_control,vds_base, tlb_get_size = bsize
      vds_menu_off = [boff,bsize]
      tp_offsets, /write
      WIDGET_CONTROL, vds_base, /destroy
      vds_display = 0
      plotting_prof = 0
      prof_area = 0
      last_window = ' '
   ENDIF

;
;  request to zoom the "A" or "B" image
;
  
   IF ((value EQ "Zoom A") OR $
       (value EQ "Zoom B")) THEN BEGIN
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=0 
      WIDGET_CONTROL,vds_msg_widg, SET_VALUE=$
           "POSITION CURSOR ON ORIGINAL IMAGE ONLY, "+$
                     "Middle mouse button for new zoom factor, "+$
                     "Right button to quit"   
      
      IF (value EQ "Zoom A") THEN $
         WIDGET_CONTROL,vds_Awidg, GET_VALUE=window $
      ELSE $
         WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window

      WSET,window
      xyouts,150,310,$
          'TO EXIT FROM ZOOM - PRESS RIGHT HAND MOUSE BUTTON ON THIS IMAGE.',$
          /device
      TVZOOM,/cont,xsize=400,ysize=400
;      tv,indgen(1024,10)*0L,0,310,/device
      WSET,window

      if (value EQ "Zoom A") then begin
         Plot_VDS, vds_awidg, vds_data_str.curr_a_img
      endif else begin
         Plot_VDS, vds_bwidg, vds_data_str.curr_b_img
      endelse

      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=1    
   ENDIF

;
;  request for cursor defined STATISTICS in the "A" or "B" image
;
  
   IF ((value EQ "Box cursor in A") OR $
       (value EQ "Box cursor in B")) THEN BEGIN
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=0 
      WIDGET_CONTROL,vds_msg_widg, SET_VALUE=$
                     "Left button for box position "+ $
                     "Middle for box size, Right to exit."   

;
;  get displayed data setup
;
      pdata = intarr(1024,320)
      y1 = vds_sp.n2_cen_s - (vds_sp.nis_ht-1)/2
      y2 = y1 + 159
      y3 = vds_sp.n1_cen_s - (vds_sp.nis_ht-1)/2
      y4 = y3 + 159
      
      if (value EQ "Box cursor in A") then begin
         WIDGET_CONTROL,vds_Awidg, GET_VALUE=window 
         pdata(*,0:159)   = vds_data_str.curr_a_img(*,y1:y2)
         pdata(*,160:319) = vds_data_str.curr_a_img(*,y3:y4)
      endif else begin 
         WIDGET_CONTROL,vds_Bwidg, GET_VALUE=window
         pdata(*,0:159)   = vds_data_str.curr_b_img(*,y1:y2)
         pdata(*,160:319) = vds_data_str.curr_b_img(*,y3:y4)
      endelse

      WSET,window
;
;  set starting values for box cursor and call it
;
      sx = 20 & sy = 20 & px = 512 & py = 160
      select_box,sx,sy,px,py,/init
;
;  add display offset in Y
;
;      py = py + vds_disp_yst
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=1    

;
;  find out which exposure we are dealing with
;  and collect and display the statistics
;
      vds_stats,pdata,sx,sy,px,py,average,sigma,vmax,vmin
;      if (value EQ "Box cursor in A") then begin
;         vds_stats,vds_data_str.curr_a_img,sx,sy,px,py,average,sigma,vmax,vmin
;      endif else begin 
;         vds_stats,vds_data_str.curr_b_img,sx,sy,px,py,average,sigma,vmax,vmin
;      endelse

   ENDIF

;
;  All data in image
;

   if (value EQ "All image A") THEN BEGIN
      vds_stats, vds_data_str.curr_a_img, /all
   endif

   if (value EQ "All image B") THEN BEGIN
      vds_stats, vds_data_str.curr_b_img, /all
   endif


;
;  request to plot PROFILES of displayed images
;
   IF (value EQ "Profile") THEN BEGIN
      WIDGET_CONTROL, vds_ana_widg, SENSITIVE=0    
      tvlct,rr,gg,bb,/get
      n = n_elements(rr)-2
      tvlct,[rr(0:n),255],[gg(0:n),255],[bb(0:n),255]
      prof_menu,strmid(value,8,1)
   ENDIF


;
;  adjust current LOOK-UP TABLE
;
   IF (value EQ "Adjust LUT") THEN BEGIN 
      XLOADCT   
      tvlct,rr,gg,bb,/get
   ENDIF

;
;  Reload standard LOOK-UP TABLE
;
   IF (value EQ "Reload default LUT") THEN BEGIN 
      tp_coltable   
      tvlct,rr,gg,bb,/get
   ENDIF


;
;  new selection of EXPOSURE for image "B"
;
   IF (value EQ "Select exposure in B") THEN BEGIN
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN
      Update_ExpInfo, VDS_exphdr(exp_no), VDSrasterhdr, vds_exp_bwidg
      vds_data_str.exp_in_b = exp_no
      vds_data_str.curr_b_img = vds_deselect(vdsrasterhdr,$
                                vds_data_str.exp_in_b-vds_data_str.first_in_mem)
      Plot_VDS, vds_bwidg, vds_data_str.curr_b_img
      prof_area = 0
      last_window = ' '
   ENDIF


;
;  new selection of EXPOSURE for image "A"
;
   IF (value EQ "Select exposure in A") THEN BEGIN
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN
      Update_ExpInfo, VDS_exphdr(exp_no), VDSrasterhdr, vds_exp_awidg
      vds_data_str.exp_in_a = exp_no
      vds_data_str.curr_a_img = vds_deselect(vdsrasterhdr,$
                                vds_data_str.exp_in_a-vds_data_str.first_in_mem)
      Plot_VDS, vds_awidg, vds_data_str.curr_a_img
      prof_area = 0
      last_window = ' '
   ENDIF

;
;  HARDCOPY requested
;
   if strmid(value,0,6) eq 'Window' then begin

      invert = strmid(value,10,1)
      if invert eq 'i' then invert = 1 else invert = 0

      w =strmid(value,7,1)
      if w eq'A' then begin
         im = vds_data_str.curr_a_img 
         widget_control, vds_awidg, get_val=hcwin
         exp_no = vds_data_str.exp_in_a
      endif else begin
         im = vds_data_str.curr_b_img
         widget_control, vds_bwidg, get_val=hcwin
         exp_no = vds_data_str.exp_in_b
      endelse

      wset, hcwin
      doy = utc2doy(str2utc(VDS_date_time(exp_no)))
      get_utc,utc
      seqc = strcompress(string('#',vdsrasterhdr.scihead.sequenceid,$
                         form='(a,i4)'),/rem)
      expc = strcompress(string('#',exp_no,form='(a,i4)'),/rem)

      label = 'Data taken: '+strmid(VDS_date_time(exp_no),0,19)+' '+$
               strcompress(string('(DOY=',doy,')',form='(a,i3,a)'),/rem)+$
               ' CDHS Seq '+seqc+' Exp. '+expc+' Plotted at: '+anytim2cal(utc) 


      tvprint, window=hcwin,reverse=invert,relative=0.85,title=label
      widget_control,vds_msg_widg,$
             set_val='      Print job spawned to '+getenv('PSLASER'),/append
      bell
   endif

;
;  display of FULL VDS image area requested
;
   IF (value EQ "Full VDS") THEN BEGIN
      Exp_Select, "VDS", exp_no 
      IF (exp_no EQ -1) THEN  RETURN;
      full_image = vds_deselect(vdsrasterhdr,exp_no-vds_data_str.first_in_mem)
      Scale_Image, full_image
      title = STRCOMPRESS(STRING("Full VDS Image from exposure number",exp_no))
      SLIDE_IMAGE, full_image, REGISTER=1, CONGRID=0, TITLE=title
  ENDIF


;
;  switch BACKGROUND subtraction ON
;         ==========

   if value eq 'On' then begin
      vds_back_sub = 1
      widget_control, vds_awidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_awidg, vds_data_str.curr_a_img
      widget_control, vds_bwidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_bwidg, vds_data_str.curr_b_img
   endif

;
;  switch BACKGROUND subtraction OFF
;         ==========

   if value eq 'Off' then  begin
      vds_back_sub = 0
      widget_control, vds_awidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_awidg, vds_data_str.curr_a_img
      widget_control, vds_bwidg, get_val=wind
      wset,wind & erase
      plot_vds, vds_bwidg, vds_data_str.curr_b_img
   endif


ENDIF

END
