;+
; Project     :	SOHO - CDS
;
; Name        :	SFDU_HELP
;
; Purpose     :	Program to return a detailed description of tape archiving.
;
; Explanation :	Although the XWINTAPE procedure prints messages to lead a 
;		user in the use of the tape archiving software, some users
;		may wish a more detailed description of the tape archiving
;		process.
;
; Use         :	SFDU_HELP, MESS_NUM, HELPTEXT
;
; Inputs      :	MESS_NUM: A counter to tell SFDU_HELP the current position
;			of the XWINTAPE procedure.
;
; Opt. Inputs :	None.
;
; Outputs     :	HELPTXT: A string array that contains the help text.
;
; Opt. Outputs:	None.
;
; Keywords    :	ERRMSG:	Returned error message.  Must be defined as a string
;			before passing to this procedure.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Data Handling, I/O, FITS, SFDU, Generic
;
; Prev. Hist. :	None.
;
; Written     :	Donald G. Luttermoser, GSFC/ARC, 11 May 1995
;
; Modified    :	Version 1, Donald G. Luttermoser, GSFC/ARC, 11 May 1995
;			Initial program.
;
; Version     :	Version 1,  11 May 1995
;-
;
PRO SFDU_HELP, MESS_NUM, HELPTEXT, ERRMSG=ERRMSG
;
ON_ERROR, 2	  ; Return to caller if error is encountered.
MESSAGE = ''	; Printed message if error is encountered.
;
; Check input parameters.
;
IF N_PARAMS() EQ 0 THEN BEGIN
	MESSAGE = 'Syntax:  SFDU_HELP, MESS_NUM, HELPTEXT'
	GOTO, HANDLE_ERROR
ENDIF
;
CASE MESS_NUM OF
	0:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 1',$
'  ',$
'The XWINTAPE procedure allows you to read or write tapes in any operating',$
'system environment.  It drives the program MAGTAPE which actually does the',$
'work.  Data files are all written in FITS format and stored on the tape as',$
'FITS files.  XWINTAPE & MAGTAPE allow the user to prepend the tape with',$
'a "detached" Standard Formatted Data Unit (SFDU) file that contains',$
'various characteristics (including filenames that follow the Consultative',$
'Committee for Space Data Systems (CCSDS) specifications) of the files.',$
'  ',$
'The default is for XWINTAPE & MAGTAPE to create and write (or read) an SFDU',$
'file to (from) the tape.  Note that before entering IDL, one should have',$
'set an environment variable (Unix) or logical name (VMS) of the form "MTn",',$
'where "n" is an integer between 0 and 9, that points to the name of the',$
'tape drive.  One can "override" the use of an SFDU by clicking on the',$
'appropriate button in the "Tape Header" box.  THIS MUST BE THE FIRST THING',$
'DONE BEFORE PRESSING ANY OTHER BUTTONS.  After clicking this button, OR NOT',$
'clicking if you plan on using SFDUs, click EITHER the "Read" or "Write"',$
'button in the "Tape Access" box.',$
'  ',$
'Note that a full write-up of the tape archiving procedures can be found in',$
'SoHO/CDS Software Note #28.'$
		]
		END
;
	1:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 2',$
'  ',$
'IDL has "built-in" functions to access a tape drive.  These IDL tape',$
'commands are only valid in a VMS environment.  However, the SoHO/CDS group',$
'has written procedures that emulate these commands in a Unix environment,',$
'which have the same names as their VMS counterparts and pass the same',$
'parameters.  However, the Unix versions of these functions will not work',$
'for versions of IDL earlier than 3.1 running in a Unix environment.  When',$
'such a condition is met, MAGTAPE will automatically switch to the "Unix mt',$
'& dd Commands" by default.  Also, the SoHO/CDS staff have noted that the',$
'IDL style commands under "DEC OSF/1 Unix" sometimes will not work -- the',$
'code either "freezes" or "crashes."  This is due to an IDL bug in the ',$
'"/NOSTDIO" keyword of the OPENU procedure.  Should you experience such a ',$
'problem, leave IDL, re-enter IDL and run XWINTAPE again.  This time however,',$
'click on the "Unix mt & dd Commands" button in the "Tape Override" box',$
'IMMEDIATELY after you select "Read" or "Write" tape access.',$
'  ',$
'Whatever action you take based on the information above, follow it by',$
'selecting the appropriate tape drive number (based upon whatever',$
'environment (Unix) or logical (VMS) variable you created before you entered',$
'IDL) in the pull-down menu of the "Tape Drive" widget.'$
		]
		END
;
	2:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 3',$
'  ',$
'The text box just below the "Message" box is labelled "Directory Name."',$
'Initially this box will contain the name of the current directory.  If you',$
'wish to change the current to a different directory from which to read or',$
'write the FITS files, move the cursor in this box and enter the new name.',$
'Once the desired directory name appears in the "Directory Name" box, click',$
'the "Accept Directory" box.',$
' ',$
'If you will be writing to a tape, the FITS files in the directory you have',$
'selected will appear in the large upper box.  If no FITS files are located',$
'in the selected directory or you typed in a non-existent directory, XWINTAPE',$
'will inform you of this problem.  One should then go back to the "Directory',$
'Name" box, type in the correct name and click the "Accept Directory"',$
'button again.',$
' ',$
'If you will be reading a tape, MAGTAPE will read the SFDU off of the tape',$
'and list the tape files in this top box.  Note that when the cursor turns',$
'into an "hourglass," the tape is being accessed and the XWINTAPE widget goes',$
'into a hibernation mode.',$
'  ',$
'Once the files are listed, select the FITS files you wish to read or write,',$
'one at a time.  Note that one can access the FITS headers of these files by',$
'clicking the "FITS Header" button anytime after this button becomes active.',$
'If all of the listed files are wanted, just click on the top entry',$
'(<Select All Displayed Files>).  Note that as the files are selected, they',$
'appear in the large bottom box.  Should you wish to remove files from the',$
'selected list, just click on the entries in the lower box.'$
		]
		END
;
	3:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 4',$
'  ',$
'Note that FITS headers of the files listed can be displayed by clicking',$
'the "FITS Header" box.  Use these headers to help you decide which files to',$
'select.',$
' ',$
'Once you have selected the FITS files you wish to access (i.e., by moving',$
'the filenames from the top to the bottom box), change any defaults',$
'(indicated by a "depressed" button in each box) you wish.  In particular:',$
'	Block Factor:	n x 2880 bytes/record for the tape [DEFAULT = 1].',$
'	Session Log:	Save the actions taken from this software in a log',$
'			 ASCII file named: tapexxxxxx.log, where the "xxxxxx"',$
'			 in this file name is the current date/time',$
'			 [DEFAULT = "save"].',$
'	Save SFDU File:	Save the SFDU created or read off of the tape in an',$
'			 ASCII file named: sfduxxxxxx.head, where, again,',$
'			 the "xxxxxx" represents the current date/time',$
'			 [DEFAULT = "no save"].',$
'	File Name Conv:	Override the default file naming convention -- see',$
'			 the doc_library listing for MAGTAPE or CDS Software',$
'			 Note #28 for a full description.',$
'	Valid CDS FITS:	Check to make sure that the FITS header and binary',$
'			 column data are valid for the CDS.  The header',$
'			 keywords are checked against the SFDU registration',$
'			 files.  The default is to make the check.  Note that',$
'			 only the first FITS file in a directory is checked.',$
'			 This check is only made for "tape writing" runs.',$
'Note that all other options should have been selected before getting to this',$
'point.',$
'  ',$
'Should you wish to abort this run, simply depress the  "!! Abort !!" button',$
'at any time before the  "<< Begin >>" button is depressed.  You are now',$
'ready to start the tape reading or writing process.  Click on "<< Begin >>"',$
'to start the process.  Note that the XWINTAPE widget is not accessable',$
'during this time.'$
		]
		END
;
	4:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 5',$
'  ',$
'While the tape drive is being accessed, file input/output messages will be',$
'printed to either the TEXT window OR to the MAIN widget if XWINTAPE is doing',$
'the driving.  Once the hour glass disappears, control is returned to the',$
'XWINTAPE widget, HOWEVER, only the "Help" and "## Exit ##" buttons are',$
'active.  To leave this widget, simply click the "## Exit ##" button.'$
		]
		END
;
	5:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 6',$
'  ',$
'The tape/FITS-files I/O has been successfully completed.  To leave this',$
'widget, simply click the "## Exit ##" button.'$
		]
		END
;
	ELSE:	BEGIN
		HELPTEXT = [ $
'>>>>>>>>> HELP MESSAGE # 7',$
'  ',$
'An error has been encountered with the message counter (MESSCNT) in',$
'XWINTAPE!  Send an email note to the CDS staff to inform them of this bug.'$
		]
		END
ENDCASE
;
; Return with no errors.
;
IF N_ELEMENTS(ERRMSG) GT 0 THEN ERRMSG = MESSAGE
RETURN
;
; Error handling portion of the procedure.
;
HANDLE_ERROR:
IF N_ELEMENTS(ERRMSG) EQ 0 THEN MESSAGE, MESSAGE
ERRMSG = MESSAGE
RETURN
;
END
