;+
; Project     :	SOHO - CDS
;
; Name        :	SFDU_QWIDG
;
; Purpose     :	A procedure make XWINTAPE widgets sensitive or insensitive.
;
; Explanation :	During actual tape I/O, it is desired to disable all displayed
;		widgets generated by XWINTAPE.  After the tape I/O, the widgets
;		can be brought back to life.
;
; Use         :	SFDU_QWIDG, Q
;
; Inputs      :	Q =	'OFF':	Disable all of the displayed widgets (DEFAULT).
;			'ON':	Make all displayed widgets active.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	INCL_EXIT: Include the "## Exit ##" button in the call to this
;			routine.  Normally "## Exit ##" is only activated after
;			the tape I/O is complete.
;
; Calls       :	None.
;
; Common      :	XTAPE_INTL
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Data Handling, I/O, FITS, SFDU, Generic
;
; Prev. Hist. :	None.
;
; Written     :	Donald G. Luttermoser, GSFC/ARC, 10 May 1995
;
; Modified    :	Version 1, Donald G. Luttermoser, GSFC/ARC, 10 May 1995
;			Initial program.
;		Version 2, Donald G. Luttermoser, GSFC/ARC, 26 May 1995
;			Modified document header and corrected mistake in 
;			XTAPE_INTL common block.
;		Version 3, Donald G. Luttermoser, GSFC/ARC, 7 December 1995
;			Added DISKNAME widget to the ON/OFF list.
;
; Version     :	Version 3,  7 December 1995
;-
PRO SFDU_QWIDG, Q, INCL_EXIT=INCL_EXIT
;
COMMON XTAPE_INTL, DISKMESS, DISKNAME, FILENAME, GETFILE, CUR_FILE, WINMESS, $
	MESSCNT, TMPSFDU, MESSAGE, ABORT, WMESS, WDIR, WNAME, WOVERRIDE, $
	WBEGIN, WACCESS, TP_MENU, BL_MENU, WLOGF, WSFDU, WSAVESFDU, WCKFITS, $
	WHELP, WFITS, WABORT, WACCDIR, WEXIT, QSUCCESS
;
ON_ERROR, 2	; Return to caller is error is encountered.
;
IF N_ELEMENTS(Q) EQ 0 THEN Q = 'OFF'
IF STRUPCASE(Q) EQ 'ON' THEN FLICK = 1 ELSE FLICK = 0
;
WIDGET_CONTROL, WMESS,     SENSITIVE = FLICK
WIDGET_CONTROL, WDIR,      SENSITIVE = FLICK
WIDGET_CONTROL, DISKNAME,  SENSITIVE = FLICK
WIDGET_CONTROL, WACCDIR,   SENSITIVE = FLICK
WIDGET_CONTROL, FILENAME,  SENSITIVE = FLICK
WIDGET_CONTROL, GETFILE,   SENSITIVE = FLICK
WIDGET_CONTROL, WNAME,     SENSITIVE = FLICK
WIDGET_CONTROL, WOVERRIDE, SENSITIVE = FLICK
WIDGET_CONTROL, WCKFITS,   SENSITIVE = FLICK
WIDGET_CONTROL, WBEGIN,    SENSITIVE = FLICK
WIDGET_CONTROL, WACCESS,   SENSITIVE = FLICK
WIDGET_CONTROL, TP_MENU,   SENSITIVE = FLICK
WIDGET_CONTROL, BL_MENU,   SENSITIVE = FLICK
WIDGET_CONTROL, WLOGF,     SENSITIVE = FLICK
WIDGET_CONTROL, WSFDU,     SENSITIVE = FLICK
WIDGET_CONTROL, WSAVESFDU, SENSITIVE = FLICK
WIDGET_CONTROL, WFITS,     SENSITIVE = FLICK
WIDGET_CONTROL, WHELP,     SENSITIVE = FLICK
WIDGET_CONTROL, WABORT,    SENSITIVE = FLICK
;
IF KEYWORD_SET(INCL_EXIT) THEN WIDGET_CONTROL, WEXIT, SENSITIVE = FLICK
;
RETURN
END
