;+
; Project     :	SOHO - CDS
;
; Name        :	SFDU_VOLHD
;
; Purpose     :	Program to generate the Volume text for a SFDU header file. 
;
; Explanation :	This routine was removed from SFDU_MAKE do to its large size.
;		Essentially it generates a text that describes the volume
;		(i.e., tape or CD) keywords and the SFDU in general.
;
;		NOTE: This procedure is designed to be accessed only from 
;		SFDU_MAKE!
;
; Use         :	SFDU_VOLHD, ADID_SFDU, VOLTEXT, VOLKWRD
;
; Inputs      :	ADID_SFDU:  A structure that contains the SFDU registration
;			file names, versions, and other various information.
;
; Opt. Inputs :	None.
;
; Outputs     :	VOLTEXT:  A string array that contains the volume (i.e., tape
;			or CD) information.
;
;		VOLKWRD:  The volume keywords of the Volume Description PVL.
;
; Opt. Outputs:	None.
;
; Keywords    :	ERRMSG:	If defined and passed, then any error messages will 
;			be returned to the user in this parameter rather than
;			being handled by the IDL MESSAGE utility.  If no 
;			errors are encountered, then a null string is 
;			returned.  In order to use this feature, the string 
;			ERRMSG must be defined first, e.g.,
;
;				ERRMSG = ''
;				SFDU_VOLHD, ADID_SFDU, VOLTEXT, VOLKWRD, $
;					ERRMSG=ERRMSG
;				IF ERRMSG(0) NE '' THEN ...
;
; Calls       :	DATATYPE.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	Returns a string of value '-1' if an error is encountered.
;
; Category    :	Data Handling, I/O, FITS, SFDU, Generic
;
; Prev. Hist. :	Removed from SFDU_MAKE to make this procedure shorter.
;
; Written     :	Donald G. Luttermoser, GSFC/ARC, 11 December 1995
;
; Modified    :	Version 1, Donald G. Luttermoser, GSFC/ARC, 11 December 1995
;			Initial program.
;
; Version     :	Version 1,  11 December 1995
;-
;
PRO SFDU_VOLHD, ADID_SFDU, VOLTEXT, VOLKWRD, ERRMSG=ERRMSG
;
ON_ERROR, 2		; Return to caller if error is encountered.
MESSAGE = ''		; Set to non-null string if error is encountered.
S_INPUT = ''		; Dummy input string.
VOLTEXT = '-1'		; Return this string if initial error encountered.
;
; Check input parameters.
;
IF N_PARAMS() NE 3 THEN BEGIN
	MESSAGE = 'Syntax:  SFDU_VOLHD, ADID_SFDU, VOLTEXT, VOLKWRD'
ENDIF ELSE BEGIN
	IF DATATYPE(ADID_SFDU,1) NE 'Structure' THEN MESSAGE = 'ADID_SFDU '+$
		'must be a structure containing SFDU registration filenames.'
ENDELSE
IF MESSAGE NE '' THEN GOTO, HANDLE_ERROR
;
; ***************************************************************************
;
; Comment concerning the Volume Description that is put at the top of each 
; tape/CD SFDU file.
;
; Retrieve this comment from the SFDU 'VOLM' file.
;
IVOLM = -1
FOR I = 0, 3 DO IF ADID_SFDU(I).NAME EQ 'VOLM' THEN IVOLM = I
IF IVOLM EQ -1 THEN BEGIN
	MESSAGE = 'Somebody screwed up the SFDU registration file look-up ' + $
		'procedure.  Please fix it.'
	GOTO, HANDLE_ERROR
ENDIF
;
OPENR, URD, ADID_SFDU(IVOLM).FILE, /GET_LUN
;
GET_ADID:
READF, URD, S_INPUT
S_INPUT = STRTRIM(S_INPUT, 2)
IF STRMID(S_INPUT, 0, 8) NE 'ADIDNAME' THEN GOTO, GET_ADID
EQPOS = STRPOS(S_INPUT, '=', 8)
IF EQPOS EQ -1 THEN EQPOS = 8	; Just in case ':' replace '=' in the future.
VLEN = STRLEN(S_INPUT)
CKADID = STRTRIM(STRMID(S_INPUT, EQPOS+1, VLEN-EQPOS-1), 2)
CKADID = STRMID(CKADID, 0, 8)
IF CKADID NE ADID_SFDU(IVOLM).CAID+ADID_SFDU(IVOLM).DDID THEN BEGIN
	MESSAGE = 'Inconsistent ADIDNAME (' + CKADID + ') in file ' + $
		ADID_SFDU(IVOLM).FILE + '.'
	GOTO, HANDLE_ERROR
ENDIF
;
; Get the Volume Keyword definitions from this file.
;
VARTYPE = ['/*', '*/', '[STRING]', '[INT]', '[LONG]', '[FLOAT]', '[DOUBLE]', $
	'[LOGICAL]']
NVARTYPE = N_ELEMENTS(VARTYPE)
VOLMGET = ''
VOLMTMP = ''
VOLMKWD = ''
MOREADD = 0
;
FIND_BLOCK:
READF, URD, S_INPUT
S_INPUT = STRTRIM(STRCOMPRESS(S_INPUT), 2)
IF STRPOS(S_INPUT, 'BEGIN_OBJECT = VOLUME_INFORMATION;') EQ -1 THEN GOTO, $
	FIND_BLOCK
;
GET_KEYWD:
READF, URD, S_INPUT
S_INPUT = STRTRIM(STRCOMPRESS(S_INPUT), 2)
IF STRPOS(S_INPUT, 'END_OBJECT;') NE -1 THEN GOTO, CLOSE_VOL
VLEN = STRLEN(S_INPUT)
EQPOS = STRPOS(S_INPUT, '= /*')
IF EQPOS NE -1 THEN BEGIN
	IF MOREADD EQ 1 THEN VOLMGET = [VOLMGET, VOLMTMP]
	VOLMKWD = [VOLMKWD, STRTRIM(STRMID(S_INPUT, 0, EQPOS), 2)]
	VOLMTMP = STRTRIM(STRMID(S_INPUT, EQPOS+1, VLEN-EQPOS-1), 2)
; Get rid of unwanted text.
	FOR I = 0, NVARTYPE-1 DO BEGIN
		CKS = STRPOS(VOLMTMP, VARTYPE(I))
		IF CKS NE -1 THEN BEGIN
			TLEN = STRLEN(VARTYPE(I))
			BLNK = ' '
			FOR J = 1, TLEN-1 DO BLNK = BLNK + ' '
			STRPUT, VOLMTMP, BLNK, CKS
		ENDIF
	ENDFOR
	VOLMTMP = STRTRIM(STRCOMPRESS(VOLMTMP), 2)
;
	MOREADD = 1
ENDIF ELSE BEGIN
	S_INPUT = STRTRIM(S_INPUT, 2)
; Get rid of unwanted text.
	FOR I = 0, NVARTYPE-1 DO BEGIN
		CKS = STRPOS(S_INPUT, VARTYPE(I))
		IF CKS NE -1 THEN BEGIN
			TLEN = STRLEN(VARTYPE(I))
			BLNK = ' '
			FOR J = 1, TLEN-1 DO BLNK = BLNK + ' '
			STRPUT, S_INPUT, BLNK, CKS
		ENDIF
	ENDFOR
	S_INPUT = STRTRIM(STRCOMPRESS(S_INPUT), 2)
	VOLMTMP = VOLMTMP + ' ' + S_INPUT
ENDELSE
GOTO, GET_KEYWD
;
CLOSE_VOL:
VOLMGET = [VOLMGET, VOLMTMP]	; Add the last description.
FREE_LUN, URD
;
; Tidy up these input strings for input into the SFDU header.
;
IKWD = WHERE(VOLMKWD NE '')
IF IKWD(0) NE -1 THEN VOLMKWD = VOLMKWD(IKWD)
IGET = WHERE(VOLMGET NE '')
IF IGET(0) NE -1 THEN VOLMGET = VOLMGET(IGET)
IF TOTAL(IGET - IKWD) NE 0 THEN BEGIN
	MESSAGE = 'Error in constructing "Volume Description" header for ' + $
		'SFDU file.'
	GOTO, HANDLE_ERROR
ENDIF
VOLMGET = STRTRIM(STRCOMPRESS(VOLMGET), 2)	; Just to be sure!
VOLMGET = VOLMGET + '.'		; Add periods to the end of the descriptions.
;
VOLKWRD = VOLMKWD	; Pass the keywords to the outside.
VOLMKWD = VOLMKWD + ':'
NVKWD = N_ELEMENTS(VOLMKWD)
KWDLEN = STRLEN(VOLMKWD)
;
; Keyword lines start with KWDHEAD blanks.
;
KWDHEAD = '    '
KWDMAX = MAX(KWDLEN) + STRLEN(KWDHEAD)
NBLANKS = 1 + KWDMAX - KWDLEN - STRLEN(KWDHEAD)
NDEF = (73 - KWDMAX - 2) > 0
;
; Non-keyword lines start with NONKWDHEAD blanks.
;
NONKWDHEAD = ' '
FOR J = 0, KWDMAX DO NONKWDHEAD = NONKWDHEAD + ' '
;
FOR I = 0, NVKWD-1 DO BEGIN
	BLNK = ' '
	FOR J = 1, NBLANKS(I)-1 DO BLNK = BLNK + ' '
	IF I EQ 0 THEN VOLTADD = KWDHEAD + VOLMKWD(I) + BLNK $
		ELSE VOLTADD = [VOLTADD, KWDHEAD + VOLMKWD(I) + BLNK]
	IADD = N_ELEMENTS(VOLTADD) - 1	; Set to last element in array.
	VLEN = STRLEN(VOLTADD(IADD))
	TLEN = STRLEN(VOLMGET(I))
	IF TLEN LE NDEF THEN BEGIN
		VOLTADD(IADD) = VOLTADD(IADD) + VOLMGET(I)
	ENDIF ELSE BEGIN
		K = NDEF
		WHILE (STRMID(VOLMGET(I), K, 1) NE ' ') AND (K GT 0) DO $
			K = K - 1
		VOLTADD(IADD) = VOLTADD(IADD) + STRMID(VOLMGET(I), 0, K)
; Now put the remainder of the definition on the next line.
CHOP_UP:
		VOLTADD = [VOLTADD, NONKWDHEAD]
		IADD = N_ELEMENTS(VOLTADD) - 1
		K = K + 1	; Get past the blank.
		KK = TLEN - K
		IF KK LE NDEF THEN BEGIN
			VOLTADD(IADD) = VOLTADD(IADD) + $
				STRMID(VOLMGET(I), K, KK)
		ENDIF ELSE BEGIN
			KSTART = K
			K = K + NDEF
			WHILE (STRMID(VOLMGET(I), K, 1) NE ' ') AND $
				(K GT KSTART) DO K = K - 1
			VOLTADD(IADD) = VOLTADD(IADD) + $
				STRMID(VOLMGET(I), KSTART, K-KSTART+1)
			GOTO, CHOP_UP
		ENDELSE
	ENDELSE
ENDFOR
;
; Now pad the added header lines with blanks out to column 73 ('/* */' will be
; added).
;
NADD = N_ELEMENTS(VOLTADD)
FOR I = 0, NADD-1 DO BEGIN
	VLEN = STRLEN(VOLTADD(I))
	BLNK = ' '
	IF VLEN LT 73 THEN FOR J = 0, 73-VLEN-1 DO VOLTADD(I) = $
		VOLTADD(I) + BLNK
ENDFOR
;
; ****************************************************************************
;
VOLTEXT = [$
 '                                                                         ',$
 'This data file is a "detached" Standard Formatted Data Unit (SFDU) file  ',$
 'of the FITS files loaded to this archive tape/CD.  It contains filename  ',$
 'information and the primary FITS header for each file.  The FITS files   ',$
 'contain archival data from the Coronal Diagnostic Spectrometer (CDS)     ',$
 'onboard SOHO.  For further information concerning the tape/CD archiving  ',$
 'procedure and SFDUs, see CDS Software Note #28.                          ',$
 '                                                                         ',$
 'In the VOLUME_INFORMATION block (NSSD3VS00227), the keywords have the    ',$
 'following meaning:                                                       ']
;
VOLTEXT = [VOLTEXT, VOLTADD]
;
VOLTEXT = [VOLTEXT, $
 '                                                                         ',$
 'Each file marker (CCSD3US00009) contains 2 submarkers:                   ',$
 '   CCSD3RS00003:  Replacement reference service -- file names associated ',$
 '                   with the SFDU, where                                  ',$
 '                   CCSDS1 = File name (short version for PC/DOS machines)',$
 '                             which follows the CCSDS1 specification,     ',$
 '                   CCSDS2 = File name (long version for VMS, Unix, and   ',$
 '                             Mac machines) which follows the CCSDS2      ',$
 '                             specification,                              ',$
 '                   CCSDS3 = Integer giving the position of the file on   ',$
 '                             the tape/CD (note that the detached SFDU    ',$
/*                              is designated as file #1 on the tape and the */
/*                              first FITS file is file #2 on the tape).     */
/*                              This follows the CCSDS3 specification.       */
/*                   Each file will logically be include at this spot in the */
/*                    SFDU and will logically include a LABEL (NSSD3IF00229) */
/*                    which identifies the file as a FITS file following the */
/*                    SOHO/CDS archive conventions.                          */
 '   NSSD3KS00228:  The FITS header associated with the file, which has    ',$
 '                   been placed in a PVL object labelled as FITS_HEADER.  ',$
 '                                                                         ']
;^-------------------------------------------------------------------------^
; VOLTEXT text must fit between the above markers ("^").
;
; Add the comment delimiters (/* */) to each main comment line.  The addition
; of these comment markers brings the total length of each comment line to 
; NSFDU_BYTE*NREC_PER_LINE-1 (=79) characters long (see SFDU_MAKE).
;
FOR I=0,N_ELEMENTS(VOLTEXT)-1 DO VOLTEXT(I) = '/* ' + VOLTEXT(I) + ' */'
;
IF N_ELEMENTS(ERRMSG) GT 0 THEN ERRMSG=MESSAGE
RETURN	;  Return to the calling program with no errors.  <<<<<<<<<<<<<
;
; Error handling portion of the procedure.
;
HANDLE_ERROR:
IF N_ELEMENTS(ERRMSG) EQ 0 THEN MESSAGE, MESSAGE
ERRMSG = MESSAGE
RETURN
;
END
