;+
; Project     :	SOHO - CDS
;
; Name        :	XWINPIC
;
; Purpose     :	Reproduce the XWINTAPE widget in a postscript file.
;
; Explanation :	The XWINTAPE widget is too large to save as a postscript file
;		using various "screen capture" software (e.g., xv).  This
;		procedure draws a reasonable facimily of this XWINTAPE widget
;		and saves it as either a standard or encapsulated postscript
;		file, hence usable for presentations or LaTeX manuals.
;
; Use         :	XWINPIC
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	NOENCAPS: Tells XWINPIC to make standard postscript file
;		          instead of encapsulating it, which is the default.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Data Handling, I/O, FITS, SFDU, Generic
;
; Prev. Hist. :	None.
;
; Written     :	Donald G. Luttermoser, GSFC/ARC, 10 August 1995
;
; Modified    :	Version 1, Donald G. Luttermoser, GSFC/ARC, 10 August 1995
;			Initial program.
;		Version 2, Donald G. Luttermoser, GSFC/ARC, 29 December 1995
;			Modified the appearance of the widget picture to 
;			reflect changes made to the real widget (i.e., the 
;			addition of the "Valid CDS FITS?" button).
;
; Version     :	Version 2,  29 December 1995
;-
PRO XWINPIC, NOENCAPS=NOENCAPS
;
; Defaults for the input parameters.
;
ASK = 'Y'  &  PASS = 0
TERM = !D.NAME
;
; Step-by-step instructions that are displayed to the real widget in XWINTAPE, 
; retained for the plots.
;
MESSCNT = 0		; The "Window Message" count.
WINMESS = STRARR(6,3)
WINMESS(0,0:2) = [$
	'If the tape does/will NOT contain an SFDU header file, click the',$
	'appropriate button in the "Tape Header" box before proceeding.  Then',$
	'click on the "Read" or "Write" button in the "Tape Access" box.']
WINMESS(1,0:2) = [$
	'To override default tape access commands, click in "Access '+$
	'Override" box.', ' ', 'Select the "Tape Drive".']
WINMESS(2,0:2) = [$
	'Enter the directory for FITS-file/tape I/O in the box below and ',$
	'click the "Accept Directory" box.', $
	'Once the names appear, the "FITS Header" button can display the '+$
		'headers.']
WINMESS(3,0:2) = [$
	'Select the files you wish to ', ' ', $
	'When done, change any defaults you wish, then hit "<< Begin >>".']
WINMESS(4,0:2) = [$
	' ', $
	'Widget will remain inactive while tape I/O is being performed.', $
	' ']
WINMESS(5,0:2) = [$
	'************************************************', $
	'Click the  "## Exit ##"  button to leave widget.', $
	'************************************************']
;
; Open the workspace window.
;
WIDGET_TITLE = 'XWINTAPE:  Read/Write FITS/SFDU Tapes'
BACKCOL = [160, 210]  &  MYCOL = [190, 60]  &  TEXTCOL=0
XS = 600      &  YS = 700
XD = XS/100.  &  YD = YS/100.
XB = 0.5*XD   &  YB = 0.5*YD
;
; Main widget
XLT = 0*XD  &  XRT = 100*XD  &  YDN = 0*YD  &  YUP = 100*YD
;
; Left hand widgets
;
LHS  = 2*YD
XML  = 1*YD      &  XMR  = 71*XD     &  YMU  = 98*YD    &  YMD  = 1*YD
;
; "Message" widget.
X1L  = XML+XD    &  X1R  = XMR-XD    &  Y1U  = YMU-YD   &  Y1D  = Y1U-10*YD
X1SL = X1L+12*XD &  X1SR = X1R-XD    &  Y1SU = Y1U-YD   &  Y1SD = Y1D+YD
; "Directory" widget.
X2L  = X1L       &  X2R  = X1R       &  Y2U  = Y1D-LHS  &  Y2D  = Y2U-6*YD  
X2SL = X2L+15*XD &  X2SR = X1L+48*XD &  Y2SU = Y2U-YD   &  Y2SD = Y2D+YD
X2BL = X2L+51*XD &  X2BR = X1R-2*XD  &  Y2BU = Y2U-YD   &  Y2BD = Y2D+YD
X2IL = X2BL+XB   &  X2IR = X2BR-XB   &  Y2IU = Y2BU-YB  &  Y2ID = Y2BD+YB
; "Initial files" list widget.
X3L  = X1L       &  X3R  = X1R       &  Y3U  = Y2D-LHS  &  Y3D  = Y3U-27*YD
; "File Naming Convention" button widget.
X4L  = X1L       &  X4R  = X1R       &  Y4U  = Y3D-LHS  &  Y4D  = Y4U-9*YD
X4SL = X4L+XD    &  X4SR = X4R-XD    &  Y4SU = Y4U-3*YD &  Y4SD = Y4D+YD
; "Access Override" & "Valid CDS FITS?" button widgets.
X5L  = X1L       &  X5R  = X1R       &  Y5U  = Y4D-LHS  &  Y5D  = Y5U-9*YD
X5SL = X5L+XD    &  X5SR = X5L+42*XD &  Y5SU = Y5U-3*YD &  Y5SD = Y5D+YD
X5TL = X5L+43*XD &  X5TR = X5R-XD    &  Y5TU = Y5U-3*YD &  Y5TD = Y5D+YD
; "Selected files" list widget.
X6L  = X1L       &  X6R  = X1R       &  Y6U  = Y5D-LHS  &  Y6D  = YMD+YD  
;
; Right hand widgets
;
RHS  = 1.2*YD
WML  = 75*XD   &  WMR  = 99*XD   &  VMU  = 98*YD    &  VMD  = 1*YD
;
; "<< Begin >>" button widget.
W1L  = WML+XD  &  W1R  = WMR-XD  &  V1U  = VMU-YD   &  V1D  = V1U-3*YD  
W1SL = W1L+YB  &  W1SR = W1R-YB  &  V1SU = V1U-YB   &  V1SD = V1D+YB
; "Tape Access" button widget.
W2L  = W1L     &  W2R  = W1R     &  V2U  = V1D-RHS  &  V2D  = V2U-12*YD
W2SL = W2L+YB  &  W2SR = W2R-YB  &  V2SU = V2U-3*YD &  V2SD = V2D+YB  
; "Tape Drive" pull-down menu widget.
W3L  = W1L     &  W3R  = 92*XD   &  V3U  = V2D-RHS  &  V3D  = V3U-4*YD
W3SL = W3L+YB  &  W3SR = 91.5*XD &  V3SU = V3U-YB   &  V3SD = V3D+YB
; "Blocking Factor" pull-down menu widget.
W4L  = W1L     &  W4R  = W1R     &  V4U  = V3D-RHS  &  V4D  = V4U-4*YD
W4SL = W4L+YB  &  W4SR = W4R-YB  &  V4SU = V4U-YB   &  V4SD = V4D+YB
; "Session Log" button widget.
W5L  = W1L     &  W5R  = W1R     &  V5U  = V4D-RHS  &  V5D  = V5U-12*YD
W5SL = W5L+YB  &  W5SR = W5R-YB  &  V5SU = V5U-3*YD &  V5SD = V5D+YB
; "Tape Header" button widget.
W6L  = W1L     &  W6R  = W1R     &  V6U  = V5D-RHS  &  V6D  = V6U-12*YD
W6SL = W6L+YB  &  W6SR = W6R-YB  &  V6SU = V6U-3*YD &  V6SD = V6D+YB
; "Save SFDU Header" button widget.
W7L  = W1L     &  W7R  = W1R     &  V7U  = V6D-RHS  &  V7D  = V7U-12*YD
W7SL = W7L+YB  &  W7SR = W7R-YB  &  V7SU = V7U-3*YD &  V7SD = V7D+YB
; "FITS Header" button widget.
W8L  = W1L     &  W8R  = W1R     &  V8U  = V7D-RHS  &  V8D  = V8U-3*YD
W8SL = W8L+YB  &  W8SR = W8R-YB  &  V8SU = V8U-YB   &  V8SD = V8D+YB
; "Help" button widget.
W9L  = W1L     &  W9R  = W1R     &  V9U  = V8D-RHS  &  V9D  = V9U-3*YD
W9SL = W9L+YB  &  W9SR = W9R-YB  &  V9SU = V9U-YB   &  V9SD = V9D+YB
; "SOHO Logo" picture widget.
W0L  = W1L     &  W0R  = W1R     &  V0U  = V9D-RHS  &  V0D  = V0U-10*YD
; "!! Abort !!" button widget.
WAL  = W1L     &  WAR  = W1R     &  VAU  = V0D-RHS  &  VAD  = VAU-3*YD
WASL = WAL+YB  &  WASR = WAR-YB  &  VASU = VAU-YB   &  VASD = VAD+YB
; "## Exit ##" button widget.
WBL  = W1L     &  WBR  = W1R     &  VBU  = VAD-RHS  &  VBD  = VBU-3*YD
WBSL = WBL+YB  &  WBSR = WBR-YB  &  VBSU = VBU-YB   &  VBSD = VBD+YB
;
WINDOW, 0, XSIZE=XS, YSIZE=YS, TITLE=WIDGET_TITLE
;
NEXTPLOT:
LOADCT, 1      ;  Blue-white color table.
;
PLOT, [0,XS], [0,YS], BACKGROUND=BACKCOL(PASS), COLOR=MYCOL(PASS), $
 XSTYLE=4+8, YSTYLE=4+8, /DEVICE, CLIP=[0,0,XS,YS], /NODATA
;
; **************** Left-hand widgets:
;
; Message box.
IF PASS EQ 1 THEN POLYFILL, [X1L,X1R,X1R,X1L,X1L], [Y1D,Y1D,Y1U,Y1U,Y1D], $
 COLOR=BACKCOL(PASS)
OPLOT, [X1L,X1R,X1R,X1L,X1L], [Y1D,Y1D,Y1U,Y1U,Y1D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, X1L+2*XD, Y1U-5*YD, 'Messages:', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
OPLOT, [X1SL,X1SR,X1SR,X1SL,X1SL], [Y1SD,Y1SD,Y1SU,Y1SU,Y1SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, X1SL+1*XD, Y1U-3*YD, WINMESS(0,0), SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, X1SL+1*XD, Y1U-5*YD, WINMESS(0,1), SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, X1SL+1*XD, Y1U-7*YD, WINMESS(0,2), SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Directory name box.
IF PASS EQ 1 THEN POLYFILL, [X2L,X2R,X2R,X2L,X2L], [Y2D,Y2D,Y2U,Y2U,Y2D], $
 COLOR=BACKCOL(PASS)
OPLOT, [X2L,X2R,X2R,X2L,X2L], [Y2D,Y2D,Y2U,Y2U,Y2D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, X2L+2*XD, Y2U-3.5*YD, 'Directory Name:', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
OPLOT, [X2SL,X2SR,X2SR,X2SL,X2SL], [Y2SD,Y2SD,Y2SU,Y2SU,Y2SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, X2SL+XD, Y2U-3.5*YD, '/disk1/local/cds/fits', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
OPLOT, [X2BL,X2BR,X2BR,X2BL,X2BL], [Y2BD,Y2BD,Y2BU,Y2BU,Y2BD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [X2IL,X2IR,X2IR,X2IL,X2IL], [Y2ID,Y2ID,Y2IU,Y2IU,Y2ID], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, X2BL+1.5*XD, Y2U-3.5*YD, 'Accept Directory', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
;
; Upper text box.
IF PASS EQ 1 THEN POLYFILL, [X3L,X3R,X3R,X3L,X3L], [Y3D,Y3D,Y3U,Y3U,Y3D], $
 COLOR=BACKCOL(PASS)
OPLOT, [X3L,X3R,X3R,X3L,X3L], [Y3D,Y3D,Y3U,Y3U,Y3D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, X3L+2*XD, Y3U-14*YD, '!17SOHO!3', SIZE=8, COLOR=TEXTCOL, CHARTHICK=5
XYOUTS, X3L+42*XD, Y3U-19*YD, '!17CDS!3', SIZE=5, COLOR=TEXTCOL, CHARTHICK=4
XYOUTS, X3L+2*XD, Y3U-18*YD, '++++++++++++++++++++++++++++++++++', $
 SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=3
XYOUTS, X3L+2*XD, Y3U-19*YD, '++++++++++++++++++++++++++++++++++', $
 SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=3
;
; File naming convention box.
IF PASS EQ 1 THEN POLYFILL, [X4L,X4R,X4R,X4L,X4L], [Y4D,Y4D,Y4U,Y4U,Y4D], $
 COLOR=BACKCOL(PASS)
OPLOT, [X4L,X4R,X4R,X4L,X4L], [Y4D,Y4D,Y4U,Y4U,Y4D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, X4L+26*XD, Y4U-2*YD, 'File Naming Convention', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
OPLOT, [X4SL,X4SR,X4SR,X4SL,X4SL], [Y4SD,Y4SD,Y4SU,Y4SU,Y4SD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [ X4L+3*XD, X4L+15.5*XD, X4L+28*XD, X4L+40.5*XD, X4L+53*XD], $
       [Y4SU-3*YD, Y4SU-3*YD, Y4SU-3*YD, Y4SU-3*YD, Y4SU-3*YD], PSYM=4, THICK=3
XYOUTS, X4L+4.5*XD,  Y4SU-3.5*YD, 'Default', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
XYOUTS, X4L+17*XD,   Y4SU-3.5*YD, 'SFDU_small', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
XYOUTS, X4L+29.5*XD, Y4SU-3.5*YD, 'SFDU_large', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
XYOUTS, X4L+42*XD,   Y4SU-3.5*YD, 'Keyword', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
XYOUTS, X4L+54.5*XD, Y4SU-3.5*YD, 'Tape Location', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
;
; Access Override box.
IF PASS EQ 1 THEN POLYFILL, [X5L,X5R,X5R,X5L,X5L], [Y5D,Y5D,Y5U,Y5U,Y5D], $
 COLOR=BACKCOL(PASS)
OPLOT, [X5L,X5R,X5R,X5L,X5L], [Y5D,Y5D,Y5U,Y5U,Y5D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, X5L+16*XD, Y5U-2*YD, 'Access Override', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
OPLOT, [X5SL,X5SR,X5SR,X5SL,X5SL], [Y5SD,Y5SD,Y5SU,Y5SU,Y5SD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [ X5L+3*XD, X5L+21*XD], [Y5SU-3*YD, Y5SU-3*YD], PSYM=4, THICK=3
XYOUTS, X5L+ 4*XD, Y5SU-3.5*YD, 'IDL Style Commands', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, X5L+22*XD, Y5SU-3.5*YD, 'Unix mt & dd Commands', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
;
; Valid CDS FITS box.
XYOUTS, X5L+49*XD, Y5U-2*YD, 'Valid CDS FITS?', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
OPLOT, [X5TL,X5TR,X5TR,X5TL,X5TL], [Y5TD,Y5TD,Y5TU,Y5TU,Y5TD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [ X5TL+2*XD, X5TL+12*XD], [Y5TU-3*YD, Y5TU-3*YD], PSYM=4, THICK=3
XYOUTS, X5TL+ 3*XD, Y5TU-3.5*YD, 'Check File', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, X5TL+13*XD, Y5TU-3.5*YD, 'Ignore Check', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
;
; Lower text box.
IF PASS EQ 1 THEN POLYFILL, [X6L,X6R,X6R,X6L,X6L], [Y6D,Y6D,Y6U,Y6U,Y6D], $
 COLOR=BACKCOL(PASS)
OPLOT, [X6L,X6R,X6R,X6L,X6L], [Y6D,Y6D,Y6U,Y6U,Y6D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, X6L+2*XD, Y6U-2*YD, 'Select files from upper window ...', SIZE=0.7, $
 COLOR=TEXTCOL, CHARTHICK=2
;
; Enclose left-hand widgets.
OPLOT, [XML,XMR,XMR,XML,XML], [YMD,YMD,YMU,YMU,YMD], COLOR=MYCOL(PASS), THICK=2
;
; **************** Right-hand widgets:
;
; Begin button.
IF PASS EQ 1 THEN POLYFILL, [W1L,W1R,W1R,W1L,W1L], [V1D,V1D,V1U,V1U,V1D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W1L,W1R,W1R,W1L,W1L], [V1D,V1D,V1U,V1U,V1D], COLOR=MYCOL(PASS), THICK=2
OPLOT, [W1SL,W1SR,W1SR,W1SL,W1SL], [V1SD,V1SD,V1SU,V1SU,V1SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, W1L+7*XD, V1U-2*YD, '<< Begin >>', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Tape Access Box.
IF PASS EQ 1 THEN POLYFILL, [W2L,W2R,W2R,W2L,W2L], [V2D,V2D,V2U,V2U,V2D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W2L,W2R,W2R,W2L,W2L], [V2D,V2D,V2U,V2U,V2D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, W2L+7*XD, V2U-2*YD, 'Tape Access', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
OPLOT, [W2SL,W2SR,W2SR,W2SL,W2SL], [V2SD,V2SD,V2SU,V2SU,V2SD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [W2L+2*XD, W2L+2*XD], [V2U-6*YD, V2U-9.5*YD], PSYM=4, THICK=3
XYOUTS, W2L+4*XD, V2U-6.5*YD, 'Read', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, W2L+4*XD, V2U-10*YD, 'Write', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Tape Drive button.
IF PASS EQ 1 THEN POLYFILL, [W3L,W3R,W3R,W3L,W3L], [V3D,V3D,V3U,V3U,V3D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W3L,W3R,W3R,W3L,W3L], [V3D,V3D,V3U,V3U,V3D], COLOR=MYCOL(PASS), THICK=2
OPLOT, [W3SL,W3SR,W3SR,W3SL,W3SL], [V3SD,V3SD,V3SU,V3SU,V3SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, W3L+4*XD, V3U-2.5*YD, 'Tape Drive', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Blocking Factor button.
IF PASS EQ 1 THEN POLYFILL, [W4L,W4R,W4R,W4L,W4L], [V4D,V4D,V4U,V4U,V4D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W4L,W4R,W4R,W4L,W4L], [V4D,V4D,V4U,V4U,V4D], COLOR=MYCOL(PASS), THICK=2
OPLOT, [W4SL,W4SR,W4SR,W4SL,W4SL], [V4SD,V4SD,V4SU,V4SU,V4SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, W4L+5*XD, V4U-2.5*YD, 'Blocking Factor', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
;
; Session Log Box.
IF PASS EQ 1 THEN POLYFILL, [W5L,W5R,W5R,W5L,W5L], [V5D,V5D,V5U,V5U,V5D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W5L,W5R,W5R,W5L,W5L], [V5D,V5D,V5U,V5U,V5D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, W5L+7*XD, V5U-2*YD, 'Session Log', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
OPLOT, [W5SL,W5SR,W5SR,W5SL,W5SL], [V5SD,V5SD,V5SU,V5SU,V5SD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [W5L+2*XD, W5L+2*XD], [V5U-6*YD, V5U-9.5*YD], PSYM=4, THICK=3
XYOUTS, W5L+4*XD, V5U-6.5*YD, 'Log File', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, W5L+4*XD, V5U-10*YD, 'No File', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Tape Header Box.
IF PASS EQ 1 THEN POLYFILL, [W6L,W6R,W6R,W6L,W6L], [V6D,V6D,V6U,V6U,V6D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W6L,W6R,W6R,W6L,W6L], [V6D,V6D,V6U,V6U,V6D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, W6L+7*XD, V6U-2*YD, 'Tape Header', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
OPLOT, [W6SL,W6SR,W6SR,W6SL,W6SL], [V6SD,V6SD,V6SU,V6SU,V6SD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [W6L+2*XD, W6L+2*XD], [V6U-6*YD, V6U-9.5*YD], PSYM=4, THICK=3
XYOUTS, W6L+4*XD, V6U-6.5*YD, 'SFDU', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, W6L+4*XD, V6U-10*YD, 'No SFDU', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Save SFDU Box.
IF PASS EQ 1 THEN POLYFILL, [W7L,W7R,W7R,W7L,W7L], [V7D,V7D,V7U,V7U,V7D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W7L,W7R,W7R,W7L,W7L], [V7D,V7D,V7U,V7U,V7D], COLOR=MYCOL(PASS), THICK=2
XYOUTS, W7L+5*XD, V7U-2*YD, 'Save SFDU File?', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
OPLOT, [W7SL,W7SR,W7SR,W7SL,W7SL], [V7SD,V7SD,V7SU,V7SU,V7SD], $
 COLOR=MYCOL(PASS), THICK=2
OPLOT, [W7L+2*XD, W7L+2*XD], [V7U-6*YD, V7U-9.5*YD], PSYM=4, THICK=3
XYOUTS, W7L+4*XD, V7U-6.5*YD, 'Yes', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
XYOUTS, W7L+4*XD, V7U-10*YD, 'No', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; FITS Header button.
IF PASS EQ 1 THEN POLYFILL, [W8L,W8R,W8R,W8L,W8L], [V8D,V8D,V8U,V8U,V8D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W8L,W8R,W8R,W8L,W8L], [V8D,V8D,V8U,V8U,V8D], COLOR=MYCOL(PASS), THICK=2
OPLOT, [W8SL,W8SR,W8SR,W8SL,W8SL], [V8SD,V8SD,V8SU,V8SU,V8SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, W8L+7*XD, V8U-2*YD, 'FITS Header', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; Help button.
IF PASS EQ 1 THEN POLYFILL, [W9L,W9R,W9R,W9L,W9L], [V9D,V9D,V9U,V9U,V9D], $
 COLOR=BACKCOL(PASS)
OPLOT, [W9L,W9R,W9R,W9L,W9L], [V9D,V9D,V9U,V9U,V9D], COLOR=MYCOL(PASS), THICK=2
OPLOT, [W9SL,W9SR,W9SR,W9SL,W9SL], [V9SD,V9SD,V9SU,V9SU,V9SD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, W9L+10*XD, V9U-2*YD, 'Help', SIZE=0.7, COLOR=TEXTCOL, CHARTHICK=2
;
; SOHO Logo Box.
IF PASS EQ 1 THEN POLYFILL, [W0L,W0R,W0R,W0L,W0L], [V0D,V0D,V0U,V0U,V0D], $
 COLOR=240
OPLOT, [W0L,W0R,W0R,W0L,W0L], [V0D,V0D,V0U,V0U,V0D], COLOR=MYCOL(PASS), THICK=2
LOFF = 0.25*(W0R-W0L)
POLYFILL, [W0L+LOFF, (W0L+W0R)/2, W0R-LOFF, (W0L+W0R)/2, W0L+LOFF], $
 [(V0D+V0U)/2, V0U, (V0D+V0U)/2, V0D, (V0D+V0U)/2], COLOR=20
XYOUTS, (W0L+W0R)/2, V0D+0.03*(V0U-V0D), 'SOHO', SIZE=1.2, CHARTHICK=7, $
 ORIENT=42., COLOR=250
XYOUTS, W0L+0.31*(W0R-W0L), V0D+0.45*(V0U-V0D), 'NASA  esa', SIZE=0.6, $
 CHARTHICK=3, ORIENT=42., COLOR=250
;
; Abort button.
IF PASS EQ 1 THEN POLYFILL, [WAL,WAR,WAR,WAL,WAL], [VAD,VAD,VAU,VAU,VAD], $
 COLOR=BACKCOL(PASS)
OPLOT, [WAL,WAR,WAR,WAL,WAL], [VAD,VAD,VAU,VAU,VAD], COLOR=MYCOL(PASS), THICK=2
OPLOT, [WASL,WASR,WASR,WASL,WASL], [VASD,VASD,VASU,VASU,VASD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, WAL+8*XD, VAU-2*YD, '!!!! Abort !!!!', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
;
; Exit button.
IF PASS EQ 1 THEN POLYFILL, [WBL,WBR,WBR,WBL,WBL], [VBD,VBD,VBU,VBU,VBD], $
 COLOR=BACKCOL(PASS)
OPLOT, [WBL,WBR,WBR,WBL,WBL], [VBD,VBD,VBU,VBU,VBD], COLOR=MYCOL(PASS), THICK=2
OPLOT, [WBSL,WBSR,WBSR,WBSL,WBSL], [VBSD,VBSD,VBSU,VBSU,VBSD], $
 COLOR=MYCOL(PASS), THICK=2
XYOUTS, WBL+7.5*XD, VBU-2*YD, '## Exit ##', SIZE=0.7, COLOR=TEXTCOL, $
 CHARTHICK=2
;
; Enclose right-hand widgets.
OPLOT, [WML,WMR,WMR,WML,WML], [VMD,VMD,VMU,VMU,VMD], COLOR=MYCOL(PASS), THICK=2
;
; Enclose all widgets and draw title bar.
OPLOT, [XLT,XRT,XRT,XLT,XLT], [YDN,YDN,YUP,YUP,YDN], COLOR=0, THICK=4
POLYFILL, [XLT,XRT,XRT,XLT,XLT], [YUP,YUP,YUP-3*YB,YUP-3*YB,YUP], COLOR=0
OPLOT, [XLT+4*XD, XLT+4*XD], [YUP, YUP-3*YB], COLOR=250, THICK=3
OPLOT, [XRT-4*XD, XRT-4*XD], [YUP, YUP-3*YB], COLOR=250, THICK=3
OPLOT, [XRT-8*XD, XRT-8*XD], [YUP, YUP-3*YB], COLOR=250, THICK=3
XYOUTS, (XLT+XRT)/2, YUP-2.5*YB, WIDGET_TITLE, SIZE=0.7, COLOR=250, $
 CHARTHICK=3, ALIGN=0.5
XYOUTS, XLT+1.3*XD, YUP-2.5*YB, '-',     SIZE=0.8, CHARTHICK=5, COLOR=250
XYOUTS, XRT-6.1*XD, YUP-2.7*YB, '!9.!3', SIZE=0.8, CHARTHICK=4, COLOR=250
XYOUTS, XRT-2.5*XD, YUP-2.6*YB, '!9B!3', SIZE=0.7, CHARTHICK=2, COLOR=250
;
IF PASS EQ 0 THEN BEGIN
  PASS = 1
  SET_PLOT, 'PS'
  IF KEYWORD_SET(NOENCAPS) THEN BEGIN
    PRINT, 'Generating postscript file:  xwinpic.ps'
    DEVICE, FILENAME='xwinpic.ps', /PORTRAIT, /INCHES, YOFFSET=1.0, $
     YSIZE=8.5, XOFFSET=0.0, XSIZE=8.0, ENCAPSULATE=0
  ENDIF ELSE BEGIN
    PRINT, 'Generating encapsulated postscript file:  xwinpic.eps'
    DEVICE, FILENAME='xwinpic.eps', /ENCAPSULATE, /PORTRAIT, /INCHES, $
      YOFFSET=1.0, YSIZE=8.5, XOFFSET=0.0, XSIZE=8.0
  ENDELSE
  GOTO, NEXTPLOT
ENDIF ELSE BEGIN
  PASS = 0
  DEVICE, /CLOSE_FILE
  SET_PLOT, TERM
ENDELSE
;
RETURN
END
