	PRO WR_TBL_HDR, LUN
;+
; Project     :	SOHO - CDS
;
; Name        :	WR_TBL_HDR
;
; Purpose     :	Write the HTML format codes to begin a table to a file. 
;
; Explanation :	This procedure creates the HTML format codes which are used
;		to begin the table(s) that will hold the CDROM processing 
;		status information.  The initial code contains the font and
;		other formatting information.  The actual rows of the table
;		are written by the procedure WR_CD_HTML.
;
; Use         :	WR_TBL_HDR, LUN
;
; Inputs      :	LUN	The logical unit number of the file to write the
;			HTML format codes to.  The file must have been 
;			opened for writeing by the calling procedure.
;
; Opt. Inputs : None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.	
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	The procedure is only designed to be called by the procedure 
;		MK_CDROM_WEB.PRO
;
; Side effects:	Writes HTML format codes to the file referenced by the logical
;		unit number passed to the procedure as the parameter LUN.
;
; Category    :	Planning, Database.
;
; Prev. Hist. :	none.
;
; Written     :	Ron Yurow, GSFC, 24 October 1997
;
; Modified    :	Version 1, Ron Yurow, GSFC, 24 October 1997
;
; Version     :	Version 1, 24 October 1997
;-
;

;
; Write the HTML format codes to begin a HTML document, included the title
; of the document.
;

	PRINTF, LUN, "<html>"
	PRINTF, LUN, "<head>"
	PRINTF, LUN, "<title>CDROM Status Table</title>"
	PRINTF, LUN, "</head>"

;
; Write the HTML format codes to begin the body of an HTML document.  Set the
; default font color to black on white.
;

	PRINTF, LUN, '<body bgcolor = "#ffffff" text = "#000000">'

;
; Write an HTML format code to center the table we are going to create.
;

	PRINTF, LUN, "<center>"

;
; Write the HTML format code to begin the table. 
;
	PRINTF, LUN, "<table border = 5 cellpadding = 7>"

;
; Write the HTML format codes for the first row of the table.  The first row
; will contain headers for each of the columns in the table.
;
	PRINTF, LUN, "<tr> 
	PRINTF, LUN, "<th> CD Volume</th>"
	PRINTF, LUN, "<th> Date </th>"
	PRINTF, LUN, "<th> First FITS File </th>"
	PRINTF, LUN, "<th> Last FITS File </th>"
	PRINTF, LUN, "<th> Comments </th>"
	PRINTF, LUN, "</tr>

;
; Were Done !!!
;

	RETURN

	END
