	PRO WR_WELCM_PG, MAX_SEQ, MAXSC, DAYLST
;+
; Project     :	SOHO - CDS
;
; Name        :	WR_WELCM_PG
;
; Purpose     :	Create a splash page for the CDROM processing web pages. 
;
; Explanation :	This procedure creates a top level HTML page for a set of 
;		web pages which describe the processing status of all the 
;		CDROMs which have currently been registered.  The actual 
;		status information is contained within a set of tables, each
;		one haveing its own web page.  The top level page created by
;		this procedure contains links to all of these sub pages.  In
;		addition, it contains some javascript routines which 
;		implement a simple search engine. 
;
; Use         :	WR_WELCM_PG, MAX_SEQ, MAXSC, DAYLST 
;
; Inputs      :	MAX_SEQ	The largest sequence number in use.  A sequences is
;			a group CDROMs which were created by the DDF at the
;			same time.
;
;		MAXSC	The maximum study counter which was used by any
;			of the CDROMs which this procedure examined.
;			same time.
;
;		DAYLST	A 3 x D array where D is number of days that SoHO 
;			has been in orbit.  The array contains the sequence
;			number and volume number for the CDROM with the 
;			latest data set for each mission day.
;
; Opt. Inputs : None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.	
;
; Keywords    :	None.
;
; Calls       :	HLINE.
;
; Common      :	None.
;
; Restrictions:	The procedure is only designed to be called by the procedure 
;		MK_CDROM_WEB.PRO
;
; Side effects:	Creates a file called "cdrom_processing.html" in the default
;		directory of the IDL session that it is run in.  This file
;		contians the HTML formated web page described above.
;
; Category    :	Planning, Database.
;
; Prev. Hist. :	none.
;
; Written     :	Ron Yurow, GSFC, 24 October 1997
;
; Modified    :	Version 1, Ron Yurow, GSFC, 24 October 1997
;
; Version     :	Version 1, 24 October 1997
;-
;

;
; Set NO_FILES to the number of files that will be required to store 
; the processing status of all the CDROMs.
;

	NO_FILES = FIX (MAX_SEQ / 20)

;
; Adjust the number of files that will be required up by one, unless the 
; maximum CDROM sequence number is evenly divisable by 20.
;

	IF NO_FILES * 20 LT MAX_SEQ THEN NO_FILES = NO_FILES + 1

;
; Open a file for writeing called "cdrom_processing.html".
;

	OPENW, LUN, "cdrom_processing.html", /GET_LUN	

;
; Write the HTML header and title codes for the web page.
;


	PRINTF, LUN, "<html>"
	PRINTF, LUN, "<head>"
	PRINTF, LUN, "<title>CDROM Processing Status</title>"

;
; Write two lines to begin the section of the web page that will contain the
; Javascript routines.
;

	PRINTF, LUN, '<script language = "JavaScript">'
	PRINTF, LUN, '<!-- JavaScript Function Definitions>'

;
; Write two lines of Javascript to declare the two global variables.
; The variable daylst will be used to hold an array associateing mission
; days with CDROM sequence and volume numbers.  The variable nodays will 
; be used to hold the number of elements in the array daylst.
;


	PRINTF, LUN, 'var daylst ; '
	PRINTF, LUN, 'var nodays ; '

;
; Write two lines of Javascript to begin the function 'init'
;

	PRINTF, LUN, 'function init ()'
	PRINTF, LUN, '{

;
; Set NDAYS to the number of elements in the array DAYLST
;

	NDAYS = N_ELEMENTS (DAYLST (*, 0))

;
; Write a line of Javascript to set the variable nodays to the value of NDAYS.
;

	PRINTF, LUN, NDAYS, FORMAT = '("   nodays = ", I0, " ;")'

;
; Write a line of Javasript to create a new array object and store it in the
; variable daylst.
;

	PRINTF, LUN, '   daylst = new Array (nodays) ; '

;
; Create a format statement that will be used when writeing the lines of 
; of Javasript code to insert data in the array daylst.
;

	FMT = '("   daylst [", I0, "] = new Array (", '
	FMT = FMT + 'I0, " , ", I0, " , ", I0, ") ; ") ' 

;
; Loop to create a series Javascript statements that will collectively fill
; the array daylst with data.  Each statement will add one row to the arary
; daylst.  The data that each statement adds to the array daylst is taken
; fromt the array DAYLST.  The loop is repeated once for every row in DAYLST.
; 
	
	FOR I = 0, NDAYS - 1 DO BEGIN

	   PRINTF, LUN, 			$
	           I, 				$
	           DAYLST (I, 0),		$ 
	           DAYLST (I, 1),		$
	           DAYLST (I, 2),		$
	           FORMAT = FMT

	ENDFOR

;
; Write a Javascript line to end the 'init' function.
;

	PRINTF, LUN, '}'

;
; Write two lines of Javascript to begin the function 'searchseq'
;

	PRINTF, LUN, 'function searchseq ()'
	PRINTF, LUN, '{'

;
; Write several lines of Javascript to declare all the variables that will be
; used by this fuction.
;

	PRINTF, LUN, '   var seq ;'
	PRINTF, LUN, '   var vol ;'
	PRINTF, LUN, '   var dest ;'
	PRINTF, LUN, '   var tblno ; '

;
; Write two lines of Javascript to retrieve the values of seq and vol from 
; the form portion of this web page.
;

	PRINTF, LUN, '   seq = self.document.find.seqfind.value ;'
	PRINTF, LUN, '   vol = self.document.find.volfind.value ;'

;
; Write a line of Javascript to calculate the value of tblno based on the
; value of seq and vol.  The value of tblno is the number indicateing in 
; which html table the data for the CDROM from sequence seq and volume vol
; can be found. 
;

	PRINTF, LUN, '   tblno = Math.floor (seq / 20) + 1 ;'

;
; Write a line of Javascript code which set dest to a string containing the
; local URL of the table entry containing the information on CDROM sequence
; seq volume vol.
;

	PRINTF, LUN, '   dest = new String ("cd_status_"', FORMAT = '(A, $)'
	PRINTF, LUN, ' + tblno + ".html#S" + seq + "V" + vol) ;'
;
; Write a line of Javascript code to load the document whith the URL we just
; stored in dest.
;

	PRINTF, LUN, '   window.location.href = dest ;'

;
; Write a Javascript line to end the 'searchseq' function.
;

	PRINTF, LUN, '}'

;
; Write two lines of Javascript to begin the function 'searchdate'
;

	PRINTF, LUN, 'function searchdate ()'
	PRINTF, LUN, '{'

;
; Write several lines of Javascript to declare all the variables that will be
; used by this fuction.
;

	PRINTF, LUN, '   var target ;'
	PRINTF, LUN, '   var yr ;'
	PRINTF, LUN, '   var mn ;'
	PRINTF, LUN, '   var dy ;'
	PRINTF, LUN, '   var tz ;'
	PRINTF, LUN, '   var epoch_day ; '
	PRINTF, LUN, '   var soho_day ;
	PRINTF, LUN, '   var seq ;'
	PRINTF, LUN, '   var vol ;'
		
;
; Write several lines of Javascript code to read the month (mn), day (dy), 
; and year (yr) to search on from the form portion of the web page.
;

	PRINTF, LUN, '   mn = self.document.find.month.selectedIndex ;'
	PRINTF, LUN, '   dy = self.document.find.day.value ;'
	PRINTF, LUN, '   yr = self.document.find.year.selectedIndex + 95 ;'

;
; Write a line of Javascript code to create a date object from the month,
; and day, and year that we just read.
;

	PRINTF, LUN, '   target = new Date (yr, mn, dy) ;'

;
; Write two lines of Javascript code to convert the which is stored in the
; date object target to GMT.
;

	PRINTF, LUN, '   tz = target.getTimezoneOffset() * 60000 ;'
	PRINTF, LUN, '   target.setTime (target.getTime () - tz) ;'

;
; Write several lines of Javascript code to do a simple check on the date
; to make sure that it is between 1 and 31.  This will obviously let some
; invalid dates through, but it is better then nothing.  If we do find an
; invalid date, the through up an alarm box and exit the function. 
;


	PRINTF, LUN, '   if (dy < 1 || dy > 31) 
	PRINTF, LUN, '      {'
	PRINTF, LUN, '      alert ("Invalid day chosen.") ; '
	PRINTF, LUN, '      self.document.find.day.value = 1 ; '
	PRINTF, LUN, '      return ;'
	PRINTF, LUN, '      }'

;
; Write two lines of Javascript code to convert the time object 'target' first
; to an epoch day (days since Jan 1, 1970) and then to a soho day (days since
; the lauch of SoHO.
;

	PRINTF, LUN, '   epoch_day = target.getTime () / 86400000 ;'
	PRINTF, LUN, '   soho_day = epoch_day - 9466 ; '

;
; Write several lines of Javascript code to create a loop which will search 
; through the array daylst looking for a row where the element in the first
; column matches the soho day which we calculated earlier.  If we do find 
; such a row, then we set seq and vol to the second and third elements in 
; that row respectively.  The loop ends when every row in the array daylst 
; has been checked.
;  
   
	PRINTF, LUN, '   seq = 0 ;
	PRINTF, LUN, '   vol = 0 ;
	PRINTF, LUN, '   for (i = 0; i < nodays ; i++)
	PRINTF, LUN, '       {
	PRINTF, LUN, '       if  (daylst [i] [0] == soho_day)
	PRINTF, LUN, '           {
	PRINTF, LUN, '           seq = daylst [i] [1] ;
	PRINTF, LUN, '           vol = daylst [i] [2] ;
	PRINTF, LUN, '           }
	PRINTF, LUN, '       } 

;
; Write two lines of Javascript code to check if seq and vol are both set
; set to 0.  This means that preceeding loop did not find a row in the array
; daylst which corresponded to the soho mission day in soho_day.
;

	PRINTF, LUN, '   if  (seq == 0 && vol == 0)
	PRINTF, LUN, '       {

;
; Set ALRSTR to a text message which will be displayed in an alert box 
; informing the user that an error occured. 
;

	ALRTSTR = "Sorry.  No CDROM has been received with data for this day."

;
; Write two lines of Javascript code to put up an alert box the message that
; we just placed in ALRTSTR.  After the user dismisses the alert box, then we
; simply exit the function.
;


	PRINTF, LUN, '       alert ("' + ALRTSTR + '") ; '
	PRINTF, LUN, '       return ;
	PRINTF, LUN, '       }

;
; Write two lines of Javascript code to place the values of seq and vol into
; two of the text entry fields of the form portion of the web page.  These
; two text entry fields are used by the funtion 'searchseq' which part of the
; CDROM processing description table to load into the browser.  
;

	PRINTF, LUN, '   self.document.find.seqfind.value = seq ;
	PRINTF, LUN, '   self.document.find.volfind.value = vol ;

;
; Call the function 'searchseq to move the browser the part of the CDROM
; processing description table with information on CDROM sequence seq and
; volume vol.
;

	PRINTF, LUN, '   searchseq () ;

;
; Write a Javascript line to end the 'init' function.
;

	PRINTF, LUN, '}'

;
; Write several HTML lines to end the section of Javascript routines as well
; as the header portion of the web page.
;


	PRINTF, LUN, '// End of Function Definitions -->'
	PRINTF, LUN, '</SCRIPT>'
	PRINTF, LUN, "</head>"

;
; Write several HTML lines to begin the body of the web page.
;

	PRINTF, LUN, '<body bgcolor = "#ffffff" '
	PRINTF, LUN, '      text    = "#000000" '
	PRINTF, LUN, '      onLoad  = "init ()" >'

;
; Write several HTML lines which will display a title for this web page.  The
; title includes the last study which has been processed.
;

	PRINTF, LUN, "<center>"
	PRINTF, LUN, "<p><font size = +1>CDROM Processing Status</font></p>"
	PRINTF, LUN, "<p><font size = +1>Last FITS file processed: </font>"
	PRINTF, LUN, "<font color = #FF0000 size = +1>"
	PRINTF, LUN, MAXSC, FORMAT = '(I0)'
	PRINTF, LUN, "</font> </p> </center>"

;
; Write some HTML formatted text which describe what the CDROM processing
; status web pages are, how to use them, and why CDROMs are processed in the
; first place.
;

	PRINTF, LUN, "<p> The final version of the corrected"
	PRINTF, LUN, "level 0 science data for SoHO is distributed to the"
	PRINTF, LUN, "instrument teams on CDROMs by the DDF.  These CDROMs"
	PRINTF, LUN, "are then processed by the CDS operations team into "
	PRINTF, LUN, "FITS files.  In general, the final distribution data "
	PRINTF, LUN, "is received by CDS approximately a month after the "
	PRINTF, LUN, "actual observations took place.  The contents of the "
	PRINTF, LUN, "CDROMs received by CDS as well as their processing "
	PRINTF, LUN, "status is described in the tables linked to this page. " 
	PRINTF, LUN, "Sets of CDROMs are grouped into sequences, and each "
	PRINTF, LUN, "sequence can contain one or more individual volumes. " 
	PRINTF, LUN, "Each table contains the data for 20 CDROM sequences. " 
	PRINTF, LUN, "If you know which table you want to view, then simply" 
	PRINTF, LUN, "click on the link to it below.  Otherwise, use the form" 
	PRINTF, LUN, "to search for the sequence number and volume of" 
	PRINTF, LUN, "the CDROM, or the day the data was received. </p>"

;
; Write some HTML text to begin a table.  The table will be invisible, used
; for formatting purposes only. 
;

	PRINTF, LUN, "<p>"
	PRINTF, LUN, "<center>"
	PRINTF, LUN, "<table>"

;
; Loop to add descriptions of each of the sub-pages containing CDROM
; processing information to the table that we started previously.  The loop
; ends when all of the page names have been added to the table. 
; 

	FOR FILE = 1, NO_FILES DO BEGIN

;
; Set filename to a string consisting of  the name of the of ith file which
; contains a table describeing the CDROM processing status.  Each table 
; tables describes the processing status of 20 sequences of CDROMs.
;  

	   FILENAME = STRING (FILE, FORMAT = '("cd_status_", I0, ".html")')

;
; Set FIRST to the first sequence of CDROMs whose processing 
; status is described by the current file.  Set LAST to the last sequence of
; CDROMs whose processing status is described by the current file.  If LAST 
; is greater then the largest CDROM sequence that has been registered, then 
; set it back to taht number. 
;

	   FIRST = ((FILE - 1) * 20) + 1
	   LAST = FIRST + 19
	   IF LAST GT MAX_SEQ THEN LAST = MAX_SEQ

;
; Write a some HTML text which describe which CDROMs are included in the 
; current file being processed.  Also write an anchor to that file, so that
; the user clicks on the description, the browser goes to that file.
;

	   PRINTF, LUN, '<tr> <td> <A HREF = "', FORMAT = '(A, $)' 
	   PRINTF, LUN, FILENAME, FORMAT = '(A, $)'
	   PRINTF, LUN, '" > ', FORMAT = '(A, $)'
	   PRINTF, LUN, 'CD Volumes ', FORMAT = '(A, $)'
	   PRINTF, LUN, FIRST, LAST, FORMAT = '(I0, " to ", I0, " </A>", $)'
	   PRINTF, LUN, " </td> </tr>"

	ENDFOR

;
; Write some HTML text to close out the table.
;

	PRINTF, LUN, '</table>'
	PRINTF, LUN, '</center>'
	PRINTF, LUN, '</p>'

;
; Call the procedure HLINE to insert some HTML text so that a horizontal
; line will be generated.
;

	HLINE, LUN

;
; Write a line of HTML text to begin the form portion of the web page.
;

	PRINTF, LUN, '<form name = "find">'

;
; Write some HTML formatted text telling the user how to use the portion of 
; web page which allows searches on CDROM sequence and volume numbers.
;

	PRINTF, LUN, '<p> Enter the Sequence Number and Volume of the CD to'
	PRINTF, LUN, 'search for, then press the Go! button.</p>'
	PRINTF, LUN, '<p> <center>'
	PRINTF, LUN, '<table>'

;
; Write some HTML format codes to create input field so that the user can
; enter the CDROM sequence number to search on.
;

	PRINTF, LUN, '<tr> <td> CD Set </td> <td>'
	PRINTF, LUN, '<input    type =          "text" '
	PRINTF, LUN, '          name =          "seqfind"'
	PRINTF, LUN, '          size =          "10" '
	PRINTF, LUN, '          value =         "1">'
	PRINTF, LUN, '</td> </tr>'

;
; Write some HTML format codes to create input field so that the user can
; enter the CDROM volume number to search on.
;

	PRINTF, LUN, '<tr> <td> CD Volume </td> <td>'
	PRINTF, LUN, '<input    type =          "text" '
	PRINTF, LUN, '          name =          "volfind"'
	PRINTF, LUN, '          size =          "10"'
	PRINTF, LUN, '          value =         "1">'
	PRINTF, LUN, '</td> </tr>'

;
; Write some HTML format codes to create button that will begin a search
; search on the sequence and volume number that user has entered in the 
; previous two input fields.  The search is initiated by calling the 
; Javascript function 'searchseq'.
;

	PRINTF, LUN, '<tr align = center> <td colspan = 2>'
	PRINTF, LUN, '<input    type =          "button" '
	PRINTF, LUN, '          name =          "search" '
	PRINTF, LUN, '          value =         "Go!"'
	PRINTF, LUN, '          onClick=        "parent.searchseq ()">'
	PRINTF, LUN, '</td> </tr>'


;
; Write some HTML format codes to finish off the previous portion of the web
; page.
;

	PRINTF, LUN, '</table>'
	PRINTF, LUN, '</center> </p>'


;
; Write some HTML formatted text telling the user how to use the portion of 
; web page which allows searches on the day, month, and year covered by a
; CDROM.
;

	PRINTF, LUN, '<p> Enter the day of the year to search for, then press'
	PRINTF, LUN, 'the Go! button.</p>'
	PRINTF, LUN, '<p> <center>'
	PRINTF, LUN, '<table>'

;
; Write some HTML format codes to create a select list with every month in 
; the year.  This saves the user the trouble of haveing to type in a month
; name or number.
;

	PRINTF, LUN, '<tr> <td>'
	PRINTF, LUN, '<select   name =		"month">'
	PRINTF, LUN, '<option> January'
	PRINTF, LUN, '<option> February'
	PRINTF, LUN, '<option> March'
	PRINTF, LUN, '<option> April'
	PRINTF, LUN, '<option> May'
	PRINTF, LUN, '<option> June'
	PRINTF, LUN, '<option> July'
	PRINTF, LUN, '<option> August'
	PRINTF, LUN, '<option> September'
	PRINTF, LUN, '<option> October'
	PRINTF, LUN, '<option> November'
	PRINTF, LUN, '<option> December'
	PRINTF, LUN, '</select>'
	PRINTF, LUN, '</td> <td>'

;
; Write some HTML format codes to create input field so that the user can
; enter the day of month to search on.
;

	PRINTF, LUN, '<input    type =          "text" '
	PRINTF, LUN, '          name =          "day"'
	PRINTF, LUN, '          size =          "5"'
	PRINTF, LUN, '          value =         "1">'
	PRINTF, LUN, '</td> <td>'

;
; Write some HTML format codes to begin a select list with every year from
; 1995 (the year of launch) to the present.  This saves the user the trouble
; of haveing to type in a year number.  
;

	PRINTF, LUN, '<select   name =		"year">'

;
; Initialize year to be an integer variable equal to 0.
;

	YEAR = 0

;
; Copy the year from the result of calling the function SYSTIME into YEAR.
;

        READS, STRMID (SYSTIME (), 20, 4), YEAR

;
; Loop to add select items to the the select list.  Each item is year.  One
; item/year is added for every year between the current year and 1995.
;
	FOR I = 1995, YEAR DO BEGIN
	   PRINTF, LUN, I, FORMAT = '("<option> ", I0)'
	ENDFOR

;
; Write the HTML format code to finish of the select list for the year to 
; search on.
;

	PRINTF, LUN, '</select>'
	PRINTF, LUN, '</td> </tr>'

;
; Write some HTML format codes to create button that will begin a search
; search on the month, day and year that the  user has entered in the 
; previous 3 input fields.  The search is initiated by calling the 
; Javascript function 'searchdate'.
;

	PRINTF, LUN, '<tr align = center> <td colspan = 3>'
	PRINTF, LUN, '<input    type =          "button" '
	PRINTF, LUN, '          name =          "search" '
	PRINTF, LUN, '          value =         "Go!"'
	PRINTF, LUN, '          onClick=        "parent.searchdate ()">'
	PRINTF, LUN, '</td> </tr>'

;
; Write some HTML format codes to finish off the previous portion of the web
; page.
;

	PRINTF, LUN, '</table>'
	PRINTF, LUN, '</center> </p>'

;
; Write an HTML format code to finish the form portion of the web page.
;

	PRINTF, LUN, '</form>'

;
; Call the procedure HLINE to insert some HTML text so that a horizontal
; line will be generated.
;

	HLINE, LUN

;
; Write the HTML format codes to end the web page.
;

	PRINTF, LUN, "</body>"
	PRINTF, LUN, "</html>"

;
; Close the file that this web page was being written to.
;

	CLOSE, LUN

;
; Were Done !!!
;

	RETURN

	END
