;+
; Project     : SOHO - CDS     
;                   
; Name        : ENG_MON_MENU
;               
; Purpose     : Define the Engineering Monitor main window. 
;               
; Explanation : Defines all the widgets used in the engineering telemetry
;               monitor program.
;               
; Use         : Only called from EMON
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Telemetry
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 29-Sep-94
;               
; Modified    : Enlarge message window.  CDP, 1-Jun-95
;               Include plotting mode parameter.   CDP, 22-Nov-95
;               Check if files were defined on command line.  CDP, 06-Dec-95
;
; Version     : Version 4, 05-Dec-95
;-            
 
PRO eng_mon_menu


;
;  main COMMON variables
;
@emon.com

;
;  setup main font
;
font = "-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1"
;
;  define main widget
;
main_base = WIDGET_BASE (TITLE='CDS Engineering Data Monitor', /FRAME, $
                         /COLUMN, xoff=10, yoff=10)
menu_base = WIDGET_BASE (main_base, /ROW)

;
;  create the exit "DONE" button
;
doneid = widget_button(menu_base, value='EXIT', uvalue='Done',font=font)

;
;  choice of A or B engineering
;
xmenu,['Eng A','Eng B'],buttons=ab_ids,menu_base,/row,/exclusive,/no_release,$
           title='Select A or B',uvalue=['ENGA','ENGB'],font=font
wanted_packets = 'A'
widget_control,ab_ids(0),set_button=1

;
;  select some telemetry files
;
dummy = widget_button(menu_base,value='Select telemetry files',uval='TMFILE',$
                      /no_rel,font=font)
if n_elements(file_name) eq 0 then num_data_files = 0


;
;  select a parameter
;
dummy = widget_button(menu_base,value='Select parameters',uval='PARMS',$
                      /no_rel,font=font)

;
; make message window widget
;
dummy = WIDGET_BASE(main_base, /column, /FRAME, YOFFSET=-100)
dummy_widg = WIDGET_LABEL(dummy, VALUE=' Messages   : ')
msg_widg = WIDGET_TEXT(dummy, XSIZE = 60, YSIZE=20, /scroll)

;
;  actions

action_base = WIDGET_BASE (main_base, /ROW)
;
;  select some telemetry files
;
readid = widget_button(action_base,value='Read telemetry.',uval='READ',$
                      /no_rel,font=font)

dummy = widget_button(action_base,value='STOP reading',uval='STOP',$
                      /no_rel,font=font)

plotid = widget_button(action_base,value='Plot parameters.',uval='PLOT',$
                      /no_rel,font=font)


dummy = widget_button(action_base,value='Help',uval='HELP',$
                      /no_rel,font=font)

;
;  realise the menu widget to make it all happen
;
WIDGET_CONTROL, /REALIZE , main_base

WIDGET_CONTROL, main_base, /CLEAR_EVENT


reading = 0
emon_plottd = 1

;
;  set it all going
;
XMANAGER, 'eng_mon', main_base
   

END

