;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_RELAYS_HIST
;               
; Purpose     : Restores data structure of CDS relay usage.
;               
; Explanation : Uses IDL RESTORE command to recall the data structure 
;               containing the history of CDS relay usage.  The structure
;               returned is an array of structures with tags .par, .time, 
;               .state and .desc.  Basic IDL commands (eg 'where') can then
;               be used to extract the particular information required.
;               
; Use         : IDL> gt_relays_hist, relay
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : RELAY - array of structures giving the relay usage history.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: Required read access to $CDS_ENG_DATA directory.
;               
; Side effects: None
;               
; Category    : Engineering
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Aug-95
;               
; Modified    : Changed evar name to CDS_ENG_DATA. CDP, 23-Oct-95
;               Changee name of log file.  CDP, 28-Nov-95
;
; Version     : Version 1, 28-Nov-95
;-            

pro gt_relays_hist, relay

;
;  check at least one parameter
;
if n_params() ne 1 then begin
   print,'Use: IDL> gt_relay_hist, relay'
   return
endif

;
;  check env. var. is defined
;
ev = getenv('CDS_ENG_DATA')
if ev eq '' then begin
   print,'Environment variable CDS_ENG_DATA is not defined.'
   return
endif

;
;  SAVE file name
;
sf = concat_dir('$CDS_ENG_DATA','relays_log')

;
;  attempt to open save file to check accessibility
;
openr,lun,sf,/get_lun,error=err
if err ne 0 then begin
   print,'Error: Unable to access the relay history save file.'
   return
endif
free_lun,lun

;
;  restore the dataset
;
restore,file=sf

end


