;+
; Project     : SOHO - CDS     
;                   
; Name        : SEL_TSENS_EVENT
;               
; Purpose     : Processes events from the SEL_TSENS_MENU.
;               
; Explanation : Any events originating within the widgets realized by 
;               SEL_TSENS_MENU are handled by this routine.
;               
; Use         : Only by XMANAGER
;    
; Inputs      : ev  -  the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with SEL_TSENS_MENU.
;               
; Side effects: None
;               
; Category    : Telemetry
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 27-Oct-95
;               
; Modified    : 
;
; Version     : Version 1, 27-Oct-95
;-            

PRO sel_tsens_event, ev

;
;  COMMON block for variables
;
@cds_temperature.com
      
;
;  interpret type of event
;
type = TAG_NAMES(ev, /STRUCTURE)

;
;  could have been a BUTTON
;                    ======
;
IF (type EQ 'WIDGET_BUTTON') THEN BEGIN
   WIDGET_CONTROL, ev.id, GET_VALUE=value, get_uvalue=uvalue
 
;
;  Done (ie exit) request received which triggers plotting of chosen 
;  parameters
; 
   IF (uvalue EQ 'Done') THEN BEGIN
      WIDGET_CONTROL, sel_tplot_base, /destroy
      widget_control, main_base, sens=1
      cds_tplot
   ENDIF

;
;  Reset request received
; 
   if (uvalue EQ 'Reset') then begin
      tplot_parms(*) = ''
      bell
      widget_control,msg_widg,set_val='Plot selection cleared.'
   endif

;
;  Cancel request received
; 
   if (uvalue EQ 'Cancel') then begin
      tplot_parms(*) = ''
      WIDGET_CONTROL, sel_tplot_base, /destroy
      widget_control, main_base, sens=1
   endif

ENDIF


;
;  or it was an INDEX input from the list itself
;               =====
;
if type eq 'WIDGET_LIST' then begin

   line = cds_temp_log(ev.index).name

;
;  already there?
;
   n = where(tplot_parms eq line)

;
;  if so, ignore
;
   if n(0) eq -1 then begin
      n = where(tplot_parms eq '')
;
;  add to list if room, if not then warn
;
      if n(0) eq -1 then begin
         flash_msg, msg_widg,'Plot list full, reset if needed.'
      endif else begin
         n = min(n)
         tplot_parms(n) = line
         widget_control, msg_widg, set_val=line, /append
      endelse
   endif
endif

END
