	PRO CDS_ATTENTION, MESSAGE
;+
; Project     : SOHO - CDS
;
; Name        : 
;	CDS_ATTENTION
; Purpose     : 
;	Bring a severe error to the operator's attention.
; Explanation : 
;	Brings a severe error message to the attention of the CDS operators, by
;	sending a mail message.
;
;	Normally, one would not call this routine directly, but would call
;	CDS_MESSAGE, /ATTENTION.
;
; Use         : 
;	CDS_ATTENTION, MESSAGE
; Inputs      : 
;	MESSAGE	= Message to be sent to the CDS operators.
; Opt. Inputs : 
;	None.
; Outputs     : 
;	None.
; Opt. Outputs: 
;	None.
; Keywords    : 
;	None.
; Env. Vars.  :	
;	CDS_OPERATOR defines the mail address of the CDS operator whose
;	attention is requested.
; Calls       : 
;	DATATYPE
; Common      : 
;	None.
; Restrictions: 
;	Because CDS_ATTENTION does not a priori know what routine called it,
;	the name of the routine should be evident from the text of the message.
; Side effects: 
;	If CDS_ATTENTION is called incorrectly, then a message describing the
;	error will be printed instead, and the IDL program will be brought to a
;	halt.
; Category    : 
;	Data Handling, Telemetry.
; Prev. Hist. : 
;	William Thompson, February 1993.
; Written     : 
;	William Thompson, GSFC, February 1993.
; Modified    : 
;	Version 1, William Thompson, GSFC, February 1993.
;	Version 2, William Thompson, GSFC, 17 September 1993.
;		Modified to allow multi-line messages.
;	Version 3, William Thompson, GSFC, 1 September 1994
;		Modified to send messages by mail.
;	Version 4, William Thompson, GSFC, 28 February 1996
;		Always write temporary file to home directory.
; Version     : 
;	Version 4, 28 February 1996
;-
;
	ON_ERROR, 2
;
;  Test the input parameter MESSAGE.  If CDS_ATTENTION is called improperly, then
;  CDS_MESSAGE will be called, and the program will be brought to a complete
;  halt.
;
	IF N_PARAMS() EQ 0 THEN CDS_MESSAGE, "Syntax:  CDS_ATTENTION, MESSAGE"
	IF N_ELEMENTS(MESSAGE) EQ 0 THEN CDS_MESSAGE,	$
		"CDS_ATTENTION:  MESSAGE not defined"
	IF DATATYPE(MESSAGE,1) NE 'String' THEN CDS_MESSAGE,	$
		"CDS_ATTENTION:  MESSAGE must be a string"
;
;  Ring the terminal bell.
;
	BELL
;
;  If the environment variable CDS_OPERATOR is defined, then spawn mail to send
;  the message.
;
	OPERATOR = GETENV('CDS_OPERATOR')
	IF OPERATOR NE '' THEN BEGIN
		OPENW, MAIL_UNIT, '$HOME/ATTENTION.txt', /GET_LUN
		PRINTF, MAIL_UNIT, 'To: ' + OPERATOR
		PRINTF, MAIL_UNIT, 'Subject: ATTENTION'
		PRINTF, MAIL_UNIT, ''
		FOR I=0,N_ELEMENTS(MESSAGE)-1 DO PRINTF, MAIL_UNIT, MESSAGE(I)
		FREE_LUN,MAIL_UNIT
		SPAWN, 'mail ' + OPERATOR +	$
			'< $HOME/ATTENTION.txt; rm $HOME/ATTENTION.txt'
	ENDIF
;
;  Write the message out to the screen, whether mailed or not.
;
	S1 = "Attention:  "
	S2 = "            "
	PRINT, S1 + MESSAGE(0)
	FOR I = 1,N_ELEMENTS(MESSAGE)-1 DO PRINT, S2 + MESSAGE(I)
;
	RETURN
	END
