	PRO CDS_TTYPE, RASTER, TTYPE
;+
; Project     :	SOHO - CDS
;
; Name        :	CDS_TTYPE
;
; Purpose     :	Determines labels for data window columns in binary tables
;
; Explanation :	Determines the values of the TTYPE keywords for the data window
;		columns in the binary tables.
;
; Use         :	CDS_TTYPE, RASTER, TTYPE
;
; Inputs      :	RASTER	   = Structure variable from READ_RASTER
;
; Opt. Inputs :	None.
;
; Outputs     :	TTYPE	= The label for each column in the binary table.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Data_handling, Telemetry, I/O, FITS, CDS.
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 10 March 1995
;
; Modified    :	Version 1, William Thompson, GSFC, 3 July 1995
;
; Version     :	Version 1, 3 July 1995
;-
;
	ON_ERROR, 2
;
;  Check the number of parameters.
;
	IF N_PARAMS() NE 2 THEN MESSAGE,	$
		'Syntax: CDS_TTYPE, RASTER, TTYPE'
;
;  From the raster structure, get the number of windows and the data window ID.
;
	DW_ID = RASTER.HEADER.SCI.DATAWINDOWID
	N_WINDOWS = RASTER.HEADER.NWINDOWS
;
;  In case we cannot properly connect the telemetry to the science plan, simply
;  return the fake values "WINDOWn"
;
	TTYPE = "WINDOW" + STRTRIM(INDGEN(N_WINDOWS)+1,2)
;
;  If we can connect the telemetry properly, then determine the proper window
;  names.
;
	GET_DATAWIN, DW_ID, DATAWIN
	IF DATAWIN.DW_ID LE 0 THEN BEGIN
		MESSAGE = 'Unable to find data window list, ID=' + TRIM(DW_ID)
		GOTO, HANDLE_ERROR
	ENDIF
;
	IF N_WINDOWS NE N_ELEMENTS(DATAWIN.WINS) THEN BEGIN
		MESSAGE = 'Number of windows in telemetry does not match ' + $
			'data window definition'
		GOTO, HANDLE_ERROR
	ENDIF
;
;  Formulate the TTYPE string, removing any leading or trailing blanks, and
;  replacing all white space with an underscore character.
;
	TTYPE = REPCHAR(STRCOMPRESS(STRTRIM(DATAWIN.WINS.WIN_NAME,2)),' ','_')
	RETURN
;
HANDLE_ERROR:
	CDS_MESSAGE, MESSAGE, /CONTINUE

	RETURN
	END
