	FUNCTION DEFCDSTIME
;+
; Project     :	SOHO - CDS
;
; Name        :	DEFCDSTIME()
;
; Purpose     :	Default time to use if no exposure headers
;
; Category    :	Class4, Operations, Telemetry
;
; Explanation :	If there are no exposure headers in the raster, then uses the
;		timestamp of the last packet read in to derive a time.
;
;		Called from GETCDSTIMES.
;
; Syntax      :	Result = DEFCDSTIME()
;
; Examples    :	
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	The result of the function is a TAI time value.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	
;
; Common      :	Uses the FITSGEN common block.
;
; Restrictions:	None.
;
; Side effects:	False start and end times are put into the catalog.  However,
;		these times are closer to reality than assuming 0.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 10-Apr-1996, William Thompson, GSFC
;
; Contact     :	WTHOMPSON
;-
;
	ON_ERROR,2
@fitsgen.cmn
;
	RETURN, OBT2TAI(LPACKET.HDR.TIME)
	END
