	FUNCTION TEST_SCI_PKT, PACKET
;+
; Project     : SOHO - CDS
;
; Name        : TEST_SCI_PKT()
;
; Purpose     : Tests if packet is a science packet.
;
; Explanation : This routine tests whether or not a given packet is part of the
;		science telemetry or something else, e.g. an engineering
;		packet.
;
; Use         : Result = TEST_SCI_PKT( PACKET )
;
;		IF TEST_SCI_PKT(PACKET) THEN ...
;
; Inputs      : PACKET = Packet to be tested.
;
; Opt. Inputs : None.
;
; Outputs     : The result of the function is either true (1) if the packet is
;		a science packet, or false (0) otherwise.
;
; Opt. Outputs: None.
;
; Keywords    : None.
;
; Calls       : None.
;
; Common      : None.
;
; Restrictions: If the packet is not a science packet, then no checking is done
;		to see if the packet is a valid CDS packet.
;
; Side effects: None.
;
; Category    : Data Handling, Telemetry.
;
; Prev. Hist. : None.
;
; Written     : William Thompson, GSFC, 22 March 1993.
;
; Modified    : Version 1, William Thompson, GSFC, 22 March 1993.
;		Version 2, William Thompson, GSFC, 31 August 1994
;			Included raster abort packet IDs.
;
; Version     : Version 2, 31 August 1994
;-
;
	ID = PACKET.HDR.ID
	RETURN, (ID EQ '01'X) OR (ID EQ '02'X) OR (ID EQ '11'X) OR	$
		(ID EQ '12'X) OR (ID EQ '21'X) OR (ID EQ '22'X) OR	$
		(ID EQ '03'X)
	END
