;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Document name: cp_dsp_strarr.pro
; Created by:    Liyun Wang, GSFC/ARC, September 2, 1994
;
; Last Modified: Wed Nov 23 15:44:21 1994 (lwang@orpheus.nascom.nasa.gov)
;                11/8/95 MKC, RAL (carter@bnsc.rl.ac.uk
;                CP_DSP_STRARR adapted from dsp_strarr.
;                11/12/95, MKC
;                          Added option to print directly to laser printer in landscape format.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;+
; PROJECT:
;      SOHO - CDS
;
; NAME:
;      CP_DSP_STRARR
;
; PURPOSE: 
;      To display a string array in a text widget with print option.
;
; EXPLANATION:
;      
; CALLING SEQUENCE: 
;      CP_DSP_STRARR, string_array [, font = font, title=title]
;
; INPUTS:
;      strings -- The string array to be displayed. 
; OPTIONAL INPUTS: 
;      None.
;
; OUTPUTS:
;      None.
;
; OPTIONAL OUTPUTS:
;      None.
;
; KEYWORD PARAMETERS: 
;      FONT   -- Font to be used for the text widget. Default: fixed
;      TITLE  -- Title of the widget window. Default: 'Info Window'
;      ONE_COPY -- Set this keyword to let xmanager know that only one copy of
;                  this widget is allowed to run at one time.
; CALLS:
;      None.
;
; COMMON BLOCKS:
;      strarrblock : used to pass string array and title to event process..
;
; RESTRICTIONS: 
;      None.
;
; SIDE EFFECTS:
;      None.
;
; CATEGORY:
;      Utilities, widgets
;
; PREVIOUS HISTORY:
;      
; MODIFICATION HISTORY:
;      Written September 2, 1994, by Liyun Wang, GSFC/ARC
;              11/8/95, MKC, Added print option.
;              11/1/96, MKC, Modified file and printer printout.
;              16/2/96, CDP, Added width parameter to output file.
;	Version 5, William Thompson, GSFC, 9 September 1996
;		Made compatible with IDL version 4.
;      
; VERSION: Version 5, 9 September 1996
;      
;-
;
PRO CP_DSP_STRARR_EVENT, event

   COMMON strarrblock, strings, title 

   wtype = WIDGET_INFO(event.id,/type)
   IF wtype EQ 1 THEN BEGIN
      WIDGET_CONTROL, event.id, get_uvalue = value
      CASE value OF
        'QUIT'  : WIDGET_CONTROL, event.top, /destroy
        'FILE'  : BEGIN

                    ; get file name for printout

                    file = PICKFILE(/WRITE)

                    ; return if no file given

                    IF file EQ '' THEN RETURN
 
                    ; open file

                    OPENW, unit, file, /GET_LUN
 
                    ; write text

                    IF N_ELEMENTS(title) GT 0 THEN PRINTF, unit, title

                    FOR k = 0, N_ELEMENTS(strings)-1 DO PRINTF, unit, strings(k)

                    ; close file

                    FREE_LUN, unit

                  END

        'PRINT' : BEGIN

                    ; open file

                    OPENW, unit, 'tempcpidl', /GET_LUN, width=132
 
                    ; write text

                    IF N_ELEMENTS(title) GT 0 THEN PRINTF, unit, title
                    
                    FOR k = 0, N_ELEMENTS(strings)-1 DO PRINTF, unit, strings(k)

                    ; close file

                    FREE_LUN, unit

                    ; print file

                    SPAWN, 'lpr -w132 tempcpidl

                    ; remove file

                    SPAWN, 'rm tempcpidl

                  END

         ELSE   : NULL
      ENDCASE
   ENDIF
END

PRO CP_DSP_STRARR, strings, font=font, title=title, one_copy=one_copy, $
                   group=group

   ; put text and title in common block

   COMMON strarrblock, s, t 
   s = strings
   t = title

   IF xregistered('cp_dsp_strarr') AND KEYWORD_SET(one_copy) THEN RETURN 
   n =  N_ELEMENTS(strings) 
   IF n EQ 0 THEN BEGIN
      PRINT, 'DSP_STRARR -- Usage:'
      PRINT, '    DSP_STRARR, string_array [, font=font]
      PRINT, ' '
      RETURN
   ENDIF
   IF datatype(strings) NE 'STR' THEN BEGIN
      PRINT, 'DSP_STRARR -- Input parameter has to be string array'
      PRINT, ' '
      RETURN
   ENDIF
   
   IF N_ELEMENTS(font) EQ 0 THEN font = 'fixed'
   IF N_ELEMENTS(title)  EQ 0 THEN title = 'Info Window'
   base = WIDGET_BASE(title = title, /column, space = 15, xpad = 5, $
                      ypad = 5)
   row1 = WIDGET_BASE(base, /row, xpad = 80)
   
   quit = WIDGET_BUTTON(row1, value = 'Dismiss', uvalue = 'QUIT', /frame)

   file = WIDGET_BUTTON(row1, value = 'File', uvalue = 'FILE', /frame) ; MKC addition

   print = WIDGET_BUTTON(row1, value = 'Print', uvalue = 'PRINT', /frame) ; MKC addition
   
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;  We will put a limit on number of lines and number of characters in
;  each line that can be shown in the widget. We set line number be
;  be 20 and number of characters in each line be 60. Byound these
;  values, there has to be a scrolling bar to guide the user to see
;  other text. 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
   IF n LE 20 THEN BEGIN
      row2 = WIDGET_LIST(base, value = strings, $
                         font = font, ysize = n)
   ENDIF ELSE BEGIN
      row2 = WIDGET_LIST(base, value = strings, $
                         ysize = 20, font = font)
   ENDELSE
   
   WIDGET_CONTROL, base, /realize
   
   XMANAGER, 'cp_dsp_strarr', base, group_leader = group
END

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; End of 'cp_dsp_strarr.pro'.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
