;+
; Project     :	SOHO - CDS
;
; Name        :	CP_INIT_STDB
;
; Purpose     :	Initializes the CDHS state database.
;
; Explanation : Removes any existing CDHS state database and recreates empty database.
;
; Use         : <cp_init_stdb>
;
; Inputs      : None.
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	find_with_def, dbcreate
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	Version 0.0, Martin Carter, RAL, 24/5/94
;
; Modified    :	
;
; Version     :	Version 0.0, 24/5/95
;-
;**********************************************************

PRO cp_init_stdb

  ; set priviledge to update database

  !PRIV = 2

  PRINT, ''
  PRINT,'Initializing cdhs state database'

  ; go to directory with cdhsstate.dbd file

  file = find_with_def('cdhsstate.dbd', '$ZDBASE')
    
  IF file EQ '' THEN MESSAGE, 'No database descriptor file'

  ; change directory 

  IF STRLEN (file) GT 14 THEN CD, STRMID ( file, 0, STRLEN(file)-13 ), CURRENT=currentdir

  ; delete database files

  files = 'cdhsstate.dbf cdhsstate.dbx cdhsstate.dbh'

  PRINT, ''
  PRINT, 'Removing files ', files

  SPAWN, 'rm ' + files

  ; create new database files

  PRINT, ''
  PRINT, 'Creating new databases'

  dbcreate, 'cdhsstate', 1, 1

  ; change back to current directory

  IF STRLEN (file) GT 14 THEN CD, currentdir

  ; reset priviledges

  !PRIV = 1  

END


