;+
; Project     :	SOHO - CDS
;
; Name        :	DO_GSET_LUT_TTC
;
; Purpose     :	Writes out commands for a GIS lookup table to the TTC file.
;
; Explanation :	Writes out the commands to set up a GIS lookup table to the TTC file
;               used to load the deferred command store.
;               NB. Encloses SCCs in quotes. Cannot use hex values instead of mnemonics for SCCs.
;              
; Use         : <do_gset_lut_ttc, unit, lut_par, timenow, commands>
;
; Inputs      : unit     = logical unit no. for output
;               lut_par  = BYTARR(11) giccing GIS LUT parameters
;               timenow  = double giving current tai time
;               commands = integer no. of deferred commands so far 
;
; Opt. Inputs : None.
;
; Outputs     : Writes commands to TTC file.
;               Updates timenow, commands.
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	shorthex, cp_get_entry, tai2utc.
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	Created from do_gset_init.
;
; Written     :	Version 0.0, Martin Carter, RAL, 23/2/96
;               
; Modified    :	0.1, 8/7/96, MKC
;                 Added commands argument.
;               0.2,   Cater for IDL5.2 hex bug.  CDP, 1-6-99
;
; Version     :	Version 0.2, 1-6-99
;-
;**********************************************************

PRO do_gset_lut_ttc, unit, lut_par, timenow, commands

    ; get LUT command delay from state database

    ss = cp_get_entry ( 'GISLTDLY', [0] )

    lut_delay = ss(0).active/1000 ; secs

    ; write out block commands to TTC file

    PRINTF, unit, '# calculate LUT for detector ' + STRTRIM(STRING(FIX(lut_par(7))),2) 
    PRINTF, unit

;    ; set up lookup table command block

;    lkp_blok = [ '7100'xl, '7200'xl, '7300'xl, '7400'xl, '7500'xl, '7600'xl, $
;                 '7D00'xl, '7E00'xl, '8100'xl, '8200'xl, '8300'xl ]

;    luts = lkp_blok OR FIX(lut_par(*))

;    PRINTF, unit, '"', tai2utc ( timenow, /ECS),'"   "0x230C ', shorthex(luts)+' ', '0xC02D"'
;    PRINTF, unit

    ; write out individual commands to TTC file

    FOR k = 0, 10 DO BEGIN

      PRINTF, unit, '"', tai2utc ( timenow, /ECS),'"   "CBGLP' + STRTRIM(k+1,2),' ', shorthex(lut_par(k)), '"'
      PRINTF, unit

      timenow = timenow + 1 ; add 1 second delay

      commands = commands + 4  ;  increment no. of INT16 words used in deferred command store by entry

    ENDFOR

    ; send calculate command

    PRINTF, unit, '"', tai2utc ( timenow, /ECS),'"   "CBGLRB"'
    PRINTF, unit

    ; add delay for calculating LUT

    timenow = timenow + lut_delay ; add delay

    ;  increment no. of INT16 words used in deferred command store by entry

    commands = commands + 4  

END

