;+
; Project     :	SOHO - CDS
;
; Name        :	FINI_CP_DB
;
; Purpose     :	Tidies up databases/directories used by CPT software.
;
; Explanation :	In order to avoid corruption of the databases used by CPT in the event
;               of CPT crashing, a duplicate copy of the databases used by CPT i.e the
;               commprep, series_id, raster_id, dexwin _id and vdswin_id databases, is made. 
;               This routine copies these back to the official version.
;               It removes the .dbh file first so that dbopen from a parallel process
;               will not be succesful on the database.
;
; Use         : <fini_cp_db>
;
; Inputs      :	None
;
; Opt. Inputs : None.
;
; Outputs     : None.
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	find_with_def, dbcreate.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	0.0, Martin Carter, RAL, 26/9/94
;
; Modified    : 0.1, MKC, 6/11/95
;                    Modified to use end_db.pro.
;               0.2, MKC, 21/11/95
;                    Added dexwin and vdswin datbases
;               0.3, MKC, 29/11/95
;                    Removed dexwin database.
;               0.4, MKC, 18/1/96
;                    Used single command for moving files.
;                    Change ordering and remove dbh file first.
;               0.5, MKC, 19/2/96
;                    Added dexwin database.
;           
; Version     :	Version 0.5, 19/2/96
;-
;**********************************************************

PRO end_db, database 

  ; find and make backup copy of database.dbd file

  file = find_with_def ( database + '.dbd', '$ZDBASE', /NOCURRENT )
    
  IF file EQ '' THEN MESSAGE, 'No ' + database + ' database descriptor file found'

  ; get directory of original database

  loc = STRPOS ( file, database + '.dbd' )

  directory = STRMID ( file, 0, loc ) ; result may be a NULL string

  ; update database files

  PRINT, 'Updating ' + database + ' files'

  SPAWN, 'rm ' + directory + 'r' + database + '.dbh ;' + $
         'mv ' + directory + 'd' + database + '.dbf ' + directory + 'r' + database + '.dbf ;' + $
         'mv ' + directory + 'd' + database + '.dbx ' + directory + 'r' + database + '.dbx ;' + $ 
         'mv ' + directory + 'd' + database + '.dbh ' + directory + 'r' + database + '.dbh' 

  PRINT, ''

END

PRO fini_cp_db

  ; find and rename database files

  end_db, 'commprep' 

  end_db, 'series_id' 

  end_db ,'raster_id' 

  end_db ,'dexwin_id' 

  end_db ,'vdswin_id' 

END

