;+
; Project     :	SOHO - CDS
;
; Name        :	GET_SLITP_DELAY
;
; Purpose     :	Calculates the time in millisecond units for a slit position movement
;
; Explanation :	Uses delay = constant + rate*no. of steps
;
; Use         : < delay = get_slitp_delay( slitp_start, slitp_end ) >
;
; Inputs      : slitp_start = slit start position;
;               slitp_end   = slit end position.
;
; Opt. Inputs : None.
;
; Outputs     : delay = delay in ms units;
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	cp_get_entry.
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	Adapted from get_slitn_delay.
;
; Written     :	Version 0.0, Martin Carter, RAL, 5/12/95
;
; Modified    :	Version 0.1, 3 May 1996, Zarro (GSFC), added common block 
;                            for speed.

;
; Version     :	Version 0.1
;-
;**********************************************************

FUNCTION get_slitp_delay, slitp_start, slitp_end

common get_slitp_delay,ss

  ; get slit number delay

  if n_elements(ss) eq 0 then ss = cp_get_entry ( 'CB2LAT', [9, 10] )

  const = ss(0).active  ; slitp const delay
  rate  = ss(1).active  ; slitp rate  delay

  ; work out slit movement

  no_of_steps = ABS(slitp_end - slitp_start)

  ; work out delay

  delay = const + rate*no_of_steps

  ; return delay in ms units

  RETURN, delay

END
