;+
; Project     :	SOHO - CDS
;
; Name        :	GET_VERSION
;
; Purpose     :	Gets s/w version number of code used to create CDS table.
;
; Explanation : Returns the current software version number of the code which creates
;               the CDS table.
;
; Inputs      : table = structure array listing information on tables used in science plan.
;
; Opt. Inputs : None.
;
; Outputs     : Updates the entries in table directly.
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	wr_series_file, wr_raster_file, wr_dexwin_file, wr_vdswin_file
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	Version 0.0, Martin Carter, RAL, 14/10/94
;
; Modified    :	Version 0.1, Martin Carter, RAL, 28/11/94
;                            Added proforma.
;               Version 0.2, MKC, RAL, 18/4/95
;                            Separated type from structure.
;                            Modified argument list.
;
; Version     :	Version 0.2, 18/4/95
;-
;**********************************************************

PRO get_version, type, table

  ; get sw version number

  IF type EQ 'SERIES' THEN BEGIN
    wr_series_file, table, /VERSION
  ENDIF ELSE IF type EQ 'RASTER' THEN BEGIN  
    wr_raster_file, table, /VERSION
  ENDIF ELSE IF type EQ 'DEXWIN' THEN BEGIN  
    wr_dexwin_file, table, /VERSION
  ENDIF ELSE IF type EQ 'VDSWIN' THEN BEGIN  
    wr_vdswin_file, table, /VERSION
  ENDIF

END
