;+
; Project     :	SOHO - CDS
;
; Name        :	NXT_SERIES_ID()
;
; Purpose     :	Returns next CDHS ID for a SERIES table.
;
; Explanation : Interrogates the series_id database to find last table used. 
;
; Use         : < cdhsid = nxt_series_id() >
;
; Inputs      : None.
;
; Opt. Inputs : None.
;
; Outputs     : cdhsid = the inext CDHS ID used to reference the table
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	dbopen, db_info, dbext, dbclose.
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	Adapted from get_series_id.
;
; Written     :	Version 0.0, Martin Carter, RAL, 9/10/96
;
; Modified    :	None.
;
; Version     :	Version 0.0, 9/10/96
;-
;**********************************************************

FUNCTION nxt_series_id

  ; define first cdhs ID 
  ; NB First 12 series tables are reserved or modified on power up
  ;     Tables start at 0.
  ; The first 10 series tables have IDs 0-9.
  ; The next 2 series tables have IDs 0xFFFE, 0xFFFF.
  ; Start the CDHS Ids so that they keep track with the table index.

  first_id = 12 

  ; open table ID database

  dbopen, 'dseries_id'

  ; check database has some entries
  ; else dbfind will flag error

  nentries = db_info ( 'entries' )

  IF nentries(0) EQ 0 THEN BEGIN

    ; database is empty
    ; set first entry

    cdhsid = first_id

  ENDIF ELSE BEGIN

    ; get next CDHS ID

    ; extract last cdhs ID 

    dbext, [ LONG ( nentries ) ], 'CDHS_ID', cdhsids   

    cdhsid = cdhsids(0) + 1

    IF cdhsids(0) EQ 32768 THEN MESSAGE, 'MAXIMUM CDHSID REACHED'

  ENDELSE

  ; close table ID database

  dbclose, 'dseries_id'

  RETURN, cdhsid

END


