;+
; Project     :	SOHO - CDS
;
; Name        :	OP_LTB_FILE
;
; Purpose     :	Opens the command preparation LTB file.
;
; Explanation :	The LTB file contains a list
;               of the tables needed by the science plan and indicates 
;               which need to be loaded and which are already loaded.
;
; Use         : <op_ltb_file, unit, startofperiod>
;
; Inputs      : startofperiod   = string containing UTC start time of science plan.
;
; Opt. Inputs : None.
;
; Outputs     : Opens LTB data file.
;               unit : logical unit for LTB file.
;
; Opt. Outputs:	None.
;
; Keywords    : None.
;
; Calls       :	concat_dir.
;                
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	Version 0.00, Martin Carter, RAL, 29/9/95
;                             Adapted from wr_ltb_file.
;
; Modified    :	Version 0.1, MKC, 23/10/95
;                 Renamed environment variables and used concat_dir.
;               Version 0.2, MKC, 7/11/95
;                 Added new input to allow clearing of all macro table IDs.
;
; Version     :	Version 0.2, 7/11/95
;-
;**********************************************************

PRO op_ltb_file, unit, startofperiod, clear

  ; Open LTB file 
  ; overwrite any existing file 

  ; get LTB file name

  filename = concat_dir ( '$CDS_CP_LTBFILES_W', startofperiod + '.LTB' )

  PRINT, 'OPENING FILE : ', filename
  PRINT, ''

  ; open file

  OPENW, unit, filename, /GET_LUN

  ; file header info

  get_utc, utc, /ECS

  PRINTF, unit, '# LTB FILE
  PRINTF, unit, '# Created ', utc
  PRINTF, unit

  ; add note to clear MACRO tables

  IF clear THEN BEGIN

    PRINT, 'CLEARING MACRO SERIES, RASTER, LINELIST, VDSWINDOW TABLE IDS'
    PRINT, ''

    PRINTF, unit, '# Clear all MACRO table IDs'
    PRINTF, unit    
    PRINTF, unit, 'TABLE_CLEAR'
    PRINTF, unit

  ENDIF

END
