;+
; Project     :	SOHO - CDS
;
; Name        :	SET_IEF
;
; Purpose     :	Translates IEF table structure into a loadable IEF table.
;
; Explanation : Sets up the loadable 5 by 14 table from the IEF parameters.
;
; Use         : < table = set_ief ( def ) >
;
; Inputs      : def = anonymous structure containing IEF database values.
;                  def.ieftab_id  = I*2      IEFTAB database ID.
;                                            Initially, this is zero.  It is updated by this routine to
;				             reflect the ID number in the database.
;                  def.desc       = C*65     Description of event generation scheme.
;                  def.upp_era    = 4(I*2)   Upper limit for each ERA measure (unsigned INT16)
;                  def.low_era    = 4(I*2)   Lower limit for each ERA measure (unsigned INT16)
;                  def.discrim    = I*2      Discriminator level (unsigned INT16)
;                  def.ev_type    = I*2      Event type (4 bits)
;                  def.pmode      = I*2      Pointing mode : NIS=0, VF=1, GIS=2 (2 bits)
;                  def.cmode      = I*2      Centroid mode : POS=0, NEG=1, ABS=2 (2 bits)
;                  def.c_banda    = I*2      Slit centre band A (INT16)
;                  def.c_bandb    = I*2      Slit centre band B (INT16)
;                  def.c_row      = I*2      Central row (INT16)
;                  def.detector   = C*1      'N'= NIS, 'G'= GIS.
;                  def.wins       =  structure array containing window info
;                    wins.iefwin_id  = I*2    Window ID.
;                    wins.win_name   = C*40   Window name
;                    wins.ev_desc    = C*65   Description of event detection scheme employed
;                    wins.win_def    = 4(I*2) Window definition ( xstart, ystart, xsize, ysize )
;                    wins.px_offset  = I*2    Pixel offset defining ROI around peak pixel.
;                    wins.exp_era    = 4(I*2) Expected values for each ERA in window.
;                    wins.dev_era    = 4(I*2) Deviations for each ERA in window.
;                    wins.wgt_era    = 4(I*2) Weights for each direct ERA in window.
;                    wins.wgt_dera   = 4(I*2) Weights for each differential ERA in window.
;
; Outputs     :	table : INTARR(5,14) parameters in loadable form.
;
; Keywords    :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Calls       :	None.
;                
; Common      :	None.
;
; Category    :	Command preparation.
;
; Prev. Hist. :	None.
;
; Written     :	Version 0.0, Martin Carter, RAL, 2/11/95
;
; Modified    :	
;
; Version     :	Version 0.0, 2/11/95
;-
;**********************************************************

FUNCTION set_ief, def

  RETURN, REPLICATE ( 999, 5, 14)

END