;
; gis_raw_table_all.pro
;
;	list the information in a raw file in tabular form
;
;
pro gis_raw_table_all, csv_file=csv_file
;
	if keyword_set(csv_file) then begin
		file = 'all_raw_data.csv'
		openw, csv_lun, /get_lun, file, width=400
		printf, csv_lun, 'Filename, det, hv, bugmcpb, ' + $
			'bigmcp, bgkrcd, bkgulcd, bkgldld, bkghvl, ' + $
			'fil, fcur, slitn, slitp, mirp, ' + $
			'hex_fcur, hex_bughv, hex_bkghvl, cal_bughv, ' + $
			'cal_bigmcp, cal_bugmcpb, Comment'
	endif
;
	result = find_file(getenv('CDS_GIS_RAW') + '/*.raw', count=count)
;
; loop over returned result
;
	countdown, count, /open
	for rawnum = 0, count-1 do begin
;
		if (rawnum mod 20) eq 0 then countdown, rawnum
		header = bytarr(512)	; initialize array	
;
		on_ioerror, skipit
		openr, lun, /get_lun, result[rawnum]
;
;  read in header
;
        	readu, lun, header      ; read header
		if keyword_set(csv_file) then $
			head_str = gis_raw_header (header, /quiet) $
		else	head_str = gis_raw_header (header)
skipit:
		on_ioerror, null
		free_lun, lun
;;;
;;;stop
;;;
;
; write it out, comment last and file name first
;
		comment = head_str.comment
		head_str.comment = ssw_strplit(result[rawnum], '/', /tail)
;
; replace all commas with a dash (commas confuse the CSV file)
;
		comment = repchar(comment, ',', '-')
;
		if keyword_set(csv_file) then begin
;
			format = '(30(A, :, ","))' 
			printf, csv_lun, format=format, head_str, comment
		
		endif		
;
	endfor		; loop over all entries
	countdown, /close
;
	if keyword_set(csv_file) then begin
		free_lun, csv_lun
		print
		print, 'File: ', file, ' written' 
	endif
;
	return
end
