;+
; Project     : SOHO - CDS
;
; Name        : CF_177LG
;
; Purpose     : To relocate ghosts
;
; Explanation : When called by GHOST_BUSTER, relocates ghosted lines
;               automatically back to parent line.
;
; Use         : only works in call from ghost_buster
;
; Inputs      : QLDS =      Structure variable of GIS data as read by
;                           READCDSFITS.
;
;              
; Opt. Inputs : PLOT =      Plots the fits.
;
; Outputs     : QLDS, corrected for some ghosts.
;
; Opt. Outputs: None.
;
; Keywords    :
;
; Calls       :
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None.
;
; Still To Do :
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : None.
;
; Written     : Carl Foley, caf@mssl.ucl.ac.uk  August 2003
;
; Modified    :
;
; Version     : 1.
;
;-
function cf_177lg,qlds,plot=plot,debug=debug,tcr=tcr
;
  restgen,file=concat_dir('$CDS_GIS_CAL_INT','177lg_g'+strcompress(string(qlds.header.gset_id),/remove_all)+'.genx'),lg,detno,o1
  window0=gt_windata(qlds,0)
  arm=gis_arm(qlds,detno-1)
  ds=size(window0)
  tcr=0.
  if ds(0) eq 1 then begin
    s1=window0
    if (total(s1(o1)) gt 0.) then begin
      a0=cfit(o1,s1(o1),a,lg)
      aa=[0,0,0,a(0),a(1),a(2)*0.6]
      ss2=a(3)*(s1(o1))/(a(3)+mgauss(o1,aa,pd))
      s2=s1
      s2(o1)=ss2
      ss3=s1(o1)-ss2
      if keyword_set(plot) then plot,o1,s1(o1)
      if keyword_set(plot) then oplot,o1,a0,thick=2
      if keyword_set(plot) then pause
      tcr=tcr+total(ss3)
      for a=0,n_elements(o1)-1 do s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))=s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))+ss3(a)
ghosted=dspline(arm(*,1),arm(*,0),arm(o1,1)-1,interp=0)
window0=s2
func = hanning (7)
 window0(ghosted)=(convol (s2, func, total (func),/edge_tr))(ghosted)
endif
endif
if ds(0) eq 2 then begin
for ap=0,n_elements(window0(0,*))-1. do begin
s1=window0(*,ap)
if (total(s1(o1)) gt 0.) then begin
  a0=cfit(o1,s1(o1),a,lg)
aa=[0,0,0,a(0),a(1),a(2)*0.6]
ss2=a(3)*(s1(o1))/(a(3)+mgauss(o1,aa,pd))
s2=s1
s2(o1)=ss2
ss3=s1(o1)-ss2
if keyword_set(plot) then plot,o1,s1(o1)
if keyword_set(plot) then oplot,o1,a0,thick=2
if keyword_set(plot) then pause
      tcr=tcr+total(ss3)
for a=0,n_elements(o1)-1 do s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))=s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))+ss3(a)
ghosted=dspline(arm(*,1),arm(*,0),arm(o1,1)-1,interp=0)
 window0(*,ap)=s2
 func = hanning (7)
 
  window0(ghosted,ap)=(convol (s2, func, total (func),/edge_tr))(ghosted)

  endif
endfor

endif
if ds(0) eq 3 then begin
  aalt=fltarr(6,ds(2),ds(3))
for ap=0,ds(2)-1 do begin
for ap1=0,ds(3)-1 do begin
s1=window0(*,ap,ap1)
if (total(s1(o1)) gt 0.) then begin
a0=cfit(o1,s1(o1),a,lg)
aa=[0,0,0,a(0),a(1),a(2)*0.6]
ss2=a(3)*(s1(o1))/(a(3)+mgauss(o1,aa,pd))
s2=s1
s2(o1)=ss2
ss3=s1(o1)-ss2
if keyword_set(plot) then plot,o1,s1(o1)
if keyword_set(plot) then oplot,o1,a0,thick=2
if keyword_set(plot) then pause
      tcr=tcr+total(ss3)
for a=0,n_elements(o1)-1 do s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))=s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))+ss3(a)
aalt(*,ap,ap1)=aa
ghosted=dspline(arm(*,1),arm(*,0),arm(o1,1)-1,interp=0)
 window0(*,ap,ap1)=s2
 func = hanning (7)
 
  window0(ghosted,ap,ap1)=(convol (s2, func, total (func),/edge_tr))(ghosted)

  
endif
endfor
endfor
if keyword_set(debug) then begin
xb=min(aalt(5,*,*))+(findgen(30)+0.5)*((max(aalt(5,*,*))-min(aalt(5,*,*)))/30.)
plot,xb,histogram(aalt(5,*,*),min=min(aalt(5,*,*)),max=max(aalt(5,*,*)),nbins=30.),psym=10.,/xs
xb=min(aalt(4,*,*))+(findgen(30)+0.5)*((max(aalt(4,*,*))-min(aalt(4,*,*)))/30.)
plot,xb,histogram(aalt(4,*,*),min=min(aalt(4,*,*)),max=max(aalt(4,*,*)),nbins=30.),psym=10.,/xs
xb=min(aalt(3,*,*))+(findgen(30)+0.5)*((max(aalt(3,*,*))-min(aalt(3,*,*)))/30.)
plot,xb,histogram(aalt(3,*,*),min=min(aalt(3,*,*)),max=max(aalt(3,*,*)),nbins=30.),psym=10.,/xs
pause
endif

endif

if ds(0) eq 4 then begin
for ap=0,ds(2)-1 do begin
for ap1=0,ds(3)-1 do begin
for ap2=0,ds(4)-1 do begin
s1=window0(*,ap,ap1,ap2)
if (total(s1(o1)) gt 0.) then begin
  a0=cfit(o1,s1(o1),a,lg)
aa=[0,0,0,a(0),a(1),a(2)*0.6]

ss2=a(3)*(s1(o1))/(a(3)+mgauss(o1,aa,pd))
s2=s1
s2(o1)=ss2
ss3=s1(o1)-ss2
if keyword_set(plot) then plot,o1,s1(o1)
if keyword_set(plot) then oplot,o1,a0,thick=2
if keyword_set(plot) then pause
      tcr=tcr+total(ss3)
for a=0,n_elements(o1)-1 do s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))=s2(fix(dspline(arm(*,1),arm(*,0),arm(o1(a),1)-1,interp=0)))+ss3(a)
ghosted=dspline(arm(*,1),arm(*,0),arm(o1,1)-1,interp=0)
 window0(*,ap,ap1,ap2)=s2
 func = hanning (7)
 
  window0(ghosted,ap,ap1,ap2)=(convol (s2, func, total (func),/edge_tr))(ghosted)

endif
endfor
endfor
endfor

endif


st_windata, qlds, 0, window0
end
