;+
; Project     : SOHO - CDS
;
; Name        : CF_GIS1A
;
; Purpose     : To fit a region of the GIS spectra
;
; Explanation : When called by GIS_FIT, automatically fits well known GIS lines
;
; Use         : gisfit=cf_gis1a(qlds,/plot)
;               gisfit=cf_gis1a(gisfit)
;               gisfit=cf_gis1a(gisfit,/plot)
;
; Inputs      : QLDS =      Structure variable of GIS data as read by
;                           READCDSFITS.
;
;
; Opt. Inputs : PLOT =      Plots the fits.
;
; Outputs     : QLDS, corrected for some ghosts.
;
; Opt. Outputs: None.
;
; Keywords    :
;
; Calls       :
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None.
;
; Still To Do :
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : None.
;
; Written     : Carl Foley, caf@mssl.ucl.ac.uk  August 2003
;
; Modified    : CAF : v1.1, caf, Mon Sep 22 2003
;               Changed the format of the output structure so that it only
;               consists of anonymous structures, to avoid conflicts.
;
; Version     : 1.1
;
;-
function cf_gis1a,qlds,plot=plot,gisfit=gisfit,minc=minc
common gisfit,gfit
  ;

  if (size(qlds.(0)) )(2) eq 8 then temp=qlds.(0) else temp=qlds
  if tag_exist(temp,'spectra') then begin
    windows=(qlds.(0).spectra)(0:2047,*)
    gset_id=(qlds.(0).gset_id)(0)
  endif else begin
    windows=reform(gt_windata(qlds,0))
    gset_id=qlds.header.gset_id
  endelse
  !p.multi=[0,3,3]
  ws=size(windows)
  wss=n_elements(size(windows))-3.
  if wss eq 4 then fitout=fltarr(13,ws(4))
  if wss eq 3 then fitout=fltarr(13,ws(2),ws(3))
  if wss eq 2 then fitout=fltarr(13,ws(2))
  if wss eq 1 then fitout=fltarr(13)
  sigm=fitout
  st=load_wavecal('GIS',gset_id=gset_id)
  w1=pix2wave('G1',indgen(2048))
  wl171=where(w1 gt 165 and w1 lt 174)
  restgen,file=concat_dir('$CDS_GIS_CAL_INT','171_speca2.genx'),fi
  wsb=0.
  eror=reform(gis_error(temp,1))
  if wss lt 4 then begin
    if wss gt 2. then wsb=ws(3)-1
    for b=0,wsb do begin
      for a=0,ws(2)-1 do begin
	if keyword_set(plot) then begin
  	  ;plot,w1(wl171),(smooth(windows(*,a,b)>0.,3))(wl171),linestyle=2
      weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl171))
      ;plot,weight
	  ;pause
	  plot,w1(wl171),cfit(w1(wl171),(smooth(windows(*,a,b)>0.,3))(wl171),aa,fi,sig,weights=weight),thick=2
	  oplot,w1(wl171),(smooth(windows(*,a,b)>0.,3))(wl171),linestyle=2
	endif else begin
;	  weight=1./((gis_error(temp,1))(*,a,b))
	  weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl171))
	  lll=cfit(w1(wl171),(smooth(windows(*,a,b),3))(wl171),aa,fi,sig,weights=weight)
	endelse
	sigm(*,a,b)=sig
	fitout(*,a,b)=aa
	delvarx,aa
	int0=(fitout(0,a,b)*fitout(2,a,b)*1.06447)
	;print,int0

	;  pause
      endfor
    endfor
  endif else begin
    a=0
    b=0
    for bb=0,ws(4)-1 do begin
      if keyword_set(plot) then begin
	plot,w1(wl171),(smooth(windows(*,a,b,bb)>0.,3))(wl171),linestyle=2
	  ;weight=1./((gis_error(temp,1))(*,a,b))
	weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl171))
    ;  plot,weight
	;  pause
	  oplot,w1(wl171),cfit(w1(wl171),(smooth(windows(*,a,b,bb)>0.,3))(wl171),aa,fi,sig,weights=weight),thick=2
      endif else begin
	;weight=1./((gis_error(temp,1))(*,a,b))
	weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl171))
     ; plot,weight
	;  pause

	lll=cfit(w1(wl171),(smooth(windows(*,a,b,bb),3))(wl171),aa,fi,sig,weights=weight)
      endelse

      fitout(*,bb)=aa
     sigm(*,bb)=sig
      delvarx,aa

	;  pause
      endfor
    endelse
    !p.multi=0.
    ; adding errors from sigma ; int_error_amp_errorwodth_error
    interror = reform(fitout(0,*)*fitout(2,*)*1.06447*sqrt((sigm(0,*)/fitout(0,*)) +(sigm(2,*)/fitout(2,*)) ))
    int=reform(fitout(0,*)*fitout(2,*)*1.06447)
    fe1={int:int,amp:reform(fitout(0,*)),pos:reform(fitout(1,*)),width:reform(fitout(2,*)),int_error:interror,amp_error:reform(sigm(0,*)),width_error:reform(sigm(2,*)),info:'This line doesnt ghost, but is extended b'}
    interror = reform(fitout(9,*)*fitout(11,*)*1.06447*sqrt((sigm(9,*)/fitout(9,*)) +(sigm(11,*)/fitout(11,*)) ))
    fe2={int:reform(fitout(9,*)*fitout(11,*)*1.06447),amp:reform(fitout(9,*)),pos:reform(fitout(10,*)),width:reform(fitout(11,*)),int_error:interror,amp_error:reform(sigm(9,*)),width_error:reform(sigm(11,*)),info:''}
    interror = reform(fitout(3,*)*fitout(5,*)*1.06447*sqrt((sigm(3,*)/fitout(3,*)) +(sigm(5,*)/fitout(5,*)) ))
    ni1={int:reform(fitout(3,*)*fitout(5,*)*1.06447),amp:reform(fitout(3,*)),pos:reform(fitout(4,*)),width:reform(fitout(5,*)),int_error:interror,amp_error:reform(sigm(3,*)),width_error:reform(sigm(5,*)),info:''}
    interror = reform(fitout(6,*)*fitout(8,*)*1.06447*sqrt((sigm(6,*)/fitout(6,*)) +(sigm(8,*)/fitout(8,*)) ))
    o1={int:reform(fitout(6,*)*fitout(8,*)*1.06447),amp:reform(fitout(6,*)),pos:reform(fitout(7,*)),width:reform(fitout(8,*)),int_error:interror,amp_error:reform(sigm(6,*)),width_error:reform(sigm(8,*)),info:''}
    ;names='fit={header:qldsi'
    names='fit={header:qldsi,Fe_VIII_168:fe1,Ni_XIV_169_68:ni1,Fe_IX_171_07:fe2,O_VI_173_1:o1'
    if tag_exist(temp,'spectra') then begin
      Result = TAG_NAMES(qlds)
    qldsi=qlds.(0)
    al1l=where(Result eq 'AL_X_332_79_2ND')
    fe3l=where(Result eq 'FE_XIII_185_7')
    fe8l=where(Result eq 'FE_XIII_216_8')
    mg1l=where(Result eq 'MG_VIII_769_4')


    if fe3l ge 0 then begin
      fe3=qlds.(fe3l)
      o2=qlds.(fe3l+1)
      fe4=qlds.(fe3l+2)
      fe5=qlds.(fe3l+3)
      fe6=qlds.(fe3l+4)
      fe7=qlds.(fe3l+5)
      namearray=['Fe_XIII_185_7','O_VI_184_1','Fe_X_184_5','Fe_VIII_186_5','Fe_XI_188_2','Fe_X_190']
      namevalue=[fe3l,fe3l+1,fe3l+2,fe3l+3,fe3l+4,fe3l+5]
    for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.('+strcompress(string(namevalue(ele)),/remove_all)+')'
  endif

  if fe8l ge 0 then begin
    fe8=qlds.(fe8l)
    names=names+',Fe_XIII_216_8:qlds.('+strcompress(string(fe8l),/remove_all)+')'
  endif

  if mg1l ge 0 then begin
    mg1=qlds.(mg1l)
    mg2=qlds.(mg1l+1)
    ne1=qlds.(mg1l+2)
    ne2=qlds.(mg1l+3)
    namearray=['Mg_VIII_769_4','Mg_VIII_772_3','Ne_VIII_770_4','Ne_VIII_780_3']
    namevalue=[mg1l,mg1l+1,mg1l+2,mg1l+3]
    for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.('+strcompress(string(namevalue(ele)),/remove_all)+')'
	;for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.(namevalue('+strcompress(string(ele),/remove_all)+'))'
  endif

  ;endif

  if al1l ge 0 then begin
    al1=qlds.(al1l)
      fe9=qlds.(al1l+1)
      fe10=qlds.(al1l+2)
      namearray=['Al_X_332_79_2nd','Fe_XIV_334_17_2nd','Fe_XVI_335_38_2nd']
      namevalue=[al1l,al1l+1,al1l+2]
      for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.('+strcompress(string(namevalue(ele)),/remove_all)+')'
    endif
  names=names+'}'
endif else begin
  time=qlds.DEL_TIMEDATA
  basetime=qlds.header.DATE_OBS
  tt=replicate(anytim2utc(basetime),n_elements((reform(time))))
  tt.time=tt.time+((reform(time)))*1000.
  uttime=int2utc(tt)
  xcen=qlds.INS_XDATA
  ycen=qlds.INS_YDATA
  wwall=fltarr(8192,n_elements(qlds(0).del_timedata)*n_elements(qlds))
  wwalle=fltarr(8192,n_elements(qlds(0).del_timedata)*n_elements(qlds))
 dw1=(where(qlds(0).detdesc.waveband eq 1))(0)
  dw2=(where(qlds(0).detdesc.waveband eq 2))(0)
  dw3=(where(qlds(0).detdesc.waveband eq 3))(0)
  dw4=(where(qlds(0).detdesc.waveband eq 4))(0)
  fac=[1,1,1,1]
  if dw1 lt 0 then fac(0)=0
  if dw2 lt 0 then fac(1)=0
  if dw3 lt 0 then fac(2)=0
  if dw4 lt 0 then fac(3)=0
  for a=0,n_elements(qlds)-1 do begin
    ww0=reform([gt_windata(qlds(a),dw1>0)*fac(0),gt_windata(qlds(a),dw2>0)*fac(1),gt_windata(qlds(a),dw3>0)*fac(2),gt_windata(qlds(a),dw4>0)*fac(3)])
    wwall(*,0+a*n_elements(qlds(0).del_timedata):n_elements(qlds(0).del_timedata)-1+a*n_elements(qlds(0).del_timedata))=ww0
    ww0e=reform([gis_error(qlds(a),(dw1+1)>1)*fac(0),gis_error(qlds(a),(dw2+1)>0)*fac(1),gis_error(qlds(a),(dw3+1)>0)*fac(2),gis_error(qlds(a),(dw4+1)>0)*fac(3)])
    wwalle(*,0+a*n_elements(qlds(0).del_timedata):n_elements(qlds(0).del_timedata)-1+a*n_elements(qlds(0).del_timedata))=ww0e
 endfor
  spectra=wwall
  gis1=total(wwall(0:2047,*)>0,1)
  gis2=total(wwall(2048:4095,*)>0,1)
  gis3=total(wwall(4096:6143,*)>0,1)
  gis4=total(wwall(6144:8191,*)>0,1)
  qldsi={time:uttime,gis1:gis1,gis2:gis2,gis3:gis3,gis4:gis4,spectra:spectra,error:wwalle,filenames:qlds.header.filename,gset_id:qlds.header.gset_id,units:qlds.detdesc.units,exp_time:qlds.header.EXPTIME,science:qlds.header.SCI_OBJ,xcen:xcen,ycen:ycen}
  names=names+'}'
endelse

;aaaa
  ;;;;;;;;;;;;;;;;;;;;;;;
  path = getenv("IDL_COMPILE_DIR")
  file = concat_dir(path,"cf_gis.pro")

  ; Write program...
  call_proc_escape = ''
  if not tag_exist(gfit,'comp') then begin
    www=(find_file('cf*gis.pro'))
    if n_elements(www) eq 1 and www(0) ne -1 then nim='0'
    if n_elements(www) eq 1 and www(0) eq -1 then nim='_'
    if n_elements(www) ne 1 then nim=strcompress(string(n_elements(www)-1),/remove_all)
    gfit={comp:nim}
  endif else begin
  nim=strcompress(string(gfit.comp*1+1),/remove_all)
  gfit.comp=nim
endelse
protxt = 'function cf'+nim+'gis,qldsi,qlds,fe1,ni1,fe2,o1

prog =[ 'on_error,0',$
      call_proc_escape,$
      '', $
      ' '+names+' ',$
      '',$
      '',$
      'return,fit']


	  comment = ['; Produced by gis_compfit.pro ',$
	  ';', $
	    '; directory, set the environment variable IDL_COMPILE_DIR',$
	    '']

	  program = [comment,protxt,'    '+prog,'end']

  wrt_ascii,program,concat_dir(path,'cf'+nim+'gis')+".pro"
  ;;;;;;;;;;;

fit=call_function('cf'+nim+'gis',qldsi,qlds,fe1,ni1,fe2,o1)
file_delete,concat_dir(path,'cf'+nim+'gis')+".pro"
delvarx,temp
return,fit
end
