;+
; Project     : SOHO - CDS
;
; Name        : CF_GIS1B
;
; Purpose     : To fit a region of the GIS spectra
;
; Explanation : When called by GIS_FIT, automatically fits well known GIS lines
;
; Use         : gisfit=cf_gis1b(qlds,/plot)
;               gisfit=cf_gis1b(gisfit)
;               gisfit=cf_gis1b(gisfit,/plot)
;
; Inputs      : QLDS =      Structure variable of GIS data as read by
;                           READCDSFITS.
;
;               gisfit =    Output structure from GIS_UTPLOT or one of the
;                           cf_gis fitting routines.
;
; Opt. Inputs : PLOT =    Plots the fits.
;
; Outputs     : QLDS, corrected for some ghosts.
;
; Opt. Outputs: None.
;
; Keywords    :
;
; Calls       :
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None.
;
; Still To Do :
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : None.
;
; Written     : Carl Foley, caf@mssl.ucl.ac.uk  August 2003
;
; Modified    : v1.1, caf, Mon Sep 22 2003
;               Changed the format of the output structure so that it only
;               consists of anonymous structures, to avoid conflicts.
;
; Version     : 1.1
;
;-
function cf_gis1b,qlds,plot=plot,gisfit=gisfit
common gisfit,gfit
;
;if keyword_set(gisfit) then qlds=gisfit
if (size(qlds.(0)) )(2) eq 8 then temp=qlds.(0) else temp=qlds
  if tag_exist(temp,'spectra') then begin
    windows=(qlds.(0).spectra)(0:2047,*)
    gset_id=(qlds.header.gset_id)(0)
    eror=(qlds.(0).error)(0:2047,*)
endif else begin
    windows=reform(gt_windata(qlds,0))
    gset_id=qlds.header.gset_id
    eror=reform(gis_error(temp,1))
 endelse


  !p.multi=[0,3,3]
  ws=size(windows)
  wss=n_elements(size(windows))-3.

  if wss eq 4 then fitout=fltarr(19,ws(4))
  if wss eq 3 then fitout=fltarr(19,ws(2),ws(3))
  if wss eq 2 then fitout=fltarr(19,ws(2))
  if wss eq 1 then fitout=fltarr(19)
  st=load_wavecal('GIS',gset_id=gset_id)
  w1=pix2wave('G1',indgen(2048))
  wl188=where(w1 gt 183 and w1 lt 191)
  restgen,file=concat_dir('$CDS_GIS_CAL_INT','188_spec_a.genx'),fi
  wsb=0.
sigm=fitout
  if wss gt 2. then wsb=ws(3)-1
  if wss lt 4 then begin
    for b=0,wsb do begin
      for a=0,ws(2)-1 do begin
	if keyword_set(plot) then begin
     weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl188))
	  plot,w1(wl188),(smooth(windows(*,a,b)>0.,3))(wl188),linestyle=2
	  oplot,w1(wl188),cfit(w1(wl188),(smooth(windows(*,a,b)>0.,3))(wl188),aa,fi,sig,weights=weight),thick=2
	endif else begin
      weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl188))
	  lll=cfit(w1(wl188),(smooth(windows(*,a,b),3))(wl188),aa,fi,sigm,weights=weight)
	endelse
sigm(*,a,b)=sig

	fitout(*,a,b)=aa
	delvarx,aa

	;  pause
      endfor
endfor
endif else begin
a=0
b=0
for bb=0,ws(4)-1 do begin
  if keyword_set(plot) then begin
    plot,w1(wl188),(smooth(windows(*,a,b,bb)>0.,3))(wl188),linestyle=2
      weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl188))
    oplot,w1(wl188),cfit(w1(wl188),(smooth(windows(*,a,b,bb)>0.,3))(wl188),aa,fi,sig,weights=weight),thick=2
  endif else begin
          weight=((eror)(*,a,b))^2.
      l=where(weight eq 0.)
	  if total(l) ge 0 then weight(l)=1.
	  weight=1./(weight(wl188))
    lll=cfit(w1(wl188),(smooth(windows(*,a,b,bb),3))(wl188),aa,fi,sig,weights=weight)
  endelse
sigm(*,bb)=sig

  fitout(*,bb)=aa
  delvarx,aa

  ;  pause
endfor

endelse
!p.multi=0.
;;;;;;;;;;;;; GIS 1 PRIME LINES ;;;;;;;;;;;;;;;;;;;;;;;
;Fe IX    171.07 cf_gis1a
;Fe XI    174.53 no
;Fe X     177.24 no
;Fe XI    180.40 no
;Fe X     184.54 ?
;Fe XII   186.88 ?
;Fe XI    188.22 cf_gis1b
;Fe XII   192.39 no
;Fe XII   193.51 no
;Fe XII   195.12 no
;Fe XII   201.12 no
;Fe XIII  203.83 no
;Fe XIV   219.12 no
;Fe XIV   220.08 no
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
interror = reform(fitout(0,*)*fitout(2,*)*1.06447*sqrt((sigm(0,*)/fitout(0,*)) +(sigm(2,*)/fitout(2,*)) ))
int=reform(fitout(0,*)*fitout(2,*)*1.06447)
fe3={int:int,amp:reform(fitout(0,*)),pos:reform(fitout(1,*)),width:reform(fitout(2,*)),int_error:interror,amp_error:reform(sigm(0,*)),width_error:reform(sigm(2,*)),info:''}
interror = reform(fitout(3,*)*fitout(5,*)*1.06447*sqrt((sigm(3,*)/fitout(3,*)) +(sigm(5,*)/fitout(5,*)) ))
o2={int:reform(fitout(3,*)*fitout(5,*)*1.06447),amp:reform(fitout(3,*)),pos:reform(fitout(4,*)),width:reform(fitout(5,*)),int_error:interror,amp_error:reform(sigm(3,*)),width_error:reform(sigm(5,*)),info:''}
interror = reform(fitout(6,*)*fitout(8,*)*1.06447*sqrt((sigm(6,*)/fitout(6,*)) +(sigm(8,*)/fitout(8,*)) ))
fe4={int:reform(fitout(6,*)*fitout(8,*)*1.06447),amp:reform(fitout(6,*)),pos:reform(fitout(7,*)),width:reform(fitout(8,*)),int_error:interror,amp_error:reform(sigm(6,*)),width_error:reform(sigm(8,*)),info:''}
interror = reform(fitout(12,*)*fitout(14,*)*1.06447*sqrt((sigm(12,*)/fitout(12,*)) +(sigm(14,*)/fitout(14,*)) ))
fe5={int:reform(fitout(12,*)*fitout(14,*)*1.06447),amp:reform(fitout(12,*)),pos:reform(fitout(13,*)),width:reform(fitout(14,*)),int_error:interror,amp_error:reform(sigm(12,*)),width_error:reform(sigm(14,*)),info:''}
interror = reform(fitout(15,*)*fitout(17,*)*1.06447*sqrt((sigm(15,*)/fitout(15,*)) +(sigm(17,*)/fitout(17,*)) ))
fe6={int:reform(fitout(15,*)*fitout(17,*)*1.06447),amp:reform(fitout(15,*)),pos:reform(fitout(16,*)),width:reform(fitout(17,*)),int_error:interror,amp_error:reform(sigm(15,*)),width_error:reform(sigm(17,*)),info:''}
interror = reform(fitout(9,*)*fitout(11,*)*1.06447*sqrt((sigm(9,*)/fitout(9,*)) +(sigm(11,*)/fitout(11,*)) ))
fe7={int:reform(fitout(9,*)*fitout(11,*)*1.06447),amp:reform(fitout(9,*)),pos:reform(fitout(10,*)),width:reform(fitout(11,*)),int_error:interror,amp_error:reform(sigm(9,*)),width_error:reform(sigm(11,*)),info:''}
names='fit={header:qldsi'
if tag_exist(temp,'spectra') then begin
  Result = TAG_NAMES(qlds)
  qldsi=qlds.(0)
  fe1l=where(Result eq 'FE_VIII_168')
  fe8l=where(Result eq 'FE_XIII_216_8')
  mg1l=where(Result eq 'MG_VIII_769_4')
  al1l=where(Result eq 'AL_X_332_79_2ND')

  if fe1l ge 0 then begin
    fe1=qlds.(fe1l)
    fe2=qlds.(fe1l+1)
    ni1=qlds.(fe1l+2)
    o1=qlds.(fe1l+3)
    namearray=['Fe_VIII_168','Ni_XIV_169_68','Fe_IX_171_07','O_VI_173_1']
    namevalue=[fe1l,fe1l+1,fe1l+2,fe1l+3]
    for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.('+strcompress(string(namevalue(ele)),/remove_all)+')'
  endif

  names=names+',Fe_XIII_185_7:fe3,O_VI_184_1:o2,Fe_X_184_5:fe4,Fe_VIII_186_5:fe5,Fe_XI_188_2:fe6,Fe_X_190:fe7'

  if fe8l ge 0 then begin
    fe8=qlds.(fe8l)
    names=names+',Fe_XIII_216_8:qlds.('+strcompress(string(fe8l),/remove_all)+')'
  endif

  if mg1l ge 0 then begin
    mg1=qlds.(mg1l)
    mg2=qlds.(mg1l+1)
    ne1=qlds.(mg1l+2)
    ne2=qlds.(mg1l+3)
    namearray=['Mg_VIII_769_4','Mg_VIII_772_3','Ne_VIII_770_4','Ne_VIII_780_3']
    namevalue=[mg1l,mg1l+1,mg1l+2,mg1l+3]
    for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.('+strcompress(string(namevalue(ele)),/remove_all)+')'
    ;for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.(namevalue('+strcompress(string(ele),/remove_all)+'))'
  endif

  if al1l ge 0 then begin
    al1=qlds.(al1l)
    fe9=qlds.(al1l+1)
    fe10=qlds.(al1l+2)
    namearray=['Al_X_332_79_2nd','Fe_XIV_334_17_2nd','Fe_XVI_335_38_2nd']
    namevalue=[al1l,al1l+1,al1l+2]
    for ele=0,n_elements(namearray)-1 do names=names+','+namearray(ele)+':qlds.('+strcompress(string(namevalue(ele)),/remove_all)+')'
    endif
    names=names+'}'
  endif else begin
    time=qlds.DEL_TIMEDATA
    basetime=qlds.header.DATE_OBS
    tt=replicate(anytim2utc(basetime),n_elements((reform(time))))
    tt.time=tt.time+((reform(time)))*1000.
    uttime=int2utc(tt)
    xcen=qlds.INS_XDATA
    ycen=qlds.INS_YDATA
    wwall=fltarr(8192,n_elements(qlds(0).del_timedata)*n_elements(qlds))
    wwalle=fltarr(8192,n_elements(qlds(0).del_timedata)*n_elements(qlds))
dw1=(where(qlds(0).detdesc.waveband eq 1))(0)
    dw2=(where(qlds(0).detdesc.waveband eq 2))(0)
    dw3=(where(qlds(0).detdesc.waveband eq 3))(0)
    dw4=(where(qlds(0).detdesc.waveband eq 4))(0)
    fac=[1,1,1,1]
    if dw1 lt 0 then fac(0)=0
    if dw2 lt 0 then fac(1)=0
    if dw3 lt 0 then fac(2)=0
    if dw4 lt 0 then fac(3)=0
    for a=0,n_elements(qlds)-1 do begin
      ww0=reform([gt_windata(qlds(a),dw1>0)*fac(0),gt_windata(qlds(a),dw2>0)*fac(1),gt_windata(qlds(a),dw3>0)*fac(2),gt_windata(qlds(a),dw4>0)*fac(3)])
    wwall(*,0+a*n_elements(qlds(0).del_timedata):n_elements(qlds(0).del_timedata)-1+a*n_elements(qlds(0).del_timedata))=ww0
  ww0e=reform([gis_error(qlds(a),(dw1+1)>1)*fac(0),gis_error(qlds(a),(dw2+1)>0)*fac(1),gis_error(qlds(a),(dw3+1)>0)*fac(2),gis_error(qlds(a),(dw4+1)>0)*fac(3)])
    wwalle(*,0+a*n_elements(qlds(0).del_timedata):n_elements(qlds(0).del_timedata)-1+a*n_elements(qlds(0).del_timedata))=ww0e
endfor
  spectra=wwall
  gis1=total(wwall(0:2047,*)>0,1)
  gis2=total(wwall(2048:4095,*)>0,1)
  gis3=total(wwall(4096:6143,*)>0,1)
  gis4=total(wwall(6144:8191,*)>0,1)
  qldsi={time:uttime,gis1:gis1,gis2:gis2,gis3:gis3,gis4:gis4,spectra:spectra,error:wwalle,filenames:qlds.header.filename,gset_id:qlds.header.gset_id,units:qlds.detdesc.units,exp_time:qlds.header.EXPTIME,science:qlds.header.SCI_OBJ,xcen:xcen,ycen:ycen}
  names=names+',Fe_XIII_185_7:fe3,O_VI_184_1:o2,Fe_X_184_5:fe4,Fe_VIII_186_5:fe5,Fe_XI_188_2:fe6,Fe_X_190:fe7}'
endelse

;aaaa
;;;;;;;;;;;;;;;;;;;;;;;
path = getenv("IDL_COMPILE_DIR")
; Write program...
call_proc_escape = ''
if not tag_exist(gfit,'comp') then begin
  www=(find_file('cf*gis.pro'))
  if n_elements(www) eq 1 and www(0) ne -1 then nim='0'
  if n_elements(www) eq 1 and www(0) eq -1 then nim='_'
  if n_elements(www) ne 1 then nim=strcompress(string(n_elements(www)-1),/remove_all)
  gfit={comp:nim}
  endif else begin
  nim=strcompress(string(gfit.comp*1+1),/remove_all)
  gfit.comp=nim
endelse
protxt = 'function cf'+nim+'gis,qldsi,qlds,fe3,ni1,o2,fe4,fe5,fe6,fe7

prog =[ 'on_error,0',$
      call_proc_escape,$
      '', $
      ' '+names+' ',$
      '',$
      '',$
      'return,fit']


comment = ['; Produced by cf_gis.pro ',$
';', $
  '; directory, set the environment variable IDL_COMPILE_DIR',$
  '']

program = [comment,protxt,'    '+prog,'end']

wrt_ascii,program,concat_dir(path,'cf'+nim+'gis')+".pro"
;;;;;;;;;;;

fit=call_function('cf'+nim+'gis',qldsi,qlds,fe3,ni1,o2,fe4,fe5,fe6,fe7)
file_delete,concat_dir(path,'cf'+nim+'gis')+".pro"
delvarx,temp
return,fit
end

  ;;;;;;;;;;;;;;;;

;  fit={header:qldsi,Fe_XIII_185_7:fe3,O_VI_184_1:o2,Fe_X_184_5:fe4,Fe_VIII_186_5:fe5,Fe_XI_188_2:fe6,Fe_X_190:fe7}
