;+
; Project     : SOHO - CDS
;
; Name        : GIS_CALIB_HEII
;
; Purpose     : Marks HeII data uncalibratable in GIS spectra.
;
; Explanation : This procedure marks the HeII line in GIS detector 2 as 
;               uncalibratable.  Called from GIS_CALIB, q.v.
;
; Use         : GIS_CALIB_HEII, missing_array, quiet
;
; Inputs      : MISSING ARRAY = Array marking missing/uncalibratable GIS data
;                           as supplied by GIS_CALIB
;               QUIET =     Flag to run quietly
;                           
; Opt. Inputs : None.
;
; Outputs     : MISSING ARRAY = Array marking missing/uncalibratable GIS data
;
; Opt. Outputs: None.
;
; Keywords    : None.
;
; Calls       : wave2pix
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None?
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : Separated from GIS_CALIB
;
; Written     : Eddie Breeveld, erb@mssl.ucl.ac.uk  3 February 1998
;
; Modified    : 
;
; Version     : v.1, 3 February 1998
;
;-
;
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
pro gis_calib_HeII, missing_array, quiet
;
; Remove the HeII 30.4 line
;
    if not keyword_set (QUIET) then print, '    HeII 30.4 removal...'
;
    HeIIpix = wave2pix ('GIS2', 30.4*10)    ; 30.4 nm on detector 2
;
; Mark the data in the missing array
;
    missing_array (HeIIpix-49:HeIIpix+50, *, *, *, 1) = -1
;
    return
end
