;+
; Project     : SOHO - CDS
;
; Name        : GIS_CALIB_PRINT
;
; Purpose     : Prints summary of GIS data.
;
; Explanation : This procedure prinst a summary of GIS data as supplied
;               by GIS_CALIB, q.v.
;
; Use         : GIS_CALIB_PRINT, data [,units]
;
; Inputs      : DATA =      GIS data as supplied by GIS_CALIB.
;                           
; Opt. Inputs : UNITS =     data units to be pronted
;
; Outputs     : None.
;
; Opt. Outputs: None.
;
; Keywords    : None.
;
; Calls       : average
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None?
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : Separated from GIS_CALIB
;
; Written     : Eddie Breeveld, erb@mssl.ucl.ac.uk  3 February 1998
;
; Modified    : v2, erb, 27 Jan 1999, Use 'g' format and added 'units'
;               v3, erb, 10 May 1999, ignore first pixel in the data
;               v4, caf,    Aug 2003, fixed bug so now works with partial
;                           GIS data.
;
; Version     : 4
;
;-
;
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
PRO GIS_CALIB_PRINT, data, units,waveband
;
; work out the value of mssing data (usually -1, but may be -100!)
;
    missing = min(data) < (-1.0)
;
    print
    print, '                 ', $
           '          GIS 1', $
           '          GIS 2', $
           '          GIS 3', $
           '          GIS 4'
;
    
    print, Format='(a, $)', 'Avg detector rates: '
 ;   for i=0, 3 do print, format='(g, $)', (average (data[*, *, *, *, i], missing=missing)>0.0) * 2048.0
adetdata=fltarr(4)
for i=0, n_elements(waveband)-1. do adetdata(waveband(i)-1)=(average (data[*, *, *, *, i], missing=missing)>0.0) * 2048.0
for i=0,3 do print, format='(g, $)', adetdata(i)
;
; Ignore the first pixel - this has accumulated data from ghost_buster
; processing -----why did eddie do this ????? carl ???? 
;
    print
    print, Format='(a, $)', 'Max in any pixel:   '
adetdata=fltarr(4)
for i=0, n_elements(waveband)-1. do adetdata(waveband(i)-1)=max (data(1:*, *, *, *, i))
for i=0,3 do print, format='(g, $)', adetdata(i)
    print
    if n_params() eq 2 then print, '(Units: ', units, ')'
    print
    return
end
;
