;+
; Project     : SOHO - CDS
;
; Name        : GIS_UTPLOT
;
; Purpose     : front end wrapper for GIS to UTPLOT, to enable ploting of GIS data
;
; Explanation : When called by GIS_FIT, automatically fits well known GIS lines
;
; Use         : GIS_UTPLOT,qlds,1,psym=1
;      
;
; Inputs      : QLDS =      Structure variable of GIS data as read by
;                           READCDSFITS.
;
;              
; Opt. Inputs : 
;
; Outputs     : Timeseries plot of GIS data
;
; Opt. Outputs: None.
;
; Keywords    :
;
; Calls       :
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None.
;
; Still To Do :
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : None.
;
; Written     : Carl Foley, caf@mssl.ucl.ac.uk  August 2003
;
; Modified    : v1.1, caf, Mon Sep 22 2003
;               Updated to be consistent with revised output structure
;               from GIS_FIT
;
; Version     : 1.1
;
;-
;.........................................................................
PRO GIS_UTPLOT,qlds,detno,psym=psym,timerange=timerange,yr=yr,uttime=uttime,gisfit=gisfit,log=log,lines=lines,over=over,plot=plot
  ; next line checks to see if a structure is passed
  ; if not ... its assumed that its a program id is passed ..
  ; this should be be checked .. 2b done !
  ;  
@gis_stage.inc
  
  if (size(qlds))(2) ne 8 then begin 
    ; previous line checks to see if qlds is past or a string / stringarr
    fqlds=qlds
    for files=0,n_elements(fqlds)-1 do begin
      list_exper,fqlds(files),o,n
      if o(0).detector ne 'G' then print,'Sorry, only works with GIS data'
      if o(0).detector ne 'G' then stop
      ;;;;;;;;;;;;;;;;;;;; many rasters ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      if n gt 1 and files eq 0 then begin
	filename=o(0).filename
	qlds=readcdsfits(o(0).filename)
	gis_smooth,qlds
	ghost_buster,qlds
	gis_calib,qlds,/heii
	for a=1,n-1 do begin
	  filename=[filename,o(a).filename]
	  qlds1=readcdsfits(o(a).filename)
	  gis_smooth,qlds1
	  ghost_buster,qlds1
	  gis_calib,qlds1,/heii
	  qlds=[qlds,qlds1]
	endfor
	
      endif
      
      if n le 1 and files eq 0 then begin
	filename=o.filename
	qlds=readcdsfits(o.filename)
	gis_smooth,qlds
	ghost_buster,qlds
	gis_calib,qlds,/heii
	
      endif
      
      if n gt 1 and files gt 0 then begin
	for a=0,n-1 do begin
	  filename=[filename,o(a).filename]
	  qlds1=readcdsfits(o(a).filename)
	  gis_smooth,qlds1
	  ghost_buster,qlds1
	  gis_calib,qlds1,/heii
	  qlds=[qlds,qlds1]
	endfor
	
      endif
      
      if n le 1 and files gt 0 then begin
	filename=[filename,o.filename]
	qlds1=readcdsfits(o.filename)
	gis_smooth,qlds1
	ghost_buster,qlds1
	gis_calib,qlds1,/heii
	qlds=[qlds,qlds1]
      endif
      
      
    endfor
  endif
  if (size(qlds.(0)) )(2) eq 8 then temp=qlds.(0) else temp=qlds
  if tag_exist(temp,'spectra') then lines=1    
  if tag_exist(temp,'spectra') then gisfit=qlds
  if tag_exist(temp,'spectra') then goto,gfit
  ;;;;;;;;;;;;;;;;;;; assumed qlds structure has now been entered ;;;;;;;;;;;;;;;
  
  time=qlds(0).DEL_TIMEDATA
  times=sort(qlds(0).DEL_TIMEDATA)
  basetime=qlds(0).header.DATE_OBS
  tt=replicate(anytim2utc(basetime),n_elements(qlds(0).del_timedata))
  tt.time=tt.time+(reform(time,n_elements(qlds(0).del_timedata)))*1000.
  tt1=tt
  ls=sort(qlds(0).del_timedata)
  for b=0,n_elements(qlds(0).del_timedata)-1 do tt(b)=tt1(ls(b))
  
  actime=int2utc(tt)				    
  wwall=fltarr(8192,n_elements(qlds(0).del_timedata)*n_elements(qlds))
  for a=0,n_elements(qlds)-1 do begin
    if a gt 0 then begin
      time=qlds(a).DEL_TIMEDATA
      times=sort(qlds(a).DEL_TIMEDATA)
      basetime=qlds(a).header.DATE_OBS
      tt=replicate(anytim2utc(basetime),n_elements(qlds(a).del_timedata))
      tt.time=tt.time+(reform(time,n_elements(qlds(a).del_timedata)))*1000.
      tt1=tt
      ls=sort(qlds(a).del_timedata)
      for b=0,n_elements(qlds(a).del_timedata)-1 do tt(b)=tt1(ls(b))
      actime=[actime,int2utc(tt)]
    endif
    winsize = gt_winsize (qlds(a))
    waveband=qlds(a).detdesc.waveband
    if n_elements(winsize) eq 4 then begin 							    
      ww0=reform([gt_windata(qlds(a),0),gt_windata(qlds(a),1),gt_windata(qlds(a),2),gt_windata(qlds(a),3)],8192,n_elements(qlds(a).del_timedata));*n_elements(qlds))
    endif else begin
      dw1=(where(qlds(0).detdesc.waveband eq 1))(0)
      dw2=(where(qlds(0).detdesc.waveband eq 2))(0)
      dw3=(where(qlds(0).detdesc.waveband eq 3))(0)
      dw4=(where(qlds(0).detdesc.waveband eq 4))(0)
      fac=[1,1,1,1]
      if dw1 lt 0 then fac(0)=0
      if dw2 lt 0 then fac(1)=0
      if dw3 lt 0 then fac(2)=0
      if dw4 lt 0 then fac(3)=0
      
      ww0=reform([gt_windata(qlds(a),dw1>0)*fac(0),gt_windata(qlds(a),dw2>0)*fac(1),gt_windata(qlds(a),dw3>0)*fac(2),fac(3)*gt_windata(qlds(a),dw4>0)],8192,n_elements(qlds(a).del_timedata));*n_elements(qlds))
    endelse
    ww0a=ww0
    ls=sort(qlds(a).del_timedata)
    for b=0,n_elements(qlds(a).del_timedata)-1 do ww0(*,b)=ww0a(*,ls(b))
    ;for b=0,n_elements(qlds(a).del_timedata)-1 do ww0(*,b)=ww0a(*,ls(b))
    wwall(*,0+a*n_elements(qlds(0).del_timedata):n_elements(qlds(0).del_timedata)-1+a*n_elements(qlds(0).del_timedata))=ww0
  endfor
  ;return,qlds
  ytitle=(qlds(0).detdesc.units)(0)
  case ytitle of
    GIS_STAGE.SMOOTHED:           ; just continue
    ;
    GIS_STAGE.RAW: begin
      ytitle='Counts'
    end
    ;
    GIS_STAGE.GHOST_CORRECT: begin
      ytitle='Smoothed counts'
    end
    GIS_STAGE.PHOTONS : begin
      ytitle='Corrected counts/second'
    end
    GIS_STAGE.STERADIAN_M2 : begin
      ytitle='Photons/m^2/sec/steradian'
    end
    GIS_STAGE.ARCSEC2_CM2 : begin
      ytitle='Photons/cm^2/sec/arcsec^2'
    end
  endcase
  ;;;;
;
 ;   wwall=fltarr(8192,n_elements(qlds(0).del_timedata)*n_elements(qlds))
 ;   dw1=(where(qlds(0).detdesc.waveband eq 1))(0)
  ;  dw2=(where(qlds(0).detdesc.waveband eq 2))(0)
  ;  dw3=(where(qlds(0).detdesc.waveband eq 3))(0)
  ;  dw4=(where(qlds(0).detdesc.waveband eq 4))(0)
;    fac=[1,1,1,1]
 ;   if dw1 lt 0 then fac(0)=0
  ;  if dw2 lt 0 then fac(1)=0
 ;   if dw3 lt 0 then fac(2)=0
 ;   if dw4 lt 0 then fac(3)=0
 ; for a=0,n_elements(qlds)-1 do begin
 ;   ww0=reform([gt_windata(qlds(a),dw1>0)*fac(0),gt_windata(qlds(a),dw2>0)*fac(1),gt_windata(qlds(a),dw3>0)*fac(2),gt_windata(qlds(a),dw4>0)*fac(3)])
 ;   wwall(*,0+a*n_elements(qlds(0).del_timedata):n_elements(qlds(0).del_timedata)-1+a*n_elements(qlds(0).del_timedata))=ww0
 ; endfor  	  
  spectra=wwall
  gis1=total(wwall(0:2047,*)>0,1)
  gis2=total(wwall(2048:4095,*)>0,1)
  gis3=total(wwall(4096:6143,*)>0,1)
  gis4=total(wwall(6144:8191,*)>0,1)  
  qldsi={time:actime,gis1:gis1,gis2:gis2,gis3:gis3,gis4:gis4,spectra:wwall,filenames:qlds.header.filename,gset_id:qlds.header.gset_id,units:qlds.detdesc.units,exp_time:qlds.header.EXPTIME,science:qlds.header.SCI_OBJ,xcen:qlds.header.xcen,ycen:qlds.header.ycen}  
;;;;;;;;;;;;;;;;;;;;;;;
  if keyword_set(lines) then gisfit=gis_fit(gisfit,plot=plot)
  gisfit={header:qldsi}
  gfit:
  delvarx,temp

  if keyword_set(lines) then begin
    u=0
    Result = TAG_NAMES(gisfit)
    print,'Select a line :'
    bb=fltarr(n_elements(result))
    bbb=fltarr(n_elements(result))
    if n_elements(result) gt 1 then begin 
      for a=1,n_elements(result)-1 do begin
	print,strcompress(fix(string(a)),/remove_all)+' :   '+Result(a)
	con:
      endfor
    
    read,'? : ',u
    u=(u)*1>1<(n_elements(result)-1)
  ;  if (size(gisfit.(u)))(2) ne 8 then begin
  ;    good=where(gisfit.(u) gt 0.)
  ;    Result = TAG_NAMES(gisfit)
  ;    if not keyword_set(log) then utplot,(gisfit.header.time)(good),(gisfit.(u))(good),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle,title=result(u) else utplot_io,(gisfit.header.time)(good),(gisfit.(u))(good),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle,title=result(u)
      
  ;  endif else begin
      good=where(gisfit.(u).(0) gt 0.)
      if not keyword_set(log) then utplot,(gisfit.header.time)(good),(gisfit.(u).(0))(good),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle,title=result(u) else utplot_io,(gisfit.header.time)(good),(gisfit.(u).(0))(good),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle,title=result(u)
  ;  endelse

    endif else begin
      if not keyword_set(detno) then begin
	print,'1 :   GIS 1'
	print,'2 :   GIS 2'
	print,'3 :   GIS 3'
	print,'4 :   GIS 4'
	read,'? : ',detno
      endif
      if not keyword_set(log) then utplot,gisfit.header.time,total(gisfit.header.spectra(2048*(detno-1):2048*detno-1,*)>0,1),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle,title=ytitle else utplot_io,gisfit.header.time,total(gisfit.header.spectra(2048*(detno-1):2048*detno-1,*)>0,1),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle
endelse
    endif else begin
        
    if not keyword_set(log) then utplot,gisfit.header.time,total(gisfit.header.spectra(2048*(detno-1):2048*detno-1,*)>0,1),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle,title=ytitle else utplot_io,gisfit.header.time,total(gisfit.header.spectra(2048*(detno-1):2048*detno-1,*)>0,1),psym=psym,timerange=timerange,yr=yr,ytitle=ytitle
  endelse
  
  
end
