;+
; Project     : SOHO - CDS
;
; Name        : GIS_WRITE_CALIB
;
; Purpose     : Prints calibration factors for GIS spectra.
;
; Explanation : This main program uses the data from RAL-TR-1999-036 to produce
;		values for the GIS for entering into the CDS intensity 
;		databases.
;
; Use         : .run GIS_CALIB_WRITE
;
; Inputs      : None.
;                           
; Opt. Inputs : None.
;
; Outputs     : Plots and prints calibration values to screen
;
; Opt. Outputs: None.
;
; Keywords    : None.
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None?
;
; Category    : Calibration, GIS, Intensity.
;
; Prev. Hist. : None.
;
; Written     : Eddie Breeveld, erb@mssl.ucl.ac.uk  22 June 1999
;
; Modified    : None.
;
; Version     : 1
;
;-
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; values [ [value, ... ], $		; photons / count
;	   [wavelength, ... ], $	; Angstroms
;	   [error, ... ] ]		; photons / count
;
	G1_sens = [ [1.93e-4, 2.10e-4, 1.63e-4, 1.43e-4, 1.47e-4], $
		    [  160.9,   172.6,   206.6,   212.6,   217.1], $
		    [0.47e-4, 0.51e-4, 0.41e-4, 0.36e-4, 0.37e-4] ]
;
	G2_sens = [ [1.38e-4, 1.63e-4, 2.06e-4, 2.31e-4, 2.59e-4], $
		    [  267.4,   283.2,   301.1,   308.6,   313.5], $
		    [0.28e-4, 0.36e-4, 0.41e-4, 0.46e-4, 0.59e-4] ]
;
	G3_sens = [ [2.99e-4, 2.73e-4], $
		    [  406.5,   446.4], $
		    [0.60e-4, 0.54e-4] ]
;
	G4_sens = [ [8.92e-5, 1.02e-4], $
		    [  731.7,   769.2], $
		    [1.84e-5, 0.21e-4] ]
;
; Single values for get_efficiency database
;
	G1_efficiency = average(G1_sens[*, 0])
	G2_efficiency = average(G2_sens[*, 0])
	G3_efficiency = average(G3_sens[*, 0])
	G4_efficiency = average(G4_sens[*, 0])
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; extend range to cover end points of detector 1
;
	end_g1 = n_elements(g1_sens[*, 0]) - 1
	g1_sens = [transpose([g1_sens[0,0], 150.0, g1_sens[0,2]]), $
			g1_sens, $
		   transpose([g1_sens[end_g1,0], 225.0, g1_sens[end_g1, 2]]) ]
	end_g1 = end_g1+2
;
	plot, g1_sens[*, 1], g1_sens[*, 0]
	oploterr, g1_sens[*, 1], g1_sens[*, 0], g1_sens[*, 2]
;
; fit a normalised (/g1_efficiency) polynomial
;
	g1_result = poly_fit(g1_sens[*, 1], $
				g1_sens[*, 0]/g1_efficiency, 3, /double)
;
	points = (findgen(101)/100.0)*(G1_sens[end_g1,1]-g1_sens[0,1]) + $
			G1_sens[0,1]
;
; overplot an (un-normalised) polynomial fit 
;
	oplot, points, poly(points, g1_result) * g1_efficiency
	pause
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; detector 2
;
	end_g2 = n_elements(g2_sens[*, 0]) - 1
	g2_sens = [transpose([g2_sens[0,0], 255.0, g2_sens[0,2]]), $
			g2_sens, $
		   transpose([g2_sens[end_g2,0], 345.0, g2_sens[end_g2, 2]]) ]
	end_g2 = end_g2+2
;
	plot, g2_sens[*, 1], g2_sens[*, 0]
	oploterr, g2_sens[*, 1], g2_sens[*, 0], g2_sens[*, 2]
; 
	g2_result = poly_fit(g2_sens[*, 1], $
		g2_sens[*, 0]/g2_efficiency, 3, /double)
;
	points = (findgen(101)/100.0)*(g2_sens[end_g2,1]-g2_sens[0,1]) + $
			g2_sens[0,1]
;
	oplot, points, poly(points, g2_result) * g2_efficiency
	pause
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; detector 3
;
	end_g3 = n_elements(g3_sens[*, 0]) - 1
	g3_sens = [transpose([g3_sens[0,0], 390.0, g3_sens[0,2]]), $
			g3_sens, $
		   transpose([g3_sens[end_g3,0], 495.0, g3_sens[end_g3, 2]]) ]
	end_g3 = end_g3+2
;
	plot, g3_sens[*, 1], g3_sens[*, 0], $
		yrange=[min(g3_sens[*,0]-g3_sens[*,2]), $
			max(g3_sens[*,0]+g3_sens[*,2]) ]
	oploterr, g3_sens[*, 1], g3_sens[*, 0], g3_sens[*, 2]
; 
	g3_result = poly_fit(g3_sens[*, 1], $
		g3_sens[*, 0]/g3_efficiency, 1, /double)
;
	points = (findgen(101)/100.0)*(G3_sens[end_g3,1]-g3_sens[0,1]) + $
			G3_sens[0,1]
;
	oplot, points, poly(points, g3_result) * g3_efficiency
	pause
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; detector 4
;
	end_g4 = n_elements(g4_sens[*, 0]) - 1
	g4_sens = [transpose([g4_sens[0,0], 660.0, g4_sens[0,2]]), $
			g4_sens, $
		   transpose([g4_sens[end_g4,0], 780.0, g4_sens[end_g4, 2]]) ]
	end_g4 = end_g4+2
;
	plot, g4_sens[*, 1], g4_sens[*, 0]
	oploterr, g4_sens[*, 1], g4_sens[*, 0], g4_sens[*, 2]
; 
	g4_result = poly_fit(g4_sens[*, 1], $
		g4_sens[*, 0]/g4_efficiency, 1, /double)
;
	points = (findgen(101)/100.0)*(G4_sens[end_g4,1]-g4_sens[0,1]) + $
			G4_sens[0,1]
;
	oplot, points, poly(points, g4_result) * g4_efficiency
	pause
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; total single fit!
;
	tot_sens = [g1_sens, g2_sens, g3_sens, g4_sens]
	end_tot = n_elements(tot_sens[*,0])-1
;
	plot, tot_sens[*, 1], tot_sens[*, 0], $
		yrange=[min(tot_sens[*,0]-tot_sens[*,2]), $
			max(tot_sens[*,0]+tot_sens[*,2]) ]
	oploterr, tot_sens[*, 1], tot_sens[*, 0], tot_sens[*, 2]
;
	tot_result = poly_fit(tot_sens[*,1], $
		tot_sens[*,0]/g1_efficiency, 6, /double)
;
	points = (findgen(1001)/1000.0)*(tot_sens[end_tot,1]-tot_sens[0,1]) $
			+ tot_sens[0,1]
	oplot, points, poly(points, tot_result) * g1_efficiency
	pause
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; vignetting (mirror position dependance) and effective area
;
; values [ [ eff_areas, ... ], $	; cm^2
;	   [ mirr_pos, ...], $		; no units
;	   [ error, ...] ]		; cm^2
;
	gis_eff = [ [ 25.1,  25.5, 24.9 ], $
		    [ 68,   128,  188	], $
		    [  0.9,   0.9,  0.9 ] ]
;
	eff_average = average(gis_eff[*,0])
;
; fit a polynomial to the data
;
	eff_result = poly_fit(gis_eff[*,1], gis_eff[*,0], 2, /double)
;
	plot, gis_eff[*,1], gis_eff[*,0], $
		yrange = [min(gis_eff[*,0]), max(gis_eff[*,0])]
;
	m_pos = findgen(188 - 68 + 1) + 68
	areas = poly(m_pos, eff_result)
;
	oplot, m_pos, areas
;
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; print (save?) results
;
	format = '(4(a, e12.3))'
	print
	print, 'Base efficiencies (counts/photon)'
	print, format=format, $
		'  G1:', G1_efficiency, '  G2:', G2_efficiency, $
		'  G3:', G3_efficiency, '  G4:', G4_efficiency
;
	format = '(a, 4e13.4)'
	print
	print, 'Wavelength dependence of the efficiencies'
	print, format=format, '  G1 polynomial coeffs:', g1_result
	print, format=format, '  G2 polynomial coeffs:', g2_result
	print, format=format, '  G3 polynomial coeffs:', g3_result
	print, format=format, '  G4 polynomial coeffs:', g4_result
;
	print
	print, 'Effective area (cm^2)'
	print, '  Average area:', eff_average
;
	format = '(a, 3e13.4)'
	print
	print, 'Vignetting against mirror position (cm^2)'
	print, format=format, '  Polynomial coeffs:', eff_result
;
	print
	dummy = '' & read, prompt='Pause', dummy
;
	format = '(6(" mirr", "  area ") / 6(i5, f7.3))'
	print
	print, format=format, transpose([[m_pos], [areas]]) 
;
end


