;+
; Project     : SOHO - CDS     
;                   
; Name        : VIEW_PHA.PRO
;               
; Purpose     : To plot PHA data collected with raw data 
;               
; Explanation : Tool to allow the user to analyse GIS raw data.
;
; Use         : IDL> view_pha [,file=file]
;		If 'file' contains a '*' it is used as a filter for the filename
;    
; Inputs      : File name *.pha
;
; Opt. Inputs : filename *.pha
;               
; Outputs     : Plots of PHA histograms with LLD and ULD shown
;               
; Opt. Outputs: None
;               
; Keywords    : file
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: !
;               
; Category    : GIS, science data
;               
; Prev. Hist. : None
;
; Written     : A Breeveld, MSSL/UCL, 1994
;            
; Modified    : A. Breeveld, MSSL/UCL, 16 Feb 1996
;			Made into a routine, and tidied up a little
;			AAB added keyword for file
;		ERB MSSL/UCL 17 April 1996
;			Read and translated header information
;		ERB MSSL/UCL 20 April 1996
;			Added file filter processing
;		ERB MSSL/UCL 24 July 1998
;			Added getenv call to pickfile
;		ERB MSSL/UCL 30 September 1999
;			output to 3 plot windows, added hardcopy and
;			smoothsize switches
;
; Version     : 2.6
;-            

pro view_pha, file=file, hardcopy=hardcopy, smoothsize=smoothsize

;
;	Program to read in pha data from Alec's EGSE like Allsingn
;
	whole=0
	header=bytarr(512)
	data=bytarr(512)
	achar=" "
;
;  Get info required from user!
;
	filter = '*.pha'
	rawfile = ''

	if keyword_set(file) then begin
		if (strpos(file, '*') ne -1) then filter = file $
		else rawfile = file
	endif
;
	if (rawfile eq '') then begin
reread:
		rawfile = pickfile(/read, $
				/must_exist, $
				path=getenv('CDS_GIS_RAW'), $
				filter=filter)
		if (rawfile eq "") then return
	endif
;
	if strpos(rawfile, '/') eq -1 then $
		rawfile = getenv('CDS_GIS_RAW') + '/' + rawfile
;
	on_ioerror, reread
	openr, lun, /get_lun, RAWFILE
	on_ioerror, null

	print,rawfile
;
;  read it all in
;
	readu, lun, header	; read header
	head_str = gis_raw_header (header)
			;Eddie's routine for printing header in English
;
	lld = [0, 34, 38, 32, 34]
	lld = lld[head_str.detector]
	uld = [0, 196, 204, 204, 198]
	uld = uld[head_str.detector]
;
	readu,lun,data
	on_ioerror,cont
	readu,lun,data
;
	while (1 eq 1) do begin
		whole=[whole,data]
		readu,lun,data
	endwhile
cont:
	whole=[whole,data]
	close,lun
	free_lun, lun
;
	ph = whole(1:*)
	window, 0
	plot,ph,psym=3,xstyle=1
;
	phd = histogram([0,ph,256])
	window, 1
	plot, phd, xrange=[1,256], xstyle=1, $
			TITLE = 'Histogram of PHA data from:  '+ RAWFILE, $
			charsize = 0.75
;
	if not keyword_set(smoothsize) then smoothsize=3
	smoothphd=[0,smooth(float(phd),smoothsize)]
	maxphd = max (smoothphd(10:200))
;
	window, 2
	plot, smoothphd, xrange=[20,256], yrange=[0,(maxphd)], $
		TITLE = 'Smoothed Histogram of PHA data from:  '+ RAWFILE, $
			charsize = 0.75, xstyle=1, ystyle=1

	oplot,[lld,lld],[0,maxphd],linestyle=2
	oplot,[uld,uld],[0,maxphd],linestyle=2
	
	modalgain = where(smoothphd(10:200) eq maxphd)
	upper = where (smoothphd(10:200) ge maxphd/2)
	upper = upper(where(upper ne 0))
	width = n_elements(upper)
	fwhm = 100*float(width)/float(modalgain)

	print,'the gain is',modalgain
	print,'the FWHM is',fwhm

	orwidth = max(upper) - min(upper)
	orfwhm = 100*float(orwidth)/float(modalgain)

	print,'or the FWHM is',orfwhm
;
	if keyword_set (hardcopy) then begin
		ps
		plot, smoothphd, xrange=[20,256], yrange=[0,(maxphd)], $
  TITLE = 'Smoothed Histogram of PHA data from:  '+ RAWFILE, $
			charsize = 0.75, $
			xstyle = 1, ystyle = 1
		oplot,[lld,lld],[0,maxphd],linestyle=2
		oplot,[uld,uld],[0,maxphd],linestyle=2
		psplot
	endif
end
