	PRO CDS_ENG_N1_PR, RESULT, FILENAME, WIDGET=WIDGET
;+
; Project     :	SOHO - CDS
;
; Name        :	CDS_ENG_N1_PR
;
; Purpose     :	Print results from CDS engineering test N1.
;
; Category    :	Data analysis, Engineering
;
; Explanation :	Prints out the results from CDS engineering test N1, either to
;		the screen or to a file.  Called from CDS_ENG_N1.
;
; Syntax      :	CDS_ENG_N1_PR, RESULT  [, FILENAME ]
;
; Examples    :	
;
; Inputs      :	RESULT	 = Output structure from CDS_ENG_N1_AN.
;
; Opt. Inputs :	FILENAME = Name of file to write output to.  If not passed,
;			   then the output is written to the screen.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	WIDGET	 = If passed, then the output is written in the
;			   specified text widget, instead of to a file or the
;			   terminal window.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 24-Oct-1995, William Thompson, GSFC
;
; Contact     :	WTHOMPSON
;-
;
	ON_ERROR, 2
;
;  Check the parameters.
;
	IF N_PARAMS() LT 1 THEN MESSAGE,	$
		'Syntax: CDS_ENG_N1_PR, RESULT  [, FILENAME ]'
;
;  If a filename was passed, then open the file for write.
;
	IF N_PARAMS() EQ 2 THEN	BEGIN
		OPENW, UNIT, FILENAME, /GET_LUN
	END ELSE UNIT = -1
;
;  Determine whether or not the output should go to a widget or to a text file.
;
	NW = N_ELEMENTS(WIDGET) EQ 1
	IF NW THEN WIDGET_CONTROL, WIDGET, SET_VALUE=''
;
;  Write out the results.
;
	OUT = 'ANALYSIS OF CDS ENGINEERING N1 STUDY ' +	$
		TRIM(RESULT(0).STUDY_COUNTER)
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = '======================================================='
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = ''
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = 'With high voltage off'
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = '---------------------'
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	STIME = ['1', '10', '100', '1000']
;
	FOR I = 0,3 DO BEGIN
	    OUT = ''
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = 'Exposure time = ' + STIME(I) + ' seconds'
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = ''
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).AVG, FORMAT="('Average = ', 4F10.3)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).SIGMA, FORMAT="('Std Dev = ', 4F10.3)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).MIN, FORMAT="('Minimum = ', 4I10)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).MAX, FORMAT="('Maximum = ', 4I10)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	ENDFOR
;
	OUT = ''
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = ''
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = 'With high voltage on'
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
	OUT = '--------------------'
	IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE	$
		PRINTF, UNIT, OUT
;
	FOR I = 4,7 DO BEGIN
	    OUT = ''
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = 'Exposure time = ' + STIME(I-4) + ' seconds'
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = ''
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).AVG, FORMAT="('Average = ', 4F10.3)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).SIGMA, FORMAT="('Std Dev = ', 4F10.3)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).MIN, FORMAT="('Minimum = ', 4I10)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	    OUT = STRING(RESULT(I).MAX, FORMAT="('Maximum = ', 4I10)")
	    IF NW THEN WIDGET_CONTROL, WIDGET, /APPEND, SET_VALUE=OUT ELSE $
		PRINTF, UNIT, OUT
	ENDFOR
;
;  Close the output file, if any.
;
	IF N_PARAMS() EQ 2 THEN FREE_LUN, UNIT
;
	RETURN
	END
