;+
; Project     :	SOHO - CDS
;
; Name        :	CDS_ENG_N1_VW
;
; Purpose     :	View results from CDS engineering test N1.
;
; Category    :	Data analysis, Engineering
;
; Explanation :	Allows the user to view any of the quadrants from CDS
;		Engineering test N1.  Called from CDS_ENG_N1.
;
; Syntax      :	CDS_ENG_N1_VW
;
; Examples    :	
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 24-Oct-1995, William Thompson, GSFC
;
; Contact     :	WTHOMPSON
;-
;
;==============================================================================
;  This is the event handler.
;==============================================================================
;
	PRO CDS_ENG_N1_VW_EVENT, EVENT
;
@cds_eng_n1.cmn
;
;  Get the event user value, and act accordingly.
;
	WIDGET_CONTROL, EVENT.ID, GET_UVALUE=EV
	CASE EV OF
;
;  An image event was seen.  Get the X and Y values.
;
	    'IMAGE': BEGIN
		X = EVENT.X
		Y = EVENT.Y
		IF (X LT 0) OR (X GT 511) OR (Y LT 0) OR (Y GT 511) THEN RETURN
		IXY = QUAD(X,Y)
		WIDGET_CONTROL, XPOS, SET_VALUE=X
		WIDGET_CONTROL, YPOS, SET_VALUE=Y
		WIDGET_CONTROL, VALUE, SET_VALUE=IXY
;
;  Display the horizontal trace.
;
		SETWINDOW, DRAW_WINDOW
		OPLOT, VEC, COL=0		;Erase graph
		OPLOT, OLD_XH, OLD_YH, COL=0	;Erase cross
		OPLOT, OLD_XV, OLD_YV, COL=0
		XYOUTS,.1,0,/NORM,VALUE,COL=0	;Erase text
;
		VEC = QUAD(*,Y)		;Get row
		OLD_XH = [X,X]
		OLD_YH = CROSSY + IXY
		OLD_XV = CROSSX + X
		OLD_YV = [IXY,IXY]
;
		OPLOT, VEC				;Graph
		OPLOT, OLD_XH, OLD_YH			;Cross
		OPLOT, OLD_XV, OLD_YV
		EMPTY
		SETWINDOW, IMAGE_WINDOW
;
		END
;
;  The "Edit color table" button was pressed.  Call XLOADCT.
;
	    'XLOADCT': XLOADCT, GROUP=EVENT.TOP
;
;  The voltage was changed.  Read in the new data file.
;
	    'VOLTAGE': BEGIN
		WIDGET_CONTROL, EVENT.ID, GET_VALUE=IVOL
		GOTO, READ_FILE
		END
;
;  The exposure time was changed.  Read in the new data file.
;
	    'EXPOSURE': BEGIN
		WIDGET_CONTROL, EVENT.ID, GET_VALUE=IEXP
		GOTO, READ_FILE
		END
;
;  The quadrant was changed.
;
	    'QUADRANT': BEGIN
		WIDGET_CONTROL, EVENT.ID, GET_VALUE=IQUAD
		GOTO, DISPLAY_QUAD
		END
;
;  The DONE button was pressed.
;
	    'DONE': WIDGET_CONTROL, EVENT.TOP, /DESTROY
	ENDCASE
;
	RETURN
;
READ_FILE:
	WIDGET_CONTROL, CNTR, SET_VALUE=STUDY_COUNTER
	WIDGET_CONTROL, /HOURGLASS
	IRAS = 4*IVOL + IEXP
	FILENAME = 's' + TRIM(STUDY_COUNTER) + 'r' + TRIM(IRAS) + '.fits'
	MESSAGE = ''
	CDS_ENG_N1_RD, PATH + FILENAME, DATA, ERRMSG=MESSAGE
	IF MESSAGE NE '' THEN BEGIN
		XACK, /MODAL, MESSAGE
		RETURN
	ENDIF
;
DISPLAY_QUAD:
	CASE IQUAD OF
		0: QUAD = DATA(0:511,512:*)	;A
		1: QUAD = DATA(512:*,512:*)	;B
		2: QUAD = DATA(0:511,0:511)	;C
		3: QUAD = DATA(512:*,0:511)	;D
	ENDCASE
	SETWINDOW, IMAGE_WINDOW
	TVSCL, QUAD
;
;  Display an empty plot.
;
	MINV = MIN(QUAD, MAX=MAXV)
	SETWINDOW, DRAW_WINDOW
	PLOT, [0,511], [MINV, MAXV], /NODATA
	VEC = INDGEN(512)
	TICKL = 0.1				;Cross length
	CROSSX = [-TICKL, TICKL]*512
	CROSSY = [-TICKL, TICKL]*(MAXV-MINV)
	SETWINDOW, IMAGE_WINDOW
;
	END
;
;==============================================================================
;  This sets up the widget.
;==============================================================================
;
	PRO CDS_ENG_N1_VW, GROUP=GROUP
;
@cds_eng_n1.cmn
	IF N_ELEMENTS(GROUP) EQ 0 THEN GROUP=0
;
;  If a copy of CDS_ENG_N1_VW is already running, then exit.
;
	IF (XREGISTERED("cds_eng_n1_vw") NE 0) THEN RETURN
;
;  If STUDY_COUNTER hasn't been defined yet, then exit.
;
	IF N_ELEMENTS(STUDY_COUNTER) EQ 0 THEN BEGIN
		MESSAGE, /CONTINUE, 'Study counter not yet defined'
		RETURN
	ENDIF
;
;  Define the main base.
;
	MAIN = WIDGET_BASE(GROUP_LEADER=Group, /ROW, /MAP,	$
		TITLE='CDS Engineering N1 View')
;
;  Define the window to hold the image.
;
	IMAGE_WIDGET = WIDGET_DRAW(MAIN, /BUTTON_EVENTS, /MOTION_EVENTS, $
		UVALUE='IMAGE', XSIZE=512, YSIZE=512)
;
;  Define the right hand base.  This contains all the other widgets.
;
	RIGHT = WIDGET_BASE(MAIN, /COLUMN, /MAP)
;
;  Define the top base.  This contains the study counter number, and a button
;  to run XLOADCT.
;
	TOP = WIDGET_BASE(RIGHT, /ROW, /MAP)
;
;  Define the widget to display the study counter number.
;
	CNTR = CW_FIELD(TOP, VALUE=STUDY_COUNTER, /ROW, /LONG, /NOEDIT, $
		TITLE='Study counter:', /ALL_EVENTS)
;
;  Define the button to start up XLOADCT.
;
	DUMMY = WIDGET_BUTTON(TOP, UVALUE='XLOADCT', VALUE='Edit color table')
;
;  Define the widgets to select the data.
;
	BUTTONS = ['Off','On']
	DUMMY = CW_BGROUP(RIGHT, BUTTONS, ROW=1, /EXCLUSIVE,		$
		LABEL_LEFT='Voltage setting:', UVALUE='VOLTAGE', SET_VALUE=0)
;
	BUTTONS = ['1','10','100','1000']
	DUMMY = CW_BGROUP(RIGHT, BUTTONS, ROW=1, /EXCLUSIVE,	$
		LABEL_LEFT='Exposure time:', UVALUE='EXPOSURE',	SET_VALUE=0)
;
	BUTTONS = ['A','B','C','D']
	DUMMY = CW_BGROUP(RIGHT, BUTTONS, ROW=1, /EXCLUSIVE,	$
		LABEL_LEFT='Quadrant:', UVALUE='QUADRANT', SET_VALUE=0)
;
;  Define the widget to hold the graph.
;
	DRAW_WIDGET = WIDGET_DRAW(RIGHT, XSIZE=512, YSIZE=280)
;
;  Define the base to hold all the information about the image.  This base
;  contains the X and Y positions, and the image value.  It also contains a
;  "Done" button.
;
	BOTTOM = WIDGET_BASE(RIGHT, /ROW, /MAP)
;
	XPOS = CW_FIELD(BOTTOM, VALUE='', /ROW, /NOEDIT, TITLE='X:', XSIZE=10)
	YPOS = CW_FIELD(BOTTOM, VALUE='', /ROW, /NOEDIT, TITLE='Y:', XSIZE=10)
	VALUE= CW_FIELD(BOTTOM, VALUE='', /ROW, /NOEDIT, TITLE='Value:', $
		XSIZE=10)
;
	DUMMY = WIDGET_BUTTON(BOTTOM, UVALUE='DONE', VALUE='Done')
;
;  Realize the widget.
;
	WIDGET_CONTROL, MAIN, /REALIZE
;
;  Get the window indices.
;
	WIDGET_CONTROL, IMAGE_WIDGET, GET_VALUE=IMAGE_WINDOW
	WIDGET_CONTROL, DRAW_WIDGET,  GET_VALUE=DRAW_WINDOW
;
;  Read in the image and select out the appropriate quadrant.
;
	WIDGET_CONTROL, CNTR, SET_VALUE=STUDY_COUNTER
	WIDGET_CONTROL, /HOURGLASS
	IVOL = 0
	IEXP = 0
	IQUAD = 0
	MESSAGE = ''
	CDS_ENG_N1_RD, PATH + 's' + TRIM(STUDY_COUNTER) + 'r0.fits', DATA, $
		ERRMSG = MESSAGE
	IF MESSAGE NE '' THEN BEGIN
		XACK, /MODAL, MESSAGE
		WIDGET_CONTROL, MAIN, /DESTROY
		RETURN
	ENDIF
	QUAD = DATA(0:511,512:*)
	SETWINDOW, IMAGE_WINDOW
	TVSCL, QUAD
;
;  Display an empty plot.
;
	MINV = MIN(QUAD, MAX=MAXV)
	SETWINDOW, DRAW_WINDOW
	PLOT, [0,511], [MINV, MAXV], /NODATA
	VEC = INDGEN(512)
	TICKL = 0.1				;Cross length
	CROSSX = [-TICKL, TICKL]*512
	CROSSY = [-TICKL, TICKL]*(MAXV-MINV)
	IXY = (MINV + MAXV) / 2
	OLD_XH = [256,256]
	OLD_YH = CROSSY + IXY
	OLD_XV = CROSSX + 256
	OLD_YV = [IXY,IXY]
	SETWINDOW, IMAGE_WINDOW
;
;  Set it all going.
;
	XMANAGER, 'cds_eng_n1_vw', MAIN
;
	END
