;+
; Project     : SOHO - CDS     
;                   
; Name        : CDS_SATURATE
;               
; Purpose     : Checks NIS data for saturation
;               
; Explanation : Records if a file has raw data values = 4095
;               
; Use         : IDL> cds_saturate, qlds
;    
; Inputs      : qlds - RAW data structure
;               
; Opt. Inputs : None
;               
; Outputs     : If saturation found, prints results to file named
;                 file.sat
;               
; Opt. Outputs: None
;               
; Keywords    : SYSTEM - writes to official HEADCAT directory, otherwise local
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Help
;               
; Prev. Hist. : None
;
; Written     : C D Pike,  RAL,  5-Aug-99
;               
; Modified    : 
;
; Version     : Version 1,  5-Aug-99
;-            

pro cds_saturate, qlds, system=system

text = strarr(20)

if gt_data_units(qlds) ne 'ADC' then begin
   print,'Routine only works on RAW data'
   return
endif

nw = gt_numwin(qlds)
break_file,qlds.header.filename,disk,dir,ff,ext

if qlds.header.comp_id eq 8 then factor = float(qlds.header.comp_opt) else $
                                 factor = 1.0

for i=0,nw-1 do begin
   d = gt_windata(qlds,i)
   n = where(d ge 4095*factor,sat)
   if sat gt 5 then begin
      rate = fix((4096.-300.)/gt_exptime(qlds))
      win = strpad('  Window: ' + trim(i) + ' ('+gt_wlabel(qlds,i)+')',27,/after)
      pix = strpad('  Num pixels: ' + trim(sat),18,/after) 
      text(i) = ff + win + pix + '  Minimum rate: ' + trim(rate) + ' c/s/pix'
   endif
endfor

n = where(text ne '',count)
if count gt 0 then begin
   text = text(n)
   if keyword_set(system) then begin
      outfile = concat_dir('CDS_HEAD_CAT',ff+'.sat')
      print_str,text,/keep,file=outfile,/quiet
   endif else begin
      print_str,text
   endelse
endif else begin
   if not keyword_set(system) then print,'No saturated pixels'
endelse


end
 

