	FUNCTION NIMCP_DEPTH_FUNCT, DTAI, PD, PDERIV
;+
; Project     :	SOHO - CDS
;
; Name        :	NIMCP_DEPTH_FUNCT()
;
; Purpose     :	Function used by GET_NIMCP
;
; Category    :	Class4, Calibration
;
; Explanation :	Function used by GET_NIMCP to express the VDS burn-in depth as
;		an exponential decline.  Called by GET_NIMCP.
;
; Syntax      :	Result = NIMCP_DEPTH_FUNCT(DTAI, PD  [, PDERIV ])
;
; Examples    :	
;
; Inputs      :	DTAI	= Number of TAI seconds since 1995-12-02T00:00:00Z.
;		PD	= The parameters of the function.  Can also be an array
;			  of parameters of dimensions (3,N)
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	PDERIV	= A placeholder to make LSTSQR work, this always
;			  returns zero.
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	None.
;
; History     :	Version 1, 25-Feb-1997, William Thompson, GSFC
;		Version 2, 06-Aug-1997, William Thompson, GSFC
;			Allow DTAI to be a vector.
;
; Contact     :	WTHOMPSON
;-
;
	PDERIV = 0.
;
	SZ = SIZE(PD)
	IF SZ(0) EQ 1 THEN BEGIN
	    NP = 1
	    RESULT = DTAI
	END ELSE BEGIN
	    NP = SZ(2)
	    RESULT = REPLICATE(DTAI(0), N_ELEMENTS(DTAI), SZ(2))
	ENDELSE
;
	FOR I = 0,NP-1 DO RESULT(0,I) = PD(0,I) + PD(1,I) * EXP(-DTAI/PD(2,I))
;
	RETURN, RESULT
	END
