;+
; Project     : SOHO - CDS     
;                   
; Name        : QCALIB
;               
; Purpose     : Compare NIS intensity calibrations
;               
; Explanation : The CDS NIS intensity calibration has evolved
;               with time.  This routine allows an easy comparison
;               of the current calibration with that available at
;               previous times.
;               
; Use         : IDL> qcalib,[date]
;    
; Inputs      : None
;               
; Opt. Inputs : date - date for ols calibration
;               
; Outputs     : plots
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : Calibration database access routines
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 
;               
; Modified    : 
;
; Version     : Version 1, 13-Sep-99
;-            
pro qcalib, date_used

on_error, 2
!p.multi=[0,1,2]

;
;  get current date
;
get_utc, date_now 

;
;  if no 'old' date given then use current date
;
if n_params()  eq 0 then begin
   date_used = date_now
endif 

;
;  get NIS1 efficiences
;
;  first with possible old date
;
WAVE1 = PIX2WAVE('N1', INDGEN(1024))
GET_EFFICIENCY, date_now, 'N1', EFF1, date_used=date_used
GET_WAVE_EFF, date_now, 'N1', COEFF1, date_used=date_used
EFF1 = EFF1 * POLY(WAVE1, COEFF1)
tot1 = total(eff1)
plot,wave1,eff1*1.0e4,yr=[0.0,2.5],/yst,$
    tit='NIS1 Intensity calibration',$
    xtit='Wavelength',$
    ytit='Sensitivity (10!E-4!N Event Photon!E-1!N)'
if n_params() gt 0 then $
   xyouts,307.,min(eff1*1.0e4)-0.1,$
              'Calibration at '+anytim2cal(date_used,/date)

;
;  then with current date
;
GET_EFFICIENCY, date_now, 'N1', EFF1
GET_WAVE_EFF, date_now, 'N1', COEFF1
EFF1 = EFF1 * POLY(WAVE1, COEFF1)
if tot1 ne total(eff1) then begin
   oplot,wave1,eff1*1.0e4,line=2
   xyouts,307.,min(eff1*1.0e4)-0.1,'Current calibration'
endif


;
;  ditto for NIS2
;
 
WAVE2 = PIX2WAVE('N2', INDGEN(1024))
GET_EFFICIENCY, date_now, 'N2', EFF2, date_used=date_used
GET_WAVE_EFF, date_now, 'N2', COEFF2, date_used=date_used
EFF2 = EFF2 * POLY(WAVE2, COEFF2)
tot2 = total(eff2)
plot,wave2,eff2*1.0e4,yr=[0,8.0],/yst,$
    tit='NIS2 Intensity calibration',$
    xtit='Wavelength',$
    ytit='Sensitivity (10!E-4!N Event Photon!E-1!N)'

xyouts,511.,max(eff2*1.0e4)+0.3,$
      'Calibration at '+anytim2cal(date_used,/date)
 
GET_EFFICIENCY, date_now, 'N2', EFF2
GET_WAVE_EFF, date_now, 'N2', COEFF2
EFF2 = EFF2 * POLY(WAVE2, COEFF2)
if tot2 ne total(eff2) then begin
   oplot,wave2,eff2*1.0e4,line=2
   xyouts,511.,max(eff2*1.0e4)+0.3,'Current calibration'
endif

!p.multi=0

end

