;+
; Project     : SOHO - CDS
;
; Name        : RESTORE_WAVECAL 
;
; Purpose     : Restores sensible default wavelength calibration from a given qlds
;
; Explanation : This procedure restores the wavelength calibration for
;               any input qlds, assuming sensible defaults.
;               Useful after restoring a QLDS from a savefile.
;
; Use         : e.g.
;                   IDL> qlds   = restore_qlds ('qlfile.qlsave')
;                   IDL> result = restore_wavecal (qlds)
;
; Inputs      : QLDS    = Structure variable of CDS data as read by READCDSFITS.
;
; Opt. Inputs : None.
;
; Outputs     : result  = returned with 1 if wavelength calibration loaded correctly 
;
; Opt. Outputs: None.
;
; Keywords    : None.
;
; Calls       : load_wavecal
;
; Common      : None.
;
; Restrictions: None.
;
; Side effects: None.
;
; Category    : Data analysis, wavelength calibration.
;
; Prev. Hist. : None.
;
; Written     : Eddie Breeveld, erb@mssl.ucl.ac.uk  12 December 1997
;
; Modified    : 
;
; Version     : Version 1, 12 Dec 1997
;
;-

Function restore_wavecal, qlds
;
;
    result = 0
    utc = gt_start(qlds)
;
    if gt_detector(qlds) eq 'GIS' then begin
        result = load_wavecal ('G', utc, gset_id=qlds.header.gset_id) 
    endif else begin
        result = load_wavecal ('N', utc)
    endelse
;
    return, result
end
