;+
; Project     : SOHO - CDS     
;                   
; Name        : NEXPOSURES()
;               
; Purpose     : Return the number of "exposures" in a QLDS
;               
; Explanation : Returns the number of exposures, defined as the
;		size of the larger of the DEL_TIME and the SSOLAR_X
;		dimensions.
;               
; Use         : NEXP = NEXPOSURES(QLDS)
;    
; Inputs      : QLDS:	A "CDS QL data strucure"
;               
; Opt. Inputs : None.
;               
; Outputs     : Ret.value.
;               
; Opt. Outputs: None.
;               
; Keywords    : NOCHECK:
;			Set to avoid checking with QLMGR whether
;			the QLDS is acceptable. Set to speed up...
;
; Calls       : QLMGR, QL_SIZES()
;
; Common      : None.
;               
; Restrictions: QLDS == QL data structure.
;               
; Side effects: None.
;               
; Category    : CDS, QuickLook
;               
; Prev. Hist. : Used to be called nraster, but change of terminology
;		(RASTER -> EXPOSURE) prompted name change.
;
; Written     : Stein Vidar Hagfors Haugan, October 1993.
;               
; Modified    : SVHH, 6-March-1995, Altered to use the ql_dimensions()
;			routine after altering the data format slightly.
;
; Version     : 1.1, 6-March-1995
;-            

FUNCTION Nexposures,f,NOCHECK=NOCHECK
  IF NOT Keyword_SET(NOCHECK) THEN QLMGR,f

  dims = ql_dimensions(f,/nocheck)
  return,dims.ssolar_x > dims.sdel_time
END

