;+
; Project     : SOHO - CDS     
;                   
; Name        : ZSIZE()
;               
; Purpose     : Return no. of "pixels along slit" in a QLDS
;               
; Explanation : "Pixels along slit" is another term for the size of 
;		the SOLAR_Y (!!) dimension in the FITS files.
;		This routine should really be named YSIZE()!.
;               
; Use         : N_SLIT_PIXELS = ZSIZE(QLDS)
;    
; Inputs      : QLDS:	A "CDS QL data structure"
;
; Opt. Inputs : None.
;               
; Outputs     : Return value.
;               
; Opt. Outputs: None.
;               
; Keywords    : NOCHECK:Set to avoid call to QLMGR.
;
; Calls       : QLMGR, QL_DIMENSIONS()
;
; Common      : None.
;               
; Restrictions: QLDS == CDS QL data structure.
;               
; Side effects: None.
;               
; Category    : CDS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, October 1993
;               
; Modified    : SVHH, 21 November - Documentation added.
;		SVHH, 6-March-1995, Introduced the use of QL_DIMENSIONS().
;
; Version     : 1.1, 6-March-1995
;-            

FUNCTION Zsize,f,NOCHECK=NOCHECK
  
  IF NOT Keyword_SET(NOCHECK) THEN QLMGR,f
  
  dims = ql_dimensions(f,/nocheck)

  return,dims.ssolar_y  
END

