FUNCTION box_filter, n, c, r
;+
; Project     : SOHO - CDS     
;                   
; Name        : box_filter()
;               
; Purpose     : make rounded edges on data to be fft filtered
;               
; Explanation : to avoid 'ringing' effects the edges of the data
;               record should be rounded 
;               
; Use         : IDL> val = box_filter(number of points in array,
;                                cut value, roll value) 
;    
; Inputs      : n, cut, roll
;               
; Opt. Inputs : None
;               
; Outputs     : array with rounded edges
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : fft
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. : ?
;
; Written     : Olav Kjeldseth-Moe, ITA, UiO
;               
; Modified    : Version 1 Nils Brynildsen, ITA, UiO, 1-July-1993
;
; Version     : Version 1 1-July-1993
;-            
i = INDGEN(n)
pi = 3.1415926535898
f2 = EXP(-pi*r*i)
f1 = f2
f1(0) = 2.*c
f1(1) = SIN(2.0*pi*c*i(1:n-1))/(pi*i(1:n-1))
fr = f1*f2  
i = n-i
f2 = EXP(-pi*r*i)
f1 = f2
f1(0) = 2.*c
f1(1) = SIN(2.0*pi*c*i(1:n-1))/(pi*i(1:n-1))
fr = fr + f1*f2  
f1 = ABS(FFT(fr,-1))
RETURN, f1/MAX(f1) 
END
