PRO dl2vel, a, back, w0
;+
; Project     : SOHO - CDS     
;                   
; Name        : dl2vel
;               
; Purpose     : transform from delta wavelength to velocity (km/s)
;               
; Explanation : uses formula for velocity: v = c*(dl/l), 
;               where c = velocity of light, dl = shift in
;               wavelength and l = wavelength of line    
;               
; Use         : IDL> dl_to_vel, fitted parameters, background value
;    
; Inputs      : fitted parameters (3, 5 or 7), backround level 
;               
; Opt. Inputs : None
;               
; Outputs     : fitted parameters with line shifts in km/s
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. : ?
;
; Written     : Nils Brynildsen, ITA, UiO 19-July-1993
;               
; Modified    : Version 1 Nils Brynildsen, ITA, UiO, 19-July-1993
;
; Version     : Version 1 19-July-1993
;-
IF N_PARAMS(0) LT 3 THEN BEGIN
   PRINT,' *** DL2VEL must be called with 3 parameters ***'
   RETURN
ENDIF           
m = N_ELEMENTS(a)
con = 2.9979e+5/w0
a(0) = ALOG10(a(0) + back)
a(1) = con*(a(1) - w0)
IF m GT 3 THEN a(3) = ALOG10(a(3) + back)
IF m GT 3 THEN a(4) = con*(a(4) - w0)
IF m GT 5 THEN a(5) = ALOG10(a(5) + back)
IF m GT 5 THEN a(6) = con*(a(6) - w0)
RETURN
END
