PRO functn, x, cf, y, pd
;+
; Project     : SOHO - CDS     
;                   
; Name        : functn
;               
; Purpose     : Make the line profile of 1,2 or 3 Gaussians
;               
; Explanation : Calls routines to produce the fitted line profile
;               
; Use         : IDL> functn,x-array,Parameters of Gaussian,
;                           partial derivatives for the Gaussian)
;       
; Inputs      : x-array, parameters of Gaussian, derivatives
;               
; Opt. Inputs : None
;               
; Outputs     : Composit lineprofile
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : cdsgauss, gauss_d_a, gauss_d_p, gauss_d_w
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. : ?
;
; Written     : Nils Brynildsen, ITA, UiO 29-June-1993
;               
; Modified    : Version 1 Nils Brynildsen, ITA, UiO, 29-June-1993
;
; Version     : Version 1 29-June-1993
;-            

n = N_ELEMENTS(x)
m = N_ELEMENTS(cf)
pd = FLTARR(n,m)

a1 = cf(0)
p1 = cf(1)
w  = cf(2)
IF m GT 3 THEN a2 = cf(3)
IF m GT 3 THEN p2 = cf(4)
IF m GT 5 THEN a3 = cf(5)
IF m GT 5 THEN p3 = cf(6)

y = cdsgauss(x,a1,p1,w) 
IF m GT 3 THEN y = y + cdsgauss(x,a2,p2,w) 
IF m GT 5 THEN y = y + cdsgauss(x,a3,p3,w)    

pd(*,0) = gauss_d_a(x,a1,p1,w)
pd(*,1) = gauss_d_p(x,a1,p1,w)
pd(*,2) = gauss_d_w(x,a1,p1,w)
IF m GT 3 THEN pd(*,2) = pd(*,2) + gauss_d_w(x,a2,p2,w)
IF m GT 5 THEN pd(*,2) = pd(*,2) + gauss_d_w(x,a3,p3,w)
IF m GT 3 THEN pd(*,3) = gauss_d_a(x,a2,p2,w)
IF m GT 3 THEN pd(*,4) = gauss_d_p(x,a2,p2,w)
IF m GT 5 THEN pd(*,5) = gauss_d_a(x,a3,p3,w)
IF m GT 5 THEN pd(*,6) = gauss_d_p(x,a3,p3,w)

RETURN
END 