PRO INT_FWHM, x, y, totint
;+
; Project     : SOHO - CDS     
;                   
; Name        : int_fwhm
;               
; Purpose     : Calculate the total line intensity from the maximum
;		intensity in the line and the FWHM
;               
; Explanation : 
;               
; Use         : IDL> int_fwhm, x, y, totint
;    
; Inputs      : x and y arrays for spectral line
;               
; Opt. Inputs : 
;               
; Outputs     : total intensity of line
;               
; Opt. Outputs: 
;               
; Keywords    : None
;
; Calls       : interp
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. :
;
; Written     : Nils Brynildsen, ITA, UiO, 9-Sept.-1993
;               
; Modified    : Version 1 Nils Brynildsen, ITA, 9-Sept-1993
;
; Version     : Version 1 9-Sept.-1993
;- 
IF N_PARAMS(0) LT 3 THEN BEGIN
  PRINT,' *** INT_FWHM must be called with 3 parameters ***'
  RETURN
ENDIF           
;
;	Find max value for line, and half max value intensity
;           
ymax = MAX(y)
index = WHERE(y EQ ymax)                    
xmax = FLOAT(x(index))
yhalf = ymax/2.
;
;	Find x-value at half max y-value to the left
;
xleft1 = MAX(x(WHERE((y LE yhalf) AND (x LT xmax(0)))))
yleft1 = MAX(y(WHERE((y LE yhalf) AND (x LT xmax(0)))))
left_index = WHERE(x EQ xleft1)
xleft2 = x(left_index+1)
yleft2 = y(left_index+1)   
INTERP, xleft1, yleft1, xleft2, yleft2, xhalfleft, yhalf
;
;	Find x-value at half max y-value to the right
;
xright2 = MIN(x(WHERE((y LE yhalf) AND (x GT xmax(0)))))
yright2 = MAX(y(WHERE((y LE yhalf) AND (x GT xmax(0)))))
right_index = WHERE(x EQ xright2)
xright1 = x(right_index-1)
yright1 = y(right_index-1)
INTERP, xright1, yright1, xright2, yright2, xhalfright, yhalf
;
;	Calculate FWHM and total intensity across line
;
fwhm = (xhalfright - xhalfleft)
totint = 1.064467*ymax*fwhm

RETURN
END