;+
; Project     : SOHO - CDS     
;                   
; Name        : int_fwhm
;               
; Purpose     : Calculate total intensity from peak intensity and the FWHM
;               
; Explanation : 
;               
; Use         : IDL> int_fwhm, x, y, totint, fwhm, shift
;    
; Inputs      : x and y arrays for spectral line
;               
; Opt. Inputs : 
;               
; Outputs     : total intensity of line
;               
; Opt. Outputs: 
;               
; Keywords    : None
;
; Calls       : interp
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. :
;
; Written     : Nils Brynildsen, ITA, UiO, 9-Sept.-1993
;               
; Modified    : Version 1 Nils Brynildsen, ITA, 27-Oct.-1993
;		Out: fwhm and line shift
;
; Version     : Version 1 9-Sept.-1993
;- 


PRO INT_FWHM_2, x, y, totint, fwhm, shift

IF N_PARAMS(0) LT 3 THEN BEGIN
    PRINT,' *** INT_FWHM must be called with 3 parameters ***'
    RETURN
ENDIF           

ymax = MAX(y)
IF ymax EQ 0.0 THEN BEGIN
    totint = 0.0
    fwhm = 0.0
    shift = x(n_elements(x)/2.)
    RETURN
ENDIF
index = FIX(WHERE(y EQ ymax))                    
xmax = FLOAT(x(index))
yhalf = ymax/2.

IF MIN(y(0:index(0))) GT yhalf THEN BEGIN
    totint = 0.0
    fwhm = 0.0
    shift = xmax
    RETURN
ENDIF

IF MIN(y(index(0):*)) GT yhalf THEN BEGIN
    totint = 0.0
    fwhm = 0.0
    shift = xmax
    RETURN
ENDIF

xleft1 = MAX(x(WHERE((y LE yhalf) AND (x LT xmax(0)))))
yleft1 = MAX(y(WHERE((y LE yhalf) AND (x LT xmax(0)))))
left_index = WHERE(x EQ xleft1)
xleft2 = x(left_index+1)
yleft2 = y(left_index+1)   
INTERP, xleft1, yleft1, xleft2, yleft2, xhalfleft, yhalf

xright2 = MIN(x(WHERE((y LE yhalf) AND (x GT xmax(0)))))
yright2 = MAX(y(WHERE((y LE yhalf) AND (x GT xmax(0)))))
right_index = WHERE(x EQ xright2)
xright1 = x(right_index-1)
yright1 = y(right_index-1)
INTERP, xright1, yright1, xright2, yright2, xhalfright, yhalf

fwhm = (xhalfright - xhalfleft)
totint = 1.064467*ymax*fwhm
shift = (xhalfright + xhalfleft)/2.
;PRINT,"Itot,width,shift: ", totint,fwhm,shift
RETURN

end
