PRO INT_SUM, x, y, back, disp, xs, itot
;+
; Project     : SOHO - CDS     
;                   
; Name        : int_sum
;               
; Purpose     : Calculate a spectral lines total intensity by
;		adding up the pixel values across the line
;               
; Explanation : 
;               
; Use         : IDL> int_sum, x, y, disp, xs, itot
;    
; Inputs      : x and y array, background, dispersion, 
;		start wavelength
;               
; Opt. Inputs : 
;               
; Outputs     : total intensity for the line
;               
; Opt. Outputs: 
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : 
;               
; Prev. Hist. : None
;
; Written     : Nils Brynildsen, ITA, UiO, 9-Sept.-1993
;               
; Modified    : Version 2 Nils Brynildsen, ITA, 13-Sept-1993
;
; Version     : Version 2 13-Sept.-1993
;- 

@tot.com
           
IF N_PARAMS(0) LT 5 THEN BEGIN
   PRINT,' *** INT_SUM must be called with 5 parameters ***'
   RETURN
ENDIF           
;
;	Set total intensity for line to 0
;
 itot = 0.0 
;
;	Plot lineprofile
;
 PLOT, x, y + back
 OPLOT, x, y + back, PSYM = 4
;
;	Intensity values are added between the given positions
;
  WIDGET_CONTROL, w1, SET_VALUE = "Set CURSOR at left and right line position."
  PRINT,"Set CURSOR at left and right line position"
  CURSOR, x1, y1, 3
  CURSOR, x2, y2, 3
  px1 = FIX((x1 - xs)/disp) 
  px2 = FIX((x2 - xs)/disp)
  py1 = y(px1)
  py2 = y(px2)
;
;	Add the y-values
;
   FOR i = px1, px2 DO BEGIN
     itot = itot + y(i) 
   ENDFOR  
; 
;	Multiply with dispersion
;
  itot = itot*disp
;   PRINT,"Itot: ", itot*disp 
 RETURN
END