FUNCTION simpson_a, y, delta_x
;+
; Project     : SOHO - CDS     
;                   
; Name        : simpson_a()
;               
; Purpose     : Simpson integration
;               
; Explanation : Simpson integration when the function to be 
;               integrated is given in array y calculated for
;               eqidistant intervals in x. Integration proceeds
;               from beginning to end of the given array if the
;               number of array points is odd.
;               
; Use         : IDL> value = simpson_a(array, dispersion)
;    
; Inputs      : array, dispersion, 
;               
; Opt. Inputs : None
;               
; Outputs     : Integrated value
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. : ?
;
; Written     : Olav Kjeldseth-Moe, ITA, UiO 
;               
; Modified    : Version 1 Nils Brynildsen, ITA, UiO, 1-July-1993
;
; Version     : Version 1 1-July-1993
;-            
m = N_ELEMENTS(y)
n = m/2
n = n*2 + 1
IF n GT m THEN n = n - 2
index = INDGEN(n)
odde = WHERE((index/2)*2 LT index)
even = WHERE((index/2)*2 GE index)
neven = N_ELEMENTS(even)
sum = y(0) + 4.*TOTAL(y(odde)) + 2.*TOTAL(y(even(1:neven - 2))) + y(n - 1)
sum = sum*delta_x/3.
RETURN,sum
END