PRO three_moment, x, y, disp, ampl, shift, width
;+
; Project     : SOHO - CDS     
;                   
; Name        : three_moment
;               
; Purpose     : calculate 3-moment of line profile
;               
; Explanation : 3-moment calculated using simpson intergration
;               
; Use         : IDL> three_moment, x-array, y-array, dispersion,
;                    max. intensity, line shift, line width   
;    
; Inputs      : x-array, y-array, dispersion
;               
; Opt. Inputs : None
;               
; Outputs     : intensity, shift, width 
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : simpson_a
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. : ?
;
; Written     : Olav Kjeldseth-Moe, ITA, UiO
;               
; Modified    : Version 1 Nils Brynildsen, ITA, UiO, 1-July-1993
;
; Version     : Version 1 1-July-1993
;-            
s0 = simpson_a(y, disp)
s1 = simpson_a(x*y, disp)
s2 = simpson_a(x*x*y, disp)
shift = s1/s0
width = (s2/s0) - (s1/s0)^2
IF width lt 0.0 THEN width = 0.0
IF width gt 0.0 THEN width = SQRT(width*2.0)
ampl = s0/width/1.772453851
RETURN
END
