; $Id: gaussfit.pro,v 1.1 1993/04/02 19:43:31 idl Exp $

PRO	THREEGAUSS,X,A,F,PDER

; NAME:
;	GAUSS_FUNCT
;
; PURPOSE:
;	EVALUATE THE SUM OF 3 GAUSSIANs AND A 2ND ORDER POLYNOMIAL
;	AND OPTIONALLY RETURN THE VALUE OF IT'S PARTIAL DERIVATIVES.
;	NORMALLY, THIS FUNCTION IS USED BY CURVEFIT TO FIT THE
;	SUM OF A LINE AND A VARYING BACKGROUND TO ACTUAL DATA.
;
	ON_ERROR,2                        ;Return to caller if an error occurs
;
	if a(2) ne 0.0 then Z1 = (X-A(1))/A(2) $	;GET Z
	else z1= 10.
;
	if a(5) ne 0.0 then Z2 = (X-A(4))/A(5) $	;GET Z
	else z2= 10.
;
	if a(8) ne 0.0 then Z3 = (X-A(7))/A(8) $	;GET Z
	else z3= 10.
;
	EZ1 = EXP(-Z1^2/2.)*(ABS(Z1) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	EZ2 = EXP(-Z2^2/2.)*(ABS(Z2) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	EZ3 = EXP(-Z3^2/2.)*(ABS(Z3) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	F = A(0)*EZ1 + A(3)*EZ2 + A(6)*EZ3 + A(9) + A(10)*X + A(11)*X^2 
                                            ;FUNCTIONS.
;
	IF N_PARAMS(0) LE 3 THEN RETURN      ;NEED PARTIAL?
;
	PDER = FLTARR(N_ELEMENTS(X),12)       ;YES, MAKE ARRAY.
	PDER(0,0) = EZ1		             ;COMPUTE PARTIALS
	PDER(0,3) = EZ2	                     ;COMPUTE PARTIALS
	PDER(0,6) = EZ2	                     ;COMPUTE PARTIALS

	if a(2) ne 0. then PDER(0,1) = A(0) * EZ1 * Z1/A(2)

	if a(5) ne 0. then PDER(0,4) = A(3) * EZ2 * Z2/A(5)

	if a(8) ne 0. then PDER(0,7) = A(6) * EZ3 * Z3/A(8)
;
	PDER(0,2) = PDER(*,1) * Z1
	PDER(0,5) = PDER(*,4) * Z2
	PDER(0,8) = PDER(*,7) * Z3
;
	PDER(*,9) = 1.
	PDER(0,10) = X
	PDER(0,11) = X^2
;
	RETURN
;
END

Function threeg_afit, x, y, a, sigmaa

;+
; NAME:
;-

on_error,2                      ;Return to caller if an error occurs

;
     find_g_arc, x, y, wg, wgh, cf, nwg
;
     a = fltarr ( 12 )
;
     a ( 0 ) = wgh ( 0 )
     a ( 1 ) = x ( wg ( 0 ) )
     a ( 2 ) = 0.0750
;
     if ( nwg gt 1 ) then begin
         a ( 3 ) = wgh ( 1 )
         a ( 4 ) = x ( wg ( 1 ) )
         a ( 5 ) = 0.0750
;
         if ( wgh ( 1 ) lt 25. ) then begin
             a ( 3 ) = 0.667 * wgh ( 1 )
             a ( 5 ) = 0.0750
         endif
     endif
;
     if ( nwg gt 2 ) then begin
         a ( 6 ) = wgh ( 2 )
         a ( 7 ) = x ( wg ( 2 ) )
         a ( 8 ) = 0.06750
;
         if ( wgh ( 2 ) lt 25. ) then begin
             a ( 6 ) = 0.667 * wgh ( 2 )
             a ( 8 ) = 0.0750
         endif
     endif else begin
         nx = n_elements ( x )
         ncen = ( nx - 1 ) / 2
;
         yf2 = twog_afit ( x, y, a2 )
;
         yd2 = y - yf2
         ym2 = max ( yd2 )
;
         wg3 = !c
;
         a ( 6 ) = 0.750 * y ( wg3 )
         a ( 7 ) = x ( wg3 )
         a ( 8 ) = 0.075
;
         if ( nwg eq 1 ) then begin
             yd2 ( !c ) = 0.
;
             ym2 = max ( yd2 )
;
             wg2 = !c
;
             a ( 3 ) = 0.50 * y ( wg2 )
             a ( 4 ) = x ( wg2 )
             a ( 5 ) = 0.075
;
         endif 
     endelse
; 
     a ( 9:11 ) = cf
;
     n = n_elements ( y )	        	;# of points.
;
     !c = 0	        	 		;reset cursor for plotting
;
     return, curvefit ( x, y, replicate ( 1., n ), a, sigmaa,              $
		function_name = "THREEGAUSS" )    ;call curvefit
;
 end
;
