; $Id: gaussfit.pro,v 1.1 1993/04/02 19:43:31 idl Exp $

PRO	THREEGAUSS,X,A,F,PDER

; NAME:
;	GAUSS_FUNCT
;
; PURPOSE:
;	EVALUATE THE SUM OF 3 GAUSSIANs AND A 2ND ORDER POLYNOMIAL
;	AND OPTIONALLY RETURN THE VALUE OF IT'S PARTIAL DERIVATIVES.
;	NORMALLY, THIS FUNCTION IS USED BY CURVEFIT TO FIT THE
;	SUM OF A LINE AND A VARYING BACKGROUND TO ACTUAL DATA.
;
	ON_ERROR,2                        ;Return to caller if an error occurs
;
	if a(2) ne 0.0 then Z1 = (X-A(1))/A(2) $	;GET Z
	else z1= 10.
;
	if a(5) ne 0.0 then Z2 = (X-A(4))/A(5) $	;GET Z
	else z2= 10.
;
	if a(8) ne 0.0 then Z3 = (X-A(7))/A(8) $	;GET Z
	else z3= 10.
;
	EZ1 = EXP(-Z1^2/2.)*(ABS(Z1) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	EZ2 = EXP(-Z2^2/2.)*(ABS(Z2) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	EZ3 = EXP(-Z3^2/2.)*(ABS(Z3) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	F = A(0)*EZ1 + A(3)*EZ2 + A(6)*EZ3 + A(9) + A(10)*X + A(11)*X^2 
                                            ;FUNCTIONS.
;
	IF N_PARAMS(0) LE 3 THEN RETURN      ;NEED PARTIAL?
;
	PDER = FLTARR(N_ELEMENTS(X),12)       ;YES, MAKE ARRAY.
	PDER(0,0) = EZ1		             ;COMPUTE PARTIALS
	PDER(0,3) = EZ2	                     ;COMPUTE PARTIALS
	PDER(0,6) = EZ2	                     ;COMPUTE PARTIALS

	if a(2) ne 0. then PDER(0,1) = A(0) * EZ1 * Z1/A(2)

	if a(5) ne 0. then PDER(0,4) = A(3) * EZ2 * Z2/A(5)

	if a(8) ne 0. then PDER(0,7) = A(6) * EZ3 * Z3/A(8)
;
	PDER(0,2) = PDER(*,1) * Z1
	PDER(0,5) = PDER(*,4) * Z2
	PDER(0,8) = PDER(*,7) * Z3
;
	PDER(*,9) = 1.
	PDER(0,10) = X
	PDER(0,11) = X^2
;
	RETURN
;
END

Function threeg_fit, x, y, a, sigmaa

;+
; NAME:
;	GAUSSFIT
;
; PURPOSE:
; 	Fit the equation y=f(x) where:
;
; 		F(x) = A0*EXP(-z^2/2) + A3 + A4*x + A5*x^2
; 			and
;		z=(x-A1)/A2
;
;	A0 = height of exp, A1 = center of exp, A2 = sigma (the width).
;	A3 = constant term, A4 = linear term, A5 = quadratic term.
; 	The parameters A0, A1, A2, A3 are estimated and then CURVEFIT is 
;	called.
;

on_error,2                      ;Return to caller if an error occurs

;
     yf = twog_fit ( x, y, ac ) 
;
     cf = ac ( 6:8 )
;
     xc = poly ( x, cf )
;
     find_gauss, x, y, wg, nwg
;
     a = fltarr ( 12 )
;
     a ( 0 ) = y ( wg ( 0 ) ) - xc ( wg ( 0 ) ) 
     a ( 1 ) = x ( wg ( 0 ) )
     a ( 2 ) = 0.5
;
     a ( 3 ) = y ( wg ( 1 ) ) - xc ( wg ( 1 ) )
     a ( 4 ) = x ( wg ( 1 ) )
     a ( 5 ) = 0.5
; 
     a ( 6 ) = y ( wg ( 2 ) ) - xc ( wg ( 2 ) )
     a ( 7 ) = x ( wg ( 2 ) )
     a ( 8 ) = 0.5
;
     a ( 9:11 ) = ac ( 6:8 )
;
     n = n_elements(y)	        	;# of points.
;
     !c=0				;reset cursor for plotting
;
     return,curvefit(x,y,replicate(1.,n),a,sigmaa, $
		function_name = "THREEGAUSS") ;call curvefit
;
 end
;
