PRO tot_int, name, pos1, pos2
;+
; Project     : SOHO - CDS     
;                   
; Name        : tot_int
;               
; Purpose     : Calculate the totel line intensity
;               
; Explanation : The total line intensity is calculated in three 
;		different ways: 1) By adding the pixel values
;				   across the selected line
;				2) By finding the FWHM and maximum
; 				   intensity
;				3) By fitting with a gaussian and 
;				   routine LSTSQR.
;               
; Use         : IDL> tot_int, 'selected spectral line', x posisjon
;	             in raster, y posisjon in raster
;    
; Inputs      : line to fine total intensity of and its raster
;		position
;               
; Opt. Inputs : None
;               
; Outputs     : Total intensities (only displayed in widget!!)
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : read_cds_im, int_sum, int_fwhm, lstsqr
;
; Common      : tot.com
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : ?
;               
; Prev. Hist. : None
;
; Written     : Nils Brynildsen, ITA, UiO 20-Sep.-1993
;               
; Modified    : Version 1 Nils Brynildsen, ITA, UiO, 20-Sep.-1993
;
; Version     : Version 1 20-Sep.-1993
;-            

@tot.com
;
;	Read TESTDATA file from Bill Thompson
;
READ_CDS_IM, image, name
nx = float((image.wavemax-image.wavemin)/image.spacing(0) + 1)
w0 = image.wavelength 
disp = image.spacing(0)
xs = w0 - (nx/2.)*disp                            
x = xs + findgen(nx)*disp

;s = size(image.array) 
;x_max = s(2)-1
;y_max = s(3)-1
y = image.array(0:nx-1,pos1,pos2) 
;
;	Find line background (continuum)
;
back = min(y)
y = y - back 

INT_SUM, x, y, back, disp, xs, tot_sum

INT_FWHM, x, y, tot_fwhm

a = [max(y), w0, 0.1]
LSTSQR,x,y,'func_f',a,noprint=1

x_l = xs + findgen(1000)*disp/100.
FUNCT_1, x_l, a,y_l, y_l1, y_l2, y_l3
OPLOT, x_l, y_l + back, psym = 3

message = "INT_SUM:    "  + STRING(FORMAT='(f8.2)',tot_sum)  + STRING(10B) $
        + "INT_FWHM: "    + STRING(FORMAT='(f8.2)',tot_fwhm) + STRING(10B) $
        + "LSTSQR:      " + STRING(FORMAT='(f8.2)',1.77245*a(0)*a(2)) $
        +  STRING(10B) + STRING(10B)

WIDGET_CONTROL, w1, SET_VALUE = message
;
;	Output to file 'totint.dat'
;
PRINTF,out_unit,name,pos1,pos2
PRINTF,out_unit,message

END
