; $Id: gaussfit.pro,v 1.1 1993/04/02 19:43:31 idl Exp $

PRO	TWOGAUSS,X,A,F,PDER

; NAME:
;	GAUSS_FUNCT
;
; PURPOSE:
;	EVALUATE THE SUM OF A GAUSSIAN AND A 2ND ORDER POLYNOMIAL
;	AND OPTIONALLY RETURN THE VALUE OF IT'S PARTIAL DERIVATIVES.
;	NORMALLY, THIS FUNCTION IS USED BY CURVEFIT TO FIT THE
;	SUM OF A LINE AND A VARYING BACKGROUND TO ACTUAL DATA.
;
; CATEGORY:
;	E2 - CURVE AND SURFACE FITTING.
; CALLING SEQUENCE:
;	FUNCT,X,A,F,PDER
; INPUTS:
;	X = VALUES OF INDEPENDENT VARIABLE.
;	A = PARAMETERS OF EQUATION DESCRIBED BELOW.
; OUTPUTS:
;	F = VALUE OF FUNCTION AT EACH X(I).
;
; OPTIONAL OUTPUT PARAMETERS:
;	PDER = (N_ELEMENTS(X),6) ARRAY CONTAINING THE
;		PARTIAL DERIVATIVES.  P(I,J) = DERIVATIVE
;		AT ITH POINT W/RESPECT TO JTH PARAMETER.
; COMMON BLOCKS:
;	NONE.
; SIDE EFFECTS:
;	NONE.
; RESTRICTIONS:
;	NONE.
; PROCEDURE:
;	F = A(0)*EXP(-Z^2/2) + A(3) + A(4)*X + A(5)*X^2
;	Z = (X-A(1))/A(2)
; MODIFICATION HISTORY:
;	WRITTEN, DMS, RSI, SEPT, 1982.
;	Modified, DMS, Oct 1990.  Avoids divide by 0 if A(2) is 0.
;	Added to Gauss_fit, when the variable function name to
;		Curve_fit was implemented.  DMS, Nov, 1990.
;
	ON_ERROR,2                        ;Return to caller if an error occurs
;
	if a(2) ne 0.0 then Z1 = (X-A(1))/A(2) $	;GET Z
	else z1= 10.
;
	if a(5) ne 0.0 then Z2 = (X-A(4))/A(5) $	;GET Z
	else z2= 10.
;
	EZ1 = EXP(-Z1^2/2.)*(ABS(Z1) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	EZ2 = EXP(-Z2^2/2.)*(ABS(Z2) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	F = A(0)*EZ1 + A(3)*EZ2 + A(6) + A(7)*X + A(8)*X^2 ;FUNCTIONS.
;
	IF N_PARAMS(0) LE 3 THEN RETURN      ;NEED PARTIAL?
;
	PDER = FLTARR(N_ELEMENTS(X),9)       ;YES, MAKE ARRAY.
	PDER(0,0) = EZ1		             ;COMPUTE PARTIALS
	PDER(0,3) = EZ2	                     ;COMPUTE PARTIALS

	if a(2) ne 0. then PDER(0,1) = A(0) * EZ1 * Z1/A(2)

	if a(5) ne 0. then PDER(0,4) = A(3) * EZ2 * Z2/A(5)
;
	PDER(0,2) = PDER(*,1) * Z1
	PDER(0,5) = PDER(*,4) * Z2
;
	PDER(*,6) = 1.
	PDER(0,7) = X
	PDER(0,8) = X^2
;
	RETURN
;
END

Function twog_afit, x, y, a, sigmaa

;+
; NAME:
;-
;

on_error,2                      ;Return to caller if an error occurs

;
     find_g_arc, x, y, wg, wgh, cf, nwg
;
     a = fltarr ( 9 )
;
     a ( 0 ) = wgh ( 0 )
     a ( 1 ) = x ( wg ( 0 ) )
     a ( 2 ) = 0.075
;
     if ( nwg gt 1 ) then begin
         a ( 3 ) = wgh ( 1 )
         a ( 4 ) = x ( wg ( 1 ) )
         a ( 5 ) = 0.075
;
         if ( wgh ( 1 ) lt 25. ) then begin
             a ( 3 ) = 0.667 * wgh ( 1 )
             a ( 5 ) = 0.0875
         endif
     endif else begin
;
         nx = n_elements ( x )
         ncen = ( nx - 1 ) / 2
;
         if ( abs ( ncen - wg ( 0 ) ) gt 8 ) then begin
;
             ymx = max ( y ( ncen-8:ncen+8 ) )
             dx = ncen - 8 + !c - wg ( 0 )
         endif else begin
             dx = 0
;
             if ( ( wg ( 0 ) - 3 ) lt 0 ) then dx = 2
             if ( ( wg ( 0 ) + 3 ) ge n_elements ( x ) ) then dx = -2
;
             if ( dx eq 0 ) then begin
                 dx = 2
                 if ( y ( wg ( 0 ) + 2 ) lt y ( wg ( 0 ) - 2 ) ) then dx = -2
             endif
         endelse
;
         a ( 3 ) = 0.750 * y ( wg ( 0 ) + dx )
         a ( 4 ) = x ( wg ( 0 ) + dx )
         a ( 5 ) = 0.075
     endelse
; 
     a ( 6:8 ) = cf ( 0:2 )
;
     n = n_elements(y)	        	;# of points.
;
     !c=0				;reset cursor for plotting
;
     return,curvefit(x,y,replicate(1.,n),a,sigmaa, $
		function_name = "TWOGAUSS") ;call curvefit
;
 end
;
