; $Id: gaussfit.pro,v 1.1 1993/04/02 19:43:31 idl Exp $

PRO	TWOGAUSS,X,A,F,PDER

; NAME:
;	GAUSS_FUNCT
;
; PURPOSE:
;	EVALUATE THE SUM OF A GAUSSIAN AND A 2ND ORDER POLYNOMIAL
;	AND OPTIONALLY RETURN THE VALUE OF IT'S PARTIAL DERIVATIVES.
;	NORMALLY, THIS FUNCTION IS USED BY CURVEFIT TO FIT THE
;	SUM OF A LINE AND A VARYING BACKGROUND TO ACTUAL DATA.
;
; CATEGORY:
;	E2 - CURVE AND SURFACE FITTING.
; CALLING SEQUENCE:
;	FUNCT,X,A,F,PDER
; INPUTS:
;	X = VALUES OF INDEPENDENT VARIABLE.
;	A = PARAMETERS OF EQUATION DESCRIBED BELOW.
; OUTPUTS:
;	F = VALUE OF FUNCTION AT EACH X(I).
;
; OPTIONAL OUTPUT PARAMETERS:
;	PDER = (N_ELEMENTS(X),6) ARRAY CONTAINING THE
;		PARTIAL DERIVATIVES.  P(I,J) = DERIVATIVE
;		AT ITH POINT W/RESPECT TO JTH PARAMETER.
; COMMON BLOCKS:
;	NONE.
; SIDE EFFECTS:
;	NONE.
; RESTRICTIONS:
;	NONE.
; PROCEDURE:
;	F = A(0)*EXP(-Z^2/2) + A(3) + A(4)*X + A(5)*X^2
;	Z = (X-A(1))/A(2)
; MODIFICATION HISTORY:
;	WRITTEN, DMS, RSI, SEPT, 1982.
;	Modified, DMS, Oct 1990.  Avoids divide by 0 if A(2) is 0.
;	Added to Gauss_fit, when the variable function name to
;		Curve_fit was implemented.  DMS, Nov, 1990.
;
	ON_ERROR,2                        ;Return to caller if an error occurs
;
	if a(2) ne 0.0 then Z1 = (X-A(1))/A(2) $	;GET Z
	else z1= 10.
;
	if a(5) ne 0.0 then Z2 = (X-A(4))/A(5) $	;GET Z
	else z2= 10.
;
	EZ1 = EXP(-Z1^2/2.)*(ABS(Z1) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	EZ2 = EXP(-Z2^2/2.)*(ABS(Z2) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS

	F = A(0)*EZ1 + A(3)*EZ2 + A(6) + A(7)*X + A(8)*X^2 ;FUNCTIONS.
;
	IF N_PARAMS(0) LE 3 THEN RETURN      ;NEED PARTIAL?
;
	PDER = FLTARR(N_ELEMENTS(X),9)       ;YES, MAKE ARRAY.
	PDER(0,0) = EZ1		             ;COMPUTE PARTIALS
	PDER(0,3) = EZ2	                     ;COMPUTE PARTIALS

	if a(2) ne 0. then PDER(0,1) = A(0) * EZ1 * Z1/A(2)

	if a(5) ne 0. then PDER(0,4) = A(3) * EZ2 * Z2/A(5)
;
	PDER(0,2) = PDER(*,1) * Z1
	PDER(0,5) = PDER(*,4) * Z2
;
	PDER(*,6) = 1.
	PDER(0,7) = X
	PDER(0,8) = X^2
;
	RETURN
;
END

Function twog_arcpf, x, y, a

;+
;-
;

on_error,2                      ;Return to caller if an error occurs

;
     fit_back, x, 10. * y, yc, cf
;
     yc = yc / 10.
;
     cf = poly_fit ( x, yc, 2 )
;
     a = fltarr ( 9 )
;
     nx = n_elements ( y )
;
     noff = ( nx - 1 ) / 2
;
     wg = [ -4, 4 ]
     wg = wg + noff
;
     a ( 0 ) = y ( wg ( 0 ) ) - yc ( wg ( 0 ) )
     a ( 1 ) = x ( wg ( 0 ) )
     a ( 2 ) = 1.0
;
     a ( 3 ) = y ( wg ( 1 ) ) - yc ( wg ( 1 ) )
     a ( 4 ) = x ( wg ( 1 ) )
     a ( 5 ) = 1.0
;
     a ( 6:8 ) = cf
;
     n = n_elements(y)	        	;# of points.
;
     !c=0				;reset cursor for plotting
;
     return,curvefit(x,y,replicate(1.,n),a,sigmaa, $
		function_name = "TWOGAUSS") ;call curvefit
;
 end
;
