;+
; Project     : SOHO - CDS     
;                   
; Name        : QLDS_FETCH
;               
; Purpose     : Fetch the specified QLDS into a named variable
;               
; Explanation : The CDS QuickLook memory management system is designed
;		to minimize the time spent by display routines fetching
;		their data. This is done by having a common block (QLSAVE)
;		that functions as a cache memory, storing the most recently
;		used QuckLook Data Structure. Other QLDS'es are stored
;		as UVALUES of non-realized WIDGET_BASEs.
;               
;		In the case of a crash of the display routines, the
;		data supplied in the call may appear lost under IDL
;		version 3.1 or later. This is due to the fact that
;		setting a UVALUE with the NO_COPY keyword actually
;		swaps the memory dynamically, leaving the "source
;		variable" undefined! The data are, however, still
;		stored as user values of unrealized widget bases.
;		Use QLDS_INVENTORY to get a display of the structure
;		of each stored QLDS, and use the value of the tag
;		QL_NO to fetch back the QLDS into a named variable
;		of your choice.
;
; Use         : QLDS_FETCH,QL_NO,NAMED_VARIABLE
;    
; Inputs      : QL_NO : The unique number assigned to a QLDS by QLMGR,
;			on the tag "QL_NO" in the structure.
;
; Opt. Inputs : None.
;               
; Outputs     : NAMED_VARIABLE : Any such, to receive the QLDS
;               
; Opt. Outputs: None.
;               
; Keywords    : TEST : Set to avoid crash when the QLDS is not available.
;                      Upon return, the destination variable will be
;                      untouched.
;
; Calls       : QLDS_CHECKIN, ASSIGN_NOCOPY
;
; Common      : QLSAVE: See QLDS_CHECKIN
;               
; Restrictions: Requires that the QLDS actually can be found
;               
; Side effects: None.
;               
; Category    : QuickLook, Management
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, ItA/UiO, 11-June-1994
;               
; Modified    : SVHH, 2-March-1995. Added !DEBUG test in ON_error handling.
;
;               Version 2, SVHH, 21 May 1996
;                       Added /TEST keyword.
;
; Version     : 1.1, 2-March-1995
;-            

PRO qlds_fetch,ql_no,destination,test=test
  common QLSAVE,sQLDS,saved
  On_Error,2
  if !DEBUG ne 0 then on_error,0
  IF N_params()	lt 2 THEN message,'Use: QLDS_FETCH,QL_NO,DESTINATION'
  qlds_checkin,ql_no,test=test
  IF N_ELEMENTS(sqlds) NE 0 THEN assign_nocopy,destination,sQLDS
END
