;+
; Project     : SOHO - CDS     
;                   
; Name        : QLDS_MANAGED()
;               
; Purpose     : Returns 1 if the supplied QLDS is already managed
;               
; Explanation : This routine is useful to detect whether a CDS Quick Look
;               program has been called by a program that is not using the
;               Quick Look memory management system (see e.g., QLDS_CHECKIN).
;
;               If a QLDS is *not* managed, a quick look program should
;               (in general) not return until it can return the QLDS.
;               
; Use         : if not qlds_managed(qlds) then ....
;    
; Inputs      : QLDS : QLDS
;               
; Opt. Inputs : None.
;               
; Outputs     : Returns 1 if supplied QLDS is already managed, i.e., available
;               though QLDS_CHECKIN.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : QLDS_CHECKIN
;
; Common      : QLSAVE : See QLDS_CHECKIN
;               
; Restrictions: None.
;               
; Side effects: None known
;               
; Category    : QuickLook, Management
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar H. Haugan, UiO, 19 August 1996
;               
; Modified    : Not yet.
;
; Version     : 1, 19 August 1996
;-            

FUNCTION qlds_managed,qlds
  COMMON qlsave, qlds_saved
  
  ON_ERROR,2
  
  IF !debug NE 0 THEN ON_ERROR,0
  
  qlds_checkin,qlds.ql_no,/test
  
  IF datatype(qlds_saved) NE 'STC' THEN RETURN,0
  
  RETURN,1
  
END

