;+
; Project     : SOHO - CDS     
;                   
; Name        : CDSLOG
;               
; Purpose     : Accumulate messages from other routines, option to save
;               
; Explanation : Creates a window in the lower right corner of the
;		screen with a text area to show lines with
;		the logged information (intensities etc...)
;
;		Normally, the window pops up in front (also from 
;		iconified state) to show the text. This may be
;		turned off.
;               
; Use         : CDSLOG,'Text to be logged'
;    
; Inputs      : The message text
;               
; Opt. Inputs : None.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : BELL: Set to cause a bell after the text is displayed
;
; Calls       : BELL, DATATYPE()
;
; Common      : CDSLOG
;               
; Restrictions: 
;               
; Side effects:
;               
; Category    : CDS,QL,DISPLAY,UTIL
;               
; Prev. Hist. : Adapted from CDSNOTIFY
;
; Written     : SVHH, February 1994
;               
; Modified    : SVHH, March 1994
;			Made it ignore group (leader) - in case
;			it's invoked first by a sub-application.
;		SVHH, 12 April 1994
;			Fixed the procedure to add (append) messages
;
; Version     : 1.0
;-            



PRO cdslog_event, event,append_text=append_text,Bell=Bell
  common CDSLOG,baseid,textid,edited,stay_hidden,text
  
  IF datatype(append_text) eq 'STR' THEN BEGIN
      IF NOT stay_hidden THEN Widget_CONTROL,baseid,iconify=0,/show
      IF datatype(text)	eq 'STR' THEN Widget_CONTROL,textid,Set_VALUE=text
      Widget_CONTROL,textid,Set_VALUE=append_text,/append
      Widget_CONTROL,textid,Get_VALUE=text
      Widget_CONTROL,textid,Set_VALUE='.',/append ; Avoid scrolling
      IF Keyword_SET(Bell) THEN	Bell
      edited=1
      return
  END
  
  
  Widget_CONTROL, event.id, Get_UVALUE = eventval	  ;find the user value
							  ;of the widget where
							  ;the event occured
  CASE eventval	OF
      
      'DONE':$
      BEGIN
	  edited=0
	  Widget_CONTROL,event.top,/destroy
	  return
      END
      
      'ICONIFY':$
      BEGIN
	  Widget_CONTROL,event.top,/iconify
      END
      
      'SAVE':BEGIN
	  filename=pickfile(title='Select file to write log to')
	  IF filename ne '' THEN BEGIN
	      openw,lun,/get_lun,filename
	      FOR i=0,N_elements(text)-1 DO printf,lun,text(i)
	      close,lun
	      free_lun,lun
	      edited = 0
	  END
      END
      
      'CLEAR':BEGIN
	  Widget_CONTROL,textid,Set_VALUE=''
	  edited=0
      END
      
      'EDIT':BEGIN
	  edited=1
	  Widget_CONTROL,textid,Get_VALUE=text
      END
      
      
      'POPUP':BEGIN
	  stay_hidden =	NOT event.select
      END
      
      ELSE:$
      BEGIN
	  Print,'Event not understood:'
	  help,event,/str
      END
  EndCASE
  Widget_CONTROL,textid,Get_VALUE=text	; Always keep the text
  
END ;============= end of cdslog event handling routine task =============


PRO cdslog_cleanup,event
  common CDSLOG,baseid,textid,edited,stay_hidden,text
  
  IF edited THEN BEGIN
      filename=pickfile(title='Select file to write log to')
      IF filename ne ''	THEN BEGIN
	  openw,lun,/get_lun,filename
	  FOR i=0,N_elements(text)-1 DO	printf,lun,text(i)
	  close,lun
	  free_lun,lun
	  edited = 0
      END
  EndIF
  text=''
END

;------------------------------------------------------------------------------
;	procedure cdslog
;------------------------------------------------------------------------------
; This routine creates the widget and registers it with the XManager.
;------------------------------------------------------------------------------
PRO cdslog,newtext,GROUP= GROUP
  common CDSLOG,baseid,textid,edited,stay_hidden,text
  
  IF(XRegistered("cdslog") NE 0) THEN BEGIN
      IF datatype(newtext)	eq 'STR' THEN $
	      cdslog_event,append_text=newtext
      return
  END
  
  DEVICE,GET_SCREEN_SIZE=SZ
  
  baseid = Widget_BASE(TITLE = "cdslog",$
			  xoffset=SZ(0),yoffset=SZ(1),/column)
  
  rbase	= Widget_BASE(baseid,/row)
  xmenu,["Quit","Iconify","Clear","Save to log file"],rbase,/row,$
	  UVALUE = ["DONE","ICONIFY","CLEAR","SAVE"]
  xmenu,["Always pop up"],rbase,uvalue=["POPUP"],buttons=buttons,/exclusive
  Widget_CONTROL,buttons(0),/set_button
  
  textid = Widget_TEXT(baseid,xsize=80,ysize=20,/scroll,$
			/editable,uvalue='EDIT')
  edited = 0
  stay_hidden =	0
  
  Widget_CONTROL, baseid, /REALIZE
  
  Widget_CONTROL, baseid,tlb_get_size=bsize
  
  Widget_CONTROL, baseid,tlb_set_xoffset=SZ(0)-bsize(0)-10,$
			  tlb_set_yoffset=SZ(1)-bsize(1)-10
  
  IF (datatype(newtext)	eq 'STR') THEN cdslog_event,append_text=newtext
  
  Xmanager, "cdslog", baseid,  $ ;GROUP_LEADER = GROUP,$
			/just_reg,cleanup="cdslog_cleanup"
  
END




PRO logtest_event,ev
  
  Widget_CONTROL,ev.id,Get_UVALUE=uvalue
  
  cdslog,group=ev.top,'Uvalue = '+uvalue
  
  IF uvalue eq 'DONE' THEN Widget_CONTROL,ev.top,/destroy
  
END



PRO logtest
  
  base = Widget_BASE(/column)
  xmenu,["A","B","DONE"],base,uvalue=["A selected","B selected","DONE"]
  
  Widget_CONTROL,base,/realize
  
  Xmanager,"logtest",base
  
END

