;+
; Project     : SOHO - CDS     
;                   
; Name        : CMOUSE_ACTION
;               
; Purpose     : Translate a mouse click accorrding to the CMOUSE status
;               
; Explanation : See CMOUSE
;               
; Use         : function = CMOUSE_ACTION(EVENT)
;    
; Inputs      : EVENT:  The mouse click event
;		
; Opt. Inputs : ID : The ID (returned by CMOUSE on creation) of the
;                    cmouse widget to be used. Allows more than one
;                    cmouse per top base.
;               
; Outputs     : FUNCTION: The translated function (a string)
;			Returns an empty string if no action is to be taken.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : None.
;
; Common      : CMOUSE
;               
; Restrictions: 
;               
; Side effects: None known.
;               
; Category    : Utility, Display
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, 11-December-1994
;               
; Modified    : Version 2, SVHH, 9-January-1996
;                          Added possibility for ID parameter in call.
;
; Version     : 2, 9-January-1996
;-            



function cmouse_action,ev,id
common cmouse,ctop,cbase

IF N_PARAMS() EQ 2 THEN i = (WHERE(id EQ cbase))(0) $
ELSE i = (where(ctop eq ev.top))(0)

if i eq -1 then message,"No mouse function translation activated"

widget_control,cbase(i),get_uvalue=status

if ev.press eq 0 then begin  ; Any continuous buttons pressed?
    if ev.release gt 0 then begin	
	status.pressed=0
	widget_control,cbase(i),set_uvalue=status
    end else if status.pressed gt 0 then begin
        button = ([-1,0,1,-1,2])(status.pressed)
        if status.rep(status.status(button)) then $
		return,status.uvalue(status.status(button))
    end
end else begin
    status.pressed = ev.press
    widget_control,cbase(i),set_uvalue=status
    return,status.uvalue(status.status( ([-1,0,1,-1,2])(ev.press) ))
endelse

return,''
end
