;+
; Project     : SOHO - CDS     
;                   
; Name        : DSP_RASTER
; 
; Purpose     : Displays locations of CDS raster using IMAGE_TOOL.
;               
; Explanation : Passes on the pointing information in the QLDS structure to IMAGE_TOOL
;		and displays the location of the CDS RASTER.
;               
; Use         : DSP_RASTER, QLDS, [SOURCE=SOURCE, GROUP=GROUP]
;    
; Inputs      : QLDS:    CDS QuickLook Data structure
;
; Opt. Inputs : None.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : SOURCE - Image source. Can either be SYNOPTIC 
;                        (using the default IMAGE_TOOL
;			 image selection) or EIT. The latter is the defult.
;		EIT    - Selects from latest EIT data base.  
;			 i
;
; Calls       : PICKFILE(),XGET_SYNOPTIC(),GT_START(),MK_POINT_STC()
;
; Common      : None.
;               
; Restrictions: Require access to the synoptic images and the EIT data located 
;               at GSFC:
;		/soho-archive/private/data/processed/eit/quicklook/
;
; Side effects: ..
;               
; Category    : CDS, QL, DISPLAY
;               
; Prev. Hist. : 
;
; Written     : P. Brekke, 26-February-1996
;
; Modyfied    : P.B. 28-Feb-1996, Changed default search directory to be SYNOPTIC
;                                 Still kept the EIT keyword for use during
; 				  planning of observations. 
; Version     : 1.0
;-            
pro dsp_raster, QLDS, source=source, group=group
	 
if not keyword_set(source) then source='SYNOPTIC'


file=''
if source eq 'SYNOPTIC' or source eq 'synoptic' then begin
  if keyword_set(group) then begin 
      file=xget_synoptic(/modal,group=group)
  endif else begin
     file=xget_synoptic()
  endelse
end

if source eq 'SUMMARY' or source eq 'summary'then begin
  if keyword_set(group) then begin 
      file=xget_synoptic(/modal,group=group,/summary)
  endif else begin
     file=xget_synoptic(/summary)
  endelse
end

if source eq 'EIT' or source eq 'eit'then $
  file=pickfile(path='/soho-archive/private/data/processed/eit/quicklook/1996')


if file eq '' then return

exps=gt_start(qlds,/exp,/ecs)

; Creating pointing structure
;
mk_point_stc,pstc
pstc.date_obs=utc2tai(exps(0))
pstc.pointings.ins_x=qlds.header.xcen
pstc.pointings.ins_y=qlds.header.ycen
pstc.pointings.width=qlds.header.ixwidth
pstc.pointings.height=qlds.header.iywidth

if keyword_set(group) then begin
  image_tool,file,point=pstc,group=group,/modal
endif else begin
  image_tool,file,point=pstc
endelse

end




