;+
; Project     : SOHO - CDS     
;                   
; Name        : DSPSPEC()
;
; Purpose     : Displays all Spectral Windows from specific exposures.
;
; Explanation : The individual Spectral Windows are deselected 
;		into their corresponding positions on the detector.
;		A somewhat different approach is used with NIS/GIS
;		data - see NDSPSPEC/GDSPSPEC. This is just a wrapper routine.
;
; Use         : dspspec,QLDS
;    
; Inputs      : QLDS: A CDS QL data structure
;               
; Opt. Inputs : None.
;               
; Outputs     : None.
;                      
;               
; Opt. Outputs: Should return the displayed data for further analysis
;               and PostScript file. To be written. 
;
; Keywords    : GROUP_LEADER:
;			If this invoked by any other CDS QuickLook 
;			display routine (group leader responsible for 
;			keeping the QLDS), this keyword should have
;			the widget ID of the top level base of the
;			calling routine.
;
;		NOCHECK:
;			Set to skip QLMGR parameter check.
;
; Calls       : GDSPSPEC, NDSPSPEC, QLMGR
;
; Common      : None.
;               
; Restrictions: QLDS must be a valid CDS QL data structure
;               
; Side effects: 
;               
; Category    : QuickLook, Display,
;               
; Prev. Hist. : Used to be just NIS-compatible. Now 
;
; Written     : Paal Brekke, 17 November 1993
;               
; Modified    : SVHH, 20 November 1993 - Brushed up documentation.
;		SVHH, Jan/Feb/March 1994 - Added new features to
;			the NIS version (zoom, profile, line identification)
;			Made the GIS version and made this into a
;			wrapper calling either NDSPSPEC/GDSPSPEC
;		SVHH, 21 May 1994
;			Made it recognize Calibration data.
; Version     : 2.0
;-            



PRO dspSPEC,QLDS,GROUP_LEADER=GROUP_LEADER,NOCHECK=NOCHECK
;
; Quick Look common block to avoid duplication/resetting of window position
;
  common QLMGR,QL_ID,QL_DATA
  
  On_Error,2
  
  IF n_params()	lt 1 THEN message,'Use: dspspec, QL_Data'
  
;
; Check type with QLmanager
; 
  IF NOT Keyword_SET(NOCHECK) THEN BEGIN
      QLMGR,QLDS,valid
      IF NOT valid THEN	message,'First argument is not a QL Data structure'
  EndIF
  
  CASE strmid(tag_names(QLDS.DetDesc(0),/structure_name),0,3) OF
      'NIS': ndspspec,QLDS,group_leader=group_leader,/NOCHECK
      'CNI': ndspspec,QLDS,group_leader=group_leader,/NOCHECK
      'GIS': gdspspec,QLDS,group_leader=group_leader,/NOCHECK
      'CGI': gdspspec,QLDS,group_leader=group_leader,/NOCHECK
  EndCASE
  
END

