;+
; Project     : SOHO - CDS     
;                   
; Name        : GET_QLDS()
;               
; Purpose     : Returns the QLDS that the display routine is working on.
;               
; Explanation : In order to avoid multiple storage of the data
;		structures operated upon by the display routines,
;		the _FIRST_ display routine invoked interactively
;		by the user has the responsibility to keep the
;		QLDS as the UVALUE of its top level base. 
;
;		The window generated in this way is called the MASTER
;		window. All display routines called by the MASTER
;		window's event handling routine should be passed
;		the widget ID of the MASTER window in the keyword
;		GROUP_LEADER, and this should be stored in the
;		UVALUE of the invoked, (SLAVE) TOP_LEVEL_BASE.
; 
;		If a SLAVE window event handling routine invokes another
;		display routine, (a sub-SLAVE), it passes the widget ID 
;		of its own TOP_LEVEL_BASE so that GET_QLDS can follow the
;		trace of widget IDs up to the MASTER, to retrieve the
;		QLDS. SET_QLDS can (SHOULD!) then also be used to 
;		"put back" the QLDS.
;               
; Use         : QLDS = GET_QLDS(EV.TOP)
;    
; Inputs      : EV.TOP -- the widget ID of the TOP_LEVEL_BASE of 
;		a window generated by a CDS QL display routine.
;               
; Opt. Inputs : None.
;               
; Outputs     : Returns the QLDS
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : DATATYPE()
;
; Common      : None.
;               
; Restrictions: See 'Explanation'
;               
; Side effects: The use of this scheme reserves the user value (UVALUE)
;		of the TOP_LEVEL_BASE of any display window.
;               
; Category    : CDS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, 10 October, 1993
;               
; Modified    : CDP,  25 October 1993 -- cut /no_copy keyword
;		SVHH, 21 November 1993 - Documentation added.
;
; Version     : 1.0
;-            


FUNCTION Get_QLDS,base	; Searches for the data structure with 
			; the displayed data 
  nocopy = (strmid(!version.release,2,1) gt '0')
  
  IF nocopy THEN Widget_CONTROL,base,Get_UVALUE=QLDS,/NO_COPY $
  ELSE		 Widget_CONTROL,base,Get_UVALUE=QLDS
  
  IF datatype(QLDS) eq 'LON' THEN BEGIN
      nubase=QLDS
      IF nocopy	THEN Widget_CONTROL,base,Set_UVALUE=QLDS,/NO_COPY $
      ELSE	     Widget_CONTROL,base,Set_UVALUE=QLDS
      IF Widget_INFO(nubase,/valid_id) ne 1 THEN BEGIN
	  message,'Cannot trace back to top level widget'
      END
      return,Get_QLDS(nubase)
  END ELSE return,QLDS
  
END

