;+
; Project     : SOHO - CDS     
;                   
; Name        : PTEST
;               
; Purpose     : Demonstration of the PQLPROFILE/PQLZOOM routines.
;               
; Explanation : Two displays, one with a plot of a function, and
;		one with a TVSCL'ed image are made, and the user
;		may click the right mouse button in the TVSCL'ed
;		image to invoke PQLZOOM, or the left mouse button 
;		in either window in order to invoke PQLPROFILE.
;
;		The middle mouse button changes the displayed data,
;		demonstrating the update functionality of the
;		PQL routines.
;
;		If the "Kill" button in the bottom of the PTEST
;		window is pushed in, the left/right mouse buttons
;		will kill any copy of PQLPROFILE/PQLZOOM for that
;		plot region.
;
; Use         : PTEST
;    
; Inputs      : NONE
;               
; Opt. Inputs : NONE
;               
; Outputs     : NONE
;               
; Opt. Outputs: NONE
;               
; Keywords    : NONE
;
; Calls       : CDSCONGRID(), PFIND(), PQLPROFILE, PQLZOOM, PSTORE()
;		SETWINDOW, TRIM(), WIDGET_BASE(), WIDGET_TEXT()
;
; Common      : PTEST -- Used to store the plotted data.
;               
; Restrictions: Just a demo.
;               
; Side effects: XMANAGER starts..
;               
; Category    : QuickLook
;               
; Prev. Hist. : None.
;
; Written     : S. V. H. Haugan, December 1994
;               
; Modified    : SVHH, 19 Jan 1994 Documentation header added
;
; Version     : 1.0
;-            

; Demonstration of the Pqlprofile an pqlzoom routine
;
;

PRO swap,a,b
  tmp =	a
  a=b
  b=tmp
END



PRO plotdata
  common ptest,plot1,plot1x,plot2,plot2x,data1,data1x,data1y,$
					 data2,data2x,data2y
  common ptest_top,top
  sz = Size(data1)
  datax = sz(1)
  datay = sz(2)
  
  !P.multi = [0,1,2]

;
; Making a 1D plot, storing the coordinate system with pstore
;  
  Plot,plot1x,plot1,xrange=[min(plot1x),max(plot1x)+1],xstyle=0,psym=4
  OPlot,plot1x,plot1

  p = pstore(1,datax,1,/clean)  ; /Clean because the other plots are
				; destroyed (but rebuilt!).
  
  pqlprofile,plot1,plot1x,P_reg=p,/change,$	; This is an "update" call
	title='Dataset id #'+trim(plot1(5)),$	; that won't make the profile
	datatitle='This is the datatitle',$	; tool pop up if it's not
	subtitle='Subtitle',$			; already there...
	xtitle='X title',ytitle='Y title'	

;
; Making a 2D TV display with axes -- note that I'm letting IDL decide
; how big..
;  
  
  xstep	= data1x(1,0)-data1x(0,0)
  ystep	= data1y(0,1)-data1y(0,0)
  
  xrange = [min(data1x)-XSTEP/2.,max(data1x)+XSTEP/2.]
  Plot,[0],xrange=xrange,xstyle=1,$
	yrange=[min(data1y)-YSTEP/2.,max(data1y)+YSTEP/2.],ystyle=1,$
	/nodata,ticklen=-.05

;
; Axes/coordinate system in place, now display the data in the available 
; space.
; 

  scrnx	= !P.clip(2)-!P.clip(0)+1
  scrny	= !P.clip(3)-!P.clip(1)+1
  
  tvscl,cdsCongrid(data1,scrnx,scrny),!P.clip(0),!P.clip(1)

;
;
;  
  p = pstore(2,datax,datay)

;
; "Update" calls to pqlprofile/pqlzoom, won't make it pop up if it's
; not there already..
;
;
  pqlprofile,data1,P_reg=p,/change,title='Dataset id #'+trim(data1(5,5)),$
		datatitle='This is the data title',subtitle='Subtitle',$
		xtitle='This is the X title',ytitle='This is the Y title'

  pqlzoom,data1,P_reg=p,/change,title='Zoom title',$
		subtitle='This is the subtitle',$
		xtitle='This is the X title',ytitle='This is the Y title'
END





PRO ptest_event,ev
  common ptest,plot1,plot1x,plot2,plot2x,data1,data1x,data1y,$
					 data2,data2x,data2y
  common text,twid
  common killstat,killstat
  
  Widget_CONTROL,ev.id,Get_UVALUE=uval
  
  CASE uval OF
      'DRAW': CASE ev.press OF
	  0: return
	  1: BEGIN  					; Profile
	      p	= pfind(ev,found,plot_number=plotnum)   ; Which window...
	      IF NOT found THEN	return
	      IF plotnum eq 1 THEN BEGIN
		  pqlprofile,event=ev,plot1,plot1x,$
			  title='Dataset id #'+trim(data1(5)),$
			  xtitle='X position',$
			  ytitle='Y position',$
			  datatitle='Z value (counts)',kill=killstat
	      END ELSE BEGIN
		  pqlprofile,event=ev,data1,$
			  title='Dataset id #'+trim(data1(5)),$
			  xtitle='X position',$
			  ytitle='Y position',$
			  datatitle='Z value (counts)',kill=killstat
	      EndELSE
	  END
	  2: BEGIN
	      swap,data1,data2 & swap,data1x,data2x & swap,data1y,data2y
	      swap,plot1,plot2 & swap,plot1x,plot2x
	      plotdata
	  END
	  4: BEGIN
	      p	= pfind(ev,found,plot_number=plotnum)
	      IF NOT found THEN	return
	      IF plotnum eq 2 THEN BEGIN
		  pqlzoom,data1,event=ev,group=ev.top,xysize = 400,/outside,$
			kill=killstat,title='Zoom title',$
			subtitle='This is the subtitle',$
			xtitle='This is the X title',$
			ytitle='This is the Y title'
	      EndIF
	  EndCASE
      EndCASE
      
      'KILL': killstat = ev.select
      
      'DONE': Widget_CONTROL,ev.top,/destroy
      ELSE: help,ev
  EndCASE
END



PRO ptest
  common ptest,plot1,plot1x,plot2,plot2x,data1,data1x,data1y,$
					 data2,data2x,data2y
  common text,twid
  common ptest_top,base
  
;
; Making the windows...
;

  base = Widget_BASE(/column)
  
  draw = Widget_DRAW(base,xsize	= 500,ysize=800,uvalue = 'DRAW',/button_ev)
  
  window = draw
  
  xmenu,["Kill"],base,/exclusive,uvalue=["KILL"]
  dummy	= Widget_BUTTON(base,value='Quit',uvalue='DONE')

  twid = widget_text(base,value='',ysize=1)   

  Widget_CONTROL,base,/realize
  Widget_CONTROL,draw,Get_VALUE=draw
  SetWindow,draw
  
;
; Just making some data to show...
;

  N = 300
  x = (findgen(N,N) mod N)
  x = x/(N-1)*!PI*1.5
  y = transpose(x)
  
  
  data1	= sin(x*y)+sin(y-x^4)
  data2	= sin(x^5+y^2)+sin((y-x)^2)
  data1x = x & data1y =	y
  data2x = x & data2y =	y
  
  x =  (x/2. + .5)^2
  
  plot1	= reform((sin(x*y)+sin(y-x^4))(*,0))
  plot1x = reform(x(*,0))
  plot2	= reform(data2(*,0))
  plot2x = reform(data2x(*,0))
  
;
; Plotting the data and waiting for things to happen
;
  plotdata
  
  Xmanager,'PTEST',base
  
END
