;+
; Project     :	SOHO - CDS
;
; Name        :	QL_BSCALE()
;
; Purpose     :	Scales VDS data for display with QL_COLTABLE color table.
;
; Explanation :	This procedure scales simulated VDS data for display with the
;		color table loaded by the routine TP_COLTABLE.  The array is
;		scaled logarithmically, so that values in the approximate range
;		0-41 are in the lower third of the color table (blue), 41-410
;		in the middle third (orange) and 410-4095 in the upper third
;		(white).  Values of 4096 and above are displayed as red pixels.
;
; Use         :	TV, QL_BSCALE(ARRAY)
;		EXPTV, QL_BSCALE(ARRAY), /NOSCALE
;
; Inputs      :	ARRAY	= Simulated VDS data array from VDS_DUMMY, or
;		equivalent.
;
; Opt. Inputs :	None.
;
; Outputs     :	The result of the function is a logarithmically scaled byte
;		array with the values matched to the number of colors for the
;		currently selected graphics device.
;
; Opt. Outputs:	None.
;
; Keywords    :	TOP	= The maximum value of the scaled image array, as used
;			  by BSCALE.  The default is !D.N_COLORS-1.
;
; Calls       :	BSCALE
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning, Technical.
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 23 September 1993.
;
; Modified    :	Version 1, William Thompson, GSFC, 23 September 1993.
;
; Version     :	Version 1, 23 September 1993.
;-
;

FUNCTION QL_BSCALE, ARRAY, TOP=TOP
  On_Error, 2
  if !DEBUG gt 0 then on_error,0
;
;  Check the number of parameters.
;
  IF N_PARAMS()	NE 1 THEN MESSAGE, 'Syntax:  Result = QL_BSCALE(ARRAY)'
;
;  Scale the input array logarithmically.
;
  I = where(ARRAY GT 0,count)
  OUTPUT = ARRAY*0.0
  if count eq 0 then return,array
  OUTPUT(I) = ALOG(1.0+ARRAY(I))
  OP = OUTPUT(I)

  BSCALE, OP
;
  OUTPUT(I)=OP
  RETURN, OUTPUT
END
