;+
; Project     : SOHO - CDS     
;                   
; Name        : QL_SIZE
;               
; Purpose     : Avoid disappearance of singular trailing dimensions
;               
; Explanation : If an array with singular trailing dimensions, e.g.,
;		fltarr(10,1,1) is passed to SIZE(), the singular 
;		dimensions are obliterated. Given the true number of
;		dimensions, this routine returns the expected value
;		of SIZE(), e.g.:
;
;		PRINT,SIZE(fltarr(10,1,1))
;		IDL> print,size(fltarr(10,1,1))
;		           1          10           4          10
;		but:
;
;		PRINT,QL_SIZE(size(fltarr(10,1,1)),3)
;                    3      10       1        1       4          10
;
; Use         : SZ = QL_SIZE(SIZE(array_expr),NDIMS)
;    
; Inputs      : array_expr : Array expression (wow!)
;		NDIMS :      The known number of dimensions
;		
; Opt. Inputs : None.
;               
; Outputs     : Return value has same meaning as with the builtin SIZE()
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : None.
;
; Common      : None.
;               
; Restrictions: None.
;               
; Side effects: None known.
;               
; Category    : CDS QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, 20-Feb-1995
;               
; Modified    : Version 2, SVHH, 21-Aug-1995
;			Now it takes the SIZE() of an array expression
;			as the first argument. This is in order to 
;			avoid memory overhead with expressions like
;			QL_SIZE(QLDS.DETDATA), which would cause copying
;			the whole array...
; Version     : 2
;-            


function QL_SIZE,SZ,NDIMS

on_error,2
if !DEBUG ne 0 then on_error,0

IF N_PARAMS() lt 2 then message,"Use: SZ = QL_SIZE(SIZE(DATA),NDIMS)"

if sz(0) eq NDIMS then return,sz ; No problem- just return

if sz(0) gt NDIMS then $
	message,"Array expression has more dimensions than expected"

if sz(0) ge 1 then $
	SZ = [NDIMS,sz(1:sz(0)),replicate(1,NDIMS-Sz(0)),SZ(sz(0)+1:*)] $
else    SZ = [NDIMS,replicate(1,NDIMS-Sz(0)),SZ(sz(0)+1:*)]

return,sz

end
