;+
; Project     :	SOHO - CDS
;
; Name        :	QLHELP
;
; Purpose     :	Widget to select help topics related to the QL Software.
;
; Explanation :	Create a widget that lists and displays the help text explaining
;    		how to use the various features available in the CDS QUICKLOOK 
;		Software. A brief description of the data structure is also included.
;
; Use         :	QLHELP, [GROUP=GROUP, MODULE=MODULE]
;		QLHELP,'DSPWAV'
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	GROUP	= The widget ID of a calling widget. Destroying that
;			  widget will kill this widget.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	 Display, Data analysis, Help utility
;
; Prev. Hist. :	Based on the CDS PLANHELP.PRO routine written by 
;		Elaine Einfalt, GSFC (HSTX), April 1994
;
; Written     :	Paal Brekke, ITA, July 7 1994
;
; Modified    :	
;
; Version     :	Version 1, 7 July 1994
;-

pro qlhelp_event, event

 widget_control, event.id, get_uvalue=input	; what was clicked on.
 widget_control, event.top, get_uvalue=help	; text window widget ID

 case input of

 'CANCEL'  : widget_control, event.top, /destroy   ; kills the widg

 'LIST'  : begin

   value = strtrim(help.topics(event.index),2)

   case value of     				; the desired topic

	'The "End Session" button': hval = [  $
	'THE "END SESSION" BUTTON 						',$
	' ',$
	' Will end the current session and return to the IDL prompt']

	'UNDERSTANDING THE CDS DATA STRUCTURE' : hval = [ $
	' ',$
	' To be written....']

    'CDS QUICKLOOK SOFTWARE' : hval = [ 		$
	'HOW TO START USING THE QUICKLOOK SOFTWARE                 ', $
	'                                                          ', $
	' The CDS QUICKLOOK software is a package of IDL routines  ',$
	' to read and display CDS data obtained from both the      ',$
	' Normal Incidence detector or the Grazing Incidence       ',$
	' detector. The data can be displayed in a number of ',$
	' ways. All vital information about the data poivided ',$
	' with the FITS header can also be displayed in a nice ',$
	' readable way. ',$
	'                                                          ', $
	' A number of routines to interactivly measure intensities,',$
	' or wavelengths, extracting profiles and making hard copies',$
	' are available.  ', $
	'                                                          ', $
	' How to start the QL software:  ', $
	'  ', $
	'     The QL software need a CDS data structure as input.  ', $
	'     To read in a CDS FITS file:   ', $
	'  ', $
	'        IDL> A = READCDSFITS(file)      ', $
	'  ', $
	'     This will put all the data + all header information  ', $
	'     into the structure A and this variable will then be  ', $
	'     input to the display routines which can be called  ', $
	'     seperately from the IDL prompt (see under ROUTINES)  ', $
	'     or from the MAIN-MENU as shown here.                  ', $
	'    ', $
	'        IDL>  DSP_MENU, A                                     ', $
	'                                                          ', $
	' A menu appear with a selection of different ways of   ', $
	' displaying the data residing in the variable A      ', $
	'                                                   ', $
	' More information about the individual buttons can be found ', $
	' by selecting the corresponding "button" in the menu in  ', $
	' in this help tool.    ', $
	'                                                          ', $
	' This help program may be accessed directly from IDL:     ', $
	'                                                          ', $
     	'    IDL> QLHELP, [module=routine]',$
	'    IDL> QLHELP, module="DSPWAV"                             ', $
	'                                                          ']

    'GENERAL OWERVIEW MODULE: DSP_MENU':  hval = [			   $
	'CDS QUICKLOOK SOFTWARE MAIN MENU                               ', $
	' ',$
	'Routine: DSP_MENU.PRO ', $
	' ', $
	' This is what we call the "MAIN MENU" where the user can ', $
	' select various ways of displaying the observed CDS data,', $
	' either from the NIS detector or the GIS detectors.', $
	' The display mode can be selected from a set of buttons.', $
	' The following instructions assume that the user is familiar', $
	' with the CDS data structure and format (see under DATA STRUCTURE', $
	' or DATA FORMAT).', $
	' ', $
	' Only a very brief description of each feature is given here.', $
	' A more detailed discussion can be found under their separate', $
	' items in the menu to the left.' ]


	'The "QL MENU" button': hval = [            $
	'THE "QL MENU" BUTTON 						',$
	' ',$
	' Used to load a new set of observation (CDS FITS file)', $
	' into the current QL session']
	

	'The "Modify Color Table" button': hval = [       $
	'THE "MODIFY COLOR TABLE" BUTTON 		    		',$
	' ',$
	' Modify current color lookup table, change contrast, or load a ', $
	' new color table.']

	'The "Deselected Spectrum" button': hval =  [         $
	'THE "Deselected Spectrum" BUTTON				',$
	' ',$
	' Displays a full spectrum or spectral windows', $
	' from specific exposures within a raster sequence.', $
        ' The individual Spectral Windows are deselected ', $
	' into their corresponding positions on the detector.', $
	' Line selection and windows given in Blue Book', $
	' can be displayed. ', $
	' Measurements of wavelengths and positions on the ', $
	' detector is possible together with line identification.']


	'The "Wavelength Slice/Profile" button': hval = [        $
	'THE "Wavelength Slice/Profile" BUTTON 			',$
	' ',$	
        ' Display data slices at specific wavelength +line profiles.', $
        ' A window is created with two types of display of the', $
	' data in four selected spectral windows. ', $
	' ', $
	' The upper display is is a cross section of the ', $
	' data at a specific wavelength, giving a spatial ', $
	' view of the region that has been scanned by the CDS NIS/GIS.', $
	' The lower display is the intensity profile along the', $
	' dispersion direction (line profile), at a selected', $
	' point in the two-dimensional image displayed in the', $
	' window above. ']

	'The "Spectral Window Exposures" button': hval = [        $
	'THE "Spectral Window Exposure" BUTTON				',$
	' ',$
	' Display all exposures of selected Spectral Windows', $
	' ', $
	' A window is created to show all the exposures of', $
        ' the selected Spectral Windows, spread out one after', $
        ' another, and to report the identity of the', $
        ' Spectral Window/exposure number that is clicked on', $
        ' by the user.']

	'The "NIS Movie" button': hval = [          $
	'THE "NIS Movie" BUTTON				',$
	' ',$
	' Display a movie of .......']

	'The "Structure Browser" button': hval = [            $
	'THE "Structure Browser" BUTTON				',$
	' ',$
	' Display contents of a structure as a pulldown menu.', $
	' A pulldown menu is created representing all the', $
        ' levels of "introspection" of the structure variable.', $
	' ', $
        ' If a tag in a structure is an array, it is "written out"', $
        ' if it is  less than SIZE, which by default is set to 30.', $
	' ', $
        ' It may be used as a standalone widget or as part of a', $
        ' menu. In the latter case, it generates a pulldown button', $
        ' that unfolds the structure.']

	'The "FITS Header" button': hval = [      $
	'THE "FITS Header" BUTTON				',$
	' ',$
	' Display basic information from a CDS QL Data Structure', $
	' ', $
	' Displays basic information in a window about the', $
        ' structure containing data from a CDS FITS level-1 file.', $
        ' Optional display of information concerning each spectral', $
        ' window appears in a separate window, as is also the case', $
        ' with the optional display of auxiliary data information.']

;-----------------------------------------------------------------

    'Main QL Display Menu' : hval = [			   $
	'DISPLAY MODE vs EDIT MODE FOR THE CDS PLANNING TOOL       ', $
	'                                                          ', $
	' When the Display button is depressed, the tool is in     ', $
	' display mode.  Display mode is used to display the plans ', $
	' for the selected time range,  display information about  ', $
	' the study selected from the list window, or display      ', $
	' information about an intrument''s study at a selected     ', $
	' time.                                                    ', $
	'                                                          ', $
	' When the Edit button is depressed, the tool is in edit   ', $
	' mode.  Edit mode is used to create or modify daily       ', $
	' science plans.  There are two edit modes, CDS-plan and   ', $
	' CDS-details.  The type of edit mode is selected by a     ', $
	' cursor click in the plan display plot window.            ', $
	' (See "plan display plot window", below)                  ', $
	'                                                          ', $
	' The specifics about mode dependent functions are         ', $
	' discuss under the various topics.                        ', $
	'                                                          ']
    
    'The "DONE" button'         : hval = [			   $
	'THE "QUIT" BUTTON                                         ', $
	'                                                          ', $
	' When the QUIT button is pressed then the CDS planning    ', $
	' tool is exitted and all related widget interfaces are    ', $
	' destroyed.                                               ', $
	'                                                          ', $
	' This button performs the same actions regardless of the  ', $
	' currently selected mode.                                 ', $
	'                                                          ']

    'The "Help" button'         : hval = [			   $
	'THE "HELP" BUTTON                                         ', $
	'                                                          ', $
	' When the Help button is pressed, this help interface is  ', $
	' created.  Only one help interface is active at a time.   ', $
	'                                                          ', $
	' This button performs the same actions regardless of the  ', $
	' currently selected mode.                                 ', $
	'                                                          ']


     else : hval = 'Sorry no help for that topic ' + value

    end

    ;
    ; Display the help information for the selected topic
    ;

    widget_control, help.second, set_value = hval


 end
 else : print,'QLHELP - Programmer error ' + input
end


return & end

;-----------------------------------------------------------------------------


pro qlhelp, group_leader=group,module=module    ; create help wigdet

   if xregistered('qlhelp') then return	; only want one at a time
   IF NOT (Keyword_SET(module)) THEN module='DSP_MENU'

   helpit = widget_base(title='CDS QUICKLOOK SOFTWARE HELP', /row, space=20)

     ;
     ; The list of help topics
     ;
   CASE module OF
     'DSP_MENU': BEGIN

        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')

	topics = [	$				; the help topics
			' CDS QUICKLOOK SOFTWARE', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
			' GENERAL OWERVIEW MODULE: DSP_MENU ', $
		    	' The "End Session" button', $
			' The "QL MENU" button ', $
			' The "Modify Color Table" button ', $
			' The "Deselected Spectrum" button ', $
		  	' The "Wavelength Slice/Profile" button ', $
			' The "Spectral Window Exposures" button ', $
			' The "NIS Movie" button ', $
			' The "Structure Browser" button ', $
			' The "FITS Header" button ', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: DSP_MENU '
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the QL MAIN MENU just click'
	starttopic(5)=' on one of the items in the menu to the left'

        END


     'GDSPSPEC': BEGIN

        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')

	topics = [	$				; the help topics
			' GENERAL OWERVIEW MODULE: GDSPSPEC ', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
		    	' The "Cursor action" button ', $
			' The "Done" button ', $
			' The "Help" button ', $
			' The "Modify color table" button ', $
			' The "Mark lines" button ', $
			' The "Postscript" button ', $
			' The "Pointing Tool" button ', $
			' The "Select exposure" slider ', $
			' The "DRAW" windows ', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: GDSPSPEC '
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the GDSPSPEC routine just click'
	starttopic(5)=' on one of the items in the menu to the left'

        END
      'DSPWAV': BEGIN


        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')

	topics = [	$				; the help topics
			' GENERAL OWERVIEW MODULE: DSPWAV ', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
			' The "Done" button ', $
			' The "Help" button ', $
			' The "Hardcopy" button (menu)', $
			' The "Diagnostics" button (menu)', $
			' The "Slit orientation" button (menu)', $
			' The "Window" buttons (menu) ', $
			' The text labels', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: DSPWAV '
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the DSPWAV options just click'
	starttopic(5)=' on one of the items in the menu to the left'
        END
       'NDSPSPEC': BEGIN


        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')

	topics = [	$				; the help topics
			' GENERAL OWERVIEW MODULE: NDSPSPEC ', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
		    	' The "Cursor action" button ', $
			' The "Done" button ', $
			' The "Help" button ', $
			' The "Modify color table" button ', $
			' The "Mark lines" button ', $
			' The "Postscript" button ', $
			' The "Pointing Tool" button ', $
			' The "Select exposure" slider ', $
			' The "DRAW" windows ', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: NDSPSPEC   (NIS Data)'
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the NDSPSPEC options just click'
	starttopic(5)=' on one of the items in the menu to the left'

        END
         
      'DSPEXP': BEGIN


        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')



	topics = [	$				; the help topics
			' GENERAL OWERVIEW MODULE: DSPEXP ', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
		    	' Main QL Display Menu', $
		    	' The "Cursor action" button ', $
			' The "Done" button ', $
			' The "Help" button ', $
			' The "Refresh screen" button ', $
			' The "Hardcopy" button ', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: DSPEXP '
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the DSPEXP options just click'
	starttopic(5)=' on one of the items in the menu to the left'
        END

      'PQLZOOM': BEGIN


        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')




	topics = [	$				; the help topics
			' GENERALL OWERVIEW MODULE: PQLZOOM ', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
		    	' Main QL Display Menu', $
			' The "Done" button ', $
			' The "Help" button ', $
			' The "Plot" button (menu)', $
			' The "Smooth" button ', $
			' The "Rescale" button ', $
			' The "Read Pos." button ', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: PQLZOOM '
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the ZOOM options just click'
	starttopic(5)=' on one of the items in the menu to the left'
        END
     

      'PQLPROFILE': BEGIN


        first = widget_base(helpit, /column, space=15)	
        quitit = widget_button(first, value='Quit', uvalue='CANCEL')




	topics = [	$				; the help topics
			' GENERAL OWERVIEW MODULE: PQLZOOM ', $
			' UNDERSTANDING THE CDS DATA STRUCTURE ', $
			' The "Done" button ', $
			' The "Help" button ', $
			' The "Plot" button (menu)', $
			' The "Save" button ', $
			' The "Line Fitting" button (menu)', $
			' The "Length of profile" slider ', $
			' The "Average over" slider ', $
			' The "Horizontal" button ', $
			' The "Vertical" button ', $
			' DATA STRUCTURE/FORMAT ' ]

    	starttopic=strarr(6)
	starttopic(0)=' This is the CDS QUICKLOOK SOFTWARE HELP TOOL'
	starttopic(1)=' 
	starttopic(2)=' Module: PQLPROFILE '
	starttopic(3)='    '
	starttopic(4)=' To get help/info about the PROFILE options just click'
	starttopic(5)=' on one of the items in the menu to the left'
        END


        ELSE :MESSAGE,'No statements matches'
     EndCASE
      

        list = widget_list(first, value=topics, ysize=25, uvalue='LIST')


     ;
     ; The topic output window
     ;

     second = widget_text(helpit, /scroll, /frame, xsize=60, ysize=30,$
              value = starttopic)

   widget_control, helpit, /realize

; Defining unnamed structure since length of topic will change
; depending on which routine that are calling QLHELP
;
helppass = {second:second, topics:topics}

   widget_control, helpit, set_uvalue=helppass 		; pass text widget ID

   xmanager, 'qlhelp', helpit, event_handler='qlhelp_event', $
			  group_leader=group
     

return & end




























