;+
; Project     : SOHO - CDS     
;                   
; Name        : SET_QLDS()
;               
; Purpose     : Put back QLDS that the display routine is working on.
;               
; Explanation : In order to avoid multiple storage of the data
;		structures operated upon by the display routines,
;		the _FIRST_ display routine invoked interactively
;		by the user has the responsibility to keep the
;		QLDS as the UVALUE of its top level base. 
;
;		The window generated in this way is called the MASTER
;		window. All display routines called by the MASTER
;		window's event handling routine should be passed
;		the widget ID of the MASTER window in the keyword
;		GROUP_LEADER, and this should be stored in the
;		UVALUE of the invoked, (SLAVE) TOP_LEVEL_BASE.
; 
;		If a SLAVE window event handling routine invokes another
;		display routine, (a sub-SLAVE), it passes the widget ID 
;		of its own TOP_LEVEL_BASE so that GET_QLDS can follow the
;		trace of widget IDs up to the MASTER, to retrieve the
;		QLDS. SET_QLDS should then also be used to "put back" 
;		the QLDS after use/alteration.
;               
; Use         : SET_QLDS,EV.TOP,QLDS
;    
; Inputs      : EV.TOP -- the widget ID of the TOP_LEVEL_BASE of 
;		a window generated by a CDS QL display routine.
;               
;		QLDS:	The CDS QL Data Structure to be put back
;
; Opt. Inputs : None.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : DATATYPE()
;
; Common      : None.
;               
; Restrictions: See 'Explanation'
;               
; Side effects: The use of this scheme reserves the user value (UVALUE)
;		of the TOP_LEVEL_BASE of any display window.
;               
; Category    : CDS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, 10 October, 1993
;               
; Modified    : CDP,  25 October 1993 -- cut /no_copy keyword
;		SVHH, 21 November 1993 - Documentation added.
;
; Version     : 1.0
;-            

PRO Set_QLDS,base,QLDS	; Puts back the data structure with 
			; the displayed data 
  
  nocopy = (strmid(!version.release,2,1) gt '0')
  
  IF nocopy THEN Widget_CONTROL,base,Get_UVALUE=groupleader,/NO_COPY $
  ELSE		  Widget_CONTROL,base,Get_UVALUE=groupleader ;,/no_copy
  
  IF datatype(groupleader) eq 'LON' THEN BEGIN
      nubase=groupleader
      IF nocopy	THEN Widget_CONTROL,base,Set_UVALUE=groupleader,/NO_COPY $
      ELSE	     Widget_CONTROL,base,Set_UVALUE=groupleader
      IF Widget_INFO(nubase,/valid_id) ne 1 THEN BEGIN
	  message,'Cannot trace back to top level widget'
      END
      Set_QLDS,nubase,QLDS
  END ELSE BEGIN
      IF nocopy	THEN Widget_CONTROL,base,Set_UVALUE=QLDS,/NO_COPY $
      ELSE	     Widget_CONTROL,base,Set_UVALUE=QLDS
  EndELSE
  
END

