;+
; Project     : SOHO - CDS     
;                   
; Name        : PIXELS_2_DATA()
;               
; Purpose     : Convert pixel --> data coordinates for SERTS image routines
;               
; Explanation : Uses the data stored for each SERTS window to calculate
;		from a pixel number/address to the corresponding
;		X/Y data coordinate.
;               
; Use         : DATA_X = PIXELS_2_DATA(SERTSW,X_PIXEL_NO)
;    
; Inputs      : SERTSW : A structure as returned by GET_SERTSW()
;
;		X_PIXEL_NO: 
;			(or Y_PIXEL_NO) the pixel number(s) to
;			calculate the corresponding data coordinate for.
;               
; Opt. Inputs : None.
;               
; Outputs     : Return value.
;               
; Opt. Outputs: None.
;               
; Keywords    : Y : 	Set to mark that it's the Y pixel no. that is
;			supplied, and to return the Y data coordinate.
;
; Calls       : GET_TV_SCALE, SET_SERTSW
;
; Common      : None.
;               
; Restrictions: There must exist a data coordinate system for the
;		given SERTS window.
;               
; Side effects: ALTERS the current SERTS window, also !P,!X,... etc.
;               
; Category    :
;               
; Prev. Hist. : None.
;
; Written     : SV Hagfors Haugan, December -93
;               
; Modified    : Never.
;
; Version     : 1.0
;-            

FUNCTION pixels_2_data,sertsw,C,y=y
  
  set_sertsw,sertsw
  
  get_tv_scale,datax,datay,scrnx,scrny,jx,jy,data
  
  IF NOT Keyword_SET(y)	THEN BEGIN
      xnorm = (((c + 0.5)*scrnx)/datax + jx)/!D.X_SIZE
      return, (xnorm - data.xs(0))/data.xs(1)
  END ELSE BEGIN
      ynorm = (((c + 0.5)*scrny)/datay + jy)/!D.Y_SIZE
      return, (ynorm - data.ys(0))/data.ys(1)
  END
  
END

