;+
; Project     : SOHO - CDS     
;                   
; Name        : PIXELS_2_DEVICE()
;               
; Purpose     : Convert pixel --> device coords for SERTS image routines
;               
; Explanation : Uses the data stored for each SERTS window to calculate
;		from a pixel number/address to the corresponding
;		X/Y device coordinate.
;               
; Use         : DEVICE_X = PIXELS_2_DEVICE(SERTSW,X_PIXEL_NO)
;    
; Inputs      : SERTSW : A structure as returned by GET_SERTSW()
;
;		X_PIXEL_NO: 
;			(or Y_PIXEL_NO) the pixel number(s) to
;			calculate the corresponding device coordinate for.
;               
; Opt. Inputs : None.
;               
; Outputs     : Return value.
;               
; Opt. Outputs: None.
;               
; Keywords    : Y : 	Set to mark that it's the Y pixel no. that is
;			supplied, and to return the Y device coordinate.
;
; Calls       : GET_TV_SCALE, SET_SERTSW
;
; Common      : None.
;               
; Restrictions: There must exist a data coordinate system for the
;		given SERTS window.
;               
; Side effects: ALTERS the current SERTS window, also !P,!X,... etc.
;               
; Category    :
;               
; Prev. Hist. : None.
;
; Written     : SV Hagfors Haugan, December -93
;               
; Modified    : Never.
;
; Version     : 1.0
;-            

FUNCTION pixels_2_device,sertsw,C,y=y,lower=lower
  
  set_sertsw,sertsw
  get_tv_scale,datax,datay,scrnx,scrny,jx,jy,data
  
  IF NOT Keyword_SET(y)	THEN BEGIN
      IF NOT Keyword_SET(lower)	THEN return,fix(((c + 0.5)*scrnx)/datax	+ jx) $
      ELSE			     return,fix((c*scrnx)/datax	+jx)
  END ELSE BEGIN
      IF NOT Keyword_SET(lower)	THEN return,fix(((c + 0.5)*scrny)/datay	+ jy) $
      ELSE			     return,fix((c*scrny)/datay	+jy)
  END
  
END

