;+
; Project     : SOHO - CDS     
;                   
; Name        : RESTORE_QLDS
;               
; Purpose     : Restore a QLDS saved with SAVE_QLDS
;               
; Explanation : With the new storage scheme using handles it's not possible to
;               use the SAVE command to store all the data in a QLDS with just
;               one simple statement. This function (together with the
;               procedure QLDS_SAVE) provides a simple interface to save and
;               restore Quick Look Data Structures.
;
; Use         : A = RESTORE_QLDS(FILENAME)
;    
; Inputs      : FILENAME : The file name to restore the QLDS from.
;               
; Opt. Inputs : None.
;               
; Outputs     : Returns a QLDS.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : datatype() handle_create() qlmgr tag_exist() trim() st_windata
;
; Common      : None.
;               
; Restrictions: Only handles 60 data windows.
;               
; Side effects: None known.
;               
; Category    : Data_Handling, I_O, Quicklook.
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar H. Haugan (UiO), 3 October 1996
;               
; Modified    : Not yet.
;
; Version     : 1, 3 October 1996
;-            

function restore_qlds,filename
  ON_ERROR,2
  
  IF N_elements(filename) NE 1 THEN $
     message,"Use : A = RESTORE_QLDS(FILENAME)"
  
  d0 = 0b & d1 = 0b & d2 = 0b & d3 = 0b & d4 = 0b & d5 = 0b & d6 = 0b 
  d7 = 0b & d8 = 0b & d9 = 0b
  d10 = 0b & d11 = 0b & d12 = 0b & d13 = 0b & d14 = 0b & d15 = 0b & d16 = 0b 
  d17 = 0b & d18 = 0b & d19 = 0b
  d20 = 0b & d21 = 0b & d22 = 0b & d23 = 0b & d24 = 0b & d25 = 0b & d26 = 0b 
  d27 = 0b & d28 = 0b & d29 = 0b
  d30 = 0b & d31 = 0b & d32 = 0b & d33 = 0b & d34 = 0b & d35 = 0b & d36 = 0b 
  d37 = 0b & d38 = 0b & d39 = 0b
  d40 = 0b & d41 = 0b & d42 = 0b & d43 = 0b & d44 = 0b & d45 = 0b & d46 = 0b 
  d47 = 0b & d48 = 0b & d49 = 0b
  d50 = 0b & d51 = 0b & d52 = 0b & d53 = 0b & d54 = 0b & d55 = 0b & d56 = 0b 
  d57 = 0b & d58 = 0b & d59 = 0b
  
  qlds = 0b
  
  restore,filename
  IF datatype(qlds) NE 'STC' THEN  $
     message,"Error in restoring QLDS from file "+filename
  
  qlmgr,qlds
  
  IF tag_exist(qlds,"detdata") THEN return,qlds
  no_copy = 1
  
  FOR i = 0,N_elements(qlds.detdesc)-1 DO BEGIN 
     IF qlds.detdesc(i).ixstop(0) GT 0 THEN BEGIN
        qlds.detdesc(i).handle = handle_create()
        exestr = "st_windata,qlds,i,d"+trim(i)+", no_copy=no_copy"
        dummy = execute(exestr)
     END
  ENDFOR
  
  return,qlds
  
END
