;+
; Project     : SOHO - CDS     
;                   
; Name        : SAVE_QLDS
;               
; Purpose     : Save a QLDS to an IDL save-file.
;               
; Explanation : With the new storage scheme using handles it's impossible to
;               simply use the SAVE command to store all the data in a QLDS
;               with just one simple statement. This routine (together with
;               the function QLDS_RESTORE) provides a simple interface to save
;               and restore Quick Look Data Structures.
;
;               By default, the /XDR switch to SAVE is used, to enable
;               platform-independent save files under VMS. This can be turned
;               off by setting XDR=0.
;
;               If the QLDS has been read in with the old storage system, the
;               whole QLDS is simply SAVEd.
;               
; Use         : SAVE_QLDS,QLDS [ ,FILENAME=FILENAME ]
;    
; Inputs      : QLDS : Quick Look Data Structure
;               
; Opt. Inputs : FILENAME : Name of file to store the QLDS in. Default is the
;                          file name (e.g., 's3300r00') plus extension
;                          '.qlsave'.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : XDR : Set to zero to avoid XDR format on VMS.
;
; Calls       : break_file default gt_windata() st_windata tag_exist() trim()
;
; Common      : None.
;               
; Restrictions: Only handles 60 data windows.
;               
; Side effects: None known.
;               
; Category    : Data_Handling, I_O, Quicklook.
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar H. Haugan (UiO), 3 October 1996
;               
; Modified    : Not yet.
;
; Version     : 1, 3 October 1996
;-            

PRO save_qlds,qlds,xdr=xrd,filename=filename
  ON_ERROR,2
  
  default,xdr,1
  break_file,qlds.header.filename,disk,dir,filnam,ext
  default,filename,filnam+'.qlsave'
  
  IF tag_exist(qlds,"detdata") THEN BEGIN
     save,qlds,filename=filename,xdr=xdr
     return
  END
  
  d0 = 0b & d1 = 0b & d2 = 0b & d3 = 0b & d4 = 0b & d5 = 0b & d6 = 0b 
  d7 = 0b & d8 = 0b & d9 = 0b
  d10 = 0b & d11 = 0b & d12 = 0b & d13 = 0b & d14 = 0b & d15 = 0b & d16 = 0b 
  d17 = 0b & d18 = 0b & d19 = 0b
  d20 = 0b & d21 = 0b & d22 = 0b & d23 = 0b & d24 = 0b & d25 = 0b & d26 = 0b 
  d27 = 0b & d28 = 0b & d29 = 0b
  d30 = 0b & d31 = 0b & d32 = 0b & d33 = 0b & d34 = 0b & d35 = 0b & d36 = 0b 
  d37 = 0b & d38 = 0b & d39 = 0b
  d40 = 0b & d41 = 0b & d42 = 0b & d43 = 0b & d44 = 0b & d45 = 0b & d46 = 0b 
  d47 = 0b & d48 = 0b & d49 = 0b
  d50 = 0b & d51 = 0b & d52 = 0b & d53 = 0b & d54 = 0b & d55 = 0b & d56 = 0b 
  d57 = 0b & d58 = 0b & d59 = 0b
  
  no_copy = 1
  
  FOR i = 0,N_elements(qlds.detdesc)-1 DO BEGIN 
     IF qlds.detdesc(i).ixstop(0) GT 0 THEN BEGIN
        exestr = "d"+trim(i)+" = gt_windata(qlds,i,no_copy=no_copy)"
        dummy = execute(exestr)
     END
  ENDFOR
 
  save,filename=filename,/XDR,qlds,$
     d0,   d1,  d2,  d3,  d4,  d5,  d6,  d7,  d8,  d9, $ 
     d10, d11, d12, d13, d14, d15, d16, d17, d18, d19, $ 
     d20, d21, d22, d23, d24, d25, d26, d27, d28, d29, $ 
     d30, d31, d32, d33, d34, d35, d36, d37, d38, d39, $ 
     d40, d41, d42, d43, d44, d45, d46, d47, d48, d49, $ 
     d50, d51, d52, d53, d54, d55, d56, d57, d58, d59
  
  IF keyword_set(no_copy) THEN BEGIN
     FOR i = 0,N_elements(qlds.detdesc)-1 DO BEGIN 
        IF qlds.detdesc(i).ixstop(0) GT 0 THEN BEGIN
           exestr = "st_windata,qlds,i,d"+trim(i)+", no_copy=no_copy"
           dummy = execute(exestr)
        END
     ENDFOR
  END
END
