;+
; Project     : SOHO - CDS     
;                   
; Name        : CAL_HDRREAD()
;               
; Purpose     : Read basic header information from CDS FITS level-1 file.
;               
; Explanation : Straightforward. Returns IDL structure described in
;		CDS QL Data Format.
;               
; Use         : HDR = CAL_HDRREAD(HEADER)
;    
; Inputs      : HEADER= The header (array of strings of a CDS FITS
;			level-1 file.
;               
; Opt. Inputs : None.
;               
; Outputs     : Return value, see above.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : FXPAR(), TRIM()
;
; Common      : None.
;               
; Restrictions: See HEADER above.
;               
; Side effects: None.
;               
; Category    : Data_Handling, I_O, CDS, FITS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, 27 September 1993
;               
; Modified    : To fix naming of obs_date parameter, CDP, 14-May-94
;		SVHH, 24 May 94  Fixed types for all tags
;
; Version     : Version 3, 24-May-94
;-            


FUNCTION Cal_Hdrread,hdr
  
  return,{CALHDR,				  $
	  filename: trim(fxpar(hdr,"FILENAME")),  $
	  date :    trim(fxpar(hdr,"DATE")),	  $
	  origin:   trim(fxpar(hdr,"ORIGIN")),	  $
	  telescop: trim(fxpar(hdr,"TELESCOP")),  $
	  instrume: trim(fxpar(hdr,"INSTRUME")),  $
	  detector: trim(fxpar(hdr,"DETECTOR")),  $
						  $
	  prog_id:  long(fxpar(hdr,"PROG_ID")),	  $
	  prog_num: long(fxpar(hdr,"PROG_NUM")),  $
	  seq_ind:  long(fxpar(hdr,"SEQ_IND")),	  $
  $;	  date_obs: fxpar(hdr,"DATE_OBS"),	$
	  date_obs: trim(fxpar(hdr,"OBS_DATE")),  $
	  datacomp: long(fxpar(hdr,"DATACOMP")),  $
	  comp_opt: long(fxpar(hdr,"COMP_OPT")),  $
	  wndw_id:  long(fxpar(hdr,"WNDW_ID")),	  $
	  ser_id:   long(fxpar(hdr,"SER_ID")),	  $
	  expcount: long(fxpar(hdr,"EXPCOUNT")),  $
	  exptime:  double(fxpar(hdr,"EXPTIME")), $
	  opslbits: trim(fxpar(hdr,"OPSLBITS")),  $
	  ops_l:    trim(fxpar(hdr,"OPS_L")),	  $
	  opsrbits: trim(fxpar(hdr,"OPSRBITS")),  $
	  ops_r:    trim(fxpar(hdr,"OPS_R")),	  $
	  slitbits: trim(fxpar(hdr,"SLITBITS")),  $
	  slit_pos: long(fxpar(hdr,"SLIT_POS")),  $
	  slit_num: long(fxpar(hdr,"SLIT_NUM")),  $
	  mir_pos:  long(fxpar(hdr,"MIR_POS")),	  $
	  nwindows: long(fxpar(hdr,"NWINDOWS")),  $
	  sciprst:  trim(fxpar(hdr,"SCIPRST")),	  $
	  ev_enab:  trim(fxpar(hdr,"EV_ENAB")),	  $  ; Don't know about this ?
	  comp_err: trim(fxpar(hdr,"COMP_ERR")),  $  ; Or this
	  vds_htr:  trim(fxpar(hdr,"VDS_HTR")),	  $  ; ..etcetera
	  vds_ori:  trim(fxpar(hdr,"VDS_ORI")),	  $  ;
	  vds_acc:  trim(fxpar(hdr,"VDS_ACC")),	  $  ;
	  vds_mode: trim(fxpar(hdr,"VDS_MODE")),  $  ;
	  vdsbinx:  long(fxpar(hdr,"VDSBINX")),	  $
	  vdsbiny:  long(fxpar(hdr,"VDSBINY")),	  $
	  gas_id:   trim(fxpar(hdr,"GAS_ID")),	  $
	  gas_volt: double(fxpar(hdr,"GAS_VOLT")),$
	  gas_curr: double(fxpar(hdr,"GAS_CURR")),$
	  gas_pres: double(fxpar(hdr,"GAS_PRES")),$
	  obs_seq:  long(fxpar(hdr,"OBS_SEQ")),	  $
	  seq_num:  long(fxpar(hdr,"SEQ_NUM")),	  $
	  seqvalid: fix(fxpar(hdr,"SEQVALID")),	  $
	  obs_mode: trim(fxpar(hdr,"OBS_MODE")),  $
	  linelist: trim(fxpar(hdr,"LINELIST")),  $
	  sci_obj:  trim(fxpar(hdr,"SCI_OBJ")),	  $
	  cmp_name: trim(fxpar(hdr,"CMP_NAME")),  $
	  cmp_no:   long(fxpar(hdr,"CMP_NO")),	  $
	  object:   trim(fxpar(hdr,"OBJECT")),	  $
	  obj_id:   trim(fxpar(hdr,"OBJ_ID")),	  $
	  date_end: trim(fxpar(hdr,"DATE_END")),  $
	  ycen:	double(fxpar(hdr,"YCEN")),	  $
	  zcen:	double(fxpar(hdr,"ZCEN")),	  $
	  angle: double(fxpar(hdr,"ANGLE")),	  $
	  width: double(fxpar(hdr,"WIDTH")),	  $
	  height: double(fxpar(hdr,"HEIGHT")),	  $
	  wavemin: double(fxpar(hdr,"WAVEMIN")),  $
	  wavemax: double(fxpar(hdr,"WAVEMAX")),  $
	  sc_y0: double(fxpar(hdr,"SC_Y0")),	  $
	  sc_z0: double(fxpar(hdr,"SC_Z0")),	  $
	  extname : trim(fxpar(hdr,"EXTNAME")),	  $
	  sc_roll: double(fxpar(hdr,"SC_ROLL"))	}
END
