;+
; Project     : SOHO - CDS     
;                   
; Name        : CAL_MKAUXDESC()
;               
; Purpose     : Return auxiliary data descriptor of correct type.
;               
; Explanation : Based the dimenstionality of the data in DATA the correct
;		type of auxiliary data descriptor is returned,
;		with the descriptor values from DATA copied
;		into the new structure.
;
; Use         : AUXDESCRIPTOR = CAL_MKAUXDESC(DATA)
;    
; Inputs      : DATA	 = a structure variable of the form that 
;			   is returned by READ_CDS
;               
; Opt. Inputs : None.
;               
; Outputs     : IDL auxiliary data descriptor, see CDS QL Data Format.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : EXECUTE
;
; Common      : None.
;               
; Restrictions: DATA must adhere to the format returned by READ_CDS
;		Normally used by AUXREAD()
;               
; Side effects: None.
;               
; Category    : Data_Handling, I_O, FITS, CDS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Haugan, 27 September 1993
;               
; Modified    : 
;
; Version     : 1.0
;-            
;
FUNCTION Cal_Mkauxdesc,column
  Ndims	= N_elements(column.axes)
  res =	0
  exestr =$
	  "res = {AUX"+trim(Ndims)+',' +  $
	  "Label	:column.Label,"+ $
	  "units	:column.units,"+ $
	  "missing:column.missing,"+	  $
	  "axes	:[column.axes],"+ $ ; We want these to be
	  "origin	:[column.origin],"+	  $ ; arrays always
	  "spacing:[column.spacing],"+	  $
	  "rotation:[column.rotation] }"
  dummy	= execute(exestr)
  return,res
END

