;+
; Project     : SOHO - CDS     
;                   
; Name        : CAL_MKDETWDESC()
;               
; Purpose     : Return detector data descriptor of correct type.
;               
; Explanation : Based on DETECTOR (= 'NIS'/'GIS') and the
;		dimenstionality of the data in DATA the correct
;		type of detector data descriptor is returned,
;		with the descriptor values from DATA copied
;		into the new structure.
;
; Use         : DETDESCRIPTOR = CAL_MKDETWDESC(DETECTOR,DATA,NDIMS)
;    
; Inputs      : DETECTOR = 'NIS' / 'GIS'
;		DATA	 = a structure variable of the form that 
;			   is returned by READ_CDS
;               NDIMS    = Number of dimensions in the data
; Opt. Inputs : None.
;               
; Outputs     : IDL detector data descriptor, see CDS QL Data Format.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : EXECUTE(), TRIM()
;
; Common      : None.
;               
; Restrictions: DATA must adhere to the format returned by READ_CDS
;		Normally used by DETREAD()
;               
; Side effects: None.
;               
; Category    : Data_Handling, I_O, FITS, CDS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Haugan, 27 September 1993
;               
; Modified    : SVHH, 21 October 1993
;			Added Max/Min tags (for use by display routines)
;		SVHH,  3 November 1993
;			Fixed bugs concerning GIS data (TDETY)
;		SVHH,  Version 1.2, 27 May 1994
;
; Version     : 1.2, 27 May 1994
;-            

FUNCTION Cal_Mkdetwdesc,detector,Data,Ndims
  
  res =	0
  
  exestr =$
	  "res = {C"+trim(detector)$
		       +trim(Ndims)+","	+ $
	  "ixstart :intarr(Ndims)," +	  $	  ; Indexes to detector block
	  "ixstop  :intarr(Ndims)," +	  $
	  "Label	 :Data.Label,"	+ $	  ; Copying from orig.
	  "Units	 :Data.Units,"	+ $
	  "Max     :float(max(Data.Array))," +	  $
	  "Min	 :float(min(Data.Array))," +	  $
	  "Missing : 0L,"+		  $	  ;Data.Missing,"
	  "Axes	 :[Data.Axes],"	+ $
	  "Origin	 :fltarr(Ndims)," +	  $ ; NB
	  "Spacing :fltarr(Ndims)+1.," +  $ ; NB
	  "Rotation:fltarr(Ndims),"+	  $ ; NB
	  "DetX	 :Data.DetX,"		    ; NB
  
  IF trim(detector) eq 'NIS' THEN exestr = exestr+"DetY	 :Data.DetY,"
  
  exestr = exestr + $
	  "Wavelength:0.0,"+$
	  "Wavemin   :0.0," +	  $
	  "Wavemax   :0.0 }"
  dummy	= execute(exestr)
  return,res
END
