;+
; Project     : SOHO - CDS     
;                   
; Name        : CAL_STORE_WND
;               
; Purpose     : Store data from read_cds into a CDS QLDS
;               
; Explanation : Stores detector data from Data.Array into:
;
; 			Det.DetData(currentix:stopix 
;					[,0:size_dimension_2 
;					[,0:size_dimension_3]] )
;
; 		The number of indexes depends on the dimensionality of the 
;		data.
;
;		- Updates CurrentIx to point to the next free index.
;
; 		- Stores indexes (to Det.DetData) for this data window into
; 		Det.DetDesc(WndNo).ixstart/ixstop
;               
; Use         : CAL_STORE_WND,WINDOW_NO,CURRENT_INDEX,DET,DATA
;    
; Inputs      : WINDOW_NO : 
;			The index (into DET.DETDESC) of the
;			detector data window in question.
;               
;		CURRENT_INDEX: 
;			The index (into DET.DETDATA's first dimension) of
;			where a block of detector data may be placed.
;
;		DET :	An IDL structure containing the tags DetDesc and
;			DetData, as described in the CDS QL Data Format.
;
;		DATA:	An IDL structure returned from READ_CDS after
;			a successful read of detector data.
;
; Opt. Inputs : None.
;               
; Outputs     : CURRENT_INDEX:
;			is updated to point to the room after
;			the current block of data in DET.DETDATA
;               
;		DET.DETDATA: The data from DATA.ARRAY i stored here.
;
;		DET.DETDESC.IXSTART,
;		DET.DETDESC.IXSTOP: 
;			Indexes into DET.DETDATA for the current detector
;			data window.
;
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : SIZE
;
; Common      : None.
;               
; Restrictions: See the data formats.
;               
; Side effects: None.
;               
; Category    : Data_Handling, CDS, QuickLook, Internal
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, 27 September 1993
;               
; Modified    : 
;
; Version     : 1.0
;-            
;

PRO cal_store_wnd,WndNo,CurrentIx,Det,Data
  On_Error,0
;
; Find dimensionality and stop indexes.
;
  Dims = Size(Data.Array)
  
  StopIx = CurrentIx + N_elements(Data.Array(*,0))-1
  
  CASE Dims(0) OF
      1	: BEGIN
	  Det.DetData(CurrentIx:StopIx)	= Data.Array(*)
	  ixstart=[CurrentIx] &	ixstop=[StopIx]
      END
      2	: BEGIN
	  Det.DetData(CurrentIx:StopIx,0:Dims(2)-1) = Data.Array
	  ixstart=[CurrentIx,0]	& ixstop=[StopIx,Dims(2)-1]
      END
      3	: BEGIN
	  Det.DetData(CurrentIx:StopIx,$
			  0:Dims(2)-1,0:Dims(3)-1) = Data.Array
	  ixstart=[CurrentIx,0,0] & ixstop=[StopIx,Dims(2)-1,Dims(3)-1]
      END
  EndCASE
  
  Det.DetDesc(WndNo).ixstart = ixstart	  ; Store indexes
  Det.DetDesc(WndNo).ixstop = ixstop
  
  CurrentIx=StopIx+1			  ; Update current index.
  
END
