	PRO CLOSE_CALFITS
;+
; Project     :	SOHO - CDS
;
; Name        :	CLOSE_CALFITS
;
; Purpose     :	Closes a FITS calibration file which is open for write.
;
; Explanation :	This procedure closes a FITS calibration whose structure was
;		defined by OPEN_CALFITS, and written by WRITE_CALFITS.
;
; Use         :	CLOSE_CALFITS
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	None.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	
;
; Common      :	CALFITS_COMMON contains data common to the routines
;		OPEN_CALFITS, WRITE_CALFITS, and CLOSE_CALFITS.  The definition
;		of this common block is in the file "calfits.cmn".
;
; Restrictions:	The routines OPEN_CALFITS and WRITE_CALFITS must already have
;		been called.
;
; Side effects:	None.
;
; Category    :	Data_handling, I/O, FITS, CDS, Calibration.
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 19 November 1993.
;
; Modified    :	Added /CONTINUE to message command, CDP, 21-Feb-94
;
; Version     :	Version 2.  21-Feb-94
;-
;
	ON_ERROR, 2
@calfits.cmn
;
;  Make sure the file has been opened and written to first.
;
	IF NOT KEYWORD_SET(ALREADY_OPEN) THEN MESSAGE,$
               'File has not been opened.',/CONTINUE
;
;  Close the file, and reset the parameters DEFINED and ALREADY_OPEN.
;
	FXBFINISH, UNIT
	DEFINED = 0
	ALREADY_OPEN = 0
;
	RETURN
	END
