;+
; Project     : SOHO-CDS
;
; Name        : MK_CDS_FITS
;
; Purpose     : make simple CDS FITS files
;
; Category    : data analysis
;
; Explanation : 
;
; Syntax      : MK_CDS_FITS,FSTART,FEND
;
; Examples    :
;
; Inputs      : FSTART,FEND = start/end FITS file numbers
;
; Opt. Inputs : None
;
;
; Outputs     : None
;
; Opt. Outputs: None
;
; Keywords    : CALIB = set to FlatField
;             : CLEAN = set to remove spikes
;             : BYTE  = set to BYTE scale
;
; Common      : None
;
; Restrictions: None
;
; Side effects: None
;
; History     : Written 22 October 1996, D. Zarro, ARC/GSFC
;
; Contact     : dzarro@solar.stanford.edu
;-

pro mk_cds_fits,fstart,fend,calib=calib,clean=clean,byte_scale=byte_scale

if not exist(fstart) then begin
 message,'Syntax: mk_cds_fits,fstart,fend',/cont
 return
endif

if not exist(fend) then fend=fstart
for i=long(fstart),long(fend) do begin
 list_exper,i,rasters,nfound
 if nfound gt 0 then begin
  for j=0,nfound-1 do begin
   ifile=trim(rasters(j).filename)
   file=find_with_def(ifile,'CDS_FITS_DATA')
   if trim(file) ne '' then begin
    message,'reading '+ifile,/cont
    ql=readcdsfits(ifile)
    qlmgr,ql,valid 
    if valid then begin
     upd_cds_point,ql
     err=''
     if keyword_set(calib) then vds_calib,ql,err=err
     if err eq '' then cds_simple_fits,ql,clean=clean,byte_scale=byte_scale
    endif
   endif
  endfor
 endif
endfor

return & end


