;+
; Project     : SOHO - CDS     
;                   
; Name        : MKDETWDESC()
;               
; Purpose     : Return detector data descriptor of correct type.
;               
; Explanation : Based on DETECTOR (= 'NIS'/'GIS') and the dimensionality of
;               the data in DATA the correct type of detector data descriptor
;               is returned, with the descriptor values from DATA copied into
;               the new structure.
;
; Use         : DETDESCRIPTOR = MKDETWDESC(DETECTOR,DATA)
;    
; Inputs      : DETECTOR = 'NIS' / 'GIS'
;               DATA     = a structure variable of the form that 
;                          is returned by READ_CDS
;               
; Opt. Inputs : None.
;               
; Outputs     : IDL detector data descriptor, see CDS QL Data Format.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : EXECUTE(), TRIM()
;
; Common      : None.
;               
; Restrictions: DATA must adhere to the format returned by READ_CDS
;               Normally used by DETREAD()
;               
; Side effects: None.
;               
; Category    : Data_Handling, I_O, FITS, CDS, QuickLook
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Haugan, 27 September 1993
;               
; Modified    : SVHH, 21 October 1993
;                       Added Max/Min tags (for use by display routines)
;               SVHH,  3 November 1993
;                       Fixed bugs concerning GIS data (TDETY)
;               SVHH,  Version 1.2, 8-June-1994
;               SVHH,  25 August 1994,
;                       Fixed another bug concerning GIS/TDETY etc..
;                       (DetY : Data.Detx)
;               PB,    26 August 1994,
;                       Changed DetZ --> DetY
;                               DetY --> DetX
;               SVHH, 21-Aug-1995, Version 2
;                       Added BinX/BinY tags.
;               Version 3, SVHH, 12 August 1996
;                       Compatible with both old and new data storage system.
;                       (Added tag HANDLE added an X in struct name).
;               Version 4, 24 September 1996
;                       Added PADDING tag.
;               Versiom 5, 7 April 1997
;                       Made MISSING tag FLOAT for GIS data.
;                       
; Version     : 5, 7 April 1997
;-            

FUNCTION MkDetWdesc,detector,Data,Ndims
  
  res =	0
  
  tags = ["HANDLE", "IXSTART", "IXSTOP", "PADDING", "LABEL", "UNITS",$
          "MAX", "MIN", "MISSING", "AXES", "ORIGIN", "SPACING",$
          "ROTATION", "DETX", "BINX"]
  
  IF trim(detector) EQ 'NIS' THEN tags = [ tags, "DETY", "BINY" ]
  
  tags = [tags, "WAVELENGTH", "WAVEMIN", "WAVEMAX", "WAVEBAND","GR_ORDER"]
  
  mx = 0.0
  mi = 0.0
  
  IF trim(detector) EQ 'NIS' THEN res = $
     create_struct(name=trim(detector)+'X'+trim(Ndims), TAGS,$
                   -1L,$
                   intarr(Ndims),$       ;;; IXSTART
                   intarr(Ndims)-1,$     ;;; IXSTOP
                   intarr(Ndims),$       ;;; PADDING
                   data.label,$
                   data.units, $ 
                   mx, $
                   mi, $
                   FLOAT(data.missing),$
                   [data.axes],$
                   [data.origin],$
                   [data.spacing],$
                   [data.rotation],$
                   data.detx,$
                   data.binx,$
                   data.dety,$
                   data.biny,$
                   data.wavelength,$
                   data.wavemin,$
                   data.wavemax,$
                   data.waveband,$
                   data.gr_order) $
  ELSE res = $
     create_struct(name=trim(detector)+'XX'+trim(Ndims), TAGS,$
                   -1L,$
                   intarr(Ndims),$
                   intarr(Ndims),$
                   intarr(Ndims),$
                   data.label,$
                   data.units, $
                   mx, $
                   mi, $
                   float(data.missing),$
                   [data.axes],$
                   [data.origin],$
                   [data.spacing],$
                   [data.rotation],$
                   data.detx,$
                   data.binx,$
;                   data.dety,$
;                   data.biny,$
                   data.wavelength,$
                   data.wavemin,$
                   data.wavemax,$
                   data.waveband,$
                   data.gr_order)
  return,res
END




