;+
; Project     : SOHO - CDS     
;                   
; Name        : PR_CAL_HDR
;               
; Purpose     : Easy print of FITS file header.
;               
; Explanation : FITS file header is read and printed out.
;               
; Use         : IDL> pr_cal_hdr, file [,/hard]
;    
; Inputs      : file  - FITS file name  (assumes current directory)
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : hard  - if present sent to a file and print it.
;
; Calls       : FXHREAD
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Data_handling, FITS, i_o
;               
; Prev. Hist. : None
;
; Written     : CDP,  RAL, 4-Mar-94
;               
; Modified    : 
;
; Version     : Version 1, 4-Mar-94
;-            

pro pr_cal_hdr, file, hard=hard

;
;  open file
;
openr, lun, file, /get_lun

;
;  read main header
;
fxhread, lun, head

;
;  print in neat format
;
hprint, head

;
;  free file
;
free_lun, lun

;
;  hard copy?
;
if keyword_set(hard) then begin
   openw,lun,file+'.hdr',/get_lun
   printf, lun, ' '
   printf, lun,'  ###############  FITS file '+file+'  ################'
   printf, lun, ' '
   printf, lun, ' '
   printf, lun, ' '
   n = n_elements(head)
   for i = 0,n-1 do begin
      printf, lun, strtrim( head(i) )               
   endfor
   free_lun, lun
   spawn,'lpr '+file+'.hdr'
   print,' '
   print,'Hard copy now on printer queue.'
   print,' '
endif

end
