;+
; Project     : SOHO - CDS
;
; Name        : VALID_QL
;
; Purpose     : checks if CDS QL structure is valid
;
; Category    : CDS planning
;
; Syntax      : IDL> valid=valid_ql(ql)
;
; Inputs      : QL = CDS QL data structure 
;
; Outputs     : VALID = 1/0 if valid/invalid
;
; Keywords    : STORAGE = 1/0 if using new/old storage scheme
;               DELETE = set to delete QL if invalid
;
; History     : 9-Nov-1999,  D.M. Zarro.  Written
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-


function valid_ql,ql,storage=storage,delete=delete

if datatype(ql) ne 'STC' then return,0b
if not have_tag(ql,'ql_id') then return,0b
if not have_tag(ql,'ql_no') then return,0b

if have_tag(ql,'detdata') then storage=0b else storage=1b

if storage then begin
 handles=get_tag_value(ql,/handle,/quiet,err=err)
 if err then return,0b
 hcheck=valid_pointer(handles)
 if min(hcheck) eq 0b then begin
  if keyword_set(delete) then delete_qlds,ql
  return,0b
 endif
endif

return,1b
end
