;+
; Project     : SOHO - CDS     
;                   
; Name        : COPY_QLDS()
;               
; Purpose     : Make a copy of a QLDS, including data windows.
;               
; Explanation : With the new storage system in the Quick Look Data Structures,
;               simply copying the QLDS (as in "b = a") does not copy the data
;               itself, since data is stored by means of handles. This
;               function returns a copy of a QLDS, with new handles pointing
;               to copies of the original data.
;               
; Use         : B = COPY_QLDS(QLDS)
;    
; Inputs      : QLDS : CDS Quick Look Data Structure.
;               
; Opt. Inputs : None.
;               
; Outputs     : Returns a copy of the QLDS.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : gt_windata(), tag_exist(), qlmgr
;
; Common      : None.
;               
; Restrictions: None.
;               
; Side effects: None.
;               
; Category    : QuickLook, Data_handling, SOHO, CDS.
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar Hagfors Haugan, UiO, 9 October 1996
;               
; Modified    : Never.
;
; Version     : 1, 9 October 1996
;-            


FUNCTION copy_qlds,qlds
  
  
  result = qlds
  
  IF NOT tag_exist(qlds,"DETDATA") THEN BEGIN
     
     FOR i = 0,N_ELEMENTS(qlds.detdesc)-1 DO BEGIN
        IF qlds.detdesc(i).ixstop(0) GE 0 THEN BEGIN
           da = gt_windata(qlds,i)
           result.detdesc(i).handle = handle_create(value=da,/no_copy)
        END
     END
  END
  
  result.ql_id = 0 ;; To get a new QL_NO.
  qlmgr,result
  
  RETURN,result
END


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; End of 'copy_qlds.pro'.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
