;+
; Project     : SOHO - CDS     
;                   
; Name        : DELETE_QLDS
;               
; Purpose     : Delete a QLDS and free handles.
;               
; Explanation : With the new storage system using handles, deleting a QLDS
;               does not free all its storage space. This routine goes through
;               the QLDS to free all the storage space, and then deletes the
;               QLDS itself.
;               
; Use         : DELETE_QLDS,QLDS
;    
; Inputs      : QLDS : Quick Look Data Structure
;               
; Opt. Inputs : None.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : delvarx handle_info() qlmgr tag_exist()
;
; Common      : None.
;               
; Restrictions: None.
;               
; Side effects: None known.
;               
; Category    : Data_Handling, QuickLook.
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar H. Haugan, UiO, 3 October 1996
;               
; Modified    : Not yet.
;
; Version     : 1, 3 October 1996
;-            

PRO delete_qlds,qlds
  on_error,2
  
  qlmgr,qlds,valid
  IF NOT valid THEN BEGIN
     message,"QLDS is not valid -- variable not deleted",/continue
     return
  END
  
  IF NOT tag_exist(qlds,"DETDATA") THEN BEGIN 
     
     FOR i = 0,N_elements(qlds.detdesc)-1 DO BEGIN
        handle = qlds.detdesc(i).handle
        IF handle_info(handle,/valid) THEN handle_free,handle
     END
  END
  
  delvarx,qlds
END

     
  
