;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_BINX()
;               
; Purpose     : Return detector X binning factor for a QLDS.
;               
; Explanation : Uses the information in the QLDS to find the BINX
;               value.
;               
; Use         : BINX = GT_BINX(QLDS)
;    
; Inputs      : QLDS: Quick Look Data Structure.
;
; Opt. Inputs : None.
;               
; Outputs     : Returns the binning factor.
;               
; Opt. Outputs: None.
;               
; Keywords    : NOPARCHECK: Set to avoid call to QLMGR.
;
; Calls       : QLMGR
;
; Common      : None.
;               
; Restrictions: 
;               
; Side effects: None.
;               
; Category    : GET
;               
; Prev. Hist. : None.
;
; Written     : SVH Haugan, UiO, 30-October-1995
;               
; Modified    : 
;
; Version     : 1.0, 30-October-1995
;-            

FUNCTION gt_binx,qlds,nocheck=nocheck
  
  ON_ERROR,2
  IF !debug GT 0 THEN ON_ERROR,0
  
  IF N_PARAMS() lt 1 THEN  $
     MESSAGE,"Use: BINX = GT_BINX(QLDS)"
  
  IF NOT KEYWORD_SET(nocheck) THEN begin
     qlmgr,qlds,valid
     IF NOT valid THEN  $
        MESSAGE,"Parameter must be a Quick Look Data Structure"
  ENDIF
  
  RETURN,qlds.detdesc(0).binx
END

