;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_DETECTOR
;               
; Purpose     : Returns the detector name ('NIS' or 'GIS')
;               
; Explanation : Information taken from the header.
;               
; Use         : detector = GT_DETECTOR(QLDS)
;    
; Inputs      : QLDS: Quick Look Data Structure
;               
; Opt. Inputs : None.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : NOCHECK: Set to avoid call to QLMGR
;
; Calls       : QLMGR
;
; Common      : None.
;               
; Restrictions: QLDS - later on it may also be a file spec.
;               
; Side effects: None.
;               
; Category    : GET routine
;               
; Prev. Hist. : None.
;
; Written     : 4-Sept-1995, Stein Vidar Hagfors Haugan
;               
; Modified    : SVHH, Version 2, 30-October-1995
;                     Added /NOCHECK keyword and on_error handling.
;
; Version     : 2, 30-October-1995
;-            

FUNCTION GT_DETECTOR,QLDS,nocheck=nocheck
  
  ON_ERROR,2
  IF !debug GT 0 THEN ON_ERROR,0
  
  IF NOT KEYWORD_SET(nocheck) THEN begin
     QLMGR,QLDS,valid
     IF NOT valid THEN  $
        MESSAGE,"Parameter must be a valid Quick Look Data Structure"
  END
  RETURN,QLDS.HEADER.detector
  
END
