;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_EXPTIME()
;               
; Purpose     : To retrieve the exposure time from a file or data structure.
;               
; Explanation : Depending on the nature of the input parameter (structure or
;               file name) the routine extracts and returns the exposure
;               time used in the raster.
;               
; Use         : IDL> s = gt_exptime(file_str)
;    
; Inputs      : file_str   -  either:-   the name of a CDS FITS file
;                                 or:-   the name of a CDS data structure
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns the exposure time (secs) used.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : FX... routines
;
; Common      : None
;               
; Restrictions: Factor of 100 fudge for calibration files.
;               
; Side effects: None
;               
; Category    : Data_handling, FITS
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 24-May-94
;               
; Modified    : To allow standard FITS directory, CDP, 25-May-94
;               To assume header value is now in seconds.  CDP, 10-Jul-95
;
; Version     : Version 3, 10-Jul-95
;-            

function gt_exptime, input

;
;  need at least one parameter
;
if n_params() eq 0 then begin
   print,'USE:   IDL> t = get_exptime(file_or_structure)
   return,0
endif

;
;  what was the input?
;
case datatype(input,1) of
   'Structure': begin
                   qlmgr, input, valid
                   if valid then begin
                      return,input.header.exptime
                   endif
                   print,'GT_EXPTIME: Structure supplied is non-standard'
                   return,0
                end
;
;  allow user to have own version of FITS files
;
      'String': begin
                   tfile = ''
                   if  file_exist(input) then begin
                      tfile = input
                   endif else begin
                     if file_exist(concat_dir('$CDS_CAL_FITS',input)) then begin
                        tfile = concat_dir('$CDS_CAL_FITS',input)
                     endif
                   endelse

;
;  FITS file doesn't exist in user or std directory
;
                   if tfile eq '' then begin
                      print,'GT_EXPTIME:  Input file does not exist.'
                      return,0
                   endif

                   fxbopen,unit,tfile,1,header
                   fxbclose,unit
                   return,fxpar(header,'EXPTIME')
                end
          else: begin
                   print,'Input must be a file name or a CDS data structure.'
                   return,0
                end
endcase

end
