;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_HDR()
;               
; Purpose     : Return value of FITS header parameter for a given QLDS
;               
; Explanation : Most header parameter values are accessible as tags under the
;               HEADER tag of the QLDS. In order to provide an alternative way
;               of reaching these values, it is possible to use GT_HDR to read
;               directly from the header text array, stored as a text array
;               in the tag HDRTEXT of the QLDS.1
;               
; Use         : result = gt_hdr(QLDS,PARAMETER)
;    
; Inputs      : QLDS: Quick Look Data Structure.
;
;               PARAMETER: Text containing the name of the FITS parameter
;                          to be read.
;               
; Opt. Inputs : None.
;               
; Outputs     : Returns FXPAR(QLDS.HDRTEXT,strPARAMETER)
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : FXPAR()
;
; Common      : None.
;               
; Restrictions: None.
;               
; Side effects: None.
;               
; Category    : GET
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar H. Haugan, UiO, 22-February-1996
;               
; Modified    : Never.
;
; Version     : 1, 22-February-1996
;-            

FUNCTION gt_hdr,qlds,parameter
  
  IF N_PARAMS() NE 2 THEN $
     MESSAGE,"Use: GT_HDR(QLDS,PARAMETER)"
  
  qlmgr,qlds,valid
  IF NOT valid THEN $
     MESSAGE,"First parameter is not a QLDS"

  parcheck,parameter,2,typ(/STR),0,'PARAMETER NAME'
  
  RETURN,fxpar(qlds.hdrtext,parameter)
END

