	PRO GT_NIS_ALIGNMENT, QLDS, XOFFSET, YOFFSET
;+
; Project     :	SOHO - CDS
;
; Name        :	GT_NIS_ALIGNMENT
;
; Purpose     :	Retrieve the NIS-1 to NIS-2 alignment offsets
;
; Category    :	Class3, Calibration
;
; Explanation :	Returns the NIS-1 to NIS-2 alignment offsets.
;
; Syntax      :	GT_NIS_ALIGNMENT, QLDS, XOFFSET, YOFFSET
;
; Examples    :	
;
; Inputs      :	QLDS	= A CDS quicklook data structure, from READCDSFITS.
;
; Opt. Inputs :	None.
;
; Outputs     :	XOFFSET, YOFFSET = The offsets of NIS-1 relative to NIS-2 in
;				   arcseconds.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Prev. Hist. :	Previously part of GT_SOLAR_XY
;
; History     :	Version 1, 30-Aug-2000, William Thompson
;               Version 2, 22-Aug-2003, William Thompson
;                       Use INS_X0,INS_Y0 instead of XCEN,YCEN
;                       Handle case when spacecraft is upside-down
;
; Contact     :	WTHOMPSON
;-
;
	IF QLDS.HEADER.DATE_OBS GT '1998-10-01' THEN BEGIN
		XOFFSET = - 0.52655029	$
			+ 0.0019413322  * QLDS.HEADER.INS_X0	$
			- 0.00017792189 * QLDS.HEADER.INS_Y0
		YOFFSET = + 8.7163046	$
			- 0.0011548530  * QLDS.HEADER.INS_X0	$
			+ 0.0036838701  * QLDS.HEADER.INS_Y0
	END ELSE BEGIN
		XOFFSET = - POLY(QLDS.HEADER.INS_X0,	$
			[1.09991,-0.000429890,6.33893E-7,-1.54685E-9])
		YOFFSET = - POLY(QLDS.HEADER.INS_Y0,	$
			[-1.62205,-0.00417618,1.29536E-6,4.74291E-9])
	ENDELSE
;
;  If the spacecraft is upside-down, then reverse the offsets.
;
        IF QLDS.DETDESC(0).SPACING(1) LT 0 THEN BEGIN
            XOFFSET = -XOFFSET
            YOFFSET = -YOFFSET
        ENDIF
;
	END
