;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_NUMEXP()
;               
; Purpose     : Get the number of exposures from a file or data structure.
;               
; Explanation : Depending on the nature of the input parameter (structure or
;               file name) the routine extracts and returns the number
;               of exposures in the raster.
;               
; Use         : IDL> s = gt_numexp(file_str)
;    
; Inputs      : file_str   -  either:-   the name of a CDS FITS file
;                                 or:-   the name of a CDS data structure
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns the number of exposures used.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : FX... routines
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Data_handling, FITS
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 25-May-94
;               
; Modified    : 
;
; Version     : Version 1, 25-May-94
;-            

function gt_numexp, input

;
;  need at least one parameter
;
if n_params() eq 0 then begin
   print,'USE:   IDL> s = get_numexp(file_or_structure)
   return,0
endif

;
;  what was the input?
;
case datatype(input,1) of
   'Structure': begin
                   qlmgr,input,valid
                   if valid then return,input.header.expcount
                   print,'GT_NUMEXP: Structure supplied is non-standard'
                   return,0
                end
;
;  allow user to have own version of FITS files
;
      'String': begin
                   tfile = ''
                   if  file_exist(input) then begin
                      tfile = input
                   endif else begin
                     if file_exist(concat_dir('$CDS_CAL_FITS',input)) then begin
                        tfile = concat_dir('$CDS_CAL_FITS',input)
                     endif
                   endelse
;
;  FITS file doesn't exist in user or std directory
;
                   if tfile eq '' then begin
                      print,'GT_NUMEXP:  Input file does not exist.'
                      return,0
                   endif

                   fxbopen,unit,tfile,1,header
                   fxbclose,unit
                   return,fxpar(header,'EXPCOUNT')
                end
          else: begin
                   print,'Input must be a file name or a CDS data structure.'
                   return,0
                end
endcase

end
