;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_NUMWIN()
;               
; Purpose     : Get the number of windows from a file or data structure.
;               
; Explanation : Depending on the nature of the input parameter (structure or
;               file name) the routine extracts and returns the number
;               of windows in the raster.
;               
; Use         : IDL> s = gt_numwin(file_str)
;    
; Inputs      : file_str   -  either:-   the name of a CDS FITS file
;                                 or:-   the name of a CDS data structure
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns the number of windows used.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : FX... routines
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Data_handling, FITS
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 3-Jun-94
;               
; Modified    : Update to new file reading routines.  CDP, 14-Jun-94
;               Insert cal/ops test.  CDP, 15-Jun-94
;
; Version     : Version 3, 15-Jun-94
;-            

function gt_numwin, input

;
;  need at least one parameter
;
if n_params() eq 0 then begin
   print,'USE:   IDL> s = get_numwin(file_or_structure)
   return,0
endif

;
;  what was the input?
;
case datatype(input,1) of
   'Structure': begin
                   qlmgr,input,valid
                   if valid then return,n_elements(input.detdesc)
                   print,'GT_NUMWIN: Structure supplied is non-standard'
                   return,0
                end
;
;  allow user to have own version of FITS files
;
      'String': begin
                   tfile = ''
                   if  file_exist(input) then begin
                      tfile = input
                   endif else begin
                     if file_exist(concat_dir('$CDS_CAL_FITS',input)) then begin
                        tfile = concat_dir('$CDS_CAL_FITS',input)
                     endif
                   endelse
;
;  FITS file doesn't exist in user or std directory
;
                   if tfile eq '' then begin
                      print,'GT_NUMWIN:  Input file does not exist.'
                      return,0
                   endif

                   fxbopen,unit,tfile,1,header,errmsg=status
                   if n_elements(status) gt 0 then if status ne '' then return,0
                   status = ''
                   if fxpar(header,'TELESCOP') eq 'CALIBRATION' then begin
                      wd = cal_detselect(unit, header, /header, status=status)
                      cal_detread,unit,header,wd,wd,status=status
                   endif else begin
                      wd = detselect(unit, header, /header, status=status)
                      detread,unit,header,wd,wd,status=status
                   endelse
                   if n_elements(status) gt 0 then begin
                      if status ne '' then begin
                         print,'Error reading definitions in FITS file.'
                         fxbclose,unit
                         return,0
                      endif
                   endif
                   fxbclose,unit
                   return,n_elements(wd.detdesc)
                end
          else: begin
                   print,'Input must be a file name or a CDS data structure.'
                   return,0
                end
endcase

end

