;+
; Project     : SOHO - CDS     
;                   
; Name        : GT_POINT()
;               
; Purpose     : Gets the pointing from a data structure.
;               
; Explanation : Depending on the nature of the input parameter (structure or
;               file name) the routine extracts and returns the pointing
;               used in the raster.
;               
; Use         : IDL> s = gt_point(qlds_str [,/ops])
;    
; Inputs      : qlds_str   -  the name of a CDS data structure
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns the pointing in either OPS or Solar terms
;               
; Opt. Outputs: None
;               
; Keywords    : OPS  -  return pointing for in OPS L/R coordinates, otherwise
;                       in Solar X/Y arcsecs.
;
; Calls       : FX... routines
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Data_handling, FITS
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 2-May-96
;               
; Modified    : 
;
; Version     : Version 1, 2-May-1996
;-            

function gt_point, input, ops=ops

;
;  need at least one parameter
;
if n_params() eq 0 then begin
   print,'USE:   IDL> point = gt_point(file_or_structure)
   return,0
endif

;
;  what was the input?
;
if datatype(input,1) eq 'Structure' then begin
   qlmgr, input, valid
   if valid then begin
      sx = input.header.xcen
      sy = input.header.ycen
      sl = input.header.ops_l
      sr = input.header.ops_r
   endif else begin
      print,'GT_POINT: Structure supplied is non-standard'
      return,0
   endelse
endif else begin   
   print,'Input must be a CDS data structure.'
   return,0
endelse
   
;
;  return with requested format
;
if keyword_set(ops) then return,[sl,sr] else return,[sx,sy]

end
