;+
; Project     : SOHO - CDS     
;                   
; Name        : ST_WINDATA
;               
; Purpose     : Putting back the data block for a detector window
;               
; Explanation : Stores the passed data array into the QLDS structure.
;               
; Use         : ST_WINDATA,QLDS,WINDOWI,DATA
;    
; Inputs      : QLDS : Quick Look Data Structure
;
;               WINDOWI : The window index
;
;               DATA : The data to be stored.
;               
; Opt. Inputs : None.
;               
; Outputs     : None.
;               
; Opt. Outputs: None.
;               
; Keywords    : NO_COPY : Set to user the /NO_COPY keyword when performing the
;                         handle_value,/set operation. Will make the DATA
;                         variable disappear.
;
; Calls       : None.
;
; Common      : None.
;               
; Restrictions: Of course, DATA should have the correct format.
;               
; Side effects: DATA becomes undefined when the /NO_COPY keyword is used.
;
;               This routine is mostly for internal use by CDS software, like
;               vds_calib and vds_debias.
;               
; Category    : Data_handling, Soho, CDS
;               
; Prev. Hist. : None.
;
; Written     : Stein Vidar H. Haugan, 9 August 1996
;               
; Modified    : Version 1, Stein Vidar H. Haugan, 9 August 1996
;		Version 2, 04-Dec-1998, William Thompson, GSFC
;			Added keyword NOPAD
;
; Version     : Version 2, 04-Dec-1998
;-            


PRO st_windata,qlds,windowi,data,no_copy=no_copy,nopad=nopad
  
  default,no_copy,0
  
  IF N_PARAMS() NE 3 THEN $
     MESSAGE,"Use : ST_WINDATA,QLDS,WINDOWI,DATA [,/NO_COPY]"
  
  parcheck,windowi,2,typ(/nat),0,'WINDOWI',minval=0, $
     maxval=N_ELEMENTS(qlds.detdesc)-1
  
  IF tag_exist(qlds,"DETDATA",/TOP_LEVEL) THEN BEGIN
     b = qlds.detdesc(windowi).ixstart
     e = qlds.detdesc(windowi).ixstop
     if keyword_set(nopad) then e = e - qlds.detdesc(windowi).padding
     CASE N_ELEMENTS(b) OF 
        1: qlds.detdata(b(0):e(0)) = data
        2: qlds.detdata(b(0):e(0),b(1):e(1)) = data
        3: qlds.detdata(b(0):e(0),b(1):e(1),b(2):e(2)) = data
        4: qlds.detdata(b(0):e(0),b(1):e(1),b(2):e(2),b(3):e(3)) = data
     END
  END ELSE BEGIN
     IF NOT handle_info(qlds.detdesc(windowi).handle,/valid_id) THEN BEGIN
        qlds.detdesc(windowi).handle = handle_create()
     END
     
     handle_value,qlds.detdesc(windowi).handle,data,/set,no_copy=no_copy
  END
END


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; End of 'st_windata.pro'.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
