;+
; Project     : SOHO - CDS     
;                   
; Name        : MKSUMWDESC()
;               
; Purpose     : Return detector data descriptor of correct type.
;               
; Explanation : SUMER version of CDS routine MkDetWinDesc.
;
;		Based on the dimenstionality of the data in DATA the correct
;		type of detector data descriptor is returned, with the
;		descriptor values from DATA copied into the new structure.
;
; Use         : DETDESCRIPTOR = MKSUMWDESC(DATA)
;    
; Inputs      : DATA	 = a structure variable of the form that 
;			   is returned by READSUMCOL
;               
; Opt. Inputs : None.
;               
; Outputs     : IDL detector data descriptor, see CDS QL Data Format.
;               
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : EXECUTE(), TRIM()
;
; Common      : None.
;               
; Restrictions: DATA must adhere to the format returned by READSUMCOL
;		Normally used by DETREAD()
;               
; Side effects: None.
;               
; Category    : Data_Handling, I_O, FITS, CDS, SUMER, QuickLook
;               
; Prev. Hist. : Converted from MkDetWDesc by Stein Vidar Haugan
;
; Written     : William Thompson, GSFC, 5 July 1996
;               
; Modified    : Version 1, William Thompson, GSFC, 5 July 1996
;		Version 2, William Thompson, GSFC, 8 July 1996
;			Add DetX and DetY to reflect changes in READSUMCOL.
;
; Version     : Version 2, 8 July 1996
;-            

FUNCTION Mksumwdesc,Data,Ndims
  
  res =	0
  exestr =$
	  "res = {"+'SUM'$
		       +trim(Ndims)+","	+ $
	  "ixstart :intarr(Ndims)," +	  $	  ; Indexes to detector block
	  "ixstop  :intarr(Ndims)," +	  $
	  "Label	 :Data.Label,"	+ $	  ; Copying from orig.
	  "Max     :float(max(Data.Array))," +	  $
	  "Min	 :float(min(Data.Array))," +	  $
	  "Missing :Data.Missing," +	  $
	  "Axes	 :[Data.Axes],"	+ $
	  "Origin	 :[Data.Origin]," +	  $
	  "Spacing :[Data.Spacing]," +	  $
	  "Rotation:[Data.Rotation],"+	  $
	  "DetX	 :Data.DetX,"+		  $
	  "DetY  :Data.DetY,"+		  $
	  "Wavelength:Data.Wavelength}"
  dummy	= execute(exestr)
  return,res
END
