;+
; Project     : SOHO - CDS     
;                   
; Name        : STORESUMWND
;               
; Purpose     : Store SUMER data from READSUMCOL into a CDS QLDS
;               
; Explanation : SUMER version of CDS routine STORE_WND.
;
;		Stores detector data from Data.Array into:
;
; 			Det.DetData(currentix:stopix 
;					[,0:size_dimension_2 
;					[,0:size_dimension_3]] )
;
; 		The number of indexes depends on the dimensionality of the 
;		data.
;
;		- Updates CurrentIx to point to the next free index.
;
; 		- Stores indexes (to Det.DetData) for this data window into
; 		Det.DetDesc(WndNo).ixstart/ixstop
;               
; Use         : STORESUMWND,WINDOW_NO,CURRENT_INDEX,DET,DATA
;    
; Inputs      : WINDOW_NO : 
;			The index (into DET.DETDESC) of the
;			detector data window in question.
;               
;		CURRENT_INDEX: 
;			The index (into DET.DETDATA's first dimension) of
;			where a block of detector data may be placed.
;
;		DET :	An IDL structure containing the tags DetDesc and
;			DetData, as described in the CDS QL Data Format.
;
;		DATA:	An IDL structure returned from READSUMCOL after
;			a successful read of detector data.
;
;		DDIMS:  The number of dimensions in the data block
;
; Opt. Inputs : None.
;               
; Outputs     : CURRENT_INDEX:
;			is updated to point to the room after
;			the current block of data in DET.DETDATA
;               
;		DET.DETDATA: The data from DATA.ARRAY i stored here.
;
;		DET.DETDESC.IXSTART,
;		DET.DETDESC.IXSTOP: 
;			Indexes into DET.DETDATA for the current detector
;			data window.
;
; Opt. Outputs: None.
;               
; Keywords    : None.
;
; Calls       : QL_SIZE
;
; Common      : None.
;               
; Restrictions: See the data formats.
;               
; Side effects: None.
;               
; Category    : Data_Handling, CDS, SUMER, QuickLook, Internal
;               
; Prev. Hist. : Converted from STORE_WND by Stein Vidar Hagfors Haugan
;
; Written     : William Thompson, GSFC, 5 July 1996
;               
; Modified    : Version 1, William Thompson, GSFC, 5 July 1996
;
; Version     : Version 1, 5 July 1996
;-            
;

PRO Storesumwnd,WndNo,CurrentIx,Det,Data
;
; Find dimensionality and stop indexes.
;
  on_error,2

  if !DEBUG ne 0 then on_error,0

  Dims = (size(data.axes))(1)
  SZ = ql_size(size(data.array),dims)

  StopIx = CurrentIx + SZ(1)-1

  CASE Dims OF
      1	: BEGIN
	  Det.DetData(CurrentIx:StopIx)	= Data.Array(*)
	  ixstart=[CurrentIx] &	ixstop=[StopIx]
      END
      2	: BEGIN
	  Det.DetData(CurrentIx:StopIx,0:SZ(2)-1) = Data.Array
	  ixstart=[CurrentIx,0]	& ixstop=[StopIx,SZ(2)-1]
      END
      3	: BEGIN
	  Det.DetData(CurrentIx:StopIx,$
			  0:SZ(2)-1,0:SZ(3)-1) = Data.Array
	  ixstart=[CurrentIx,0,0] & ixstop=[StopIx,SZ(2)-1,SZ(3)-1]
      END
      4 : begin
	  Det.DetData(CurrentIx:StopIx,$
			  0:SZ(2)-1,0:SZ(3)-1,0:SZ(4)-1) = Data.Array
	  ixstart=[CurrentIx,0,0,0] & ixstop=[StopIx,SZ(2)-1,SZ(3)-1,SZ(4)-1]
      end
  EndCASE
  
  Det.DetDesc(WndNo).ixstart = ixstart	  ; Store indexes
  Det.DetDesc(WndNo).ixstop = ixstop
  
  CurrentIx=StopIx+1			  ; Update current index.
  
END


