;+
; Project     : SOHO - CDS     
;                   
; Name        : SUMDETREAD()
;               
; Purpose     : Reads detector data from SUMER FITS level-1 file.
;
; Explanation : SUMER version of CDS routine DetRead.
;
;		Based on information from DETSELECT(), read and store
;		detector data from the file into one contiguous array,
;		QLDS.DetData, with descriptors (indexes & wavelength 
;		information) in QLDS.DetDesc(WndNo)
;               
; Use         : Sumdetread,UNIT,HEADER,QLDS,SELECTION_DATA
;    
; Inputs      : UNIT = Device unit associated with the FITS file
;		HEADER = Header (string array) of the FITS file
;		QLDS = The QuickLook data structure to put data into.
;		SELECTION_DATA = Structure from DETSELECT() with
;			information on windows etc.
;               
; Opt. Inputs : None.
;               
; Outputs     : Places the data from the file into the QLDS.
;               
; Opt. Outputs: None.
;               
; Keywords    : STATUS : Set to an initialized, named variable to 
;		return an error message instead of crashing. If
;		everything's ok, a null string will be returned.
;
; Calls       : FXBDIMEN(), MKSUMWDESC(), READSUMCOL, STORESUMWND, TRIM()
;		WINDOWNO()
;               
; Common      : None.
;               
; Restrictions: UNIT/HEADER must refer to a SUMER FITS level-1 file.
;		Normally used internally from READSUM2CDS.
;               
; Side effects: None.
;               
; Category    : Data_Handling, I_O, CDS, SUMER, FITS, QuickLook
;               
; Prev. Hist. : Converted from DETREAD by Stein Vidar Hagfors Haugan.
;
; Written     : William Thompson, GSFC, 5 July 1996
;               
; Modified    : Version 1, William Thompson, GSFC, 5 July 1996
;
; Version     : Version 1, 5 July 1996
;-            

PRO Sumdetread,unit,header,QLDS,selection,status=status
  
  
  On_Error,2
  IF !DEBUG ne 0 THEN On_Error,0
  
  CurrentIx = 0
  
  Det_ColNo = selection.Det_ColNo
  selected = selection.selected
  hdr_only = (selected eq 0)
  Ncols	= N_elements(QLDS.DetDesc)
  Ddims	= N_elements(QLDS.DetDesc(0).ixstart)
  F_rows = selection.F_rows
  N_rows = selection.N_rows
;
; Store all detectore windows.
;
  FOR WindowNo=0,Ncols-1 DO BEGIN
      readsumcol,unit,Window,Det_ColNo(WindowNo),header=hdr_only(WindowNo) ;, $
						  ; status=status
      IF N_elements(status) gt 0 THEN IF status ne '' THEN return
      QLDS.DetDesc(WindowNo) = MkSumWdesc(Window,Ddims)
      IF selected(WindowNo) THEN StoreSumWnd,WindowNo,CurrentIx,QLDS,Window $
      ELSE BEGIN
	  tdim = fix(fxbDimen(Unit,Det_ColNo(WindowNo)))  ; Mark ghost indexes
	  IF F_rows THEN tdim =	[tdim,N_rows]
	  QLDS.DetDesc(WindowNo).ixstart(*)=0
	  QLDS.DetDesc(WindowNo).ixstop	= tdim - 1
	  QLDS.DetDesc(WindowNo).ixstop(0) = -tdim(0)+1
      END
  END
  
END


