;+
; Project     : SOHO - CDS     
;                   
; Name        : CHECK_NIS_WCAL
;               
; Purpose     : Demonstrates applicability of current NIS wavecal.
;               
; Explanation : 
;               
; Use         : IDL> check_nis_wcal
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : ANGSTROMS - residuals plotted as Angstroms instead of pixels
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 10-Oct-96
;               
; Modified    : 
;
; Version     : Version 1, 10-Oct-96
;-            
pro check_nis_wcal, angstrom=angstrom

;
;  to check current (2/10/96) NIS1 wavecal, just averaged a recent NISAT
; data set and plotted against wavecal and used ezfit to get line 
; wavelengths. 

print,' '
print,'The plots show the residuals between the derived wavelengths'
print,'of a number of lines and the listed wavelengths for those lines.'
print,"The NIS1 spectra used were Bill Thompson's composite spectrum"
print,'(solid) and a recent NISAT data set (open circles).'
print,'The NIS2 data were also taken from a recent NISAT study.'
print,'This is supposed to show that, given a wavelength in the line list,'
print,'the current wavecal will set the data extraction windows correctly'
print,'to within a pixel.  If you have any evidence to the contrary, please
print,'let me know.'
print,' '

obs =  [315.023, 316.210, 319.836, 334.173, 347.396, $
        349.852, 356.022, 360.738, 364.454, 368.055]

obs1 = [314.994, 316.186, 319.809, 347.368, 349.827, 355.994, $
        364.431, 368.023]

lab1 =  [ 315.039, 316.205, 319.826, 347.403, $
         349.873, 356.012, 364.467, 368.070]

lab =  [ 315.039, 316.205, 319.826, 334.172, 347.403, $
         349.873, 356.012, 360.761, 364.467, 368.070]



circle_sym,/fill


!p.multi=[0,1,2]

if not keyword_set(angstrom) then begin
   plot,obs,(obs-lab)/0.070,psym=8,/ynoz,ytit='Deviation (pixels)',$
                     tit='NIS1',yr=[-1,1],chars=1.3,xtit='Wavelength'
   circle_sym
   oplot,obs1,(obs1-lab1)/0.070,psym=8
endif else begin
   plot,obs,(obs-lab),psym=8,/ynoz,ytit='Deviation (Ang)',$
              tit='NIS1',yr=[-0.3,0.3],chars=1.3,xtit='Wavelength'
   circle_sym
   oplot,obs1,(obs1-lab1),psym=8
endelse


obs =  [515.653,522.250,525.868,543.981,550.103,562.852,$;568.303,$
        572.350,580.926,584.360,609.816,625.012,629.826]

lab =  [515.617,522.213,525.796,543.892,550.031,562.803,$;568.417,$
        572.331,580.975,584.334,609.829,624.941,629.732]

circle_sym,/fill

avg = average(obs-lab)
if not keyword_set(angstrom) then begin
   plot,obs,(obs-lab)/0.117,psym=8,/ynoz,ytit='Deviation (pixels)',$
               tit='NIS2',yr=[-1,1],chars=1.3,xtit='Wavelength'
   oplot,[100,700],[avg/0.117,avg/0.117],lin=2
endif else begin
   plot,obs,(obs-lab),psym=8,/ynoz,ytit='Deviation (Ang)',$
                  tit='NIS2',yr=[-0.3,0.3],chars=1.3,xtit='Wavelength'
   oplot,[100,700],[avg,avg],lin=2
endelse
!p.multi=0
end





!p.multi=0
end
