;+
; Project     : SOHO - CDS     
;                   
; Name        : NIS1_RELCAL
;               
; Purpose     : Demonstrate possible NIS1 relative intensity calibration.
;               
; Explanation : Using pairs of density insensitive lines the relative 
;               intensity calibration for the NIS1 waveband was bootstrapped
;               from the short wavelength lines.
;               
; Use         : IDL> nis1_relcal
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Demonstration, intensity, calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Aug-96
;               
; Modified    : 
;
; Version     : Version 1, 16-Aug-96 
;-            

pro nis1_relcal

wav = [315.0,  339.0,  316.2,  319.8,  352.1,  364.5,  346.9,  364.5, $
       360.7,  335.4,  369.2,  352.7]

rel = [1.0,      1.52,   1.02,   1.07,   1.96,   2.72,   1.8,    2.69, $
       2.04,     1.5,    2.84,    2.0]

circle_sym,/fill

n = sort(wav)
wav = wav(n)
rel = rel(n)

plot,wav,rel,xr=[310,380],xst=1,yr=[0,4],yst=1,syms=1.5,psym=8,$
       xtit='Wavelength',ytit='Relative Sensitivity',tit='NIS1',chars=1.3

for i=0,n_elements(wav)-1 do begin
   oplot,[wav(i),wav(i)],[rel(i)-0.2,rel(i)+0.2]
endfor

c = poly_fit(wav,rel,2,yfit)
x = findgen(70)+310.
oplot,x,poly(x,c)
end

