;+
; Project     : SOHO - CDS     
;                   
; Name        : NIS2_RELCAL
;               
; Purpose     : Demonstrate possible NIS2 relative intensity calibration.
;               
; Explanation : Using pairs of density insensitive lines the relative 
;               intensity calibration for the NIS2 waveband was bootstrapped
;               from the long wavelength lines.
;               
; Use         : IDL> nis2_relcal
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Demonstration, intensity, calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Aug-96
;               
; Modified    : 
;
; Version     : Version 1, 16-Aug-96 
;-            

pro nis2_relcal

wav = [525.8,557.77,574.01,599.6,609.8,624.94]

rel = [2.04,1.64,1.42,1.1,1.06,1.0]

circle_sym,/fill

n = sort(wav)
wav = wav(n)
rel = rel(n)

plot,wav,rel,xr=[510,650],xst=1,yr=[0,4],yst=1,syms=1.5,psym=8,$
       xtit='Wavelength',ytit='Relative Sensitivity',tit='NIS2',chars=1.3

for i=0,n_elements(wav)-1 do begin
   oplot,[wav(i),wav(i)],[rel(i)-0.2,rel(i)+0.2]
endfor

c = poly_fit(wav,rel,1,yfit)
x = findgen(140)+510.
oplot,x,poly(x,c)
end

