;+
; Project     : SOHO - CDS     
;                   
; Name        : NIS_BIAS_DEMO
;               
; Purpose     : Demonstrates NIS bias levels from daily synoptic scans.
;               
; Explanation : The NIS bias levels drift slowly with time and sometimes
;               is subject to sudden changes.  These plots not only
;               show the slow trends but also the glitches as deduced 
;               from the daily synoptic scans.
;               
; Use         : IDL> nis_bias_demo
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 13-Nov-96
;               
; Modified    : Latest data, complete to 24-Jul-97.  28-Jul-97
;                            complete to 28-May-98 
;                            added a bit of post-recovery data
;                            added data to May 2000
;
; Version     : Version 2, 28-Jul-97
;               Version 3, 29-May-98
;               Version 4, 13-Nov-98
;               version 5, 17-May-00
;-
pro nis_bias_demo,post=post

back = 0
date = 0
result = 0
cresult = 0
circle_sym,/fill

!p.multi=[0,1,2]

;
;  NIS1
;
if not keyword_set(post) then begin
   restore,concat_dir('$CDS_ENG_DEMO','All_bias_2_may98')
   t = anytim2utc(date)
   utplot,t,back(*,0),psym=8,yr=[150,460],/yst,$
            timer=['1996-1-1','2001-1-1'],/xst,$
            chars=1.5,tit='NIS1 Bias level',xtit='Date',$
            ytit='NIS1 bias level (adu)'
   restore,concat_dir('$CDS_ENG_DEMO','post_recovery_syndata')
   t = anytim2utc(dates)
   outplot,t,bias(0,*),psym=8
endif else begin
   restore,concat_dir('$CDS_ENG_DEMO','post_recovery_syndata')
   t = anytim2utc(dates)
   utplot,t,bias(0,*),psym=8,yr=[195,205],/yst,$
            timer=['1998-1-1','2001-1-1'],/xst,$
            chars=1.5,tit='NIS1 Bias level',xtit='Date',$
            ytit='NIS1 bias level (adu)'
endelse

;
; NIS2
;
if not keyword_set(post) then begin
   restore,concat_dir('$CDS_ENG_DEMO','All_bias_2_may98')
   t = anytim2utc(date)
   utplot,t,back(*,2),psym=8,yr=[200,340],/yst,$
            timer=['1996-1-1','2001-1-1'],/xst,$
            chars=1.5,tit='NIS2 Bias level',xtit='Date',$
            ytit='NIS2 bias level (adu)'
   restore,concat_dir('$CDS_ENG_DEMO','post_recovery_syndata')
   t = anytim2utc(dates)
   outplot,t,bias(2,*),psym=8
endif else begin
   restore,concat_dir('$CDS_ENG_DEMO','post_recovery_syndata')
   t = anytim2utc(dates)
   utplot,t,bias(2,*),psym=8,yr=[205,215],/yst,$
            timer=['1998-1-1','2001-1-1'],/xst,$
            chars=1.5,tit='NIS2 Bias level',xtit='Date',$
            ytit='NIS2 bias level (adu)'
endelse



!p.multi=0
end

