;+
; Project     : SOHO - CDS     
;                   
; Name        : NIS_WAVECAL_DEMO
;               
; Purpose     : Demonstrate NIS wavelength calibration.
;               
; Explanation : Demonstrates the data used to form the NIS wavecal.  Pixel
;               values were derived from composite spectral atlas data
;               (study NISAT) by McWhirter, Brooks et al) and the wavelengths
;               are from the Chianti line lists.
;               
; Use         : IDL> nis_wavecal_demo
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : OLD - display pre-loss calibration 
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration, wavelength
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 30-Jul-96
;               
; Modified    : Updated for post-recovery data.  CDP, 12-Nov-98 
;
; Version     : Version 2, 12-Nov-98
;-            

pro nis_wavecal_demo, old=old


;
;  NIS1
;  ----
;

;  set up wavelengths and pixels locations

if keyword_set(old) then begin
   m1tit = 'NIS1 wavelength calibration (pre-loss)'
   m2tit = 'NIS2 wavelength calibration (pre-loss)'
   wav = [313.754,$  
      314.327,$  
      315.039,$  
      316.205,$  
      317.039,$  
      319.826,$  
      332.789,$
      335.253,$  
      339.006,$
      341.949,$
      346.852,$  
      347.403,$  
      352.106,$  
      352.662,$
      356.056,$
      358.621,$  
      364.467,$  
      365.240,$  
      365.543,$
      368.070,$
      369.153] ;- only for original pre-loss data  

;
;   measured pixel values
;
pix = [8.8355e+01,$ 
     9.6479e+01,$ 
     1.0632e+02,$ 
     1.2343e+02,$ 
     1.3514e+02,$ 
     1.7532e+02,$ 
     3.6038e+02,$ 
     3.9581e+02,$ 
     4.4900e+02,$ 
     4.9110e+02,$ 
     5.6079e+02,$ 
     5.6859e+02,$ 
     6.3565e+02,$ 
     6.4355e+02,$ 
     6.9125e+02,$ 
     7.2766e+02,$ 
     8.1094e+02,$ 
     8.2159e+02,$ 
     8.2646e+02,$ 
     8.6203e+02,$ 
    8.7774e+02]

endif else begin

   m1tit = 'NIS1 wavelength calibration (post recovery)'
   m2tit = 'NIS2 wavelength calibration (post recovery)'
   wav = [313.754,$  
      314.327,$  
      315.039,$  
      316.205,$  
      317.039,$  
      319.826,$  
      332.789,$
      339.006,$
      341.949,$
      346.852,$  
      347.403,$  
      352.106,$  
      352.662,$
      356.056,$
      358.621,$  
      364.467,$  
      365.543,$
      368.070]
  
   pix = [95.1,$
      102.9,$
       112.4,$
       129.2,$
       141.1,$
       181.5,$
       366.0,$
       455.2,$
       497.2,$
       566.9,$
       574.9,$
       641.5,$
       649.5,$
       697.2,$
       733.7,$
       816.8,$
       831.0,$
       867.9]
  
endelse

!p.multi=[0,1,2]
circle_sym,/fill

c = poly_fit(pix,wav,1,yfit)
res = yfit - wav
av = average(res)
std = stdev(res)

plot,pix,res,psym=8,yr=[-0.3,0.3],yst=1,xr=[-200,1200],xst=1,syms=1.5,$
   tit = m1tit,$
   xtit = 'Pixel number',ytit='Residual from linear fit (Angstroms)'
c = poly_fit(pix,res,2,yfit)
oplot,findgen(1023),poly(findgen(1023),c),th=2
oplot,[0,1024],[av,av],line=3

c = poly_fit(pix,wav,2,yfit)
res = yfit - wav
av = average(res)
std = stdev(res)
;print,c


plot,pix,res,psym=8,yr=[-0.3,0.3],yst=1,xr=[-200,1200],xst=1,syms=1.5,$
   xtit = 'Pixel number',ytit='Residual from 2nd order fit (Angstroms)'
xyouts,400.,-0.2,'RMS residual: '+string(std,form='(f5.3)')+' Angstroms'
xyouts,400.,-0.25,'              '+string(std/c(1),form='(f4.2)')+'  Pixels'
oplot,[0,1024],[av,av],line=3


if !d.name ne 'PS' then yes_no,'Hit return when ready for NIS2'

;
;   NIS2
;   ----
;
;  Post recovery version
;

if keyword_set(old) then begin

   wav = [550.031, 557.765, $
       515.617,$
       522.213, 537.030, 584.334, $
       606.65, 608.397, 624.941, 541.128, $
       542.073, 543.892, 559.948, $
       564.528, 525.796, $
       553.329, $
       554.076, 554.513, 555.263, 629.732, 580.908, 520.665];;

   pix = [317.036, 383.092, $
        21.401, $
        78.040, 205.439, 610.053, $
       800.536, 814.988, 956.179, 240.632, $
       248.682, 264.308, 402.266, $
       441.208, 109.072, $
       345.288, $
       351.597, 355.438, 361.756, 997.115, $
       580.778, 64.983]

endif else begin

   wav = [515.617,522.213,525.796,520.665,550.031,557.765,558.594,537.030,$
        584.334,624.941,541.128,542.073,543.892,562.803,553.329,554.076,$
        554.513,555.263,629.732,580.908]

   pix = [34.9,91.8,122.6,78.4,330.5,396.8,403.8,219.1,$
          623.5,969.3,254.5,262.0,278.0,439.6,359.5,365.6,$
          369.3,375.2,1010.4,594.3]

endelse


n = sort(pix)
wav = wav(n)
pix = pix(n)

c = poly_fit(pix,wav,1,yfit)
res = yfit - wav
av = average(res)
std = stdev(res)

plot,pix,res,psym=8,yr=[-0.3,0.3],yst=1,xr=[-200,1200],xst=1,syms=1.5,$
   tit = m2tit,$
   xtit = 'Pixel number',ytit='Residual from linear fit (Angstroms)'

c = poly_fit(pix,res,2,yfit)
oplot,findgen(1023),poly(findgen(1023),c),th=2
oplot,[0,1024],[av,av],line=3

c = poly_fit(pix,wav,2,yfit)
;print,c
res = yfit - wav
av = average(res)
std = stdev(res)



plot,pix,res,psym=8,yr=[-0.3,0.3],yst=1,xr=[-200,1200],xst=1,syms=1.5,$
   xtit = 'Pixel number',ytit='Residual from 2nd order fit (Angstroms)'
xyouts,400.,-0.2,'RMS residual: '+string(std,form='(f5.3)')+' Angstroms'
xyouts,400.,-0.25,'              '+string(std/c(1),form='(f4.2)')+'  Pixels'
oplot,[0,1024],[av,av],line=3

!p.multi=0
end


