;+
; Project     : SOHO - CDS     
;                   
; Name        : PLOT_CDS_CRAYS
;               
; Purpose     : Demonstrates counts of cosmic rays detected by CDS
;               
; Explanation : Spectral atlas data (NISAT_S) is obtained twice a week as
;               part of the CDS synoptic studies.  Full spectral data are
;               extracted and 10 exposures are made at 2" X-steps.  These
;               data were cleaned using the CDS_CLEAN_SPIKE routine and a record
;               kept of how many pixels were determined to have been affected
;               by cosmic ray hits.   The results are plotted against time. 
;               The circled data derive from longer exposure (usually 300 secs
;               as opposed to the normal 50 sec) versions of the study.  It is
;               not clear why the majority of them should show a reduced cr count
;               except possibly that in the shorter exposures some the lower signal
;               to noise ratio leads to some 'genuine' data pixels being labelled
;               as cosmic-ray-affected.
;               
; Use         : IDL> plot_cds_crays
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : UTPLOT
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Engineering
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Sep-97 
;               
; Modified    : 
;
; Version     : Version 1, 12-Sep-97
;-            
pro plot_cds_crays

date = 0
htot = 0
hh = 0
exptime = 0

restore,concat_dir('$CDS_ENG_DEMO','nisat_cr_stats')
restore,concat_dir('$CDS_ENG_DEMO','nisat_date')
restore,concat_dir('$CDS_ENG_DEMO','nisat_exptime')

circle_sym,/fill

utplot,str2utc(date),htot/exptime,psym=8,tit='Cosmic Ray count from NISAT',$
           xtit='1996/7',ytit='Total pixels affected/second',chars=1.5,$
           timera=str2utc(['1-apr-96','1-may-97']),/xst

n = where(exptime ne 50)
circle_sym
outplot,str2utc(date(n)),htot(n)/exptime(n),psym=8,syms=2
end

