;+
; Project     : SOHO - CDS     
;                   
; Name        : PLOT_SLIT_OFFSETS
;               
; Purpose     : Demonstrates Y-pixel offsets for different slits.
;               
; Explanation : Owing mainly to machining errors of the CDS plate
;               the centres of the various slits are not co-aligned
;               when each is at its home position.  This has the consequence
;               that images taken with different slits will not be aligned
;               spatially.  This plot demonstrates the current offsets thought
;               to be applicable.
;               
; Use         : IDL> plot_slit_offsets
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Engineering
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Sep-97 
;               
; Modified    : 
;
; Version     : Version 1, 12-Sep-97
;-            
pro plot_slit_offsets


x = [2,4,6,8,10]
;
;  central images locations for different slits
;
y1 = [70.0,71.6,70.0,68.5,70.5]*1.68
y2 = [71.2,71.4,70.5,69.0,71.0]*1.68

circle_sym,/f

plot,x,y1-y1(3),psym=8,syms=1.5,tit='CDS slit offsets (+ve = North)',$
     xtit='Slit',$
     chars=1.8,xr=[0,12],$
     /yst,yr=[-1,10],xtickn=[' ','2x2','4x4','8x51','2x240','4x240',' '],$
     ytit='Offset (arcsec)'
oplot,[0,12],[0,0],line=2
oplot,[11,11],[9.5,9.5],psym=8,syms=1.2
xyouts,11.2,9.5,'NIS1'

circle_sym
oplot,x,y2-y2(3),syms=2.,psym=8
oplot,[11,11],[9.,9.],psym=8,syms=1.2
xyouts,11.2,9.0,'NIS2'

end
