	PRO SUNSIZE_DEMO
;+
; Project     : SOHO - CDS     
;                   
; Name        : SUNSIZE_DEMO
;               
; Purpose     : Demonstrate apparent size/position of sun each day.
;               
; Explanation : Demonstrates the estimated size of the sun based on an analysis
;		of the daily SYNOP_F scans.  Two plots are made:  the first is
;		the ratio of the size of the sun relative to the expected size,
;		and the second is the offset of the calculated sun center from
;		the assumed sun center.  The dates when the pointing
;		calibration was changed in the database are marked as vertical
;		dashed lines.  The sun center positions from before April 16
;		are too high because the spacecraft pointing was different
;		then.
;               
; Use         : IDL> sunsize_demo
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration, pointing
;               
; Prev. Hist. : None
;
; Written     : William Thompson, GSFC, 21 August 1996
;               
; Modified    : Version 1, William Thompson, GSFC, 21 August 1996
;               Version 2, CDP, Use CDS_UTPLOT.  9-Jan-97
;               Version 3, Use standard UTPLOT, increase character size. CDP,
;                          12-Sep-97
;                             
; Version     : Version 3, 12 September 1997
;-            
;
	ON_ERROR, 2
;
;  Make a list of the dates when the pointing calibration was changed.
;
	CALIB = ['1996/03/31', '1996/04/01', '1996/04/16', '1996/06/11', $
		 '1996/08/19']
;
;  Make a list of data files to show.
;
	FILES = ['sun_size2.idl', 'sun_size.idl']
	TITLE = ['Without recalibration', 'With recalibration']
	TIMERANGE = ['31-Mar-1996','20-Aug-1996']
;
;  Step through the different calibration files.
;
	FOR I_FILE = 0,1 DO BEGIN
		RESTORE, FIND_WITH_DEF(FILES(I_FILE),'$CDS_ENG_DEMO')
;
;  For the recalibration data, subtract 198 from all points before 16-Apr-1996.
;
		IF I_FILE EQ 1 THEN BEGIN
			W = WHERE(DATE.MJD LE 50189)
			CENTER(W) = CENTER(W) - 198
		ENDIF
;
;  Plot the relative solar size.  Mark when the calibration was changed.
;
		ERASE
		SETVIEW, 1, 1, 1, 2
		UTPLOT, DATE, ASIZE, YRANGE=[0.995,1.02], /YNOZERO, PSYM=2, $
			YTITLE='Estimated/Actual Size Ratio',		$
			TITLE=TITLE(I_FILE), TIMERANGE=TIMERANGE, CHARS=2.5
		FOR I=0,N_ELEMENTS(CALIB)-1 DO OUTPLOT, [CALIB(I),CALIB(I)], $
			!Y.CRANGE, PSYM=0, LINESTYLE=1
;
;  Plot the relative solar center data.
;
		SETVIEW, 1, 1, 2, 2
		UTPLOT, DATE, CENTER, YRANGE=[-10,20], PSYM=2,	$
			YTITLE='Center Offset in Arcseconds',	$
			TIMERANGE=TIMERANGE, CHARS=2.5
		FOR I=0,N_ELEMENTS(CALIB)-1 DO OUTPLOT, [CALIB(I),CALIB(I)], $
			!Y.CRANGE, PSYM=0, LINESTYLE=1
		SETVIEW
;
;  Wait for the user to continue.
;
		IF (I_FILE EQ 0) AND (!D.NAME NE 'PS') THEN BEGIN
			DUMMY = ''
			READ, 'Press return to continue...', DUMMY
		ENDIF
	ENDFOR		
;
	RETURN
	END
