;+
; Project     : SOHO - CDS     
;                   
; Name        : SYNOPTIC_STATS
;               
; Purpose     : Demonstrates statistics from daily synoptic scans.
;               
; Explanation : 
;               
; Use         : IDL> synoptic_stats
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : CALIB  - use calibrated data instead of raw.
;               WINDOW - specify which wavelength window (default all)
;               RASTER - specify which raster (default all nine)
;               OVER
;               YR
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Engineering
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 25-Jul-96
;               
; Modified    : Change utplot name.  CDP, 2-Oct-96
;               Cut out bias level plot - done elsewhere.  CDP, 13-Nov-96
;
; Version     : Version 3, 13-Nov-96
;-            
pro synoptic_stats, calib=calib, window=window, raster=raster, over=over, yr=yr


if n_elements(window) eq 0 then window = [0,1,2,3]
if n_elements(raster) eq 0 then raster = [0,1,2,3,4,5,6,7,8]

t = 0
date = 0
result = 0
cresult = 0
back = 0

restore,concat_dir('$CDS_ENG_DEMO','iced_synop_allres_A')
datea = date
resulta = result
cresulta = cresult

restore,concat_dir('$CDS_ENG_DEMO','iced_synop_allres_B')

utc = str2utc([datea,date])


circle_sym,/fill
if not keyword_set(over) then !p.multi=[0,1,n_elements(raster)/2]


;
;  calibrated or raw?
;
if keyword_set(calib) then begin
   result = cresult
   resulta = cresulta
endif


n = where(window eq 0, count)
if count gt 0 then begin
   for i=0,8 do begin
      n = where(raster eq i,count)
      if count gt 0 then begin
         he = [reform(resulta(i,0,*)),reform(result(i,0,*))]
         if not keyword_set(over) then begin
            if n_elements(yr) eq 0 then yr = [10,60]
            utplot,utc,he,psym=8,yr=yr,$
                   tit='He I - raster '+trim(i),xtit='1996/97',chars=1.5  
         endif else begin
            outplot,utc,he,psym=1
         endelse
      endif
   endfor
   if !d.name ne 'PS' then yes_no,'Hit return when ready to continue',ans
endif

n = where(window eq 1, count)
if count gt 0 then begin
   for i=0,8 do begin
      n = where(raster eq i,count)
      if count gt 0 then begin
         fe = [reform(resulta(i,1,*)),reform(result(i,1,*))]
         if not keyword_set(over) then begin
            if n_elements(yr) eq 0 then yr = [0,5]
            utplot,utc,fe,psym=8,yr=yr,$
                   tit='Fe XVI - raster '+trim(i),xtit='1996',chars=1.5
         endif else begin
            outplot,utc,fe,psym=1
         endelse
      endif
   endfor
   if !d.name ne 'PS' then yes_no,'Hit return when ready to continue',ans
endif


n = where(window eq 2, count)
if count gt 0 then begin
   for i=0,8 do begin
      n = where(raster eq i,count)
      if count gt 0 then begin
         mg = [reform(resulta(i,2,*)),reform(result(i,2,*))]
         if not keyword_set(over) then begin
            if n_elements(yr) eq 0 then yr = [0,50]
            utplot,utc,mg,psym=8,yr=yr,$
                   tit='Mg IX - raster '+trim(i),xtit='1996',chars=1.5  
         endif else begin
            outplot,utc,mg,psym=1
         endelse
      endif
   endfor
   if !d.name ne 'PS' then yes_no,'Hit return when ready to continue',ans
endif


n = where(window eq 3, count)
if count gt 0 then begin
   for i=0,8 do begin
      n = where(raster eq i,count)
      if count gt 0 then begin
         ov = [reform(resulta(i,3,*)),reform(result(i,3,*))]
         if not keyword_set(over) then begin
            if n_elements(yr) eq 0 then yr = [10,50]
            utplot,utc,ov,psym=8,yr=yr,$
                   tit='O V - raster '+trim(i),xtit='1996',chars=1.5  
         endif else begin
            outplot,utc,ov,psym=1
         endelse
      endif
   endfor
endif

;cleanplot

end




