;+
; Project     : SOHO - CDS     
;                   
; Name        : TILT_NIS1_DEMO
;               
; Purpose     : Demonstrate variation of NIS1 spectral line tilt.
;               
; Explanation : The spectral lines in NIS1 are tilted with respect to the 
;               dispersion direction.  This tilt is a function of wavelength
;               (or equivalently spectral bin) as shown in this plot.
;               Note that the sign convention is such that spectral lines at
;               the bottom (south) of the slit are moved to larger bin numbers.
;
; Use         : IDL> tilt_nis1_demo
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Nov-96
;               
; Modified    : Version 2, 2-Jul-1998, William Thompson, GSFC
;			Brought up-to-date with latest data
;
; Version     : Version 2, 2-Jul-1998
;-            

pro tilt_nis1_demo

tilt = [636,745,548,485,548,461,417,399,427,261,132,123]
pix =  [ 93,131,178,448,487,534,569,646,693,812,863,953]

tilt = float(tilt)/1.0e5
circle_sym,/fill

yerr = fltarr(12)+0.0007
cds_plot_err,pix,tilt,yerr=yerr,psym=8,yr=[0,0.01],$
        ytit='Tilt (pixels/pixel along slit)',chars=1.5,syms=1.3,$
        xtit='Spectral bin',tit='NIS1 tilt factors',xr=[0,1023],/xst,/yst

c = poly_fit(pix,tilt,1,yfit)
oplot,pix,yfit
print,c(*)
xyouts,50,0.001,'Tilt = 0.0075942 - 6.135603e-6 * spectral bin',chars=1.3

file = find_with_def('tilt.idl', '$CDS_ENG_DEMO')
if file eq '' then return
restore, file
linecolor,1,'Green'
linecolor,2,'Red'
oplot_err, t1.center, t1.tilt, yerr=t1.sigma, color=1
c = polyfitw(t1.center, t1.tilt, 1/t1.sigma^2, 2, yfit)
oplot, t1.center, yfit, color=2
print,c(*)
xyouts,50,0.0005,'Tilt = 0.00707712 - 2.28799E-7*bin - 6.36054E-9*bin^2', $
	color=2, charsize=1.3

end

