;+
; Project     : SOHO - CDS     
;                   
; Name        : TILT_NIS2_DEMO
;               
; Purpose     : Demonstrate variation of NIS2 spectral line tilt.
;               
; Explanation : The spectral lines in NIS2 are tilted with respect to the 
;               dispersion direction.  This tilt is a function of wavelength
;               (or equivalently spectral bin) as shown in this plot. Note 
;               that the convention is that the spectral line at the bottom
;               (south) of the slit is shifted towards larger bin numbers.
;               Note also that the data are fitted with a quadratic mainly
;               because the values at bins ~990 are well defined from other
;               observations and would be inconsistent with a linear fit
;               through the data.
;               
; Use         : IDL> tilt_nis2_demo
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Nov-96
;               
; Modified    : Version 2, 2-Jul-1998, William Thompson, GSFC
;			Brought up-to-date with latest data
;
; Version     : Version 2, 2-Jul-1998
;-            

pro tilt_nis2_demo

;
;  line tilt in pixels*10-5 per pixel along the slit
;
tilt = [350,340,317,426,369,309,296,266,245,263,346,187,262,342,267,418,400]

;
;  mean pixel measured
;
pix =  [22,69,111,200,260,311,351,386,426,472,520,575,615,732,819,954,994] 

tilt = float(tilt)/1.0e5
circle_sym,/fill

yerr = fltarr(20)+0.0005
cds_plot_err,pix,tilt,yerr=yerr,psym=8,yr=[0,0.007],$
        ytit='Tilt (pixels/pixel along slit)',chars=1.5,syms=1.3,$
        xtit='Spectral bin',tit='NIS2 tilt factors',xr=[0,1023],/xst,/yst

c = poly_fit(pix,tilt,2,yfit)
oplot,pix,yfit,th=2
xyouts,50,0.001,'Tilt = 0.00397 - 4.763135e-6*bin + 4.764016e-9*bin*bin',$
       chars=1.3

file = find_with_def('tilt.idl', '$CDS_ENG_DEMO')
if file eq '' then return
restore, file
linecolor,1,'Green'
linecolor,2,'Red'
oplot_err, t2.center, t2.tilt, yerr=t2.sigma, color=1
c = polyfitw(t2.center, t2.tilt, 1/t2.sigma^2, 3, yfit)
oplot, t2.center, yfit, color=2
print,c(*)
xyouts,50,0.0005, color=2, charsize=1.2,	$
    'Tilt = 0.00397512 + 1.47323E-6*bin - 1.266E-8*bin^2 + 1.19576E-11*bin^3'

end

