;+
; Project     : SOHO - CDS     
;                   
; Name        : DASH_LINE()
;               
; Purpose     : Turn a line image into a dashed line.
;               
; Explanation : To draw a line on an image we need a (1xN) image. This routine
;               takes such an image and makes it into a dashed line by setting
;               dashed pieces to 255.  An attempt is made to make the dashes 
;               an appropriate size for the particular array.
;               
; Use         : IDL> dash = dash_line(line)
;    
; Inputs      : line  - an array for a solid line (1 or 2-d)
;               
; Opt. Inputs : None
;               
; Outputs     : Function return value is the dashed line image
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Data_display, Image
;               
; Prev. Hist. :
;
; Written     : C D Pike, RAL, 21-May-1993
;               
; Modified    : 
;
; Version     : Version 1, 21-May-1993
;-            

function dash_line,line

;
;  check if input is a maximum of a 2-d array
;
s = size(line)

if s(0) gt 2 then begin
   bell,2
   print,'Input line must be at most a 2-d array.'
   return,line*0
endif

;
;  get dimensions
;
if s(0) eq 1 then begin
   nx = s(1) & ny = 0 
endif else begin
   nx = s(1) & ny = s(2)
endelse
 

;
;  blank off bits
;
if nx gt ny then begin
   step = nx/10 & step = (step > 5) < 20 
   for i=step,nx-step,2*step do line(i:i+step-1,*) = 255
endif else begin   
   step = ny/10 & step = (step > 5) < 20
   for i=step,ny-step,2*step do line(*,i:i+step-1) = 255
endelse

return,line

end
