;+
; Project     : SOHO - CDS     
;                   
; Name        : DEL_WINDOW
;               
; Purpose     : Delete window definitions, ie. set contents to zero/blank.
;               
; Explanation : To allow editing of the line/window list in the technical
;               planning software, it is possible to remove a line window
;               from the current list with this procedure.  
;               
; Use         : IDL> del_window [,num]
;    
; Inputs      : None
;               
; Opt. Inputs : num  - if it exists, gives the specific number of the line
;                      in the current list to delete.  If not present then
;                      all lines are deleted.
;               
; Outputs     : The common block variables line_window and num_windows are
;               updated.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Needs technical planning common blocks
;               
; Side effects: Updates common block variables 'line_window' and 'num_windows'.
;               
; Category    : Technical planning
;               
; Prev. Hist. :
;
; Written     : C D Pike, RAL, 14-May-93
;               
; Modified    : Initialise .x_pos to -1 not zero.  CDP, 24-Mar-94
;               Zero flag indicator as well.       CDP, 07-Nov-95
;
; Version     : Version 3, 07-Nov-95
;-            

pro del_window, num

;
;  need the line_windows and size of structure
;
@tplan_com

;
;  if no line singled out, do all of them
;
if n_elements(num) eq 0 then num = indgen(max_num_lwindow)

;
;  set all to zero/blank
;
line_window(num).x_pos  = -1
line_window(num).lam    = 0.0
line_window(num).order  = 0
line_window(num).inten  = 0.0
line_window(num).y_pos  = 0
line_window(num).left   = 0
line_window(num).right  = 0
line_window(num).height = 0
line_window(num).id     = ' '
line_window(num).flag   = 0

end
