;+
; Project     : SOHO - CDS     
;                   
; Name        : ERASE_NIS_WIN
;               
; Purpose     : Erase the NIS line-windows on the technical planning plot.
;               
; Explanation : Allows updating of the display in the technical planning
;               routine MK_RASTER to reflect the deletion of a line window
;               from the current list.
;               
; Use         : IDL> erase_nis_win ,[num]
;    
; Inputs      : None
;               
; Opt. Inputs : num  -  the particular line window to erase, otherwise all.
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Technical planning
;               
; Prev. Hist. :
;
; Written     : C D Pike, RAL, 14-May-1993
;               
; Modified    : Replace calls to NINT by ROUND.  CDP, 17-Jun-95
;
; Version     : Version 2, 17-Jun-95
;-            

pro erase_nis_win,num

;
;  use tp common for image data and display mode
;
@tplan_com

;
;  If the parameter num was specified, it is the window to rub out, 
;  otherwise do all of them.
;
;  If in 'display all' mode then kill the outline markers and the blocks at
;  top/bottom, otherwise kill the data display
;
if n_elements(num) eq 0 then begin
   num = max(where(line_window.x_pos gt 0))
   for i=0,num do begin
      if line_window(i).x_pos le 1023 then begin
       y = (line_window(i).y_pos gt 127)*128
       ys = y > 7
       yb = ys + 60 - fix(round(float(line_window(i).height)/4.0))
       yt = yb + fix(round(float(line_window(i).height)/2.))
       xl = line_window(i).left  > 0
       xr = line_window(i).right < 1023
       if window_mode eq 'ALL' then begin
          tv,tp_bscale(VDS_image_data(xl:xl,yb:yt)),xl,yb
          tv,tp_bscale(VDS_image_data(xr:xr,yb:yt)),xr,yb
          tv,tp_bscale(VDS_image_data(xl:xr,yb:yb)),xl,yb
          tv,tp_bscale(VDS_image_data(xl:xr,yt:yt)),xl,yt
          block = bytarr(xr-xl+1,8)
          if y eq 0 then tv,block,xl,0 else tv,block,xl,248
       endif else begin
          block = bytarr(xr-xl+1,128)
          tv,tp_bscale(block),xl,y
       endelse
      endif
   endfor
;
;  only one window specified
;
endif else begin
   if line_window(num).x_pos le 1023 then begin
      y = (line_window(num).y_pos gt 127)*128
      ys = y > 7
      yb = ys + 60 - fix(round(float(line_window(num).height)/4.0))
      yt = yb + fix(round(float(line_window(num).height)/2.))
      xl = line_window(num).left  > 0
      xr = line_window(num).right < 1023
      if window_mode eq 'ALL' then begin
         tv,tp_bscale(VDS_image_data(xl:xl,yb:yt)),xl,yb
         tv,tp_bscale(VDS_image_data(xr:xr,yb:yt)),xr,yb
         tv,tp_bscale(VDS_image_data(xl:xr,yb:yb)),xl,yb
         tv,tp_bscale(VDS_image_data(xl:xr,yt:yt)),xl,yt
         block = bytarr(xr-xl+1,8)
         if y eq 0 then tv,block,xl,0 else tv,block,xl,248
      endif else begin
         block = bytarr(xr-xl+1,128)
         tv,tp_bscale(block),xl,y
      endelse
   endif
endelse

end

