;+
; Project     : SOHO - CDS     
;                   
; Name        : NIS_IN_WINDOW()
;               
; Purpose     : Decide which NIS line_window cursor is in, if any.
;               
; Explanation : In the technical planning display, decide whether the current
;               cursor position falls within the bounds of any of the currently
;               defined NIS line windows.
;               
; Use         : IDL> hit = nis_in_window(line_structure, cur_x, cur_y)
;    
; Inputs      : line_structure  - the data structure containing details of the
;                                 currently defined line windows list.  The 
;                                 structure is defined in tp_def_struct.
;
;               cur_x           - the current x-value of the cursor position.
;               cur_y           - the current y-value of the cursor position.
;               
; Opt. Inputs : None
;               
; Outputs     : The function return value is the number of the identified 
;               line-window.  A value of -1 is returned if the cursor position
;               is not within a window.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: Returns only the first line-window found, tough on overlapping
;               windows.
;               
; Side effects: None
;               
; Category    : Technical planning
;               
; Prev. Hist. :
;
; Written     : C D Pike, RAL, 14-May-93
;               
; Modified    : 
;
; Version     : Version 1, 14-May-1993
;-            

function nis_in_window, line, x_pos, y_pos

;
;  check parameters
;
if n_params() lt 3 then begin
   print,'Use: IDL> n = nis_in_window(line_window_str, cur_x_pos, cur_y_pos)
   return,-1
endif

;
;  which VDS spectrum was cursor in?
;
cur_upper = y_pos gt 127

;
;  which spectrum is each window in?
;
win_upper = line.y_pos gt 127

;
;  in which window is the cursor?
;
hit = where( (line.left le x_pos) and (line.right ge x_pos) and $
             (cur_upper eq win_upper) )

;
;  only allow single value return, tough on overlapping windows
;
return,hit(0)


end
