;+
; Project     : SOHO - CDS     
;                   
; Name        : SORT_WINDOWS
;               
; Purpose     : Sort the technical planning line_window structure.
;               
; Explanation : In the line_window structure of window details an invalid
;               entry is signified by the tag .x_pos having a negative value.
;               This procedure sorts the input structure on the x_pos tag
;               and returns the number of valid (ie x_pos > 0) entries.
;               
; Use         : IDL> sort_windows, line_window_str, num_windows
;    
; Inputs      : line_window_str     -  the line-window structure defined in 
;                                      tp_def_struct.
;               
; Opt. Inputs : None
;               
; Outputs     : num_windows         -  the number of valid entries in the list.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Technical planning
;               
; Prev. Hist. :
;
; Written     : C D Pike, RAL, 14-May-93
;               
; Modified    : Changed invalid entry to one with .x_pos < 0, CDP, 23-Mar-94
;
; Version     : Version 2, 23-Mar-94
;-            

pro sort_windows,line,num

;
;  check parameter and its type
;
if n_params() lt 2 then begin
   bell
   print,'Use: sort_windows, line_window_str, number_valid_windows'
   return
endif

if datatype(line) ne 'STC' then begin
   bell
   print,'SORT_WINDOWS: Input parameter must be a structure,'
   return
endif

;
;  set a dummy (impossibly large) value for all the non-defined (or deleted)
;  entries
;
zero = where(line.x_pos lt 0)

if zero(0) ge 0 then line(zero).x_pos = 9999

;
;  now get sort vector
;
s = sort(line.x_pos)

;
;  and do the sort
;
line = line(s)

;
;  restore the zero values
;
zero = where(line.x_pos eq 9999)
if zero(0) ge 0 then line(zero).x_pos = -1 

;
;  calculate number of valid entries
;
num = max(where(line.x_pos ge 0)) + 1

end
