	FUNCTION TP_BSCALE, ARRAY, TOP=TOP
;+
; Project     :	SOHO - CDS
;
; Name        :	TP_BSCALE()
;
; Purpose     :	Scales VDS data for display with TP_COLTABLE color table.
;
; Explanation :	This procedure scales simulated VDS data for display with the
;		color table loaded by the routine TP_COLTABLE.  The array is
;		scaled logarithmically, so that values in the approximate range
;		0-41 are in the lower third of the color table (blue), 41-410
;		in the middle third (orange) and 410-4095 in the upper third
;		(white).  Values of 4096 and above are displayed as red pixels.
;
; Use         :	TV, TP_BSCALE(ARRAY)
;		EXPTV, TP_BSCALE(ARRAY), /NOSCALE
;
; Inputs      :	ARRAY	= Simulated VDS data array from VDS_DUMMY, or
;		equivalent.
;
; Opt. Inputs :	None.
;
; Outputs     :	The result of the function is a logarithmically scaled byte
;		array with the values matched to the number of colors for the
;		currently selected graphics device.
;
; Opt. Outputs:	None.
;
; Keywords    :	TOP	= The maximum value of the scaled image array, as used
;			  by BSCALE.  The default is !D.N_COLORS-1.
;
; Calls       :	BSCALE
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning, Technical.
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 23 September 1993.
;
; Modified    :	Version 1, William Thompson, GSFC, 23 September 1993.
;
; Version     :	Version 1, 23 September 1993.
;-
;
	ON_ERROR, 2
;
;  Check the number of parameters.
;
	IF N_PARAMS() NE 1 THEN MESSAGE, 'Syntax:  Result = TP_BSCALE(ARRAY)'
;
;  Scale the input array logarithmically.
;
	OUTPUT = ALOG10(1+(999./4096.)*ARRAY)
	BSCALE, OUTPUT, MIN=0, MAX=3, TOP=TOP
;
	RETURN, OUTPUT
	END
