;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_CALC_COMP
;               
; Purpose     : To calculate effect of compression on VDS data array
;               
; Explanation : For the sum over line and sum over windows compression
;               schemes, this routine performs that summation over the
;               the data windows in the displayed data.
;               
; Use         : tp_calc_comp, data, str
;    
; Inputs      : data  - the VDS data array intarr(1024,256)
;               
; Opt. Inputs : None
;               
; Outputs     : Data array is updated
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Technical, planning
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 20-Oct-94
;               
; Modified    : Updated numbers of sum line/window schemes.  CDP, 2-Nov-95
;               Handle unlikely case of FULL CCD extraction. CDP, 08-Jan-96
;               Changed method of displaying summed data. CDP, 14-Mar-96
;
; Version     : Version 4, 14-Mar-96
;-            

pro tp_calc_comp, data, tp_obs

;
;  relevant compression scheme (only 6 - sum lines and 7 - sum windows allowed)
;
if tp_obs.raster_v.comp_id ne 6 and tp_obs.raster_v.comp_id ne 7 then return

;
;  how many windows to deal with (cut out VDS background ones)
;
nw = tp_obs.data_win.n_windows
if tp_obs.data_win.vds_back then nw = nw - 4
for i=0,nw-1 do begin

   if tp_obs.data_win2(i).win_def(1) eq 0 then begin
      s = size(data)
      x1 = 0 & x2 = 1023
      y1 = 0 & y2 = s(2)-1
   endif else begin
      x1 = tp_obs.data_win2(i).win_def(0)
      x2 = tp_obs.data_win2(i).win_def(0) + tp_obs.data_win2(i).win_def(2)-1
      y1 = tp_obs.data_win2(i).win_def(1) - 392 + 8
      y2 = tp_obs.data_win2(i).win_def(1) -392+8+tp_obs.data_win2(i).win_def(3)-1
   endelse

   t = data(x1:x2,y1:y2)

;
;  sum over line (depends on orientation)
;
   if tp_obs.raster_v.comp_id eq 6 then begin
      if tp_obs.raster_v.vds_orient eq 0 then begin
         tot = total(t,1)
         tot = tot/n_elements(tot)
         for k=x1,x2 do data(k,y1:y2) = tot 
      endif else begin
         tot = total(t,2)
         tot = tot/n_elements(tot)
         for k=y1,y2 do data(x1:x2,k) = tot 
      endelse
   endif

;
;  sum over window
;
   if tp_obs.raster_v.comp_id eq 7 then begin
      tot = max(t)/2
      data(x1:x2,y1:y2) = tot
   endif
endfor

end
   





