;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_CALL_HELP
;               
; Purpose     : Put up a help window for widget event generated.
;               
; Explanation : When the mk_raster routine is in ONLINE HELP mode then the
;               widget events are trapped and the user-value of the widget
;               generating the event is passed to here so the appropriate
;               help can be generated.
;               
; Use         : tp_call_help, user_value, ev
;    
; Inputs      : user_value  - the user value specified at the creation of the
;                             widget.
;               ev          - the event structure
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : popup_msg
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Help, planning
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 16-Feb-95
;               
; Modified    : 
;
; Version     : Version 1, 16-Feb-95
;-            

pro tp_call_help, uvalue, ev

@tplan_com


;
;  trap null uvalue from image area
;
if uvalue eq '' then uvalue = 'BLANK'

;
;  trap exclusive buttons being turned off
;
if tag_exist(ev,'SELECT') then begin
   if ev.select eq 0 then return
endif

;
;  trap image area events being depressed
;
if tag_exist(ev,'PRESS') then begin
   if ev.press eq 0 then return
endif

;
;  select text
;
same_as_this:
n = where(tp_help.topic eq uvalue)

if n(0) eq -1 then begin
   popup_msg,font=tp_font,/multiple,group=base,$
             title='mk_raster help',$
             ['Help on this',$
             'would be nice!']
   print,'Need help on ',uvalue
   return
endif else begin
   n = n(0)
   n1 = where(tp_help.topic eq tp_help.text(tp_help.startline(n)))
   if n1(0) ge 0 then begin
      uvalue = tp_help.topic(n1(0))
      goto, same_as_this
   endif 
   text = tp_help.text(tp_help.startline(n):tp_help.stopline(n))
   popup_msg,font=tp_font,/multiple,group=base,$
             title='CDS mk_raster help',text,/left
endelse

return
end





