;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_CLEAR_LINES
;               
; Purpose     : Clears LINES/WINDOWS branches of tp_obs structure.
;               
; Explanation : Sets the contents of the .line_list(2), .data_win(2)
;               .vds_win, .line_w and .flag_w  tags in the main observation
;               definition structure to their default values.
;               
; Use         : IDL>  tp_clear_lines [,/win]
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : WIN  - set if only want extraction windows cleared.
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Planning Technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL 12-Jul-94
;               
; Modified    : Add /WIN keyword.  CDP, 29-Nov-94
;               Include clearing of higher up IDs.  CDP, 10-Nov-95
;
; Version     : Version 3, 10-Nov-95
;-                       

pro tp_clear_lines,win=win

;
;  main structure is in common block
;
@tplan_com


;
;  clear display  if present
;
if xregistered('tp_display_dew') then begin
   widget_control, dew_image, get_val=wind
   wset,wind
   erase
endif

;
;  reset the line window structure
;
if not keyword_set(win) then begin
   tp_obs.line_w.x_pos  =  -1     
   tp_obs.line_w.lam    =  0.0     
   tp_obs.line_w.order  =  0     
   tp_obs.line_w.inten  =  0.0     
   tp_obs.line_w.y_pos  =  0     
   tp_obs.line_w.left   =  0     
   tp_obs.line_w.right  =  0     
   tp_obs.line_w.height =  0     
   tp_obs.line_w.id     =  ' '
   tp_obs.line_w.flag   =  0
   
;
;  clear main line list tag structure
;
   tp_obs.line_list.ll_id  =       0     
   tp_obs.line_list.detector  =  ' '     
   tp_obs.line_list.ll_desc  =   ' '     
   tp_obs.line_list.n_lines  =     0

;
;  clear secondary line list structure
;

   tp_obs.line_list2.ll_id  =       0     
   tp_obs.line_list2.linename  =  ' '     
   tp_obs.line_list2.line_ind  =    0     
   tp_obs.line_list2.wavelnth  =  0.0     
   tp_obs.line_list2.gr_order  =    0     
   tp_obs.line_list2.cen_pix  =     0     
   tp_obs.line_list2.waveband  =    0
;
;  tidy counters
;
   num_windows = 0

;
;  clear other IDs that are affected
;
   tp_obs.raster_v.ras_var  =     0     
   tp_obs.raster_v.ll_id    =     0     
   tp_obs.raster_v.dw_id    =     0     

endif

;
;  clear data window tags
;
tp_obs.data_win.dw_id  =       0     
tp_obs.data_win.detector  =  ' '     
tp_obs.data_win.ll_id  =       0     
tp_obs.data_win.n_windows  =   0

tp_obs.data_win2.dw_id  =       0     
tp_obs.data_win2.win_ind  =     0     
tp_obs.data_win2.win_name  =  ' '     
tp_obs.data_win2.win_def(*)  =  0


tp_obs.vds_win.dw_id  =       0     
tp_obs.vds_win.vwin_ind  =    0     
tp_obs.vds_win.vwin_def(*)  = 0

end     
      
