	PRO TP_COLTABLE
;+
; Project     :	SOHO - CDS
;
; Name        :	TP_COLTABLE
;
; Purpose     :	Loads a special color table for technical planning.
;
; Explanation :	This routine loads a special color table for technical
;		planning.  It is to be used in conjunction with TP_BSCALE.  The
;		first third of the color table is mainly blue.  This gradually
;		turns to orange and then to white.  This is to provide
;		visibility over three decades of VDS data.  The topmost color
;		is pure red to indicate saturation.
;
; Use         :	TP_COLTABLE
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	The color tables for the current graphics device are modified.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	None.
;
; Common      :	Uses the standard IDL common block COLORS.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning, Technical.
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 23 September 1993.
;
; Modified    :	Version 1, William Thompson, GSFC, 23 September 1993.
;               Version 2, CDP, To handle B&W terminals.  12-Jan-96
;		Version 3, William Thompson, GSFC, 8 April 1998
;			Changed !D.N_COLORS to !D.TABLE_SIZE for 24-bit displays
;
; Version     : Version 3, 8 April 1998
;-
;
	ON_ERROR, 2
	COMMON COLORS, R_ORIG, G_ORIG, B_ORIG, R_CURR, G_CURR, B_CURR
;
	R_ORIG = BYTARR(!D.TABLE_SIZE)
	G_ORIG = R_ORIG
	B_ORIG = R_ORIG
;
;  Define the color tables.  But ignore if B&W terminal
;
	N = (!D.TABLE_SIZE - 1) / 3
        IF N EQ 0 THEN RETURN
;
	X = FINDGEN(N)
	BB = X^(1./3.)
	B_ORIG(0) = BYTE( BB * 255 / MAX(BB) )
	BB = BYTE( (X * 255) / (N - 1) )
	B_ORIG(N) = REVERSE(BB)
	B_ORIG(2*N) = BB
;
	G_ORIG(0) = BYTE( FINDGEN(3*N) * 255 / (3*N-1) )
	R_ORIG(0) = BYTE( FINDGEN(2*N) * 255 / (2*N-1) )
	R_ORIG(2*N:*) = 255B
;
;  Load the color tables.
;
	R_CURR = R_ORIG
	G_CURR = G_ORIG
	B_CURR = B_ORIG
;
	TVLCT, R_ORIG, G_ORIG, B_ORIG
;
	RETURN
	END
