;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_DB2INT
;               
; Purpose     : Transfer database line list structure to TPLAN internal.
;               
; Explanation : The structure returned by the linelist database interrogation
;               routine get_linelist is not that required internally by the
;               technical planning procedure TPLAN.  This procedure loads
;               the TPLAN internal structures from data contained in the 
;               database structure.
;               
; Use         : IDL>  tp_db2int,db_ll, raster
;    
; Inputs      : db_ll  - structure returned by routine GET_LINELIST
;               raster - raster structure returned by GET_RASTER
;               
; Opt. Inputs : None
;               
; Outputs     : None - internal structure held in common
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 24-Aug-94
;               
; Modified    : Use copy_struct.  CDP, 7-Apr-95
;
; Version     : Version 2, 5-Apr-95
;-            

pro tp_db2int, db_ll, raster

;
;  common for communication of structures etc
;
@tplan_com

;
;  clear the internal line windows first
;
lw = replicate({line_window_rec},max_num_lwindow)
lw.x_pos = -1
temp = tp_obs.line_w
copy_struct, lw, temp
tp_obs.line_w = temp

;
;  number of lines involved
;
nl = indgen(n_elements(db_ll.lines))

;
;  work through the transfer, tag by tag
;
tp_obs.line_w(nl).x_pos = db_ll.lines(nl).cen_pix
tp_obs.line_w(nl).lam   = db_ll.lines(nl).wavelnth
tp_obs.line_w(nl).order = db_ll.lines(nl).gr_order
tp_obs.line_w(nl).inten = 0
if db_ll.detector eq 'G' then begin
   tp_obs.line_w(nl).y_pos = 0
endif else begin
   tp_obs.line_w(nl).y_pos = abs(db_ll.lines(nl).waveband - 2) * 128
endelse
tp_obs.line_w(nl).left   = db_ll.lines(nl).cen_pix - raster.w_width/2
tp_obs.line_w(nl).right  = tp_obs.line_w(nl).left + raster.w_width - 1
tp_obs.line_w(nl).height = raster.w_height*2
tp_obs.line_w(nl).id     = db_ll.lines(nl).linename


;
;  store in local structure
;
line_window = tp_obs.line_w

;
; now copy the TPLAN structures which mirror the database structures.
; (can't use copy_struct as can't make it selective enough)
;
tp_obs.line_list.ll_id    = db_ll.ll_id
tp_obs.line_list.detector = db_ll.detector
tp_obs.line_list.ll_desc  = db_ll.ll_desc
tp_obs.line_list.n_lines  = n_elements(db_ll.lines)

;
;  clear out line_list structure
;
tp_obs.line_list2.linename = ''
tp_obs.line_list2.wavelnth = 0.0
tp_obs.line_list2.gr_order = 0
tp_obs.line_list2.cen_pix  = 0
tp_obs.line_list2.waveband = 0

;
;  load the new values
;

tp_obs.line_list2(nl).linename = db_ll.lines(nl).linename
tp_obs.line_list2(nl).wavelnth = db_ll.lines(nl).wavelnth
tp_obs.line_list2(nl).gr_order = db_ll.lines(nl).gr_order
tp_obs.line_list2(nl).cen_pix  = db_ll.lines(nl).cen_pix
tp_obs.line_list2(nl).waveband = db_ll.lines(nl).waveband

;
;  don't forget the ids further up
;
tp_obs.raster_v.ll_id = db_ll.ll_id

end

