;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_DISP_IEF
;               
; Purpose     : Defines display of ief definitions.
;               
; Explanation : Creates the widgets which form the window within which
;               the ief definitions are displayed.
;               
; Use         : tp_disp_ief, status
;    
; Inputs      : None
;               
; Opt. Inputs : None
;                        
; Outputs     : status - 1 if entries found in database, 0 else.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with MK_RASTER
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 07-Nov-95
;               
; Modified    : 
;
; Version     : Version 1, 07-Nov-95
;-            

pro tp_d_flg_event, ev

;
;  common for data and widgets ids
;
@tplan_com

;
;  type of event?
;
type = tag_names(ev,/structure)
widget_control, ev.id, get_uvalue=uvalue

;
;  Exit/Done button?
;
if type eq 'WIDGET_BUTTON' then begin

   if uvalue eq 'LOAD' then begin

      if n_elements(ief_str) gt 0 then begin
         nw = n_elements(ief_str.wins)
;
;  check we have room to add the flag windows
;
         if (num_windows + nw) lt max_num_lwindow then begin

;
;  delete any other flag lines if they are 'detached' or unflag them if they
;  are included.
;
            if flag_state eq 1 then begin
               n = where(line_window.flag eq 1, count)
               if count gt 0 then line_window(n).flag = 0
            endif else begin
               n = where(line_window.flag eq 1, count)
               if count gt 0 then begin
                  for i=0,n_elements(n)-1 do begin
                     erase_nis_win, n(i)
                     del_window, n(i)
                  endfor
               endif
            endelse
            sort_windows, line_window, num_windows
            
            for i=0,nw-1 do begin
               v0 = ief_str.wins(i).win_def(0)
               v1 = ief_str.wins(i).win_def(1)
               v2 = ief_str.wins(i).win_def(2)
               v3 = ief_str.wins(i).win_def(3)
               print,'Window ',i,' --> ',ief_str.wins(i).win_def
               line_window(num_windows).x_pos = v0 + (v2/2)
               line_window(num_windows).y_pos = (v1 gt 511) * 128
               line_window(num_windows).left = v0 
               line_window(num_windows).right = v0 + v2 - 1
               line_window(num_windows).height = v3*2
               line_window(num_windows).order = 1
               line_window(num_windows).flag  = 1
               line_window(num_windows).id = ief_str.wins(i).win_name
               if tp_obs.raster_p.detector eq 'N' then begin
                  if (v1 gt 511) then sp = 'N1' else sp = 'N2'
                  line_window(num_windows).lam = pix2wave(sp,v0+(v2/2))
                  display_nis_win, num_windows
               endif else begin
                  sp = 'G4'
                  if v0 le 6143 then sp = 'G3'
                  if v0 le 4095 then sp = 'G2'
                  if v0 le 2047 then sp = 'G1'
                  line_window(num_windows).lam = pix2wave(sp,v0+(v2/2))
                  display_gis_win, num_windows
               endelse
               num_windows = num_windows + 1
            endfor
            sort_windows, line_window, num_windows   
            tp_recalc_dew,' '
         endif else begin
            bell
            widget_control, info_line,/append,set_val=$
               'Adding flag windows would exceed maximum number of allowed '
            widget_control, info_line,/append,set_val=$
               'extraction windows. '
         endelse
      endif
      widget_control, flag_base, /destroy
   endif

;
;  Cancel button
;
   if uvalue eq 'CANCEL' then begin
      widget_control, flag_base, /destroy
   endif
endif

;
;  A user selection from the list?
;
if type eq 'WIDGET_LIST' then begin

  widget_control,ev.id,get_uvalue=uservalue
  if n_elements(uservalue) eq 0  then uservalue = ''
  prefix = strmid(uservalue,0,3)
  case prefix(0) of
     'fg_': begin
;             list_ief, flag, num, detector=tp_obs.raster_p.detector
;             id_wanted = flag(ev.index).ras_id
;             get_ief,id_wanted,flag
;             chosen_flag = id_wanted
             get_ief,ev.index+1,ief_str
            end
      else:
  endcase 
endif

end


PRO tp_disp_ief, status

;
;  common for data and widgets ids
;                       
@tplan_com

;
;  guard against trigger happy users
;
if xregistered('tp_disp_ief') then begin
  widget_control,flag_base,map=1
  status = 1
  return
endif

;
;  retrieve entries from data base
;
;list_flag, flag, num, detector=tp_obs.raster_p.detector
flag1 = {ieftab_id:0, desc:''}
i = 1
while flag1.ieftab_id ne -1 do begin
   get_ief,i,flag1
   i = i+1
endwhile
num = i-2

flag = replicate({ieftab_id:0, desc:''},num)
for i=0,num-1 do begin
   get_ief,i+1,def
   flag(i).ieftab_id = def.ieftab_id
   flag(i).desc = def.desc
endfor

;
;  only proceed if there is something to display
;
if num gt 0 then begin
   flids = flag.ieftab_id
   
;
;  create main base
;
   if tp_obs.raster_p.detector eq 'N' then begin
      text = 'NIS raster flags'
   endif else begin
      text = 'GIS raster flags'
   endelse

   flag_base = WIDGET_BASE(title=text,/FRAME,/COLUMN,$
                         group_leader = base, xoffset=500,yoffset=50)


;
;  'Done' button to exit
;
   bbase = widget_base(flag_base,/row)
   doneid = widget_button(bbase, value='Load flag windows', uvalue='LOAD')
   cancid = widget_button(bbase, value='Cancel', uvalue='CANCEL')


;
;  tart up output
;
   text = strarr(num)
   for i=0,num-1 do begin
      text(i) = string('#',flids(i),' - ',form='(a1,i2,a3)')+flag(i).desc
   endfor

;
;  widgets for display of primary raster details
;
   dummyt = widget_label(flag_base,/frame,$
                 value='Select from these flag window definitions')
   dummyf = widget_list(flag_base,value=text,uvalue='fg_'+text,ysize=(num+2 < 20))



;
;  make it all appear
;
   widget_control, flag_base, /realize
   status = 1
endif else begin
   bell,3
   flash_msg,info_line,'No flag definitions in database.'
   status = 0
endelse


end
