;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_DISP_LLIST
;               
; Purpose     : Defines display of database line lists.
;               
; Explanation : Creates the widgets which form the window within which
;               the database line lists are displayed.
;               
; Use         : tp_disp_llist, status
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : status - equals 1 if entries found 0 else
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with TPLAN
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 24-Aug-94
;               
; Modified    : Add selection of data window parameters. CDP, 18-oct-94
;               Add return status.  CDP, 6-Dec-94
;               Added picking up of data windows.  CDP, 21-Feb-95
;               Fixed bug when no linelists found.  CDP, 28-Sep-95
;               Rest variation ID when LL selected and fix format. CDP, 21-May-97
;
; Version     : Version 5, 21-May-97
;-            

pro tp_d_ll_event, ev

;
;  common for data and widgets ids
;
@tplan_com

;
;  type of event?
;
type = tag_names(ev,/structure)


;
;  Exit/Done button?
;
if type eq 'WIDGET_BUTTON' then begin
   tp_recalc_dew,' '
   widget_control, ll_base, /destroy
endif

;
;  A user selection from the list?
;
if type eq 'WIDGET_LIST' then begin

  widget_control,ev.id,get_uvalue=uservalue
  if n_elements(uservalue) eq 0  then uservalue = ''
  prefix = strmid(uservalue,0,3)
  case prefix(0) of
     'll_': begin
             widget_control, dwdb_base,set_val=' Searching .....'
             raster_ll_std = 1
;
;  reconstitute the full list
;
             list_linelist,temp,n
;
;  and pick out the displayed bits we had before
;
             n = where(temp.detector eq tp_obs.raster_p.detector)
             tempd = temp(n)
;
;  match the descriptor (now for specific detector) to find index in full list
;
             desc = tempd(ev.index).ll_desc
             n = where(temp.ll_desc eq desc and $
                       temp.detector eq tp_obs.raster_p.detector)

             chosen_llist = n(0) + 1
             get_linelist,chosen_llist,db_ll
;
;  pick up a dummy raster structure for default width and height
;
             get_raster,1,1,raster
             if n_tags(raster) lt 2 then begin
                raster = {dummy, w_width: 0, w_height: 0}
             endif
             raster.w_width = curr_lwidth
             raster.w_height = curr_lheight/2
;
;  load into internal structure and display
;
             tp_db2int, db_ll, raster
             tp_obs.raster_v.ras_var = 0
             load_tp_struct, tp_obs

;
;  get a selection of data window specifications for that line list
;
             list_datawin, chosen_llist, dw, num
             if num gt 0 then begin
                text = strarr(num)
                for i=0, num-1 do begin
                   if tp_obs.raster_p.detector eq 'N' then begin
                      s = fmt_vect([dw(i).w_width,dw(i).w_height*2])
                   endif else begin
                      s = fmt_vect([dw(i).w_width])
                   endelse
                   text(i) = string('#',i+1,' - ',dw(i).dw_desc,s,$
                                     form='(a,i3,3a)')
                endfor
                widget_control, dwdb_base, set_val=text,$
                                      set_uval='dw_'+text
             endif else begin
                widget_control, dwdb_base, $
                          set_val='No data windows specified for that line list'
             endelse
             tp_recalc_dew,' '
            end

     'dw_': begin
               list_datawin, chosen_llist, dw, n
               if n gt 0 then begin
                  get_raster,1,1,raster
                  if n_tags(raster) lt 2 then begin
                     raster = {dummy, w_width: 0, w_height: 0}
                  endif
                  curr_lwidth = dw(ev.index).w_width
                  curr_lheight = dw(ev.index).w_height*2
                  raster.w_width = curr_lwidth
                  raster.w_height = curr_lheight/2
                  get_linelist,chosen_llist,db_ll
                  tp_obs.data_win.dw_desc = dw(ev.index).dw_desc
;
;  check if background windows were selected
;
                  for i=0,2 do widget_control,vdsb_ids(i),set_b=0
                  if dw(ev.index).vds_back then begin
                     vds_extension = 1
                     widget_control,vdsb_ids(0),set_b=1
                     tp_obs.data_win.vds_back = 1
                  endif else begin
                     vds_extension = 0
                     widget_control,vdsb_ids(1),set_b=1
                     tp_obs.data_win.vds_back = 0
                  endelse
                  tp_db2int, db_ll, raster

;
;  was a data window list defined?
;
                  get_datawin,dw(ev.index).dw_id,dex
                  n = where(dex.wins.win_def(2) gt 0)
                  if n(0) ge 0 then begin
                     tp_obs.data_win.n_windows = n_elements(n)
                     tp_obs.data_win2.win_def(*)  = 0
                     tp_obs.data_win2.win_name    = ' '
                     for i=0,n_elements(n)-1 do begin
                       tp_obs.data_win2(i).win_def(*)  = dex.wins(i).win_def(*)
                       tp_obs.data_win2(i).win_name    = dex.wins(i).win_name
                     endfor
                     tp_obs.raster_v.dw_id = dex.dw_id
                     tp_obs.data_win.dw_id = dex.dw_id
                     tp_obs.data_win2.dw_id = dex.dw_id
                  endif

                  load_tp_struct, tp_obs
                  tp_recalc_dew,' '
               endif 
            end              
     else:
  endcase 
endif

end


PRO tp_disp_llist, status

;
;  common for data and widgets ids
;                       
@tplan_com

;
;  guard against trigger happy users
;
if xregistered('tp_disp_llist') then begin
  widget_control,ll_base,map=1
  status = 1
  return
endif


;
;  retrieve entries from data base
;
list_linelist, ll, num, detector=tp_obs.raster_p.detector

;
;  only proceed if there is something to display
;
if num gt 0 then begin
   llids = ll.ll_id

;
;  create main base
;
   ll_base = WIDGET_BASE(title='Database line lists',/FRAME,/COLUMN,$
                         group_leader = base, xoffset=500,yoffset=300,$
                         xsize=400)


;
;  'Done' button to exit
;
   doneid = widget_button(ll_base, value='Done', uvalue='Done')

;
;  tart up output
;
   text = strarr(num)
   for i=0,num-1 do begin
      text(i) = string('#',llids(i),' - ',form='(a1,i3,a3)')+ll(i).ll_desc
   endfor

;
;  widget for display of line list details
;
   if tp_obs.raster_p.detector eq 'G' then begin
      title = 'Select from these GIS line lists.'
   endif else begin
      title = 'Select from these VDS line lists.'
   endelse
   dummyt = widget_label(ll_base,/frame,value=title)
   dummyf = widget_list(ll_base,value=text,uvalue='ll_'+text,ysize=(num+2 < 20))

;
;  and for data windows based on those line lists
;
   dummyt = widget_label(ll_base,/frame,$
                 value='Select from these associated data windows (optional)')
   dwdb_base = widget_list(ll_base,ysize=10)



;
;  make it all appear
;
   widget_control, ll_base, /realize
   status = 1

endif else begin
   flash_msg,info_line,'No line lists in database.'
   status = 0
endelse


end
