;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_DISPLAY_DEW
;               
; Purpose     : Defines the window to display Data Extraction Windows.
;               
; Explanation : Creates the widgets which form the window within which
;               the DEWs are displayed.
;               
; Use         : tp_display_dew
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with TPLAN
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 14-Jul-94
;               
; Modified    : 
;
; Version     : Version 1, 14-Jul-94
;-            

pro tp_d_dew_event, ev

;
;  common for data and widgets ids
;
@tplan_com

;
;  common holding LUT
;
common tp_colors, r,g,b

widget_control, ev.id, get_uval=uval, get_val=val 

;
;  Restore LUT and finish
;
if uval eq 'Done' then begin
   tvlct,r,g,b
   widget_control, dew_base, /destroy
endif

;
;  Allow user-selection of various combinations
;
if uval eq 'BOTH' then begin
   tp_plot_dew, tp_obs  
endif

if uval eq 'VDSHard' then begin
   tp_plot_dew, tp_obs, /hard
endif

if uval eq 'DEW' then begin
   tp_plot_dew, tp_obs, /soft 
endif

;
;  Hardcopy menu
;
if strmid(uval,0,2) eq 'HC' then begin
   ps
   case strmid(uval,3,4) of
      'BOTH': tp_plot_dew, tp_obs  
      'DEWO': tp_plot_dew, tp_obs, /soft 
      'VDSO': tp_plot_dew, tp_obs, /hard
        else:
   endcase
   psplot
endif

end

;
;   MAIN program 
;   ------------
;


PRO tp_display_dew

;
;  common for data and widgets ids
;
@tplan_com
common tp_colors, r,g,b

;
;  guard against trigger happy users
;
if xregistered('tp_display_dew') then begin
  widget_control,info_line,set_val='Current windows already on display',/append
  widget_control,dew_base,map=1
  return
endif


;
;  create main base
;
dew_base = WIDGET_BASE(title='Data Extraction Windows',  /FRAME, /COLUMN,$
                       group_leader = base, xoffset=850, yoffset=800)
dew_butt = widget_base(dew_base, /row, group_leader=base)

dew_widg = lonarr(4)

;
;  'Done' button to exit
;
doneid = widget_button(dew_butt, value='Done', uvalue='Done')

;
;  buttons to select display
;
softid = widget_button(dew_butt, value='Data Extraction Windows only', $
                       uvalue='DEW')

;
;  tailor to instrument
;
if tp_obs.raster_p.detector eq 'N' then begin
   hardid = widget_button(dew_butt, value='VDS Hardware windows only', $
                          uvalue='VDSHard')
   bothid = widget_button(dew_butt, value='Both sets of windows', $
                          uvalue='BOTH')
endif

;
;  for hardcopy option
;
xpdmenu,['"Hardcopy"{',$
         '"Both sets"   HC_BOTH',$
         '"DEW only"    HC_DEWO',$
         '"VDS only"    HC_VDSO','}'],dew_butt

              
;
;  widgets for display of windows
;

a1  = WIDGET_BASE(dew_base, /ROW)
dew_image = widget_draw(a1,xsize=600,ysize=600)


;
;  make it all appear
;
WIDGET_CONTROL, dew_base, /realize

;
;  load top value of colour table to be white
;
tvlct,rr,gg,bb,/get
n = n_elements(rr)-1
r = rr & g = gg & b = bb
rr(n) = 255 & gg(n) = 255 & bb(n) = 255
tvlct,rr,gg,bb


end
