;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_DISPLAY_GP
;               
; Purpose     : Defines the window to display VDS parameters.
;               
; Explanation : Creates the widgets which form the window within which
;               the VDS detector parameters are displayed.
;               
; Use         : tp_display_gp
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with TPLAN
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 12-Jul-94
;               
; Modified    : 
;
; Version     : Version 1, 12-Jul-94
;-            

pro tp_d_gp_event, ev

;
;  common for data and widgets ids
;
@tplan_com

widget_control, ev.id, get_uval=val

if val eq 'Done' then begin
   widget_control, gp_base, /destroy
endif

end

;
;  MAIN program  
;  ------------
;

PRO tp_display_gp

;
;  common for data and widgets ids
;
@tplan_com

;
;  guard against trigger happy users
;
if xregistered('tp_display_gp') then begin
  widget_control,info_line,set_val='Current values already on display.',/append
  widget_control,gp_base,map=1
  return
endif

;
;  create main base
;
gp_base = WIDGET_BASE(title='GIS detector parameters',  /FRAME, /column,$
                       group_leader = base, xoffset=800, yoffset=800)

gp_widg = lonarr(8)

;
;  'Done' button to exit
;
doneid = widget_button(gp_base, value='Done', uvalue='Done')

              
;
;  widgets for display of detector details
;
details_base = widget_base(gp_base,/row)
aw = widget_base(details_base,/column)

a0 = widget_base(aw,/row)
a00 = widget_label(a0,value = 'Unit:')
dummy = widget_text(a0,xsize=12,ysize=1,value='Voltage',frame=0)

a1  = WIDGET_BASE(aw, /ROW)
a11 = WIDGET_LABEL(a1, VALUE='GIS1:')
gp_widg(0) = WIDGET_TEXT(a1,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_volt1)) 


a2  = WIDGET_BASE(aw, /ROW)
a21 = WIDGET_LABEL(a2, VALUE='GIS2:')
gp_widg(1) = WIDGET_TEXT(a2,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_volt2)) 


a3  = WIDGET_BASE(aw, /ROW)
a31 = WIDGET_LABEL(a3, VALUE='GIS3:')
gp_widg(2) = WIDGET_TEXT(a3,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_volt3)) 

a4  = WIDGET_BASE(aw, /ROW)
a41 = WIDGET_LABEL(a4, VALUE='GIS4:')
gp_widg(3) = WIDGET_TEXT(a4,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_volt4)) 

;
;  now right hand column
;
bw = widget_base(details_base,/column)

b0 = widget_base(bw,/row)
b00 = widget_label(b0,value = '')
dummy = widget_text(b0,xsize=12,ysize=1,value=' LUT ')

b1  = WIDGET_BASE(bw, /ROW)
gp_widg(4) = WIDGET_TEXT(b1,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_lut1)) 


b2  = WIDGET_BASE(bw, /ROW)
gp_widg(5) = WIDGET_TEXT(b2,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_lut2)) 


b3  = WIDGET_BASE(bw, /ROW)
gp_widg(6) = WIDGET_TEXT(b3,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_lut3)) 

b4  = WIDGET_BASE(bw, /ROW)
gp_widg(7) = WIDGET_TEXT(b4,XSIZE=12,YSIZE=1,$
                         value=string(tp_obs.state.gis_lut4)) 


;
;  make it all appear
;
WIDGET_CONTROL, gp_base, /realize

end
