;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_EDIT_LINES
;               
; Purpose     : Widget to edit the technical planning lines list.
;               
; Explanation : later!
;               
; Use         : Only within TPLAN
;    
; Inputs      : file_name      -  the full path name to the lines file
;               line_structure -  the structure containing the current 
;                                 line/window information.
;               
; Opt. Inputs : None
;               
; Outputs     : TPLAN structure tp_obs is updated.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : tp_edit_table
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Technical planning
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 24-May-1993
;               
; Modified    : Major rewrite.  CDP, 22-Sep-94
;               Add selection from line list.  CDP, 3-Apr-95
;               Put out 'be patient' message on exit and cut arrays
;               to size actually usable.  CDP, 09-Nov-95
;               Cut out desensitising of buttons when CDS line list
;               selected.  CDP, 10-Oct-96
;
; Version     : Version 5, 10-Oct-96

;-            


pro tp_el_event, event


;
;  procedure to control events from technical planning line list editing 
;  routine TP_EDIT_LINES.
;

;
;  commons for communication of original and edited arrays plus other stati.
;
common tp_el, in_array, out_array, edid, butt, ll_desc
common comm_with_table, info_2
common obs_spec, tp_obs, max_num_lwindow, max_num_fwindow
common tplan_layout, base
common tp_sell,sel_line_base, line_list_id, base_1, lls, line, nlls
common l_wind, window_state, curr_lwidth, line_window, lhit, $
               num_windows, curr_llist, curr_llist_name, curr_lheight
 
;
;  only the button widgets produce an event to be detected here
;  so get which button
;
widget_control,event.id,get_uvalue=uvalue,get_value=value

;
;  act on the button
;
case strmid(uvalue,0,4) of
;
;  QUIT button just exits without any update of the line-window details being
;       saved.
;
   'Quit': begin
             exit_status = 'QUIT'
             widget_control, info_2, $
                set_val='Please wait, this takes a while..........' 
             widget_control,event.top,/destroy
             widget_control, base, sensitive=1
             tp_redisplay
           end

;
;  OK indicates a normal exit, updates are saved in the internal variables.
;
   'OK  ': begin
             widget_control,edid,get_value=out_array
             widget_control, info_2, get_val=ll_desc
             ll_desc = ll_desc(0)
             widget_control, info_2, $
                set_val='Please wait, this takes a while..........' 
             widget_control,event.top,/destroy
             widget_control, base, sensitive=1
             lin_used = n_elements(out_array)/5
             for i=0,lin_used-1 do begin
                tp_obs.line_list2(i).linename = out_array(0,i)
                tp_obs.line_list2(i).wavelnth = out_array(1,i)
                tp_obs.line_list2(i).gr_order = out_array(2,i)
                tp_obs.line_list2(i).cen_pix  = out_array(3,i)
                tp_obs.line_list2(i).waveband = out_array(4,i)
             endfor
             if not same_data(in_array, out_array) then begin
                tp_obs.raster_v.ras_var=0
                tp_obs.raster_v.ll_id=0
                tp_obs.line_list.ll_id=0
                tp_obs.line_list2.ll_id=0
                tp_obs.raster_v.dw_id=0
                tp_obs.data_win.dw_id=0
                tp_obs.data_win2.dw_id=0
             endif



;
;  number of lines now defined?
;
             tp_obs.line_list.n_lines = max(where(out_array(1,*) ne '')) + 1

;
;  load descriptor
;
             tp_obs.line_list.ll_desc  = ll_desc
   

;
;  update rest of structure
;
             tp_tp2int
             copy_struct,tp_obs.line_w, line_window
             sort_windows, line_window, num_windows


;
;  update the display
;
             tp_redisplay
;
;  update the extraction windows
;

             tp_recalc_dew, 'OK'

           end

;
;  RESET sets the table back to what it was originally ie all changes made so
;        far are lost.
;
   'Rese': begin
             widget_control,edid,set_value=in_array
           end

;
;  HELP displays a simple text file of help. 
;
   'Help': begin
             widg_help,'tp_editl_help.hlp'
           end

;
;  READ allows line list to be read from ascii file
;
   'Read': begin
              widget_control, butt, sens=0
              if tp_obs.raster_p.detector eq 'N' then begin
                 filter = '*.nis'
              endif else begin
                 filter = '*.gis'
              endelse
              file = cdspickfile(/read,filter=filter)
              if file ne '' then begin
                 out_array = in_array
                 out_array(*,*) = ''
                 rd_line_list,file,title,desc,out_array
                 tp_obs.line_list.ll_desc = desc
                 widget_control,info_2,set_value=desc
                 widget_control,edid,  set_value=out_array
              endif
              widget_control, butt, sens=1
           end 


;
;  SELECT allows line list to be selected from CDS list
;
   'Sele': begin
;              widget_control, butt, sens=0
              if tp_obs.raster_p.detector eq 'N' then begin
                 ll = cds_sline(300,650,/cds)
              endif else begin
                 ll = cds_sline(140,800,/cds)
              endelse
              sel_line_menu
;              widget_control, butt, sens=1
           end 


;
;  By_pixel sorts the current line-window contents by line centre pixel.
;  Must translate to numeric array otherwise it sorts as a character and then
;  eg 698 > 1023!
;
   'By_P': begin
             widget_control,edid,get_value=out_array
             blank = where(out_array(3,*) eq '')
             if blank(0) ge 0 then out_array(3,blank) = '9999'
             s = sort(out_array(3,*))
             for i=0,4 do out_array(i,*) = out_array(i,s)
             blank = where(out_array(3,*) eq '9999')
             if blank(0) ge 0 then out_array(3,blank) = ''
             widget_control,edid,set_value=out_array
           end
;
;  By_wavelength sorts the current line-window contents by wavelength.
;
   'By_W': begin
             widget_control,edid,get_value=out_array
             blank = where(out_array(1,*) eq '')
             if blank(0) ge 0 then out_array(1,blank) = '9999'
             s = sort(out_array(1,*))
             for i=0,4 do out_array(i,*) = out_array(i,s)
             blank = where(out_array(1,*) eq '9999')
             if blank(0) ge 0 then out_array(1,blank) = ''
             widget_control,edid,set_value=out_array
           end
     else:
endcase

end

;
;   main line-editing routine
;   =========================
;

pro tp_edit_lines

common tp_el, in_array, out_array, edid, butt, ll_desc
common tp_sell,sel_line_base, line_list_id, base_1, lls, line, nlls

common comm_with_table, info_2

;
;  common for transmission of variables
;
@tplan_com

;
;  set default header in case needed
;
in_header = 'CDS Line List'
exit_status = ''


;
;  Base widget for the display of the line list
;
base_1 = widget_base(/column,title=in_header)

;
;  set up the compound widget for the table editing
;
colhead = strarr(5,2)
colhead(*,0) = ['Line','Wavelength','Grating','Centre','Spectral']
colhead(*,1) = ['Identification','(Angstroms)','Order','Pixel','Band']
coledit = [1,1,1,1,1]

;
; setup the array values from the tp_obs structure
;
if tp_obs.raster_p.detector eq 'N' then begin
   mlines = 24 
   if vds_extension then mlines = 20
endif else begin
   mlines = 48
endelse

;
;  don't forget independent flag windows
;
if flag_state eq 0 then begin
   n = where(tp_obs.data_win2.win_flag eq 1,count)
   mlines = mlines + count 
endif

in_array = strarr(5,mlines)
nl = tp_obs.line_list.n_lines

for i=0,nl-1 do begin
   in_array(0,i) = tp_obs.line_list2(i).linename
   in_array(1,i) = string(tp_obs.line_list2(i).wavelnth,form='(f9.3)')
   in_array(2,i) = tp_obs.line_list2(i).gr_order
   in_array(3,i) = tp_obs.line_list2(i).cen_pix
   in_array(4,i) = tp_obs.line_list2(i).waveband
endfor

;
;  the widget creation cw
;
edid = tp_edit_table(base_1,ncols=5,nrows=mlines,value=in_array,$
                     coledit=coledit,colhead=colhead,/rowskip,cellsize=12,$
                     det=tp_obs.raster_p.detector)

;
;  provide an escape and options to reset or sort the table 
;
butt = widget_base(base_1,/row,space=20)
bfont = '-adobe-helvetica-bold-r-normal--14-100-100-100-p-82-iso8859-1'
b3 = widget_button(butt,value='OK  ',uvalue='OK  ',font=bfont)
b2 = widget_button(butt,value='Reset',uvalue='Reset')
b4 = widget_button(butt,value='Help',uvalue='Help')
xpdmenu,['/Sort/ {',' /By_Pixel/',' /By_Wavelength/','}'],butt
b5 = widget_button(butt,value='Read ASCII file',uvalue='Read')
b6 = widget_button(butt,value='Select from CDS line list',uvalue='Select')
b1 = widget_button(butt,value='Quit',uvalue='Quit')

;
;  text widgets for getting new line list name
;
info = widget_base(base_1,/column)
dum2   = widget_label(info,val='Enter line list DESCRIPTION here (50 chars)')
info_2 = widget_text(info,/ed,xsize=50,ysize=1,uvalue='LLdesc',$
                     value=tp_obs.line_list.ll_desc)

;
;  set it off...
;
widget_control,base_1,/realize

;
;  ...and control it.  

xmanager,'tp_edit_lines',event_handler='tp_el_event',base_1



end

