;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_GET_DUMDATA
;               
; Purpose     : Package to get dummy data for technical planning.
;               
; Explanation : Calls either vds_dummy or gis_dummy to return suitable
;               dummy data for the technical planning program TPLAN.  It
;               can be used outwith TPLAN if a structure of the correct form
;               (eg as output by TPLAN) is used as the input parameter.
;
; Use         : IDL> tp_get_dumdata, struct, data_array
;
; Inputs      : struct - technical planning structure.
;               
; Opt. Inputs : None
;               
; Outputs     : data_array - array containing GIS or VDS dummy data.
;                            An integer value -1 is returned on error.
;               
; Opt. Outputs: None
;               
; Keywords    : ZONE - determines model for dummy data calculation
;
; Calls       : GIS_DUMMY
;               VDS_DUMMY
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Technical planning.
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 15-Sep-94
;               
; Modified    : Add call to compression effects routine. CDP, 21-Oct-94
;               Added zone keyword.  CDP, 24-Mar-95
;               Add real data option.  CDP, 04-May-99
;               Change destination of error message.  CDP, 13-Jul-99
;
; Version     : Version 5, 13-Jul-99
;-            


pro tp_get_dumdata, tp_obs, out, zone=zone

;
;  common for base widget ID
;
common tplan_layout, base

;
;  indicate things are happening
;
widget_control, base, /hour
;
;  arrays for slit definitions
;
slit_len = [2,4,51,240,240,240]
slit_wid = [2,4,8,2,4,90]

;
;  if no zone then assume QUIET region
;
if not keyword_set(zone) then begin
   use_zone = -4
endif

;
;  if negative, using real data
;
if zone eq -4 then begin
   rfile = concat_dir('$CDS_PLAN_TECH','real_qnis_data')
endif
if zone eq -5 then begin
   rfile = concat_dir('$CDS_PLAN_TECH','real_anis_data')
endif

if zone eq -5 or zone eq -4 then begin
   if not file_exist(rfile) then begin
      bell
      print,'Data file does not exist. '+rfile
      current_zone = old_zone
      return
   endif
                                  
   out = intarr(1024,320)
   openr,rlun,rfile,/get_lun
   readu,rlun,out
   free_lun,rlun
   out = out(*,31:288)
   case tp_obs.raster_p.slit_num of
      1: begin
            dummy1 = out(*,67)
            dummy2 = out(*,188)
            out = intarr(1024,256)
            out(*,67)  = dummy1
            out(*,188) = dummy2
         end
      2: begin
            dummy1 = out(*,67:68)
            dummy2 = out(*,188:189)
            out = intarr(1024,256)
            out(*,67:68)   = dummy1
            out(*,188:189) = dummy2
         end
      3: begin
            dummy1 = out(*,55:80)
            dummy2 = out(*,176:201)
            out = intarr(1024,256)
            out(*,55:80)   = dummy1
            out(*,176:201) = dummy2
         end
      else:
   endcase
   tp_calc_comp, out, tp_obs
   return
endif


if zone gt 10 then use_zone = 4 else use_zone = zone

;
;  array index of slit
;
snum = tp_obs.raster_p.slit_num - 1

case tp_obs.raster_p.detector of
  'N': begin
          vds_dummy,expose=float(tp_obs.raster_v.exptime),$
                    wlist=1,$
                    slit=slit_wid(snum),$
                    image=out,/no_file,zone=use_zone
          case tp_obs.raster_p.slit_num of
              1: begin
                  dummy1 = out(*,67)
                  dummy2 = out(*,188)
                  out = intarr(1024,256)
                  out(*,67)  = dummy1
                  out(*,188) = dummy2
                 end
              2: begin
                  dummy1 = out(*,67:68)
                  dummy2 = out(*,188:189)
                  out = intarr(1024,256)
                  out(*,67:68)   = dummy1
                  out(*,188:189) = dummy2
                 end
              3: begin
                  dummy1 = out(*,55:80)
                  dummy2 = out(*,176:201)
                  out = intarr(1024,256)
                  out(*,55:80)   = dummy1
                  out(*,176:201) = dummy2
                 end
           else:
          endcase
          tp_calc_comp, out, tp_obs
       end
  'G': begin
        gis_dummy,expose=float(tp_obs.raster_v.exptime),$
                  wlist=1,$
                  slit=slit_wid(snum),$
                  length=slit_len(snum),$
                  image=out,/no_file,zone=use_zone
       end
  else: out = -1
endcase

end
