;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_PLOT_GIS
;               
; Purpose     : Plots the spectral data from the CDS GIS detector.
;               
; Explanation : Takes the GIS data array and plots the data from the requested
;               band.  If the band specified equals 4 then this is taken as
;               an indication to plot all four (0-3) bands on a single page.
;               
; Use         : IDL> tp_plot_GIS, GIS_data, GIS_band
;    
; Inputs      : data   - GIS data array to plot
;               
; Opt. Inputs : band   -  the particular band to plot. Default (or a value
;                         of 5 means plot all 4 bands.
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Technical planning
;               
; Prev. Hist. :
;
; Written     : C D Pike, RAL, 9-Jun-93                     
;               
; Modified    : Set minimum negative intensity plot range. CDP, 23-Mar-95
;               Set minimum ymax value to 1.   CDP, 15-Nov-95
;
; Version     : Version 3, 15-Nov-95
;-            

pro tp_plot_gis, data, band

;
;  check number of parameters
;
if n_params() lt 1 then begin
   bell
   print,'Use:  IDL> tp_plot,GIS, GIS_data, GIS_band'
   return
endif

;
;  trap no data
;
if n_elements(data) eq 0 then return



;
;  set default to plot all data and trap bad band values
;
if n_elements(band) eq 0 or band lt 1 or band gt 4 then band = 5

;
;  set up wavelength array
;
wave = fltarr(4,2048)
for i=1,4 do begin
   spec = 'G'+string(i,format='(i1)')
   wave(i-1,*) = pix2wave(spec,indgen(2048))
endfor

;
;  plot ranges
;
r = [fix(pix2wave('G1',0)), fix(pix2wave('G1',2047))+1,$
     fix(pix2wave('G2',0)), fix(pix2wave('G2',2047))+1,$
     fix(pix2wave('G3',0)), fix(pix2wave('G3',2047))+1,$
     fix(pix2wave('G4',0)), fix(pix2wave('G4',2047))+1]

;
;  if all data are to be plotted then set up screen and plot
;
if band eq 5 then begin
   !p.multi = [0,2,2]
   for i=0,3 do begin
      if min(data(i,*)) lt 0 then ymin = -10000 else ymin=0
      ymax = 1.2*max(data(i,*)) > 1
      plot,wave(i,*),data(i,*),psym=10,xrange=[r(i*2),r(i*2+1)],xstyle=1,$
                     yrange=[ymin,ymax],ystyle=1,$
                     xtitle='Wavelength (A)',col=236 
   endfor
   !p.multi = 0
endif else begin
   if min(data(band-1,*)) lt 0 then ymin = -10000 else ymin=0
   ymax = 1.2*max(data(band-1,*)) > 1
   plot,wave(band-1,*),data(band-1,*),psym=10,$
                       xrange=[r((band-1)*2),r((band-1)*2+1)],xstyle=1,$ 
                       ystyle=1,yrange=[ymin,ymax],$
                       xtitle='Wavelength (A)',col=236 
endelse

end


