;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_PLOT_VDS
;               
; Purpose     : Defines the window to display data in the NIS windows.
;               
; Explanation : Creates the widgets which form the window within which
;               the windows are displayed.
;               
; Use         : tp_plot_vds
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For use with MK_RASTER
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 04-Mar-96
;               
; Modified    : 
;
; Version     : Version 1, 04-Mar96
;-            

pro tp_plot_vds_event, ev

;
;  common for data and widgets ids
;
@tplan_com

;
;  common holding LUT
;
common tp_colors, r,g,b

                         
widget_control, ev.id, get_uval=uval, get_val=val

case strmid(uval,0,3) of

;
;  Restore LUT and finish
;
   'DON': begin
             tvlct,r,g,b
             widget_control, plot_vds_base, /destroy
          end

;
;  Plot further windows if available
;
   'MOR': tp_draw_vwin, tp_obs

;
;  Hardcopy menu
;
   'HAR': tp_draw_vwin, tp_obs, /hard

;
;  Band selection
;

   'PVD': begin
             if ev.select eq 1 then begin
                case uval of
                    'PVDSEX_1': nis_pdef = [1,0,0]
                    'PVDSEX_2': nis_pdef = [0,1,0]
                    'PVDSEX_3': nis_pdef = [0,0,1]
                     else:
                endcase
                pwin_start = 0
             endif
          end
;
;  Plot unit selection
;

   'PAX': begin
             if ev.select eq 1 then begin
                case uval of
                    'PAX_1': pvds_pl = 0
                    'PAX_2': pvds_pl = 1
                endcase
             endif
          end
endcase

end


;
;   MAIN program 
;   ------------
;


PRO tp_plot_vds

;
;  common for data and widgets ids
;
@tplan_com

;
;  common holding LUT
;
common tp_colors, r,g,b

;
;  guard against trigger happy users
;
if xregistered('tp_plot_vds') then begin
  widget_control,info_line,set_val='Current windows already on display',/append
  widget_control,plot_vds_base,map=1
  return
endif


;
;  create main base
;
plot_vds_base = WIDGET_BASE(title='VDS Data Windows',  /FRAME, /COLUMN,$
                       group_leader = base, xoffset=850, yoffset=800)
pvds_butt = widget_base(plot_vds_base, /row, group_leader=base)

pvds_widg = lonarr(4)

;
;  'Done' button to exit
;
doneid = widget_button(pvds_butt, value='Done', uvalue='DON')

;
;  Plot more windows if available
;
softid = widget_button(pvds_butt, value='More ....', uvalue='MOR')


;
;  Hardcopy option
;
hardid = widget_button(pvds_butt, value='Hardcopy', uvalue='HAR')

;
;  Spectral band selection
;
pvds_bbase = widget_base(pvds_butt,map=1)
pvds_ids = lonarr(3)
xmenu,['NIS1','NIS2','Both'],buttons=pvds_ids,pvds_bbase,/row,$
                   title='VDS window selection.', /exclusive,$
                   uvalue=['PVDSEX_1','PVDSEX_2','PVDSEX_3']
for i=0,2 do widget_control,pvds_ids(i),set_button=0
widget_control,pvds_ids(2),set_button=1
nis_pdef=[0,0,1]

;
;  Plot units selection
;
pvds_mbase = widget_base(pvds_butt,map=1)
pvds_mids = lonarr(2)
xmenu,['Pixel','Wavelength'],buttons=pvds_mids,pvds_mbase,/row,$
                   title='Plot axis.', /exclusive,$
                   uvalue=['PAX_1','PAX_2']
for i=0,1 do widget_control,pvds_mids(i),set_button=0
widget_control,pvds_mids(0),set_button=1
pvds_pl = 0

              
;
;  Widget for display of windows
;

a1  = WIDGET_BASE(plot_vds_base, /ROW)
vdsp_image = widget_draw(a1,xsize=750,ysize=500)

;
;  start at the beginning
;
pwin_start = 0

;
;  make it all appear
;
WIDGET_CONTROL, plot_vds_base, /realize

;
;  load top value of colour table to be white
;
tvlct,rr,gg,bb,/get
n = n_elements(rr)-1
r = rr & g = gg & b = bb
rr(n) = 255 & gg(n) = 255 & bb(n) = 255
tvlct,rr,gg,bb
 



end
