;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_READ_HELP()
;               
; Purpose     : Read a text help file.
;               
; Explanation : Reads a text help file in the same format as WIDG_HELP and
;               returns the information read as a structure.
;               
; Use         : IDL> text = tp_read_help(file)
;    
; Inputs      : file - the text file. If no extension is specified, .hlp will
;                      be assumed, will also search the path if not in the
;                      current directory.
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns a structure such that the headings are in
;               structure.topic(x) and the text for that topic is in 
;               structure.text(structure.startline(x):structure.stopline(x))
;
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Planning, technical, help
;               
; Prev. Hist. : Based on code extracted from WIDG_HELP.
;
; Written     : C D Pike, RAL, 20-Feb-95
;               
; Modified    : 
;
; Version     : Version 1, 20-Feb-95
;-            

function tp_read_help, FILENAME

;
;  Define the error status.
;

ON_ERROR, 2

;
;  Open the help file.
;
FILE = FIND_WITH_DEF(FILENAME,!PATH,'.hlp')
IF FILE EQ '' THEN MESSAGE, 'Unable to open file '+FILE
OPENR, UNIT, FILE, /GET_LUN

;
;  Read in the first topic header, and the first
;
N_TOPICS = 1
CUR_LINE = 0
LINE = ''
TOPIC = ''
TEXT = ''
STARTLINE = 0
READF, UNIT, LINE
TOPIC = STRMID(LINE,1,STRLEN(LINE)-1)
READF, UNIT, TEXT

;
;  Keep reading the file, and collect all the topics and text.
;
WHILE NOT EOF(UNIT) DO BEGIN
   READF, UNIT, LINE
   IF STRMID(LINE,0,1) EQ '!' THEN BEGIN
      IF N_TOPICS EQ 1 THEN STOPLINE = CUR_LINE ELSE $
        STOPLINE = [STOPLINE, CUR_LINE]
      N_TOPICS = N_TOPICS + 1
      TOPIC = [TOPIC, STRMID(LINE,1,STRLEN(LINE)-1)]
      STARTLINE = [STARTLINE, CUR_LINE+1]
   END ELSE BEGIN
      CUR_LINE = CUR_LINE + 1
      TEXT = [TEXT, LINE]
   ENDELSE
ENDWHILE

STOPLINE = [STOPLINE, CUR_LINE]
FREE_LUN, UNIT

;  Pass a structure containing all the relevant information.
;
HELPPASS = {$
TOPIC: TOPIC,$
TEXT: TEXT,$
STARTLINE: STARTLINE,$
STOPLINE: STOPLINE}


RETURN,HELPPASS
END
