;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_READ_TEXTW
;               
; Purpose     : Reads TPLAN editable text widgets.
;               
; Explanation : Every event from the main TPLAN widget causes the editable
;               text widgets (containing the raster step sizes, number of
;               steps and the raster and line lists descriptions) to be read
;               and stored.  This safeguards against the user not hitting
;               return after entering new data.
;               
; Use         : tp_read_textw
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : tplan_com.pro
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 24-Aug-94
;               
; Modified    : Make sure texts are limited to 50 chars.  CDP, 14-Sep-94
;               Allow texts up to 64 chars.  CDP, 17-Oct-95
;
; Version     : Version 3, 17-Oct-94
;-            

pro tp_read_textw

;
;  common for all communications
;
@tplan_com

;
;  read step sizes
;
widget_control, sssx, get_val=val
tp_obs.raster_p.xstep = fix(val(0))

widget_control, sssy, get_val=val
if valid_num(val(0),/integer) then begin
   tp_obs.raster_p.ystep = fix(val(0))
endif else begin
   tp_obs.raster_p.ystep = 0
endelse   

;
;  and the number of locations
;
widget_control, nsx, get_val=val
tp_obs.raster_p.nx = fix(val(0))

widget_control, nsy, get_val=val
if valid_num(val(0),/integer) then begin
   tp_obs.raster_p.ny = fix(val(0))
endif else begin
   tp_obs.raster_p.ny = 1
endelse   

;
;  primary raster description
;
widget_control, wrp_info_2, get_val=val
tp_obs.raster_p.ras_desc = strmid(val(0),0,64)

;
;  raster variation description
;
widget_control, wrv_info_2, get_val=val
tp_obs.raster_v.rv_desc = strmid(val(0),0,64)

;
;  line list description
;
widget_control, wll_info_2, get_val=val
tp_obs.line_list.ll_desc = strmid(val(0),0,64)

;
;  data window description
;
widget_control, wdw_info_2, get_val=val
tp_obs.data_win.dw_desc = strmid(val(0),0,64)


end


