;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_TP2INT
;               
; Purpose     : Transfer line list structure within TPLAN structure.
;               
; Explanation : When the line list is edited within TPLAN, only the
;               line_list and line_list2 sub-structures are updated.
;               This routine copies the details in those two stuctures to
;               the other internal sub-structures used within tp_obs
;               
; Use         : IDL>  tp_tp2int
;    
; Inputs      : None
;               
; Opt. Inputs : None
;               
; Outputs     : None - internal structure held in common
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;
; Common      : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Planning, technical
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 22-Sep-94
;               
; Modified    : Use copy_struct for flexibility.  CDP, 7-Apr-95
;               Handle flags     CDP, 26-Jun-95
;
; Version     : Version 3, 26-Jun-95
;-            

pro tp_tp2int

;
;  common for communication of structures etc
;
@tplan_com

;
;  save the lines that were labelled as flags, because lines might get
;  sorted and rearranged in the edit program
;
nf= where(tp_obs.line_w.flag gt 0)
if nf(0) ge 0 then flag_wav = tp_obs.line_w(nf).lam

;
;  clear the internal line windows first (convoluted because of need to use 
;  copy struct which cannot? take structure tags as output variable)
;
lw = replicate({line_window_rec},max_num_lwindow)
lw.x_pos = -1
temp = tp_obs.line_w
copy_struct,lw, temp
tp_obs.line_w = temp

;
;  number of lines involved
;
if tp_obs.line_list.n_lines gt 0 then begin


   nl = indgen(tp_obs.line_list.n_lines)

;
;  work through the transfer, tag by tag
;
   tp_obs.line_w(nl).x_pos = tp_obs.line_list2(nl).cen_pix
   tp_obs.line_w(nl).lam   = tp_obs.line_list2(nl).wavelnth
   tp_obs.line_w(nl).order = tp_obs.line_list2(nl).gr_order
   tp_obs.line_w(nl).inten = 0
   if tp_obs.raster_p.detector eq 'G' then begin
      tp_obs.line_w(nl).y_pos = 0
   endif else begin
      tp_obs.line_w(nl).y_pos = abs(tp_obs.line_list2(nl).waveband - 2) * 128
   endelse
   tp_obs.line_w(nl).left   = tp_obs.line_list2(nl).cen_pix - curr_lwidth/2
   tp_obs.line_w(nl).right  = tp_obs.line_w(nl).left + curr_lwidth - 1
   tp_obs.line_w(nl).height = curr_lheight
   tp_obs.line_w(nl).id     = tp_obs.line_list2(nl).linename
endif

;
;  put back the flag windows
;
if n_elements(flag_wav) gt 0 then begin
   for i=0,n_elements(flag_wav)-1 do begin
      n = where(tp_obs.line_w.lam eq flag_wav(i))
      if n(0) ge 0 then tp_obs.line_w(n(0)).flag = 1
   endfor
endif

;
;  wholesale copy to other structure used by TPLAN
;
   line_window = tp_obs.line_w

;
;  reset number of windows
;
num_windows = tp_obs.line_list.n_lines

end

