;+
; Project     : SOHO - CDS     
;                   
; Name        : TP_UPDATE_LINES
;               
; Purpose     : Update the line_list2 structure in tp_obs.
;               
; Explanation : When changes have been made to the line selection (add,
;               delete etc.) the changes are initially recorded only in
;               the internal line_window structure.  This can and is
;               copied straight to tp_obs.line_w but the new information
;               in there needs to be copied to the tp_obs.line_list and
;               .line_list2 structures which mimic the database structures.
;               This routine does that transfer.
;               
; Use         : tp_update_lines, tp_obs
;    
; Inputs      : tp_obs - the standard tplan observation structure.
;               
; Opt. Inputs : None
;               
; Outputs     : Contents of tp_obs are updated
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: For internal use of TPLAN
;               
; Side effects: None
;               
; Category    : Technical planning.
;               
; Prev. Hist. :
;
; Written     : C D Pike, 14-Jul-1994
;               
; Modified    : 
;
; Version     : Version 1, 14-Jul-94
;-            

pro tp_update_lines, tp_obs

;                             
;  clear them out first
;
tp_obs.line_list2(*).linename = ' '
tp_obs.line_list2(*).line_ind = 0
tp_obs.line_list2(*).wavelnth = 0
tp_obs.line_list2(*).gr_order = 0
tp_obs.line_list2(*).cen_pix  = 0
tp_obs.line_list2(*).waveband = 0

;
;  update number of valid lines
;
num = where(tp_obs.line_w.lam gt 0.0)
if num(0) eq -1 then begin
   tp_obs.line_list.n_lines = 0
   return 
endif else begin
   num = n_elements(num)
   tp_obs.line_list.n_lines = num
endelse


;
;  load data-base line_list2 structure
;
for i=0,num-1 do begin
   tp_obs.line_list2(i).linename = tp_obs.line_w(i).id
   tp_obs.line_list2(i).line_ind = i
   tp_obs.line_list2(i).wavelnth = tp_obs.line_w(i).lam
   tp_obs.line_list2(i).gr_order = tp_obs.line_w(i).order
   tp_obs.line_list2(i).cen_pix  = tp_obs.line_w(i).x_pos
   obs_lam = tp_obs.line_w(i).lam * tp_obs.line_w(i).order
   if tp_obs.raster_p.detector eq 'N' then begin
      tp_obs.line_list2(i).waveband = (obs_lam gt 400.) + 1
   endif else begin
      tp_obs.line_list2(i).waveband = which_gis_band(obs_lam)
   endelse
endfor
end
