;+
; Project     : SOHO - CDS     
;                   
; Name        : WHICH_GIS_BAND()
;               
; Purpose     : Determine which GIS band contains given wavelength.
;               
; Explanation : Given the wavelength limits of the GIS bands, determine
;               which band a particular wavelength falls in.
;               
; Use         : IDL> n = which_gis_band( wavelength )
;    
; Inputs      : wavelength  -  the wavelength to locate in a band
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns a band 1 - 4 or a value of -1 on error.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration, GIS.
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 10-Jun-1993
;               
; Modified    : Use pix2wave instead of hardcoded limits.  CDP, 4-Apr-95
;
; Version     : Version 2, 4-Apr-95
;-            

function which_gis_band, wave

;
; check has parameter
;
if n_params() ne 1 then begin
   bell
   print,'Use: n = which_gis_band(wavelength)'
   return,-1
endif

;
;  wavelength limits
;
b1_start = pix2wave('G1',0)
b1_end   = pix2wave('G1',2047)
b2_start = pix2wave('G2',0)
b2_end   = pix2wave('G2',2047)
b3_start = pix2wave('G3',0)
b3_end   = pix2wave('G3',2047)
b4_start = pix2wave('G4',0)
b4_end   = pix2wave('G4',2047)

;
;  create output array
;
band = intarr(n_elements(wave))
band(*) = -1

;
;  select out entries belonging to each band
;
n1 = where((wave ge b1_start) and (wave le b1_end))
n2 = where((wave ge b2_start) and (wave le b2_end))
n3 = where((wave ge b3_start) and (wave le b3_end))
n4 = where((wave ge b4_start) and (wave le b4_end))

;
;  load output array with valid entries
;
if n1(0) ge 0  then band(n1) = 1
if n2(0) ge 0  then band(n2) = 2
if n3(0) ge 0  then band(n3) = 3
if n4(0) ge 0  then band(n4) = 4

;
;  switch to scalar if only single value
;
if n_elements(band) eq 1 then band = band(0)
return,band


end

