;+
; Project     : SOHO - CDS     
;                   
; Name        : WHICH_NIS_BAND()
;               
; Purpose     : Determine which NIS band contains given wavelength.
;               
; Explanation : Given the wavelength limits of the NIS bands, determine
;               which band a particular wavelength falls in.
;               
; Use         : IDL> n = which_nis_band( wavelength )
;    
; Inputs      : wavelength  -  the wavelength to locate in a band
;               
; Opt. Inputs : None
;               
; Outputs     : Function returns a band 1 - 2 or a value of -1 on error.
;               
; Opt. Outputs: None
;               
; Keywords    : None
;
; Calls       : None
;               
; Restrictions: None
;               
; Side effects: None
;               
; Category    : Calibration, NIS.
;               
; Prev. Hist. : None
;
; Written     : C D Pike, RAL, 21-Sep-94
;               
; Modified    : Use pix2wave instead of hardcoded limits.  CDP, 4-Apr-95
;
; Version     : Version 2, 4-Apr-95
;-            

function which_nis_band, wave

;
; check has parameter
;
if n_params() ne 1 then begin
   bell
   print,'Use: n = which_nis_band(wavelength)'
   return,-1
endif

;
;  wavelength limits
;
b1_start = pix2wave('N1',0)
b1_end   = pix2wave('N1',1023)
b2_start = pix2wave('N2',0)
b2_end   = pix2wave('N2',1023)

;
;  create output array
;
band = intarr(n_elements(wave))
band(*) = -1

;
;  select out entries belonging to each band
;
n1 = where((wave ge b1_start) and (wave le b1_end))
n2 = where((wave ge b2_start) and (wave le b2_end))

;
;  load output array with valid entries
;
if n1(0) ge 0  then band(n1) = 1
if n2(0) ge 0  then band(n2) = 2

;
;  switch to scalar if only single value
;
if n_elements(band) eq 1 then band = band(0)
return,band


end

