	PRO LIST_RES_TYPE, TYPES, IDS
;+
; Project     :	SOHO - CDS
;
; Name        :	LIST_RES_TYPE
;
; Purpose     :	List all resource types
;
; Explanation :	Extracts a list of all resource type names from the
;		resource_type database.
;
; Use         :	LIST_RES_TYPE, TYPES  [, IDS ]
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	TYPES	= A string array of all resource type names.
;
; Opt. Outputs:	IDS	= ID numbers associated with the TYPES.
;
; Keywords    :	None.
;
; Calls       :	DBOPEN, DBEXT
;
; Common      :	Common block LIST_RES_TYPE contains the result of the first
;		time this routine is called.  Subsequent calls go to this
;		common block rather than directly to the file.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning, database
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 3 April 1995
;
; Modified    :	Version 1, William Thompson, GSFC, 3 April 1995
;		Version 2, William Thompson, GSFC, 14 August 1995
;			Added common block LIST_RES_TYPE and optional output
;			parameter.
;
; Version     :	Version 2, 14 August 1995
;-
;
	COMMON LIST_RES_TYPES, RES_TYPES, TYPE_IDS
	ON_ERROR, 2
;
;  Check the number of parameters.
;
	IF N_PARAMS() LT 1 THEN MESSAGE,	$
		'Syntax:  LIST_RES_TYPE, TYPES  [, IDS ]'
;
;  If the routine has not already been called, then open the database, and
;  extract all the resource type names.  Store them in the common block.
;
	IF N_ELEMENTS(RES_TYPE) EQ 0 THEN BEGIN
		DBOPEN, 'resource_type'
		DBEXT, -1, 'type_id,res_type', TYPE_IDS, RES_TYPES
		RES_TYPES = STRTRIM(RES_TYPES,2)
		DBCLOSE
	ENDIF
;
;  Return the information from the common block.
;
	TYPES = RES_TYPES
	IDS = TYPE_IDS
;
	RETURN
	END
