;+
; Project     : SOHO - CDS     
;                   
; Name        : GET_RES_NAME
;               
; Purpose     : return a valid resource name 
;               
; Category    : Planning
;               
; Explanation : 
;               
; Syntax      : IDL> res_name=get_res_name(res)
;    
; Examples    : 
;
; Inputs      : RES - string name to check
;               
; Opt. Inputs : None
;               
; Outputs     : RES_NAME - actual resource name if valid, null otherwise
;
; Opt. Outputs: None
;               
; Keywords    : ERR = string error message
;
; Common      : None
;
; Restrictions: Only one resource name can be checked at a time
;               
; Side effects: None
;               
; History     : Version 1,  2-Aug-1995,  D M Zarro.  Written
;
; Contact     : DMZARRO
;-            


function get_res_name,res,err=err

err='' & res_name=''
if datatype(res) ne 'STR'  then begin
 err='Only one resource at a time please'
 message,err,/cont
 return,res_name
endif else tres=res(0)

list_res_type,res_types
res_types=strupcase(strtrim(res_types,2))
res_types=['DELAYED_CMD','NRT_RESERVED','COM_TIMES','SUPPORT',res_types]

;-- default to MDI_M for MDI

check2=grep('MDI',tres)
if check2 ne '' then begin
 check3=grep('MDI_H',tres)
 if check3 eq '' then tres='MDI_M'
endif

;-- check for delayed commands

check1=grep('DLY',tres)
check2=grep('DEL',tres)
if (check1 ne '') or (check2 ne '') then tres='DELAYED_CMD'

check2=grep('OT',tres)
if check2 ne '' then tres='SUP'

check=grep(tres,res_types,index=index)
if n_elements(check) gt 1 then begin
 err='Ambiguous keyword entered '
 message,err,/cont
 print,'    ',res_types(index)
 return,res_name
endif else begin
 if check(0) eq '' then begin
  err='unsupported resource '+res(0)
  message,err,/cont
  return,res_name
 endif
endelse
res_name=res_types(index)

return,res_name & end
                                                  


