;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       KAP_CONTENTS()
;
; PURPOSE:
;       Read in the latest KAP (or CAP or IAP) file for the given date
;
; CATEGORY:
;       Science Planning
;
; EXPLANATION:
;
; SYNTAX:
;       Result = kap_contents(date)
;
; INPUTS:
;       DATE - Date for which the KAP file is read; can be in any CDS
;              time format
;
; OPTIONAL INPUTS:
;       None.
;
; OUTPUTS:
;       result - String array containing contents of the KAP (default)
;                or CAP or IAP file; a null string will be returned if
;                error occurs for any reason
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORDS:
;       ERROR - Named variable containing any error message. If no
;               error occurs, ERROR will be a null string
;       IAP   - Set this keyword to read the latest IAP file
;       CAP   - Set this keyword to read the latest CAP file
;       VERSION - A named variable containing the file version
;
; COMMON:
;       None.
;
; RESTRICTIONS:
;       None.
;
; SIDE EFFECTS:
;       None.
;
; HISTORY:
;       Version 1, August 21, 1995, Liyun Wang, GSFC/ARC. Written
;       Version 2, September 1, 1995, Liyun Wang, GSFC/ARC
;          Added keyword VERSION and keywords IAP, CAP so that CAP and
;             IAP files can be read as well
;       Version 3, July 28, 1997, Zarro (SAC/GSFC) - Modified to call 
;          FIND_KAP_FILE
;
; CONTACT:
;       Liyun Wang, GSFC/ARC (Liyun.Wang.1@gsfc.nasa.gov)
;-
;

FUNCTION kap_contents, date, error=error, iap=iap, cap=cap, version=version,$
        file=file

   error=''
   file=find_kap_file(date, error=error, iap=iap, cap=cap, version=version)

   if error eq '' then return,rd_ascii(file) else return,''

END
