	FUNCTION KAP_VERS, FILENAME
;+
; Project     :	SOHO - CDS
;
; Name        :	KAP_VERS()
;
; Purpose     :	Returns the version number of a KAP file
;
; Explanation :	This routine looks at the name of a KAP file, and determines
;		the version number.  It assumes a filename of the form
;		"ECSyyyymmddvvv.KAP".
;
; Use         :	Version = KAP_VERS(FILENAME)
;
; Inputs      :	FILENAME = The name of the KAP file.
;
; Opt. Inputs :	None.
;
; Outputs     :	The result of the function is the version number extracted from
;		the filename.  If unable to determine a version number, then -1
;		is returned instead.
;
; Opt. Outputs:	None.
;
; Keywords    :	None.
;
; Calls       :	DATATYPE, BREAK_FILE
;
; Common      :	None.
;
; Restrictions:	Only works if the filename has the correct format.
;
; Side effects:	None.
;
; Category    :	Planning, Activity plans
;
; Prev. Hist. :	None.
;
; Written     :	William Thompson, GSFC, 24 May 1995
;
; Modified    :	Version 1, William Thompson, GSFC, 24 May 1995
;		Version 2, William Thompson, GSFC, 2 August 1995
;			Made compatible with NFS on VMS computers.
;
; Version     :	Version 2, 2 August 1995
;-
;
	ON_ERROR, 2
;
;  Check the input parameters.
;
	IF N_PARAMS() NE 1 THEN BEGIN
		MESSAGE, 'Syntax:  Version = KAP_VERS(FILENAME)'
	END ELSE IF N_ELEMENTS(FILENAME) NE 1 THEN BEGIN
		MESSAGE, 'FILENAME must be a scalar'
	END ELSE IF DATATYPE(FILENAME,1) NE 'String' THEN BEGIN
		MESSAGE, 'FILENAME must be a character string'
	ENDIF
;
;  Break the filename into its constituent parts.
;
	BREAK_FILE, FILENAME, DISK, DIR, NAME, EXT
;
;  Remove any embedded dollar signs, which may be added by NFS on VMS systems,
;  e.g. Multinet.
;
	REMCHAR, NAME, '$'
;
;  Parse the filename to determine the version number, assuming a filename of
;  the form ECSyyyymmddvvv.KAP.
;
	VERS = STRMID(NAME, 11, 3)
	IF VALID_NUM(VERS) THEN VERS = FIX(VERS) ELSE VERS = -1
;
	RETURN, VERS
	END
