;---------------------------------------------------------------------------
; Document name: mk_plan_copy_ev.pro
; Created by:    Liyun Wang, GSFC/ARC, June 5, 1995
;
; Last Modified: Tue Aug  6 10:50:42 1996 (lwang@achilles.nascom.nasa.gov)
;---------------------------------------------------------------------------
;
PRO mk_plan_copy_ev, event
;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       MK_PLAN_COPY_EV
;
; PURPOSE: 
;       Event "processor" for MK_PLAN_COPY
;
; EXPLANATION:
;       MK_PLAN_COPY calls box_cursor2 (with the keyword EVENT_PRO pointing
;       to this routine) to provide a boxed cursor to copy a plan entry
;       graphically. This routine is used to update widget contents in 
;       mk_detail for start date/time of the plan entry. 
;
; CALLING SEQUENCE: 
;       mk_plan_copy_ev, event
;
; INPUTS:
;       EVENT   - Event structure having the following tags: 
;
;          DAY  - TAI at 00:00 UT on day of display
;          WID  - Array of elements of 2 or 4, text widget IDs in
;                 which the date/time of start (and stop) time of the
;                 plan are updated
;          DUR  - Duration of the plan entry in seconds
;          X    - X position of the cursor in device pixels
;          Y    - Y position of the cursor in device pixels
;
; OPTIONAL INPUTS: 
;       None.
;
; OUTPUTS:
;       None.
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORD PARAMETERS: 
;       None.
;
; CALLS:
;       TAI2UTC
;
; COMMON BLOCKS:
;       None.
;
; RESTRICTIONS: 
;       None.
;
; SIDE EFFECTS:
;       None.
;
; CATEGORY:
;       
; PREVIOUS HISTORY:
;       Written June 5, 1995, Liyun Wang, GSFC/ARC
;
; MODIFICATION HISTORY:
;       Version 1, created, Liyun Wang, GSFC/ARC, June 5, 1995
;       Version 2, July 21, 1995, Liyun Wang, GSFC/ARC
;          Made end date/time of the copied plan updatable in their widgets
;       Version 3, August 6, 1996, Liyun Wang, NASA/GSFC
;          Shortened routine name to MK_PLAN_COPY_EV (for Ultrix)
;
; VERSION:
;       Version 3, August 6, 1996
;-
;
   ON_ERROR, 2
   x = [event.x,event.y]
   temp = CONVERT_COORD(x, /device, /to_data)
   start_tai = 3600.d0*FLOAT(temp(0))+event.day
   WIDGET_CONTROL, event.wid(0), set_value = tai2utc(start_tai, /ecs, /date)
   WIDGET_CONTROL, event.wid(1), set_value = tai2utc(start_tai, /ecs, /time)
   IF N_ELEMENTS(event.wid) GT 2 THEN BEGIN
      stop_tai = start_tai+event.dur
      WIDGET_CONTROL, event.wid(2), set_value=tai2utc(stop_tai, /ecs, /date)
      WIDGET_CONTROL, event.wid(3), set_value=tai2utc(stop_tai, /ecs, /time)
   ENDIF   
END

;---------------------------------------------------------------------------
; End of 'mk_plan_copy_ev.pro'.
;---------------------------------------------------------------------------
