;+
; Project     : SOHO - CDS     
;                   
; Name        : MK_PLAN_EXIST
;               
; Purpose     : check contents of MK_PLAN_SHARED common blocks
;               
; Category    : Planning
;               
; Explanation : 
;               
; Syntax      : IDL> s=mk_plan_exist(info)
;    
; Examples    : 
;
; Inputs      : INFO - Info structure that should have at least the following
;                      tags:
;               REQ_ITEMS  - string array of selected DB items
;               DTYPE      - SOHO plan type to show. 0: SCI, 1: DET
;               
; Opt. Inputs : None
;               
; Outputs     : 1 - if at least one requested item is found in
;                   STARTDIS/STOPDIS range.
;               0 - no items found
;
; Opt. Outputs: None
;               
; Keywords    : None
;
; Common      : MK_PLAN_SHARED
;               
; Restrictions: None
;               
; Side effects: None
;               
; History     : Version 1,  14-Feb-1996,  D M Zarro.  Written
;
; Contact     : DMZARRO
;-            

;-----------------------------------------------------------------

pro pcheck,item,found

@mk_plan_shared
found=0
if (not exist(startdis)) or (not exist(stopdis)) then return

if datatype(item) eq 'STR' then begin
 s=execute('chk =exist('+item+')')
 if chk then begin
  s=execute('itime=get_plan_itime('+item+')')
  s=execute('d1='+item+'.(itime)')
  s=execute('d2='+item+'.(itime+1)')
 endif
endif

if datatype(item) eq 'STC' then begin
 if exist(item) then begin
  itime=get_plan_itime(item)
  d1=item.(itime) & d2=item.(itime+1)
 endif
endif

if exist(d1) and exist(d2) then begin
 clook=where( (d1 lt stopdis) and (d1 gt startdis),count1)
 clook=where( (d2 lt stopdis) and (d2 gt startdis),count2)
 found=(count1 gt 0) or (count2 gt 0)
endif

return & end
;-----------------------------------------------------------------

function mk_plan_exist,info

on_error,1

@mk_plan_shared

if datatype(info) ne 'STC' then return,0
if not tag_exist(info,'REQ_ITEMS') then return,0
inst=which_inst()
req_items=info.req_items

;-- look for DETAILS

if  (grep('DET', req_items))(0) ne '' then begin
 if inst eq 'C' then begin
  item='cds_detail'
  pcheck,item,found
  if found then return,1
 endif

 if inst eq 'S' then begin
  item='sumer_detail'
  pcheck,item,found
  if found then return,1
 endif
endif

;-- look for FLAGS

if  (grep('FLA', req_items))(0) ne '' then begin
 item='cds_flag'
 pcheck,item,found
 if found then return,1
endif

;-- look for ALT

if  (grep('ALT', req_items))(0) ne '' then begin
 item='cds_alt'
 pcheck,item,found
 if found then return,1
endif

;-- look for SCIENCE

if  (grep('SCI', req_items))(0) ne '' then begin
 if  inst eq 'C' then begin
  item='cds_science'
  pcheck,item,found
  if found then return,1
 endif

 if  inst eq 'S' then begin
  item='sumer_science'
  pcheck,item,found
  if found then return,1
 endif
endif

;-- look for TELEMETRY

if (grep('Telemetry', req_items))(0) ne '' then begin 
 tel_list=['dsn','mdi_m','mdi_h','tape_dump']
 for i=0,n_elements(tel_list)-1 do begin
  item=tel_list(i)
  pcheck,item,found
  if found then return,1
 endfor
endif

;-- look for COMMANDING

if (grep('Command', req_items))(0) ne '' then begin 
 com_list=['dlydtimes','svm','nrt','trcr','tnorcr']
 for i=0,n_elements(com_list)-1 do begin
  item=com_list(i)
  pcheck,item,found
  if found then return,1
 endfor 
endif

;-- look for SUPPORT

if (grep('Support', req_items))(0) ne '' then begin 
 item='support'
 pcheck,item,found
 if found then return,1
endif

;-- look for GENERAL and DETAILED plans for other instruments

soho_inst=get_soho_inst()
check=where_vector(req_items,soho_inst,/trim,count)
read_sci=(count gt 0)

if read_sci then begin
 insts=soho_inst(check)
 for i=0,count-1 do begin
  inst=insts(i)
  get_instrument,inst,desc
  code=desc.code
  dprint,inst,code
  if (info.dtype eq 0) and exist(soho_splan) then begin
   clook=where(code eq soho_splan.instrume,icount)
   if icount gt 0 then begin
    sub_soho=soho_splan(clook)
    pcheck,sub_soho,found
    if found then return,1
   endif
  endif
  if (info.dtype eq 1) and exist(soho_dplan) then begin
   clook=where(code eq soho_dplan.instrume,icount)
   if icount gt 0 then begin
    sub_soho=soho_dplan(clook)
    pcheck,sub_soho,found
    if found then return,1
   endif
  endif
 endfor
endif

;-- made it this far then there is nothing there

return,0 & end

