;---------------------------------------------------------------------------
; Document name: mk_soho_dbase.pro
; Created by:    Liyun Wang, GSFC/ARC, August 21, 1995
;
; Last Modified: Mon May  6 11:06:23 1996 (lwang@achilles.nascom.nasa.gov)
;---------------------------------------------------------------------------
;
PRO mk_soho_dbase, parent, child, dur_unit=dur_unit, map=map, lfont=lfont
;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       MK_SOHO_SBASE
;
; PURPOSE: 
;       Create widget fields for SOHO DET plans
;
; CATEGORY:
;       Planning
; 
; EXPLANATION:
;       
; SYNTAX: 
;       mk_soho_dbase, parent, child
;
; INPUTS:
;       PARENT - parent widget upon which to construct widgets
;
; OPTIONAL INPUTS: 
;       None.
;
; OUTPUTS:
;       CHILD - Widget ID of the created child widget
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORDS: 
;       MAP   - 1/0 for visible/invisible
;       LFONT - font for label widgets
;
; COMMON:
;       None.
;
; RESTRICTIONS: 
;       None.
;
; SIDE EFFECTS:
;       None.
;
; HISTORY:
;       Version 1, August 21, 1995, Liyun Wang, GSFC/ARC. Written
;       Version 2, May 6, 1996, Liyun Wang, GSFC/ARC
;          Added N_POINT text widget
;
; CONTACT:
;       Liyun Wang, GSFC/ARC (Liyun.Wang.1@gsfc.nasa.gov)
;-
;
   ON_ERROR, 1
   
   IF N_ELEMENTS(map) EQ 0 THEN map=1
   lfont = (get_dfont(lfont))(0)

   child = WIDGET_BASE(parent, /row, map=map)

;---------------------------------------------------------------------------
;  SCI_OBJ, SCI_SPEC, DISTURB., and OBS_PROG
;---------------------------------------------------------------------------
   col = WIDGET_BASE(child, /row, /frame)

   tmp0 = WIDGET_BASE(col, /column)

   xsize = 27
   tmp = WIDGET_BASE(tmp0, /row)
   sci_objb = WIDGET_BUTTON(tmp, value='SCI_OBJ ', font=lfont, $
                            uvalue='sci_obj')
   sci_obj = WIDGET_TEXT(tmp, value='', xsize=xsize, uvalue='sobj_text', $
                         font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   sci_specb = WIDGET_BUTTON(tmp, value='SCI_SPEC', font=lfont, $
                             uvalue='sci_spec')
   sci_spec = WIDGET_TEXT(tmp, value='', xsize=xsize, uvalue='spec_text', $
                          font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   disturbb = WIDGET_BUTTON(tmp, value='DISTURB.', font=lfont, $
                            uvalue='disturbances')
   disturb = WIDGET_TEXT(tmp, value='', xsize=xsize, uvalue='disturb_text', $
                         font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   obsprogb = WIDGET_BUTTON(tmp, value='OBS_PROG', font=lfont, $
                            uvalue='obsprog')
   obsprog = WIDGET_TEXT(tmp, value='', xsize=xsize, uvalue='obsprog_text', $
                         font=lfont)
   
;---------------------------------------------------------------------------
;  OBJECT, OBJ_ID, PROG_ID, and CMP_NO
;---------------------------------------------------------------------------
   tmp0 = WIDGET_BASE(col, /column)

   tmp = WIDGET_BASE(tmp0, /row)
   objectb = WIDGET_BUTTON(tmp, value='OBJECT ', uvalue='object', font=lfont)
   object = WIDGET_TEXT(tmp, value='', xsize=6, font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   obj_idb = WIDGET_BUTTON(tmp, value='OBJ_ID ', font=lfont, uvalue='obj_id')
   obj_id = WIDGET_TEXT(tmp, value='', xsize=6, /edit, font=lfont, $
                        uvalue='obj_id_txt')

   tmp = WIDGET_BASE(tmp0, /row)
   progb = WIDGET_BUTTON(tmp, value='PROG_ID', uvalue='prog_id', font=lfont)
   prog_id = WIDGET_TEXT(tmp, value='', xsize=6, font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   cmpb = WIDGET_BUTTON(tmp, value='CMP_NO ', uvalue='cmpb', font=lfont)
   cmp_no = WIDGET_TEXT(tmp, value='', xsize=6, /edit, uvalue='cmp_no', $
                        font=lfont)
   
;---------------------------------------------------------------------------
;  Date/Time
;---------------------------------------------------------------------------
   col = WIDGET_BASE(child, /column, /frame)

   tmp0 = WIDGET_BASE(col, /row)
   start_lab = WIDGET_LABEL(tmp0, value='DATE_OBS', font=lfont)
   date_obs = WIDGET_TEXT(tmp0, xsize=10, uvalue='date_obs', font=lfont)
   time_obs = WIDGET_TEXT(tmp0, xsize=12, uvalue='time_obs', font=lfont)

   tmp0 = WIDGET_BASE(col, /row)
   stop_lab = WIDGET_LABEL(tmp0, value='DATE_END', font=lfont)
   date_end = WIDGET_TEXT(tmp0, xsize=10, /edit, uvalue='date_end', font=lfont)
   time_end = WIDGET_TEXT(tmp0, xsize=12, /edit, uvalue='time_end', font=lfont)

   tmp0 = WIDGET_BASE(col, /row)
   tmp = WIDGET_LABEL(tmp0, value='PLAN_DUR', font=lfont)
   pduration = WIDGET_TEXT(tmp0, value='', xsize=10, /edit, $
                           uvalue='pduration', font=lfont)
   unit_str = ['SECONDS', 'MINUTES', 'HOURS']
   dunit = cw_bselector2(tmp0, unit_str, uvalue='dur_unit', /return_index, $
                        font=lfont)
   IF N_ELEMENTS(dur_unit) EQ 0 THEN dur_unit = 1.0
   ii = (WHERE(dur_unit EQ ['1.0', '60.0', '3600.0']))(0)
   IF ii GE 0 THEN WIDGET_CONTROL, dunit, set_value=ii

   tmp0 = WIDGET_BASE(col, /row)
   cur_lab = WIDGET_LABEL(tmp0, value='CUR_TIME', font=lfont)
   date_cur = WIDGET_TEXT(tmp0, xsize=10, /editable, uvalue='date_cur', $
                          font=lfont)
   time_cur = WIDGET_TEXT(tmp0, xsize=12, /editable, uvalue='time_cur', $
                          font=lfont)

;---------------------------------------------------------------------------
;  Pointing parameters
;---------------------------------------------------------------------------
   col = WIDGET_BASE(child, /row, /frame)

   tmp0 = WIDGET_BASE(col, /column)

   tmp = WIDGET_BASE(tmp0, /row)
   tmp1 = WIDGET_LABEL(tmp, value='INSTRUM', font=lfont)
   inst_txt = WIDGET_TEXT(tmp, value='', xsize=7, font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   xcen_lb = WIDGET_LABEL(tmp, value='XCEN " ', font=lfont)
   xcen = WIDGET_TEXT(tmp, value='', xsize=7, /edit, uvalue='xcen', $
                      font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   ycen_lb = WIDGET_LABEL(tmp, value='YCEN " ', font=lfont)
   ycen = WIDGET_TEXT(tmp, value='', xsize=7, /edit, uvalue='ycen', $
                      font=lfont)
   
   tmp = WIDGET_BASE(tmp0, /row)
   tmp1 = WIDGET_LABEL(tmp, value='  ANGLE', font=lfont)
   angle = WIDGET_TEXT(tmp, xsize=7, font=lfont)
   
   tmp0 = WIDGET_BASE(col, /column)
   
   tmp = WIDGET_BASE(tmp0, /row)
   tmp1 = WIDGET_LABEL(tmp, value='N_POINT', font=lfont)
   npoint_txt = WIDGET_TEXT(tmp, xsize=8, font=lfont)
   
   tmp = WIDGET_BASE(tmp0, /row)
   tmp1 = WIDGET_LABEL(tmp, value='IXWIDTH', font=lfont)
   ixwidth = WIDGET_TEXT(tmp, xsize=8, font=lfont)
   
   tmp = WIDGET_BASE(tmp0, /row)
   tmp1 = WIDGET_LABEL(tmp, value='IYWIDTH', font=lfont)
   iywidth = WIDGET_TEXT(tmp, xsize=8, font=lfont)

   tmp = WIDGET_BASE(tmp0, /row)
   tmp1 = WIDGET_LABEL(tmp, value=' JITTER', font=lfont)
   jitter = WIDGET_TEXT(tmp, xsize=8, font=lfont)

   wids = {prog_id:prog_id, $
           progb:progb, $
           object:object, $
           objectb:objectb, $
           obj_id:obj_id, $
           obj_idb:obj_idb, $
           cmp_no:cmp_no, $
           cmpb:cmpb, $
           inst_txt:inst_txt, $
           dunit:dunit, $
           start_lab:start_lab, $
           stop_lab:stop_lab, $
           sci_obj:sci_obj, $
           sci_objb:sci_objb, $
           sci_spec:sci_spec, $
           sci_specb:sci_specb, $
           disturbb:disturbb, $
           disturb:disturb, $
           obsprog:obsprog, $
           obsprogb:obsprogb, $
           date_obs:date_obs, $
           time_obs:time_obs, $
           date_end:date_end, $
           time_end:time_end, $
           date_cur:date_cur, $
           time_cur:time_cur, $
           pduration:pduration, $
           xcen:xcen, $
           ycen:ycen, $
           npoint_txt:npoint_txt,$ 
           angle:angle, $
           ixwidth:ixwidth, $
           iywidth:iywidth, $
           jitter:jitter}

   WIDGET_CONTROL, child, set_uvalue=wids
END
;---------------------------------------------------------------------------
; End of 'mk_soho_dbase.pro'.
;---------------------------------------------------------------------------
