;---------------------------------------------------------------------------
; Document name: mk_soho_edp.pro
; Created by:    Liyun Wang, GSFC/ARC, August 31, 1995
;
; Last Modified: Tue Jan 16 15:05:39 1996 (lwang@achilles.nascom.nasa.gov)
;---------------------------------------------------------------------------
;
;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       MK_SOHO_EDP
;
; PURPOSE: 
;       Clone a given plan entry to other instruments
;
; CATEGORY:
;       Planning
; 
; EXPLANATION:
;       
; SYNTAX: 
;       mk_soho_edp, plan, soho_splan
;
; EXAMPLES:
;       
; INPUTS:
;       PLAN       - Plan structure to be cloned
;       SOHO_SPLAN - SOHO wide Science plan entries
;
; OPTIONAL INPUTS: 
;       None.
;
; OUTPUTS:
;       None, but SOHO_SPLAN may be changed
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORDS: 
;       STATUS
;       GROUP 
;       MODAL
;       ERROR
;
; COMMON:
;       @mk_soho_com
;
; RESTRICTIONS: 
;       None.
;
; SIDE EFFECTS:
;       SOHO_PLANS is changed.
;
; HISTORY:
;       Version 1, August 31, 1995, Liyun Wang, GSFC/ARC. Written
;
; CONTACT:
;       Liyun Wang, GSFC/ARC (Liyun.Wang.1@gsfc.nasa.gov)
;-
   
PRO mk_soho_edp_event, event

   ON_ERROR,1
   WIDGET_CONTROL, event.top, get_uvalue = unseen
   WIDGET_CONTROL, event.id, get_uvalue = uvalue
   WIDGET_CONTROL, unseen, get_uvalue = info, /no_copy
   
   CASE (uvalue) OF
      'CANCEL': BEGIN
         info.status = 0
         WIDGET_CONTROL, unseen, set_uvalue = info, /no_copy
         xkill,event.top
         RETURN
      END
      'GO': BEGIN
;---------------------------------------------------------------------------
;        Add the plan to the given instrument
;---------------------------------------------------------------------------
         WIDGET_CONTROL, /hour
         FOR i=0, N_ELEMENTS(info.ilist)-1 DO BEGIN
            IF info.inst_idx(i) THEN BEGIN 
               curr_inst = info.ilist(i)
               soho_splan = info.soho_splan
               WIDGET_CONTROL, info.mess, $
                  set_value='Cloning entry for '+curr_inst+'...', /append
               IF datatype(soho_splan) EQ 'STC' THEN BEGIN
                  mk_soho_extplan, soho_splan, curr_inst, inst_plans, $
                     other_plans
               ENDIF
               info.tplan.instrume = get_soho_inst(curr_inst)
               IF exist(inst_plans) THEN db_inst_plans = inst_plans
               mk_plan_add, info.tplan, inst_plans, err=err, /insert
               IF err NE '' THEN BEGIN
                  WIDGET_CONTROL, info.mess, set_value=err, /append
                  IF NOT exist(error) THEN error = err ELSE $
                     error = [error, err]
                  info = rep_tag_value(info, error, 'ERRMSG')
                  inst_plans = db_inst_plans
               ENDIF ELSE BEGIN
                  mk_plan_change, inst_plans, ninst_plans, startdis, tgap=tgap
                  mk_plan_write, ninst_plans, db_inst_plans
                  IF exist(db_inst_plans) THEN inst_plans = db_inst_plans
                  IF exist(other_plans) THEN $
                     soho_splan = [inst_plans, other_plans] $
                  ELSE $
                     soho_splan = inst_plans
                  info = rep_tag_value(info, soho_splan, 'SOHO_SPLAN')
                  info.status = 1
               ENDELSE
            ENDIF 
         ENDFOR
         WIDGET_CONTROL, unseen, set_uvalue = info, /no_copy
         xkill,event.top
         RETURN
      END
      ELSE:
   ENDCASE

   bv = grep(uvalue, info.ilist, index = ii)
   IF ii(0) GE 0 THEN BEGIN
      i = ii(0)
      IF info.inst_idx(i) THEN BEGIN
         info.inst_idx(i) = 0
      ENDIF ELSE BEGIN
         info.inst_idx(i) = 1
      ENDELSE
      WIDGET_CONTROL, info.pbuttons(i), set_button = info.inst_idx(i)
   ENDIF
   WIDGET_CONTROL, unseen, set_uvalue = info, /no_copy
   RETURN
END

;---------------------------------------------------------------------------
;  Main routine starts here
;---------------------------------------------------------------------------
PRO mk_soho_edp, plan, soho_splan, error=error, status=status, $
                 group=group, modal=modal

   ON_ERROR, 1
   status = 0

   IF datatype(plan) NE 'STC' THEN BEGIN
      error = 'Wrong type of input parameter'
      MESSAGE, error, /cont
      RETURN
   ENDIF

   IF datatype(soho_splan) NE 'STC' THEN soho_splan = ''

   tplan = plan
   itime = get_plan_itime(tplan)
   inst_list = get_soho_inst()
   inst = get_soho_inst(tplan.instrume)

   FOR i=0, N_ELEMENTS(inst_list)-1 DO BEGIN
      IF inst_list(i) NE inst THEN BEGIN
         IF N_ELEMENTS(ilist) EQ 0 THEN ilist = inst_list(i) ELSE $
            ilist = [ilist, inst_list(i)]
      ENDIF
   ENDFOR
   
   inst_idx = INTARR(N_ELEMENTS(ilist))
   inst_idx(*) = 1

   bfont = "-adobe-courier-bold-r-normal--20-140-100-100-m-110-iso8859-1"
   bfont = (get_dfont(bfont))(0)

   lfont = "-misc-fixed-bold-r-normal--13-100-100-100-c-70-iso8859-1"
   lfont = (get_dfont(lfont))(0)
   
   wbase = WIDGET_BASE(title='CLONE ENTRY', /column)

   bt_base = WIDGET_BASE(wbase, /row, /frame)
   exit = WIDGET_BUTTON(bt_base, value='Cancel', uvalue='CANCEL', font=bfont)
   go = WIDGET_BUTTON(bt_base, value='Go', uvalue='GO', font=bfont)
   
   row2 = WIDGET_BASE(wbase, /column, /frame)
   tmp = WIDGET_LABEL(row2, value='Plan to be Cloned', font=bfont)
   
   temp = WIDGET_BASE(row2, /row)
   tmp = WIDGET_LABEL(temp, value='INSTRUMENT', font=lfont)
   tmp = WIDGET_TEXT(temp, value=inst, font=lfont, xsize=6)
   
   temp = WIDGET_BASE(row2, /row)
   tmp = WIDGET_LABEL(temp, value='START_TIME', font=lfont)
   tmp = WIDGET_TEXT(temp, value=anytim2utc(tplan.(itime), /ecs), $
                     font=lfont, xsize=23)
   
   temp = WIDGET_BASE(row2, /row)
   tmp = WIDGET_LABEL(temp, value='STOP_TIME ', font=lfont)
   tmp = WIDGET_TEXT(temp, value=anytim2utc(tplan.(itime+1), /ecs), $
                     font=lfont, xsize=23)
   
   temp = WIDGET_BASE(row2, /row)
   tmp = WIDGET_LABEL(temp, value='SCI_OBJ   ', font=lfont)
   tmp = WIDGET_TEXT(temp, value=STRTRIM(tplan.sci_obj), font=lfont, xsize=23)
   
   row3 = WIDGET_BASE(wbase, /column, /frame)
   tmp = WIDGET_LABEL(row3, value='Instruments to Clone to', font=bfont)
   
   temp = WIDGET_BASE(row3, /column)
   xmenu, ilist, temp, /row, /nonexclusive, uvalue=ilist, font=bfont,$
      buttons=pbuttons
   
   FOR i = 0, N_ELEMENTS(ilist)-1 DO BEGIN
      WIDGET_CONTROL, pbuttons(i), set_button = inst_idx(i)
   ENDFOR
   
   mess = WIDGET_TEXT(wbase, ysize=5, font=lfont, /scroll)
   
   offsets = get_cent_off(wbase, group, valid=valid)
   IF valid THEN BEGIN
      xoff = offsets(0) & yoff=offsets(1)
      WIDGET_CONTROL, wbase, /realize, tlb_set_xoff=xoff, $
         tlb_set_yoff=yoff, /map
   ENDIF ELSE WIDGET_CONTROL, wbase, /realize, /map
   update = 0

   info = {ilist:ilist, inst_idx:inst_idx, tplan:tplan, status:status, $
           pbuttons:pbuttons, mess:mess, errmsg:'', bt_base:bt_base,$
           soho_splan:soho_splan}

   unseen = WIDGET_BASE()
   WIDGET_CONTROL, unseen, set_uvalue = info, /no_copy
   WIDGET_CONTROL, wbase, set_uvalue = unseen

   XMANAGER, 'mk_soho_edp', wbase, group=group, modal=KEYWORD_SET(modal) 
   
   WIDGET_CONTROL, unseen, get_uvalue = info, /no_copy, /destroy
   
   status = info.status
   error = info.errmsg
   soho_splan = info.soho_splan
   
   RETURN
END

;---------------------------------------------------------------------------
; End of 'mk_soho_edp.pro'.
;---------------------------------------------------------------------------
