;---------------------------------------------------------------------------
; Document name: mk_soho_extplan.pro
; Created by:    Liyun Wang, GSFC/ARC, August 31, 1995
;
; Last Modified: Tue Jan 16 15:07:12 1996 (lwang@achilles.nascom.nasa.gov)
;---------------------------------------------------------------------------
;
PRO mk_soho_extplan, soho_splan, instrume, inst_plans, other_plans
;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       MK_SOHO_EXTPLAN
;
; PURPOSE: 
;       Extract science plans for a given instrument from SOHO SCI plans
;
; CATEGORY:
;       Planning
; 
; EXPLANATION:
;       
; SYNTAX: 
;       mk_soho_extract_plan, soho_splan, instrume, inst_plans, other_plans
;
; INPUTS:
;       SOHO_SPLAN - SOHO wide SCIENCE plan entries
;       INSTRUME   - Instrument name (in long form)
;
; OPTIONAL INPUTS: 
;       None.
;
; OUTPUTS:
;       INST_PLANS  - Extracted SCI plan entries for INSTRUME
;       OTHER_PLANS - Othe SCI plan entries in SOHO_SPLAN except INST_PLANS
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORDS: 
;       None.
;
; COMMON:
;       None.
;
; RESTRICTIONS: 
;       None.
;
; SIDE EFFECTS:
;       None.
;
; HISTORY:
;       Version 1, August 31, 1995, Liyun Wang, GSFC/ARC. Written
;
; CONTACT:
;       Liyun Wang, GSFC/ARC (Liyun.Wang.1@gsfc.nasa.gov)
;-
;

   IF datatype(soho_splan) NE 'STC' OR instrume EQ '' THEN BEGIN
      dprint, 'No plans or instrument name passed in.'
      delvarx, inst_plans, other_plans
      RETURN
   ENDIF
   
   inst_name = get_soho_inst(instrume)
   
   ii = WHERE(soho_splan.instrume EQ inst_name, count)
   IF count GT 0 THEN BEGIN
      inst_plans = soho_splan(ii)
      ii = WHERE(soho_splan.instrume NE inst_name, count)
      IF count GT 0 THEN other_plans = soho_splan(ii) ELSE $
         delvarx, other_plans
   ENDIF ELSE BEGIN
      delvarx, inst_plans
      other_plans = soho_splan
   ENDELSE
   RETURN
   
END

;---------------------------------------------------------------------------
; End of 'mk_soho_extplan.pro'.
;---------------------------------------------------------------------------
