;---------------------------------------------------------------------------
; Document name: new_edit_item.pro
; Created by:    Liyun Wang, GSFC/ARC, August 29, 1995
;
; Last Modified: Tue Oct 17 11:08:25 1995 (lwang@achilles.nascom.nasa.gov)
;---------------------------------------------------------------------------
;
FUNCTION new_edit_item, custom_stc, new_item
;+
; PROJECT:
;       SOHO - CDS/SUMER
;
; NAME:
;       NEW_EDIT_ITEM()
;
; PURPOSE: 
;       Rearrange REQ_ITEMS in CUSTOM_STC 
;
; CATEGORY:
;       Utitility, Planning
; 
; EXPLANATION:
;       
; SYNTAX: 
;       Result = new_edit_item(custom_stc, new_item)
;
; EXAMPLES:
;       IF new_edit_item(custom_stc, 'CDS-SCI') NE 0 THEN ...
;
; INPUTS:
;       CUSTOM_STC - Customization strcuture that has a tag REQ_ITEMS
;                    as a string array listing items to be plotted; will
;                    be modified upon a successful return.
;       NEW_ITEM   - String of plan item to be edited
;
; OPTIONAL INPUTS: 
;       None.
;
; OUTPUTS:
;       RESULT - 1 if NEW_ITEM can be made editable, 0 otherwise
;
;       Note: CUSTOM_STC is modified upon a successful return
;
; OPTIONAL OUTPUTS:
;       None.
;
; KEYWORDS: 
;       None.
;
; COMMON:
;       None.
;
; RESTRICTIONS: 
;       None.
;
; SIDE EFFECTS:
;       CUSTOM_STC is changed upon a successful return.
;
; HISTORY:
;       Version 1, August 29, 1995, Liyun Wang, GSFC/ARC. Written
;
; CONTACT:
;       Liyun Wang, GSFC/ARC (Liyun.Wang.1@gsfc.nasa.gov)
;-
;
   ON_ERROR, 1
   IF datatype(custom_stc) NE 'STC' OR $
      datatype(new_item) NE 'STR' THEN RETURN, 0
   nplot = N_ELEMENTS(custom_stc.req_items) 
   IF custom_stc.req_items(nplot-1) NE new_item THEN BEGIN
      WIDGET_CONTROL, /hour
      req_items = custom_stc.req_items
      IF (WHERE(req_items EQ new_item))(0) GE 0 THEN BEGIN
         ii = WHERE(req_items NE new_item)
         IF ii(0) GE 0 THEN req_items = req_items(ii)
         req_items = [req_items, new_item]
      ENDIF ELSE req_items(nplot-1) = new_item
      custom_stc = rep_tag_value(custom_stc, req_items, 'REQ_ITEMS')
   ENDIF ELSE RETURN, 0
   RETURN, 1
END

;---------------------------------------------------------------------------
; End of 'new_edit_item.pro'.
;---------------------------------------------------------------------------
