;+
; Project     :	SOHO - CDS
;
; Name        :	PRG_ANOMALY()
;
; Purpose     :	Purges old and deleted SOHO anomaly records
;
; Explanation :	
;
; Use         :	S=PRG_ANOMALY()
;
; Inputs      :	None.
;
; Opt. Inputs :	None.
;
; Outputs     :	The result of the function is a logical value representing
;		whether or not the operation was successful, where 1 is
;		successful and 0 is unsuccessful.
;
; Opt. Outputs:	None.
;
; Keywords    :
;       ERRMSG    = If defined and passed, then any error messages will be
;                   returned to the user in this parameter rather than
;                   depending on the MESSAGE routine in IDL.  If no errors are
;                   encountered, then a null string is returned.  In order to
;                   use this feature, ERRMSG must be defined first, e.g.
;
;                       ERRMSG = ''
;                       Result = PRG_ANOMALY( ERRMSG=ERRMSG )
;                       IF ERRMSG NE '' THEN ...
;
; Common      :	None.
;
; Restrictions:	None.
;
; Side effects:	None.
;
; Category    :	Planning, Databases.
;
; Prev. Hist. :	None.
;
; Written     :	Dominic Zarro (ARC/GSFC) 21 January 1996
;
; Version     :	Version 1
;-
;

	function prg_anomaly, errmsg=errmsg

	on_error, 1
;
;  Initialize RESULT to represent non-success.  If the routine is successful,
;  this value will be updated below.
;
	result = 0
;
;  Make sure that the user has privilege to write into the database.
;
	if !priv lt 3 then begin $
           message = '!PRIV must be 3 or greater to write into the database'
           goto, handle_error
	endif
;
;  Open the database for update, and search for entries which are marked for
;  deletion.  If any are found, then delete them.
;
	dbopen, 'anomaly', 1
	entries = dbfind('deleted=y', /silent)
	if !err gt 0 then dbdelete, entries
;
;  Signal success.
;
	result = 1
	goto, finish
;
;  Error handling point.
;
handle_error:
	if n_elements(errmsg) ne 0 then errmsg = 'PRG_ANOMALY: ' + message $
		else message, message, /continue
;
;  Close the database, and return.
;

finish:
	dbclose
;
	return, result
	end
