
PRO read_line_fits, fname, struc, shift=shift, stis=stis, vcheck=vcheck, eis=eis

;+
; NAME
;
;    READ_LINE_FITS
;
; EXPLANATION
;
;    The routine spec_gauss_widget outputs Gaussian line fits in a particular
;    format. READ_LINE_FITS reads these files and optionally performs line
;    identifications using CHIANTI.
;
;    An earlier version of spec_gauss_widget did not print parameters
;    for the background fit. For this reason you will see two options
;    below, one for reading the background parameters fits, and one
;    that doesn't. 
;
; INPUTS
;
;    FNAME  The name of the file output by SPEC_GAUSS_WIDGET.
;
; OUTPUTS
;
;    STRUC  An IDL structure containing the line fits and identified
;           transitions.
;
; KEYWORDS
;
;    STIS   Use the STIS line ID file for performing line
;           identifications.
;
;    EIS    Use the Hinode/EIS line ID file for performing line
;           identifications. 
;
; OPTIONAL INPUTS
;
;    SHIFT  The radial velocity of the star to apply when performing line
;           identifications.
;
;    VCHECK A line is identified if it is within +/- VCHECK km/s of the
;           lab. wavelength of the line.
;
; CALLS
;
;    READ_LINE_IDS
;
; HISTORY
;
;    Ver. 1, 27-Oct-2008, Peter Young
;-

list=file_search(fname)
IF list[0] EQ '' THEN BEGIN
  print,'% READ_LINE_FITS: the file '+fname+' does not exist. Returning...'
  return
ENDIF

IF n_elements(vcheck) EQ 0 THEN vcheck=15.0

IF keyword_set(stis) THEN line_id=getenv('STIS_LINE_IDS')
IF keyword_set(eis) THEN line_id=getenv('SSW')+'/hinode/eis/idl/atest/pyoung/eis_line_ids.txt'

str={wvl: 0., swvl: 0., peak: 0., speak: 0., width: 0., swidth: 0., $
     int: 0., sint: 0., ion: '', i: 0, j: 0, trans: '', shift: 0., $
     gf: 0., aval: 0., $
     x0: 0., x1: 0., y0: 0., y1: 0., sigy0: 0., sigy1: 0.}
empty_str=str
struc=0

form1='(2f12.4,2e12.3,2f12.4,2e12.4)'
form2='(2f12.4,2e12.3,2f12.4,2e12.4,2f12.4,4e12.4)'

openr,lin,fname,/get_lun

str1=''
WHILE eof(lin) NE 1 DO BEGIN
  readf,lin,str1
  str=empty_str
  IF strlen(str1) LE 96 THEN BEGIN
    reads,str1,format=form1,l,sl,p,sp,w,sw,t,st
  ENDIF ELSE BEGIN
    reads,str1,format=form2,l,sl,p,sp,w,sw,t,st,x0,x1,y0,y1,sigy0,sigy1
   ;
    str.x0=x0
    str.x1=x1
    str.y0=y0
    str.y1=y1
    str.sigy0=sigy0
    str.sigy1=sigy1
  ENDELSE
  str.wvl=l
  str.swvl=sl
  str.peak=p
  str.speak=sp
  str.width=w
  str.swidth=sw
  str.int=t
  str.sint=st
 ;
  IF n_elements(line_id) NE 0 THEN BEGIN
    range=v2lamb(vcheck,l)
    read_line_ids,line_id,l,out,shift=shift,range=range
    IF n_tags(out) NE 0 THEN BEGIN
      str.ion=trim(out[0].name)
      str.gf=out[0].gf
      str.aval=out[0].aval
      str.shift=lamb2v(l-out[0].wvl,out[0].wvl)
      str.trans=out[0].trans
      str.i=out[0].lvl1
      str.j=out[0].lvl2
    ENDIF
  ENDIF
 ;
  IF n_tags(struc) EQ 0 THEN struc=str ELSE struc=[struc,str]
ENDWHILE

free_lun,lin

END
