;+                                                                              
; Project     : HESSI                                                           
;                                                                               
; Name        : SOCK_COPY                                                       
;                                                                               
; Purpose     : copy file via HTTP sockets                                      
;                                                                               
; Category    : utility system sockets                                          
;                                                                               
; Syntax      : IDL> sock_copy,url_file,outdir=outdir                           
;                                                                               
; Inputs      : URL_FILE = remote file name to copy with URL path               
;               OUT_NAME = optional output name for copied file
;                                                                               
; Outputs     : None                                                            
;                                                                               
; Keywords    : OUT_DIR = output directory to copy file                         
;               ERR   = string error message                                    
;                                                                  
; History     : 27-Dec-2001,  D.M. Zarro (EITI/GSFC) - Written                  
;               23-Dec-2005, Zarro (L-3Com/GSFC) - removed COMMON               
;               26-Dec-2005, Zarro (L-3Com/GSFC) 
;                - added /HEAD_FIRST to HTTP->COPY to ensure checking for              
;                  file before copying                               
;               18-May-2006, Zarro (L-3Com/GSFC) 
;                - added IDL-IDL bridge capability for background copying                  
;               10-Nov-2006, Zarro (ADNET/GSFC) 
;                - replaced read_ftp call by ftp object
;                1-Feb-2007, Zarro (ADNET/GSFC)
;                - allowed for vector OUT_DIR
;               4-June-2009, Zarro (ADNET)
;                - improved FTP support
;                                                                               
; Contact     : DZARRO@SOLAR.STANFORD.EDU                                       
;-                                                                              
                                                                                
pro sock_copy,url,out_name,err=err,_ref_extra=extra,copy_file=copy_file,$
                     out_dir=out_dir
                                                                                
err=''                                                                          
if is_blank(url) then begin                                                     
 err='missing input URL'                                                        
 pr_syntax,'sock_copy,url'                                                      
 return                                                                         
endif                                                                           
                                                    
n_url=n_elements(url)                                                           
copy_file=strarr(n_url)    
if is_blank(out_dir) then out_dir=curdir()
if ~test_dir(out_dir[0],/verb,err=err) then return
if n_elements(out_dir) ne n_url then out_dir=replicate(out_dir[0],n_url)
for i=0,n_url-1 do begin                                                        
 use_ftp=stregex(url[i],'ftp://',/bool) eq 1b
 if ~obj_valid(sock) then begin
  if use_ftp then sock=obj_new('ftp',err=err,_extra=extra) else $
   sock=obj_new('http',err=err,_extra=extra)             
 endif
 if is_string(err) then continue
 sock->copy,url[i],out_name,_extra=extra,err=err,copy_file=temp,out_dir=out_dir[i]
 if is_string(err) then continue
 copy_file[i]=temp
endfor                                                 
                         
if n_url eq 1 then begin
 copy_file=copy_file[0]
 out_dir=out_dir[0]
endif
                                                                                
obj_destroy,sock
                                                                                
return                                                                          
end                                                                             
