;+
; Project     : HESSI
;
; Name        : ETHZ__DEFINE
;
; Purpose     : Define a site object for Phoenix Radio Spectrogram data
;
; Category    : Ancillary GBO Synoptic Objects
;
; Syntax      : IDL> c=obj_new('ethz')
;
; History     : Written 18 Nov 2002, D. Zarro (EER/GSFC)
;
; Contact     : dzarro@solar.stanford.edu
;-
;-----------------------------------------------------------------------------
;-- init 

function ethz::init,_ref_extra=extra

if ~self->specread::init(_extra=extra) then return,0

self.site=obj_new('site')
if ~obj_valid(self.site) then return,0

self.site->setprop,rhost='www.astro.phys.ethz.ch',ext='.fits',org='month',$
                 topdir='/pub/rag/phoenix-2/bursts/fits',/full,$
                 delim='/',ftype='phnx*',smode=0,cache=0,/passive

return,1
end

;---------------------------------------------------------------------

pro ethz::cleanup

self->specread::cleanup
obj_destroy,self.site

return & end

;------------------------------------------------------------------------
;-- store FITS info in object

pro ethz::set_fits,file,index,data,index1,data1,header=header

if ~is_struct(index) then return

frequency=data1.frequency*index1.tscal2+index1.tzero2

if (index.cdelt1 gt 0.) then $
 time=index.crval1+index.cdelt1*dindgen(index.naxis1) else $
  time=data1.time*index1.tscal1+index1.tzero1

utbase=anytim2utc(index.time_d$obs+' '+index.date_d$obs,/vms)

freq=string(float(frequency),format='(i7.0)')+' MHz'
dunit='Flux (45*log10[SFU + 10]'
self->set,xdata=time,ydata=data,dim1_ids=freq,dim1_unit='Frequency (MHz)',$
             data_unit=dunit,id='Phoenix: '+utbase,/no_copy,$
             dim1_vals=float(frequency),utbase=utbase,/secs,$
             filename=file,dim1_use=indgen(4),/positive,header=header

return & end

;-----------------------------------------------------------------------
function ethz::search,tstart,tend,_ref_extra=extra,count=count,type=type

self.site->setprop,tstart=tstart,tend=tend
self.site->list,files,_extra=extra,count=count
if count gt 0 then begin
 rhost=self.site->getprop(/rhost)
 files='ftp://'+rhost+files
 type=replicate('radio/spectra',count)
endif

return,files

end

;------------------------------------------------------------------------------
;-- self structure

pro ethz__define                 

self={ethz,inherits specread, site:obj_new()}

return & end

