;+
; Project     : HESSI
;
; Name        : SYNOP_DB__DEFINE
;
; Purpose     : Define database for Synoptic data achive
;
; Category    : HESSI, Synoptic, Database, widgets, objects
;
; History     : 13-Aug-2000,  D.M. Zarro (EIT/GSFC)  Written
;
; Modifications:
;              30-Mar-2009, K Tolbert.  Added soxs,xrs,hsi (SOXS, MESSENGER, and
;                RHESSI) data types, and associated them with synop_spex class.
;
; Contact     : DZARRO@SOLAR.STANFORD.EDU
;-
                                             
;---------------------------------------------------------------------------
;-- init Synoptic DB

 function synop_db::init

 self->init_names

 dprint,'% SYNOP_DB::INIT ',1

 return,1 & end

;-----------------------------------------------------------------------------
;-- init site names

 pro synop_db::init_names

;'bbso   | Big Bear Solar Obs. | images | optical | bbso* | bbso',$

 t=['kisf   | Kiepenheuer-Institute Obs. | images | optical | kisf* | ' ,$
    'kanz   | Kanzelhohe Solar Obs.   | images | optical |  * | remote' ,$
    'meud   | Meudon Obs.| images |  optical | meud* | ' ,$
;    'mdi    | SOHO/MDI| images | magnetic | mdi*maglc* | ',$
;    'mdi    | SOHO/MDI | images | optical | mdi*igram* |',$
;    'mwso   | Mt. Wilson Solar Obs.| images | optical | mwso*igram* | ',$
;    'mwso   | Mt. Wilson Solar Obs.| images | magnetic | mwso*magmp* | ',$
;    'mwso   | Mt. Wilson Solar Obs.| images | doppler | mwso*dopp* | ',$ 
    'nobe   | Nobeyama Radioheliograph | images | radio | * | remote' ,$
    'ovsa   | Owens Valley Solar Obs. | lightcurves | radio | ovsa*sp* |',$
    'ovsa   | Owens Valley Solar Obs. | lightcurves | radio | ovsa*lc* |',$
    'ethz   | Phoenix ETH Zurich | spectra | radio | * | remote' ,$
    'osra   | Potsdam Obs. of Solar Radioastronomy | spectra | radio | osra* | remote' ,$
;    'rstn   | Radio Solar Telescope Network | lightcurves | radio | rstn* |',$
    'trac_ | TRACE (prepped) | images | euv | trac*WL_* |',$
    'trac_ | TRACE (prepped) | images | euv | trac*1600_* |',$
    'trac_ | TRACE (prepped) | images | euv | trac*171_*  |' ,$
    'trac_ | TRACE (prepped) | images | euv | trac*195_*  |' ,$
    'trac_ | TRACE (prepped) | images | euv | trac*1216_*  |' ,$
    'nancay | Nancay | images | radio | * | remote ',$
    'sxi    | GOES12/SXI | images | sxr | * | remote',$
    'mdi    | SOHO/MDI (Magnetogram) | images | optical | * | remote',$
    'mdi_c  | SOHO/MDI (Continuum) | images | optical | * | remote',$
    'synop_spex | Solar X-ray Spectrometer (SOXS) | spectra | sxr | * | remote',$
    'bbso   | Big Bear Solar Observatory (BBSO) | images | optical | *_ha* | remote ',$
    'euvi   | STEREO/SECCHI-EUVI | images | euv | * | remote',$
    'cor1   | STEREO/SECCHI-COR1 | images | optical | * | remote',$
    'cor2   | STEREO/SECCHI-COR2 | images | optical | * | remote',$
    'trace  | TRACE  | images | euv | * | remote',$
    'eit    | SOHO/EIT | images | euv | * | remote', $
    'xrt2    | HINODE/XRT | images | sxr | * | remote', $
    'eit_   | SOHO/EIT (prepped) | images  | euv  | eit* | ']

 db={abbr:'',name:'',dir:'',wave:'',patt:'',remote:''}
 site_db=self->make_db(t,db)

 ptr=self.site_db
 ptr_alloc,ptr
 *ptr=site_db
 self.site_db=ptr

return & end

;----------------------------------------------------------------------------
;-- convert string DB to structure

 function synop_db::make_db,sinput,sdb
 np=n_elements(sinput)
 if (np eq 0) or (n_elements(sdb) eq 0) then return,-1
 ntags=n_elements(tag_names(sdb))
 db=replicate(sdb,np)
 for i=0,np-1 do begin
  temp=str2arr(sinput[i],delim='|')
  ntemp=n_elements(temp)
  for j=0,(ntags < ntemp)-1 do begin
   var=strtrim((temp[j]),2)
   db[i].(j)=var
  endfor
 endfor  

 return,db
 end 
                
;-------------------------------------------------------------------------

 pro synop_db::cleanup

 dprint,'% SYNOP_DB::CLEANUP'
 ptr_free,self.site_db

 return & end
        
;--------------------------------------------------------------------------
;-- get site name DB

function synop_db::list_synop_sites

return,*self.site_db

end
                   
 
;---------------------------------------------------------------------------
;-- get site names & abbr

function synop_db::list_synop_names,abbr

site_db=self->list_synop_sites()

names=site_db.name
abbr=site_db.abbr
names=reform(get_uniq(names,sorder))
abbr=reform((abbr)[sorder])                     

return,names

end

;--------------------------------------------------------------------------
;-- check if file is at a remote site

function synop_db::is_remote,file,class=class,count=count,have_url=have_url

count=0 & class=''
if is_blank(file) then return,0b

nfile=n_elements(file)
out=bytarr(nfile)
class=strarr(nfile)
sites=self->list_synop_sites()
chk=where(sites.remote ne '',count)
if count eq 0 then return,out

chk=stregex(strtrim(file,2),'[\\\/]?([a-z]+)_',/extract,/sub,/fold)
abbr=strlowcase(chk[1,*])
for i=0,nfile-1 do begin
 ok=where((abbr[i] eq sites.abbr) and (sites.remote ne ''),count)
 if count gt 0 then begin
  out[i]=1b & class[i]=(sites.remote)[ok[0]]
 endif
endfor

;-- check files with URL addresses

if keyword_set(have_url) then begin
 chk=where2(stregex(file,'ftp:|http:',/bool),fcount,comp=comp,ncomp=ncomp)
 if ncomp gt 0 then out[comp]=0b
 if fcount gt 0 then out[chk]=1b
endif

if nfile eq 1 then begin
 out=out[0] & class=class[0]
endif

remote=where(out,count)

return,out & end

;----------------------------------------------------------------------------
;-- return object class name matching filename

function synop_db::get_class,file

if is_blank(file) then return,'fits'

acro=['cont','fdmg','xrt','kanz','eit','efr','efz','trac','tri','mg1','bbso','kpno','rstn','phnx','nobe','hxr',$
        'ovsa','osra','les','xrs','hsi','if','nb']

class=['mdi','mdi','xrt2','kanz','eit','eit','eit','trace','trace','spirit','bbso','kpno','rstn','ethz','nobe','hxrs',$
       'ovsa_ltc','osra','synop_spex','synop_spex','synop_spex','nobe','nancay']

bfile=file_break(file)
for i=0,n_elements(acro)-1 do begin
 if stregex(bfile,acro[i],/bool,/fold) then return,class[i]
endfor

;-- check if class is defined

fclass=fits_class(file)
if is_string(fclass) then return,fclass

return,'fits'

end
              
;-----------------------------------------------------------------------------

pro synop_db__define                 

temp={synop_db,site_db:ptr_new()}

return & end
